(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1339646,      28934]
NotebookOptionsPosition[   1327790,      28556]
NotebookOutlinePosition[   1328204,      28574]
CellTagsIndexPosition[   1328161,      28571]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example of the F-box simulation", "Title",
 CellChangeTimes->{{3.721118845556562*^9, 3.721118854288225*^9}}],

Cell[CellGroupData[{

Cell["Setting up", "Subsubsection",
 CellChangeTimes->{{3.725629304388626*^9, 3.725629306443288*^9}}],

Cell[TextData[{
 "Stochastic simulations of the non-self recognition (NSR) system in plants \
assume a constant population of N diploid individuals, which amounts to 2N \
haplotypes. The haplotypes are sequences S = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "k0"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "k1"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "k2"], TraditionalForm]]],
 " . . . ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "kL"], TraditionalForm]]],
 " that contain a single female determining SRNase and a fixed number L of \
male SLF genes. The life cycle consists of mutation, followed by reproduction \
and viability selection. We assume that the plants have the same (i.e. \
annual) life cycle so at each generation all plants are subject to all the \
steps in the life cycle. Duplication and recombination is neglected. The key \
parameters of the model are:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Mu]", "R"], " ", "-"}], TraditionalForm]]],
 " mutation rate in the RNase \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Mu]", "F"], " ", "-", " "}], TraditionalForm]]],
 "mutation rate in the SLF\n\[Alpha] - selfing probability\n\[Delta] - \
inbreeding depression, probability that a selfer does not reach maturity\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["N", 
     RowBox[{"R", " "}]], "=", " ", 
    RowBox[{
     SubscriptBox["N", "F"], " ", "-", " ", 
     RowBox[{
     "number", " ", "of", " ", "available", " ", "types", " ", "of", " ", 
      RowBox[{"SRNase", " ", "/", " ", "SLF"}]}]}]}], TraditionalForm]]],
 " (RTypes, FTypes)\nL - number of SLFs per haplotype\n\nFor this example we \
chose 500 generations with a population size of 250 individuals. If these \
values are large, the code runs slowly."
}], "Text",
 CellChangeTimes->{{3.7235244329463654`*^9, 3.723524440246974*^9}, {
   3.723524490298315*^9, 3.723524524466873*^9}, {3.7235245767884073`*^9, 
   3.723525253495977*^9}, {3.7235252890739603`*^9, 3.723525360258917*^9}, 
   3.72352552351086*^9, {3.7235307101736937`*^9, 3.723530746911935*^9}, {
   3.723530919535027*^9, 3.723531082196344*^9}, {3.724388820516902*^9, 
   3.724388835033498*^9}, {3.7256298579225063`*^9, 3.725629912841186*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"RTypes", " ", "=", " ", 
    RowBox[{"{", "50", "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "number", " ", "of", " ", "available", " ", "RNase", " ", "types"}], " ", 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FTypes", " ", "=", " ", 
    RowBox[{"{", "50", "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "available", " ", "SLF", " ", "types"}], 
   " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"SLength", " ", "=", " ", 
    RowBox[{"{", "15", "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "SLF", " ", "per", " ", "haplotype"}], 
   " ", "*)"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]R", " ", "=", " ", "0.001"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "mutation", " ", "rate", " ", "in", " ", "RNase", " ", "per", " ", 
    RowBox[{"Rnase", "/", "per"}], " ", "generation"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]F", " ", "=", " ", "0.001"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "mutation", " ", "rate", " ", "in", " ", "SLF", " ", "per", " ", "SLF", 
    " ", "per", " ", "generation"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"alp", " ", "=", " ", "0.9"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "fraction", " ", "of", " ", "pollen", " ", "landing", " ", "on", " ", 
    "the", " ", "same", " ", "pistils"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"del", " ", "=", " ", "0.95"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"decrease", " ", "in", " ", "fitness", " ", "of", " ", "selfers"}],
    " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"popsize", " ", "=", " ", "250"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"population", " ", "size"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"generations", " ", "=", " ", "500"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "generations"}], " ", 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.721119015963407*^9, 3.721119088289143*^9}, {
   3.7213725743785477`*^9, 3.721372574526082*^9}, {3.722577371224036*^9, 
   3.722577421157995*^9}, {3.72344728965372*^9, 3.723447363537402*^9}, 
   3.723524392540161*^9, {3.723525273899723*^9, 3.7235252831381397`*^9}, {
   3.723525366499003*^9, 3.723525378701622*^9}, {3.723525432722951*^9, 
   3.723525434085236*^9}, 3.723525483737584*^9, {3.723525901981132*^9, 
   3.7235259137326736`*^9}, {3.723526371215611*^9, 3.723526371622031*^9}, 
   3.7235264869531307`*^9, 3.7235307623207493`*^9, {3.724390036568656*^9, 
   3.724390036911043*^9}, {3.72439033550893*^9, 3.724390335642692*^9}, {
   3.724390464823132*^9, 3.724390465260887*^9}, {3.7243926347140617`*^9, 
   3.724392638769417*^9}, {3.72439279471279*^9, 3.724392795750845*^9}, {
   3.725624970313138*^9, 3.7256251987015247`*^9}, {3.7256254100556498`*^9, 
   3.725625410327381*^9}, {3.725625683079575*^9, 3.725625687254882*^9}, {
   3.725625770030342*^9, 3.725625770204452*^9}, {3.72562882097884*^9, 
   3.7256288211301947`*^9}}],

Cell[TextData[{
 "Initially, all haplotypes are self-compatible (SC) and have the same SRNase \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "1"], TraditionalForm]]],
 ". We consider two situations: in the first case all haplotypes are the same \
random collection of L SLFs (IC=2), while in the second case each SLF of \
haplotype is drawn independently (IC=1). The figure shows all genotypes, \
i.e., it contains 2*popsize rows. "
}], "Text",
 CellChangeTimes->{{3.723525492918778*^9, 3.72352582865801*^9}, {
  3.726390416763912*^9, 3.726390454163417*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"IC", " ", "=", " ", "2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"IC", " ", "==", " ", "1"}], ",", " ", 
     RowBox[{
      RowBox[{"uniqs", " ", "=", " ", 
       RowBox[{"CreateInitialPopulationRandom", "[", 
        RowBox[{"popsize", ",", " ", 
         RowBox[{
         "FTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", " ", 
         RowBox[{
         "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", " ", 
         RowBox[{
         "SLength", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        "]"}]}], ";"}]}], "]"}], ";"}], "\t\t"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"IC", " ", "==", " ", "2"}], ",", " ", 
     RowBox[{
      RowBox[{"uniqs", " ", "=", " ", 
       RowBox[{"CreateInitialPopulationRandom1", "[", 
        RowBox[{"popsize", ",", " ", 
         RowBox[{
         "FTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", " ", 
         RowBox[{
         "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", " ", 
         RowBox[{
         "SLength", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        "]"}]}], ";"}]}], "]"}], ";"}], "\t"}], "\[IndentingNewLine]", 
 RowBox[{"uniqs", "//", "visualizeD"}]}], "Input",
 CellChangeTimes->{{3.721119015963407*^9, 3.721119088289143*^9}, {
   3.7213725743785477`*^9, 3.721372574526082*^9}, {3.722577371224036*^9, 
   3.722577421157995*^9}, {3.72344728965372*^9, 3.723447363537402*^9}, 
   3.723524392540161*^9, {3.723525273899723*^9, 3.7235252831381397`*^9}, {
   3.723525366499003*^9, 3.723525378701622*^9}, {3.723525432722951*^9, 
   3.723525434085236*^9}, 3.723525483737584*^9, {3.723525832194339*^9, 
   3.723525845543942*^9}, {3.723526062932026*^9, 3.723526106538005*^9}, {
   3.7235261429923964`*^9, 3.7235261435585947`*^9}, {3.723530778487892*^9, 
   3.7235308121663094`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzt0N1rDQAYBvCVz9EwH4mrSXLFGkUSb6SNREtCbugUasXYBUIhX1HTSmqW
SUlSmI+W0ZTSmuMzsqwRM5vNzhFKZByZP+Dcu/hdPPX23Dxvv0mJ8hUbBuTk
5PT1p6A//+6ap9ea26amY/r2facmr0pH+8KaqotbPka2/npmw8nk1XRUjPqW
t7I+FV1DmnsTBT1R0TclU9bQHdMGP7796ENLTKyuK3o/vCU2z7wy89TGjkh+
ykkMXXs31u28fKCr9X58Tj0YPaiqM77+GFOyujQZKy/Oyes99yRrXzli4Iwb
Vf27F853Xh7ZHddL5zYW/uqIgj8lmeTHnrjTVPt6WWFb1M1atrHl/Musf+47
0fqwuy8dy8tGDnqR6onaz2N3pKo7o+n7gMzwIx+itvh39dIzz+Lwz/zMl23P
ozZZvqmmOB2ls+t27b7XFbkl84cdbXsXlw6+Or3/dyoKmxtGLdnRGevnLVjT
cas99pRU5haNfxfHmnt/jXtZH2czi/MnrGqKk42LziZmpOL4zaV7527tiMGP
8t4eqn+T1Zk/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/
f/78+fPnz58/f/78+fPnz58/f/78+fPnz58/f/78+fP/n/3/AqQHLHE=
   "], {{0, 0}, {32, 
   250}}, {0, 1}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Frame->True,
  FrameLabel->{
    FormBox["\"Genotype\"", TraditionalForm], 
    FormBox["\"Individual\"", TraditionalForm]},
  FrameTicks->{{None, None}, {None, None}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->200,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultPlotStyle" -> Automatic, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05]}]], "Output",
 CellChangeTimes->{{3.7235260742288113`*^9, 3.723526107257477*^9}, {
   3.723526144632806*^9, 3.723526151450399*^9}, 3.723526375467801*^9, 
   3.7235264908378143`*^9, 3.7235308155814133`*^9, 3.7243898939387217`*^9, 
   3.72439003904813*^9, 3.724390337997064*^9, 3.724390468185178*^9, 
   3.724392641632597*^9, 3.724392798076387*^9, 3.725625223324501*^9, 
   3.725625412727847*^9, 3.7256256901202507`*^9, 3.725625871354775*^9, 
   3.725626219760058*^9, 3.725626655552709*^9, 3.725628824070369*^9, 
   3.725629824147026*^9, 3.726390400347562*^9, 3.7263908343290033`*^9}]
}, Open  ]],

Cell["\<\
The speed of the simulation can be monitored by running the next command \
before the simulation. The speed depends on the population size, number of \
available SRNase/SLF types and also on the mutation rate and sequence length \
L so small numbers are advised to use for exploration.\
\>", "Text",
 CellChangeTimes->{{3.723530845137375*^9, 3.723530889942691*^9}, {
  3.7235310977976637`*^9, 3.723531251537796*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk", "//", "Dynamic"}]], "Input",
 CellChangeTimes->{{3.7235262212712393`*^9, 3.723526239406088*^9}}],

Cell[BoxData[
 DynamicBox[ToBoxes[$CellContext`kk, StandardForm],
  ImageSizeCache->{23., {1., 9.}}]], "Output",
 CellChangeTimes->{3.7235262400561*^9, 3.723526377670479*^9, 
  3.7235264924771748`*^9, 3.7235308172477922`*^9, 3.7235312540802307`*^9, 
  3.724389899816814*^9, 3.724390041154111*^9, 3.7243903398472443`*^9, 
  3.724390469944326*^9, 3.7243927999149933`*^9, 3.725625253514377*^9, 
  3.725625414470677*^9, 3.72562569213647*^9, 3.725625873417406*^9, 
  3.725626224208091*^9, 3.725626657704216*^9, 3.725628829111661*^9, 
  3.7256298296682167`*^9, 3.726390458036853*^9, 3.7263908374165087`*^9}]
}, Open  ]],

Cell["\<\
Here we run the main stochastic simulation with the initial condition stored \
in a variable uniqs.\
\>", "Text",
 CellChangeTimes->{{3.723530845137375*^9, 3.723530889942691*^9}, {
  3.7235310977976637`*^9, 3.723531300608135*^9}, {3.72562626864478*^9, 
  3.7256262688677263`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RunAD", "[", "uniqs", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.721119015963407*^9, 3.721119088289143*^9}, {
   3.7213725743785477`*^9, 3.721372574526082*^9}, {3.722577371224036*^9, 
   3.722577421157995*^9}, {3.72344728965372*^9, 3.723447363537402*^9}, 
   3.723524392540161*^9, {3.723525273899723*^9, 3.7235252831381397`*^9}, {
   3.723525366499003*^9, 3.723525378701622*^9}, {3.723525432722951*^9, 
   3.723525434085236*^9}, 3.723525483737584*^9, {3.723525832194339*^9, 
   3.723525845543942*^9}, 3.723526047256468*^9, {3.723526180125251*^9, 
   3.72352618116404*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Clustering haplotypes to RNase classes\"\>"], "Print",
 CellChangeTimes->{3.7256259288998117`*^9, 3.725626284698773*^9, 
  3.725626547783231*^9, 3.725626707265469*^9, 3.725628929005603*^9, 
  3.725629946896516*^9, 3.726390573574304*^9, 3.726390807708417*^9, 
  3.726390948575006*^9}],

Cell[BoxData["\<\"Computing birth/death of S-alleles\"\>"], "Print",
 CellChangeTimes->{3.7256259288998117`*^9, 3.725626284698773*^9, 
  3.725626547783231*^9, 3.725626707265469*^9, 3.725628929005603*^9, 
  3.725629946896516*^9, 3.726390573574304*^9, 3.726390807708417*^9, 
  3.726390948950704*^9}],

Cell[BoxData["\<\"Computing founder haplotypes\"\>"], "Print",
 CellChangeTimes->{3.7256259288998117`*^9, 3.725626284698773*^9, 
  3.725626547783231*^9, 3.725626707265469*^9, 3.725628929005603*^9, 
  3.725629946896516*^9, 3.726390573574304*^9, 3.726390807708417*^9, 
  3.726390949366852*^9}],

Cell[BoxData["\<\"Computing last survivors\"\>"], "Print",
 CellChangeTimes->{3.7256259288998117`*^9, 3.725626284698773*^9, 
  3.725626547783231*^9, 3.725626707265469*^9, 3.725628929005603*^9, 
  3.725629946896516*^9, 3.726390573574304*^9, 3.726390807708417*^9, 
  3.726390949438753*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization of haplotype class frequencies", "Subsubsection",
 CellChangeTimes->{{3.723527357029483*^9, 3.7235273684676456`*^9}, {
  3.72353151468268*^9, 3.723531519178145*^9}}],

Cell["\<\
We summarize the simulation by plotting the frequencies of the SI classes \
(red) and SC classes (green). Each SI/SC class corresponds to a single curve. \
The frequencies sum up to one and most of the curves are not visible because \
the class is not present and the corresponding frequencies are 0.\
\>", "Text",
 CellChangeTimes->{{3.723531312401016*^9, 3.72353145777255*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"t1", " ", "=", " ", "1"}], ";", " ", 
   RowBox[{"t2", " ", "=", " ", "generations"}], ";"}], " "}], "\n", 
 RowBox[{"\t", 
  RowBox[{"P0", " ", "=", " ", 
   RowBox[{"Show", "[", "\n", "     \t", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ListLinePlot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"SIcounts", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"t1", " ", ";;", " ", "t2"}], ",", " ", "k"}], "]"}], 
           "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", "popsize"}], ")"}]}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotStyle", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", " ", 
            RowBox[{"apple13", "[", 
             RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}], ",", " ", 
         RowBox[{"PlotRange", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
         RowBox[{"Frame", " ", "->", " ", "True"}], ",", 
         RowBox[{"ImageSize", " ", "->", " ", "1000"}]}], "]"}], 
       "\[IndentingNewLine]", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", "1", ",", " ", "Fnumber"}], "}"}]}], "]"}], 
     ",", "\n", "     \t", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ListLinePlot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"SCcounts", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"t1", " ", ";;", " ", "t2"}], ",", " ", "k"}], "]"}], 
           "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", "popsize"}], ")"}]}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotStyle", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", " ", 
            RowBox[{"apple13", "[", 
             RowBox[{"[", "6", "]"}], "]"}]}], "}"}]}], ",", " ", 
         RowBox[{"PlotRange", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}]}]}], "]"}], 
       "\[IndentingNewLine]", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", "1", ",", " ", "Fnumber"}], "}"}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Frequency\>\"", ",", " ", "None"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
         "\"\<generation\>\"", ",", " ", 
          "\"\<SI/SC class freq. mutants/offsprings/adults\>\""}], "}"}]}], 
       "}"}]}], ",", " ", 
     RowBox[{"ImageSize", " ", "->", " ", "1000"}], ",", " ", 
     RowBox[{"AspectRatio", " ", "->", " ", "0.2"}], ",", " ", 
     RowBox[{"AxesOrigin", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRange", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "t2"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "1"}], "}"}]}], "}"}]}]}], "]"}]}]}], "\n", 
 RowBox[{"     "}]}], "Input",
 CellChangeTimes->{
  3.72352636131345*^9, {3.7235265670282*^9, 3.723526567498163*^9}, {
   3.7235267347257566`*^9, 3.723526738507228*^9}, {3.725625312957592*^9, 
   3.725625398410187*^9}, {3.725625952969681*^9, 3.725626018222245*^9}, {
   3.725629959540559*^9, 3.725629960457732*^9}, {3.7256304093661823`*^9, 
   3.725630409780101*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.008333333333333333], Thickness[Large], LineBox[CompressedData["
1:eJxdWGmsXGUZPjbENMSYCSEGsTGHSpq6MohYK9a+BUpb2sK0vW1v93Pn7vuZ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       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.008333333333333333], Thickness[Large], LineBox[CompressedData["
1:eJxdWXmsHHUd/9kY0xhiNoQoYmOGSmo9WcRasWK/5RBKW7rv6Ovr6+vrvH33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       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DcO50QcBeAfVJQuKCgoDEIIIYRMzuyQ44JZch6WnE3OMEf4H2FaOh9h
jmBxgjmCkSgpEFoh5G+a0aenN69z4SvOf37u3Ysj4q+LIv69L5z9TBxPOvIS
POBL8WX4cjziK/FV+Gp8Db4WX4evxxO+Ad+Ib8I341vwrfg2fDu+A9+J78J3
43vwvfgMTkcXHPeR47ifHMcD5DgeJMfxEDmOh8lxPEKO41FyHI+R43icHMcT
5DieJMdxlhzHU+Q4nibHMR+dcMENxzP0ccENxzn6uOCG41n6uOCG4zn6uOCG
43n6uOCG4wX6uOCG40X6uOCG4yX6uOCG42X6uOCG4xX6uOCG41X6uOCG4zX6
uOCG43X6uOCG4w36uOCG4036uOCGIx894oQzLrjihjuOt9jHCWdccMUNdxzn
2ccJZ1xwxQ13HG+zjxPOuOCKG+443mEfJ5xxwRU33HG8yz5OOOOCK26443iP
fZxwxgVX3HDH8T77OOGMC6644Y7jA/ZxwhkXXHHDHceH7OOEMy644oY7jo/Y
xwlnXHDFDXccH7OPE8644Iob7jg+YR8nnHHBFTfccXzKPk4444Irbrjj+Ix9
nHDGBVfccMfxOfs44YwLrrjhjmM5esAjnnDCM854wQWfcMUrbnjDHe84vjh6
wCOecMIzznjBBZ9wxStueMMd7zi+PHrAI55wwjPOeMEFn3DFK254wx3vOL46
esAjnnDCM85fpb9///OPs+fzhf9qy39eLriQn3DlvRU3vOGOdxxfHz3gEU84
4RlnvOCCT7jiFTe84Y53HN8cPeARTzjhGWe84IJPuOIVN7zhjncc3x494BFP
OOEZZ7zggk+44hU3vOGOdxzfHT3gEU844RlnvOCCT7jiFTe84Y53HN8fPeAR
TzjhGWe84IJP3/P9I19xwxvueMfxw9EDHvGEE55xxgsu+IQrXnHDG+54x/Hj
0QMe8YQTnnHGCy74hCteccMb7njH8dPRAx7xhBOeccYLLviEK15xwxvueMfx
89EDHvGEE55xxgsu+IQrXnHDG+54x/HL0QMe8YQTnnHGCy74hCteccMb7njH
8evRAx7xhBOeccYLLviEK15xwxvueMfx29EDHvGE0//+B2ZpKxk=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2Dmu5UQYBeAfIkIHBAQEBiGEEEJmnuliHhtMM89FQzM0Q5vmAc3U1BKu
xAYqJbsLIKglXLGCWoKRiBABQq8R8leJ9en46ATlyNecPnfqzOUR8edlEf8+
j896IrYnbXkFHvCV+Cp8NR7xtfg6fD2+Ad+Ib8I34wnfgm/Ft+Hb8R34TnwX
vhvfg+/F9+H78QP4QXwCp60LjofIcTxMjuMRchyPkuN4jBzH4+Q4niDH8SQ5
jqfIcTxNjuMZchzPkuM4SY7jOXIcz5PjmLdOuOCG4wX6uOCG4xR9XHDD8SJ9
XHDD8RJ9XHDD8TJ9XHDD8Qp9XHDD8Sp9XHDD8Rp9XHDD8Tp9XHDD8QZ9XHDD
8SZ9XHDD8RZ9XHDD8TZ9XHDD8Q59XHDD8S59XHDDkbceccIZF1xxwx3He+zj
hDMuuOKGO47T7OOEMy644oY7jvfZxwlnXHDFDXccH7CPE8644Iob7jjOsI8T
zrjgihvuOD5kHyecccEVN9xxfMQ+TjjjgituuOP4mH2ccMYFV9xwx/EJ+zjh
jAuuuOGO4yz7OOGMC6644Y7jU/ZxwhkXXHHDHcdn7OOEMy644oY7js/Zxwln
XHDFDXccX7CPE8644Iob7jjOsY8TzrjgihvuOJatBzziCSc844wXXPAOV7zH
DR9wxyuOL7ce8IgnnPCMM15wwTtc8R43fMAdrzjObz3gEU844Rnn8+nvX//4
/eTpfPxfaSEveIcr3uOGD7jjFcdXWw94xBNOeMYZL7jgHa54jxs+4I5XHEdb
D3jEE054Pkp/XTz729EvF47vOx9duv9y6f7JC9799/5y7Hq0/X727DV8wB2v
OL7eesAjnnDCM854wQXvcMV73PABd7zi+GbrAY94wgnPOOMFF7zDFe9xwwfc
8Yrj260HPOIJJzzjjBdc8A5XvMcNH3DHK44LWw94xBNOeMYZL7jgHa54jxs+
4I5XHN9tPeARTzjhGWe84IJ3uOI9bviAO15xfL/1gEc84YRnnPGCC97hive4
4QPueMXxw9YDHvGEE55xxgsueIcr3uOGD7jjFcePWw94xBNOeMYZL7jgHa54
jxs+4I5XHD9tPeARTzjhGWe84IJ3uOI9bviAO15xXNx6wCOecMIzznjBBe9w
xXvc8AF3vOL4eesBj3jC6X//A1TxM5c=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1jnu3kQcBuAfVJQuKCgoDEIIIYTMvpNhXwMm7PvwDwlLgJgt7DBH+I4w
LZ2PMEf4xAnmCEaipEAoSMiPG+vRq9evNJrC151cPHPuyoj464qIf9+Xn+1U
7J+051V4wFfja/C1eMTX4xvwjfgmfDO+Bd+KJ3wbvh3fge/Ed+G78T34Xnwf
vh8/gB/ED+GH8Smc9i44HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjuM0OY4XyHG8SI5j3jvhghuOl+jjghuOM/RxwQ3Hy/RxwQ3H
K/RxwQ3Hq/RxwQ3Ha/RxwQ3H6/RxwQ3HG/RxwQ3Hm/RxwQ3HW/RxwQ3H2/Rx
wQ3HO/RxwQ3Hu/RxwQ3He/RxwQ3H+/RxwQ1H3nvM6e/f//zj9Em+/B+QyDMu
uOKGO9+PD9jHCWdccMUNdxwn7OOEMy644oY7jrPs44QzLmf351nJG+44PmQf
J5xxwRU33HGcYx8nnHHBFTfccZz/7/yWy+c3nuf+n2cfF1xxwx3HR3uPOOGM
C6644Y7jY/ZxwhkXXHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccF9jHCWdc
cMXtwv4+d/L4jH2ccMYFV9xwx/E5+zjhjAuuuOGO4wv2ccIZF1xxwx3HRfZx
whkXXHHDHcey94BHPOGEZ5zxggs+4IpX3PARd7zh+HLvAY94wgnPOOMFF3zA
Fa+44SPueMPx1d4DHvGEE55xxgsu+IArXnHDR9zxhuPrvQc84gknPOOMF1zw
AVe84oaPuOMNxzd7D3jEE054xhkvuOADrnjFDR9xxxuOb/ce8IgnnPCMM15w
wQdc8YobPuKONxyX9h7wiCec8IwzXnC5tP8/OZBXvOKGj7jjDcd3ew94xBNO
eMYZL7jgA654xQ0fcccbju/3HvCIJ5zwjDNecMEHXPGKGz7ijjccP+w94BFP
OOEZZ7zggg+44hU3fMQdbzh+3HvAI55wwjPOeMEFH3DFK274iDvecPy094BH
POGEZ5zxggs+4IpX3PARd7zh+HnvAY94wgnPOOMFF3zAFa+44SPueMPxy94D
HvGEE55xxgsu+IArXnHDR9zxhuPXvQc84gknPOOMF1zwAVe84oaPuOMNx297
D3jEE07/+x9ETjSF
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1zcO5kQYBuAPKkoXFBQUBiGEEEImZ3bIccEsOQ9LjmtyhjmCjzAtnY8w
R/jFCeYIRqKkQGgL5OdrRo9evXrruer8hXPvXxoRf18S8d978fYzcbx05GV4
wJfjK/CVeMRX42vwtfg6fD2+Ad+IJ3wTvhnfgm/Ft+Hb8R34TnwXvhvfg+/F
9+H78Rmcji44HiDH8SA5jofIcTxMjuMRchyPkuN4jBzH4+Q4niDH8SQ5jqfI
cTxNjuMsOY5nyHE8S45jPjrhghuO5+jjghuOc/RxwQ3H8/RxwQ3HC/RxwQ3H
i/RxwQ3HS/RxwQ3Hy/RxwQ3HK/RxwQ3Hq/RxwQ3Ha/RxwQ3H6/RxwQ3HG/Rx
wQ3Hm/RxwQ3HW/RxwQ3H2/RxwQ1HPnrECWdccMUNdxzvsI8TzrjgihvuOM6z
jxPOuOCKG+443mUfJ5xxwRU33HG8xz5OOOOCK26443iffZxwxgVX3HDH8QH7
OOGMC6644Y7jQ/ZxwhkXXHHDHcdH7OOEMy644oY7jo/ZxwlnXHDFDXccn7CP
0yfpnz/++vPs+eXivyiTF1xxwx3Hp+zjhDMuuOKGO47P2McJZ1xwxQ13HJ+z
jxPOuOCKG+44vmAfJ5xxwRU33HFcYB8nnHHBFTfccSxHD3jEE054xhkvuOAV
V7zhhk+44x3Hl0cPeMQTTnjGGS+44BVXvOGGT7jjHcdXRw94xBNOeMYZL7jg
FVe84YZPuOMdx9dHD3jEE054xhkvuOAVV7zhhk+44x3HN0cPeMQTTnjGGS+4
4BVXvOGGT7jjHce3Rw94xBNOeMYZL7jgFVe84YZPuOMdx3dHD3jEE054xhkv
uOAVV7zhhk+44x3H90cPeMQTTnjGGS+44BVXvOGGT7jjHccPRw94xBNOeMYZ
L7jgFVe84YZPuOMdx49HD3jEE054xhkvuOAVV7zhhk+44x3HT0cPeMQTTnjG
GS+44BVXvOGGT7jjHcfPRw94xBNOeMYZL7jgFVe84YZPuOMdxy9HD3jEE054
xhkvuOAVV7zhhk+44x3Hr0cPeMQTTnjGGS+44BVXvOGGT7jjHcdvRw94xBNO
eMYZL7jgFVe84YZPuOMdx+9HD3jEE07/+188ERhB
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2MsOH1McB/AfK8tZWFhYDBERERn3ux6X1rWMou51tOpSpYOilDqP8E+8
wGzt5gEsziNMPMF5hJFYiYVIJTKf2Uw++eab72JOZpK56fSFE2evjYg/r4n4
93712o7E/kp7Xoc7fD2+Ad+Ie3wzvgXfim/Dt+M78J14wHfhu/E9+F58H74f
P4AfxA/hh/Ej+FH8GH4cH8Fp74LjCXIcT5LjeIocx9PkOI6SH01///rH78dP
5//O6bG9yzH6z9DH8Sw5jufIcTxPjuMFchwvkuM4To7jJXIcL5PjGPdOuOCK
4xX6uOCK4wR9XHDF8Sp9XHDF8Rp9XHDF8Tp9XHDFcZI+Lif/O9/T1fNdyeMN
+rjgiuNN+rjgiuMt+rjgiuNt+rjgiuMd+rjgiuNd+rjgiuM9+rjgiuMUfVxO
7d9vlTzep48Lrjjy3j1OOOOCZ1xxw/EB+zjhjAueccUNx2n2ccIZFzzjihuO
M/vn2+N0Jv115dxvF3+5dNWZvJxhH1fccHy4d48TzrjgGVfccJxlHyecccEz
rrjh+Ih9nHDGBc+44objY/ZxwhkXPOOKG45P2McJZ1zwjCtuOD5lHyecccEz
rrjhOMc+TjjjgmdcccPxGfs44YwLnnHFDcd59nHCGRc8n+d7Rd5wfM4+Tjjj
gmdcccPxBfs44YwLnnHFDccF9nHCGRc844objmnvDvd4wAmPOOMJF3zAM15w
xStueMPx5d4d7vGAEx5xxhMu+IBnvOCKV9zwhuOrvTvc4wEnPOKMJ1zwAc94
wRWvuOENx9d7d7jHA054xBlPuOADnvGCK15xwxuOi3t3uMcDTnjEGU+44AOe
8YIrXnHDG45v9u5wjwec8IgznnDBBzzjBVe84oY3HN/u3eEeDzjhEWc84YIP
eMYLrnjFDW84vtu7wz0ecMIjznjCBR/wjBdc8Yob3nBc2rvDPR5wwiPOeMIF
H/CMF1zxihvecHy/d4d7POCER5zxhAs+4BkvuOIVN7zh+GHvDvd4wAmPOOMJ
F3zAM15wxStueMNxee8O93jACY844+ky/2/ID3jGC654xQ1vOH7cu8M9HnDC
I854wgUf8IwXXPGKG95w/LR3h3s84IRHnPGECz7gGS+44hU3vOG4sneHezzg
hEec8YQLPuAZL7jiFTe84fh57w73eMDpf/8DerBCTQ==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1rnO3kQYBeAXKkoXKSgoDEIIIYTMvpNhDVvAhB0SGAJhCUscCFsCYQoK
SkvcgFsa9F0AxVzCJ65guAMjUSEKhP5EyM801qOjo+Nu5tqTZ46dujIi/roi
4r/vwVkPx/akLa/CHT6Er8bX4B5fh6/HN+Ab8U34ZnwLHvCt+DZ8O74D34nv
wnfje/C9+D58P34AP4gfwodx2rrgeJgcxyPkOB4lx/EYOY7HyXE8QY7jCDmO
J8lxPEWO42lyHM+Q43iWHMdRchzPkeN4nhzHuHXCBVccL9DHBVccx+jjgiuO
F+njgiuOl+jjgiuOl+njgiuOV+jjgiuOV+njgiuO1+jjgiuO1+njgiuON+jj
giuON+njgiuO4+nCoV+P/HH+x4N7Lx1P//zy5+9HT84HLsfT3xdP/3bu558O
XC/n06V78sQl50t9XE6wj+Mt/h8XXHG8TR8XXHHkrXuccMYFL7jihuMd9nHC
GRe84IobjpPs44QzLnjBFTcc77KPE8644AVX3HC8xz5OOOOCF1xxw3GKfZxw
xgUvuOKG4332ccIZF7zgihuOD9jHCWdc8IIrbjg+ZB8nnHHBC6644fiIfZxw
xgUvuOKG4zT7OOGMC15wxQ3Hx+zjhDMueMEVNxyfsI8TzrjgBVfccHzKPk44
44IXXHHD8Rn7OOGMC15wxQ3HGfZxwhkXvOCKG45p6w73eMAJjzhP2/fQhMu0
fU/N5MtllwPvyCves9/wiuPs1h3uz27/byBPeMQZT7jgGS94hyve44ZXHJ9v
3eEeDzjhEWc84YJnvOAdrniPG15xfLF1h3s84IRHnPGEC57xgne44j1ueMVx
busO93jACY844wkXPOMF73DFe9zwiuPLrTvc4wEnPOKMJ1zwjBe8wxXvccMr
jq+27nCPB5zwiDOecMEzXvAOV7zHDa84vt66wz0ecMIjznjCBc94wTtc8R43
vOL4ZusO93jACY844wkXPOMF73DFe9zwiuPbrTvc4wEnPOKMJ1zwjBe8wxXv
ccMrjvNbd7jHA054xBlPuOAZL3iHK97jhlccF7bucI8HnPCIM55wwTNe8A5X
vMcNrzi+27rDPR5wwiPOeMIFz3jBO1zxHje84vh+6w73eMAJjzjjCRc84wXv
cMV73PCK4+LWHe7xgBMeccYTLnjGC97hive44RXHD1t3uMcDTv/7X7CcVJE=

       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2WuoVFUUwPGVREhEnA8SRhKnEomep6eZmdvSyp6jlZm9TqZldmfmzHuy
1+5DVFQwFPQwoWNqZZlN9rKQ2pVQEMQQgUREJyRC6sNIQfSC7nXWpdZ/vlx+
rLP22uusfc7cyz1mZXXp6iki8ttBIhM/R5/hfLEfZzkVjuBp7u+t+7+6YmWm
60xHfAYcw8fCM+FZ8PHwCfBJ8ClwAp8Gnw6fof2l2t+ZiJ8Fnw3Phs+B58Dn
wnPh8+B58PnwfNhZe1gWIA7LBYjDciHisCxEHJZFiMNyEeKwXIw4LJcgDsti
xGG5FHFYLkMclssRh+UKxGG5EnFYrkIclpK1gz0cYFmCfNjDAZalyIc9HGC5
GvmwhwMs1yAf9nCA5Vrkwx4OsCxDPuzhAMt1yIc9HGBZjnzYwwGW65EPezjA
sgL5sIcDLDcgH/ZwgOVG5MMeDrDchHzYwwGWm5EPezjAcgvyYQ8HWFLrGHZw
Cns4hwNcwHIr6sMOTmEP53CAC1hWoj7s4BT2cA4HuIDlNtSHHZzCHs7hABew
rEJ92MEp7OEcDnABy2rUhx2cwh7O4QAXsNyO+rCDU9jDORzgApY7UB92cAp7
OIcDXMCyBvVhB6dr7O+/Hs5xfYALWO5EfdjBKezhHA5wActa1IcdnMIezuEA
F7Dchfqwg1PYwzkc4AKWMdSHHZyO6by9zn/M/Xn/2l3Npx7R+U/GeyOHMTfn
7c/bH76wfuRizH37x0TCJv37qezWPzfx2TpyXHZHHrzs8JN3vD6yK7tLD5ty
4sNHvD9yWnaXz350Qfpj0Pplt3fL87vj/idav+wO3bMpm3foZ1q/7H5ZsvPo
h37+WOuX3W//fN3dN0stFTd124wVq+Z+pPUrbvmBDatdxa6fVtzd+2adNnXb
Lq1fcRvGo/U1ul5ecU9Nn2hArw8V7fdTrV9x48188+Xvaqm6hY+N/fTXVs2P
q+64Awm7tX7V9ptW3ebx7vZsmuy/qv2+p/Wr2u+bWr/q7pm2/eIf1r2t9atu
7vdXPfFMZYfWz9wXGxe9++s/Go8y98HiiRv+ru4ns9cnsMvcUad+N/OQB7eM
XMrsfNNM78/GkbPMzttnel76I/cyO/88cxPdLNm5feQ+8kOm90fzB5nOZ5v2
i/0NYanZ/UY1vV+btf+a3X9Ss/txNVu/VNP139H+a/b8ZpP13tL+kd+D85qd
X79m5x1qdn6Dmp1fUbPzGuJ6qdv9RnVbL67r/db9J3W7vqu7A8d3v65fqtv+
0ro+/69q/3U7b1+3++vV0X8d86/r++YV7b9uz8Ngcn8vaf91O98h4tKw844a
Gn9a+4eThtZ/Vvtv2PdbCdenDZz/ht2Pb9jz2GvY+5NP5uvz3G/Y+x0a+j7R
+z1AvED+EOtL014fNe31MZw0bb5r2nmUmvZ+pk3bX9Z045u9eu+W17T/pht/
+Y6fgJe1f+TnTT0fL2r/WC8gPsB6BTzE+tKy5yFq2fnEcNLC91PLvm9LLTz/
Lf0+eUP7hz3ye3Dess9Hv4Xnv2XnM2jhfd+y8x227HmRtn1fRm37vMZt+/wl
bTs/18b5b+t+n9T+2/Z5yNr2+fGI99r2ecnbdt79tp1fwPWDtj0PBeLDyX43
aP8dG486Nh537PlJOnr+c+2/g/47eP6xXtax/Xis3+vg+e/Y92G/Y+cd4EHH
nq8C9YbYn3RtP1HX3r+4a89H0rX1XBfff127/xT5WRff/117nnrYT96197ff
tecnTK7/uPbftb+PFpPuav9d/H/ibif//0RwDCewg0twCmewh3twDvfhAA/g
Ah7Css46gmM4gR1cglM4gz3cg3O4Dwd4ABfwEJZ7rCM4hhPYwSU4hTPYwz04
h/twgAdwAQ9hudc6gmM4gR1cglM4gz3cg3O4Dwd4ABfwEJb7rCM4hhPYwSU4
hTPYwz04h/twgAdwAQ9hud86gmM4gR1cglM4gz3cg3O4Dwd4ABfwEJYHrCM4
hhPY/ed/AQVl0Ek=
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DcO5kQYBuAPKkoXFBQUBiGEEEImZ3bIccEsOQ9LzoYlxzmCjzAt3X+E
OYLFCeYIRqKkQGgL5OdrRo9evXr7uer8l+fevzQi/r4k4r/34u1n4njpyMvw
gC/HV+Ar8Yivxtfga/F1+Hp8A74RT/gmfDO+Bd+Kb8O34zvwnfgufDe+B9+L
78P34zM4HV1wPECO40FyHA+R43iYHMcj5DgeJcfxGDmOx8lxPEGO40lyHE+R
43iaHMdZchzPkON4lhzHfHTCBTccz9HHBTcc5+jjghuO5+njghuOF+jjghuO
F+njghuOl+jjghuOl+njghuOV+jjghuOV+njghuO1+jjghuO1+njghuON+jj
ghuON+njghuOt+jjghuOt+njghuOfPSIE8644Iob7jjeYR8nnHHBFTfccZxn
HyecccEVN9xxvMs+TjjjgituuON4j32ccMYFV9xwx/E++zjhjAuuuOGO4wP2
ccIZF1xxwx3Hh+zjhDMuuOKGO46P2McJZ1xwxQ13HB+zjxPOuOCKG+44PmEf
J5xxwRU33HF8yj5OOOOCK2644/iMfZxwxgVX3HDH8Tn7OOGMC6644Y7jC/Zx
whkXXHHDHceX7OOEMy644oY7juXoAY94wgnPOOMFF7ziik+44Q13vOP46ugB
j3jCCc844wUXvOKKT7jhDXe84/j66AGPeMIJzzjjBRe84opPuOENd7zjuHD0
gEc84YRnnPGCC15xxSfcLqR//vjrz7Pn88V/u4284x3HN0cPeMQTTnjGGS+4
4BVXfMINb7jjHce3Rw94xBNOeMYZL7jgFVd8wg1vuOMdx3dHD3jEE054xhkv
uOAVV3zCDW+44x3H90cPeMQTTnjGGS+44BVXfMINb7jjHccPRw94xBNOeMYZ
L7jgFVd8wg1vuOMdx49HD3jEE054xhkvuOAVV3zCDW+44x3HT0cPeMQTTnjG
GS+44BVXfMINb7jjHcfPRw94xBNOeMYZL7jgFVd8wg1vuOMdxy9HD3jEE054
xhkvuOAVV3zCDW+44x3Hr0cPeMQTTnjGGS+44BVXfMINb7jjHcdvRw94xBNO
eMYZL7jgFVd8wg1vuOMdx+9HD3jEE07/+1/iQhgx
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1znu3kQcBuAfVJQuKCgoDEIIIYTMvpNhXwMm7PsQCEtY4gBh/8Mc4TvC
tHQ+whzhEyeYIxiJkgKhICE/01iPXr16K1vj685eOHPuyoj464qIf5+Xz3Yq
9ifteRUe8NX4GnwtHvH1+AZ8I74J34xvwbfiCd+Gb8d34DvxXfhufA++F9+H
78cP4AfxQ/hhfAqnvQuOR8hxPEqO4zFyHI+T43iCHMeT5DieIsfxNDmOZ8hx
PEuO4zlyHM+T4zhNjuMFchwvkuOY90644IbjJfq44IbjDH1ccMPxMn1ccMPx
Cn1ccMPxKn1ccMPxGn1ccMPxOn1ccMPxBn1ccMPxJn1ccMPxFn1ccMPxNn1c
cMPxDn1ccMPxLn1ccMPxHn1ccMPxPn1ccMOR9x5xwhkXXHHDHccH7OOEMy64
4oY7jrPs44QzLrjihjuOD9nHCWdccMUNdxwfsY8TzrjgihvuOM6xjxPOuOCK
G+44PmYfJ5xxwRU33HF8wj5OOOOCK2644/iUfZxwxgVX3HDH8Rn7OOGMC664
4Y7jPPs44YwLrridT3///ucfp8/my/9VnTw+Zx8nnHHBFTfccXzBPk4444Ir
brjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuMC+zjhjAuuuOGOY9l7wCOecMIz
znjBBR9wxStu+Ig73nBc3HvAI55wwjPOeMEFH3DFK274iDveLu6/R/H1Ph/w
iCec8IwzXnDBB1zxihs+4o43HN/sPeARTzjhGWe84IIPuOIVN3zEHW84vt17
wCOecMIzznjBBR9wxStu+Ig73nBc2nvAI54u7d+fRD7jjBdc8AFXvOKGj7jj
Dcd3ew94xBNOeMYZL7jgA654xQ0fcccbju/3HvCIJ5zwjDNecMEHXPGKGz7i
jjccP+w94BFPOOEZZ7zggg+44hU3fMQdbzh+3HvAI55wwjPOeMEFH3DFK274
iDvecPy094BHPOGEZ5zxggs+4IpX3PARd7zh+HnvAY94wgnPOOMFF3zAFa+4
4SPueMPxy94DHvGEE55xxgsu+IArXnHDR9zxhuNk7wGPeMIJzzjjBRd8wBWv
J//dP5bL9492sr+PHHGnv+H4de8Bj3jCCc844wUXfMAVr7jhI+54w/Hb3gMe
8YTT//4H3lgvzw==
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2LnqJUUcBeCfRoYdGBgYtCIiItLuu1Ou4zba7ruWo+O+tDo646hjBQaG
F3yBSk3kPoBBPcLFJyjfoAUjMRD5M0h/lTQfh1MHOuigrzj52TOnLo6Ivy6K
+O95dNZjsT1py0vwgC/Fl+HL8YivxFfhq/E1+Fp8Hb4eT/gGfCO+Cd+Mb8G3
4tvw7fgOfCe+C9+N78H34mM4bV1w3EeO435yHA+Q43iQHMdD5DgeJsdxnBzH
I+Q4HiXH8Rg5jsfJcTxBjuMEOY4nyXE8RY5j3jrhghuOp+njghuOZ+jjghuO
Z+njghuO5+jjghuO5+njghuOF+jjghuOF+njghuOl+jjghuOl+njghuOV+jj
ghuOV+njghuO1+jjghuO1+njghuON+jjghuON+njghuOvPWIE8644Iob7jje
Yh8nnHHBFTfccZxkHyecccEVN9xxvM0+TjjjgituuON4h32ccMYFV9xwx3GK
fZxwxgVX3HDH8S77OOGMC6644Y7jPfZxwhkXXHHDHcf77OOEMy644oY7jg/Y
xwlnXHDFDXccH7KPE8644Iob7jg+Yh8nnHHBFTfccXzMPk4444Irbrjj+IR9
nHDGBVfccMfxKfs44YwLrrjhjuMz9nHCGRdcccMdx7L1gEc84YRnnPGCC97h
ive44QPueMXx+dYDHvGEE55xxgsueIcr3uOGD7jjFccXWw94xBNOeMYZL7jg
Ha54jxs+4I5XHF9uPeARTzjhGWe84IJ3uOI9bviAO15xnN56wCOecMIzznjB
Be9wxXvc8AF3vOL4ausBj3jCCc844wUXvMMV73HDB9zxiuPrrQc84gknPOOM
F1zwDle8xw0fcMcrjjPpn1/+/P3EyXz033u44OXII/lEnsjnM+nv8x/+dvrn
s0fOF/Jy5OVM+vbSX4//ce7HIxfu23FfxXvub9x/uJD/dOROvrIfZ7fvY8Aj
nnDCM854wQXvcMV73PABd7zi+GbrAY94wgnPOOMFF7zDFe9xwwfc8Yrj3NYD
HvGEE55xxgsueIcr3uOGD7jjFce3Ww94xBNOeMYZL7jgHa54jxs+4I5XHN9t
PeDxu+33ZiJPeMYZL7jgHa54jxs+4I5XHN9vPeARTzjhGWe84IJ3uOI9bviA
O15xnN96wCOecMIzznjBBe9wxXvc8AF3vOL4YesBj3jC6X//C+CyYKE=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2Lnu3UQcBeAfVJQuKCgoDEIIIYTMvpNhXwMm7PuQEJYEiIEAAf4J8whX
4gWmpbsPQDGPcMUTzCMYiQpRIBQQ8ufG+nR8dOTCku3rTp47cfrKiPjjioh/
zpeP9Vhsj7TlVXjAV+Nr8LV4xNfjG/CN+CZ8M74F34onfBu+Hd+B78R34bvx
PfhefB++Hz+AH8QP4YfxMZy2LjgeIcfxKDmOx8hxPE6O4wlyHE+S43iKHMfT
5DieIcfxLDmO58hxPE+O4zg5jhfIcbxIjmPeOuGCG46X6OOCG44T9HHBDcfL
9HHBDccr9HHBDcer9HHBDcdr9HHBDcfr9HHBDccb9HHBDceb9HHBDcdb9HHB
Dcfb9HHBDcc79HHBDce79HHBDcd79HHBDcf79HHBDUfeesQJZ1xwxQ13HB+w
jxPOuOCKG+44TrKPE8644Iob7jhOsX8q/fXL778dP5kvv4clnHGhX3HDHceH
7OOEMy644oY7jtPs44QzLrjihjuOj9jHCWdccMUNdxwfs48TzrjgihvuOD5h
HyecccEVN9xxfMo+TjjjgituuOM4wz5OOOOCK2644zi7fZ7Hs+zjjAuuuOGO
47OtR5xwxgVX3HDH8Tn7OOGMC6644Y7jC/ZxwhkXXHHDHcc59nHCGRdcccMd
x7L1gEc84YRnnPGCC97hive44QPueMXx5dYDHvGEE55xxgsueIcr3uOGD7jj
FcdXWw94xBNOeMYZL7jgHa54jxs+4I5XHF9vPeARTzjhGWe84IJ3uOI9bviA
O15xnN96wCOecMIzznjBBe9wxXvc8AF3vOL4ZusBj3jCCc844wUXvMMV73HD
B9zxiuPbrQc84gknPOOMF1zwDle8xw0fcMcrju+2HvCIJ5zwjDNecME7XPEe
N3zAHa84Lmw94BFPOOEZZ7zggne44j1u+IA7XnF8v/WARzzhhGec8YIL3uGK
97jhA+54xfHD1gMe8YQTnnHGCy54hyve44YPuOMVx49bD3jEE054xhkvuOAd
rniPGz7gjlccR1sPeMQTTnjGGS9H6c9LZ349//OFf/9fHf37/Vsue4cr1+/J
239eLvtA3o+239cr18fFrYeL3D+ecMIzznjBBe9wxXvc8AF3vOK4tPWARzzh
hGec8YIL3uGK97jhA+54xfHT1gMe8YTT//4baWZVaw==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1zkKJkUYBuBPI8MODAwMWhEREWn33Sn3Xdtx38vRcRmXaXXcRh3rCA1e
oFKz/wAGdYQfT1BHaMFIDEQGkX4qKR5e3nrT7qtOnT15+tKI+POSiH/vi2c7
EfuT9rwMD/hyfAW+Eo/4anwNvhZfh6/HN+Ab8YRvwjfjW/Ct+DZ8O74D34nv
wnfje/C9+D58Pz6B094FxwPkOB4kx/EQOY6HyXE8Qo7jUXIcj5HjeJwcxxPk
OJ4kx/EUOY6nyXE8Q47jWXIcz5HjmPdOuOCG43n6uOCG4yR9XHDD8QJ9XHDD
8SJ9XHDD8RJ9XHDD8TJ9XHDD8Qp9XHDD8Sp9XHDD8Rp9XHDD8Tp9XHDD8QZ9
XHDD8SZ9XHDD8RZ9XHDD8TZ9XHDD8Q59XHDDkfceccIZF1xxwx3Hu+zjhDMu
uOKGO45T7OOEMy644oY7jvfYxwlnXHDFDXcc77OPE8644Iob7jhOs48Tzrjg
ihvuOD5gHyecccEVN9xxfMg+TjjjgituuOP4iH2ccMYFV9xwx/Ex+zjhjAuu
uOGO4wz7OOGMC6644Y7jE/ZxwhkXXHHDHcen7OOEMy644oY7js/YxwlnXHDF
DXccn7OPE8644Iob7jjOsn82/f3rH78/c2q5+B+eyDMuuOKGO45l7wGPeMIJ
zzjjBRe84ooPuOEj7njD8cXeAx7xhBOeccYLLnjFFR9ww0fc8Ybjy70HPOIJ
JzzjjBdc8IorPuCGj7jjDcdXew94xBNOeMYZL7jgFVd8wA0fcccbjnN7D3jE
E054xhkvuOAVV3zADR9xxxuOr/ce8IgnnPCMM15wwSuu+IAbPuKONxzf7D3g
EU844RlnvOCCV1zxATd8xB1vOL7de8AjnnDCM854wQWvuOIDbviIO95wfLf3
gEc84YRnnPGCC15xxQfc8BF3vOH4fu8Bj3jCCc844wUXvOKKD7jhI+54w3F+
7wGPeMIJzzjjBRe84ooP5/ffxw0fz6e/Lpz57dwv3110/y/PF73xXvyw94BH
POGEZ5zxggteccUH3PARd7zh+HHvAY94wgnPOOMFF7ziig+44SPueMPx094D
HvGEE55xxgsueMUVH3DDR9zxhuPC3gMe8YQTnnHGCy54xRUfcMNH3PGG4+e9
BzziCaf//Q83syrf
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd132IFVUYx/EniZCImD8krCSmEImsvGZmZraPpZmleX3JzN5Om5aZuZOa
rTv33j1RIVHBLaOgBE8vFprYVGYiZqey6AXiEkFERBMSIRFMJEQvQrvuuX+c
7/1n+fDMc575zZyBs+f29i1eNUpEjp0kMvx35Ff1SPzTmKPhBB4Dj4XHwSl8
HjwengCfD18AXwhfDNfgyfAl8BT4UngqfBk8Db4cng5fAc+Ar4RnwlfBPbDG
trDMQh2Wq1GH5RrUYZmNOixzUIflWtRhmYs6LNehDss81GG5HnVYbkAdlvmo
w7IAdVhuRB2WhajDUo+tsIU9LIvQD1vYw7IY/bCFPSxL0A9b2MOyFP2whT0s
N6EftrCHZRn6YQt7WG5GP2xhD8ty9MMW9rDcgn7Ywh6WFeiHLexhuRX9sIU9
LLehH7awh+V29MMW9rDcgX7Ywh6WO9EPW9jDYmKnsMIGtrCDPVzCchfmwwob
2MIO9nAJSy/mwwob2MIO9nAJy92YDytsYAs72MMlLCsxH1bYwBZ2sIdLWFZh
PqywgS3sYA+XsNyD+bDCBrawgz1cwnIv5sMKG9jCDvZwCctqzIcVNrCFHezh
Epb7MB9W2MAWdrCHS1jWYD6ssIEt7GAPl7Dcj/mwwga2sIM9XMKyFvNhhQ1s
YQd7uITlAcyHFTawhR3s4RKWdZgPK2xgCzvYwyUsfZjfp//t/OObBb125P9w
7dN/WmsObtzaP2KDuu3ajNh1nY3Y4/qyT/Mxe+b+PPBY+D8/C/X2iBM4zXTz
0QmTR+9+asS1LF5fs/j+6lk8z6Ceod+i3kbdwUWG5wt34BKuYHkwdgKncA1W
uA4bOIMt3IYdXMAe7sAlXMGyPnYCp3ANVrgOGziDLdyGHVzAHu7AJVzBsiF2
AqdwDVa4Dhs4gy3chh1cwB7uwCVcwbIxdgKncA1WuA4bOIMt3IYdXMAe7sAl
XMHyUOwETuEarHAdNnAGW7gNO7iAPdyBS7iCZVPsBE7hGqxwHTZwBlu4DTu4
gD3cgUu4guXh2AmcwjVY4Tps4Ay2cBt2cAF7uAOXcAVLf+ykPz5PpHANVrgO
G6yfwRZuww4uYA934BKuYNkcO4FTuAYrXIcNnMEWbsMOLmAPd+ASrmAZiJ3A
KVyDFa7DBs5gC7dhBxewH4jPj52B+PxaDsTn12ognH+fC+ffPNS3hfNvrgfm
nTZq4pbXw/7Pdfn0vZ9vOvRW2P+5fvXynH1/Ht8b9n+uu4bHJfvD/s/D/QSb
XL/YdGj7WZM+COffXEfvHrdi5YwPw/m3u35wO9fVz/ze6Jl6KJx/cz12/Nv+
oxM+CuffXB/1Xw7dwSfhfJ/r1rEnLzv9oo9D/lx/+Hv4BkK9zHXKiV9whfWk
EdeTRlxPG/H6tUZ4fodD/oZuOHHDn4b8jXi+aei2w2mxfnVYL8N6tqGvZTNP
/e5VH/I3wvsLdg2d/eTaX//d2c2P9XxDlx7Z8dLhNFzfQb1Ef9XQM4fHvxPe
hzR1/zmP/7Zof3jeSTPsh4MhP1xr6tDL+2nh0++H/M14P9SbevakH8ef8sh7
IX9Th8INJQzXZ7jeNsN+2xfy43qH64umTtxyxvdf//VuyA93miH/2yE/XHXz
7gn5Wzp/2hOzzC9FyN/SocWWHNnxZsjf0hPbc/uukL8Vfx/aCs/jjZAf/QbX
Z931Xgz5Wzrc/cK6Z0P+Vvy9ulb8vRbd9Z4P+bv9r4T8rbB/XMiP+6uQRwbj
55MMhvqBkH8wvM+wv2uD4XmH/a2D2psMf8Gf9fwPuVKb0Q==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1TkO5zQcBeAfVJQpKCgoAkIIIYTCvjNmXwfCvoOZYdhhwr6Dj/A/glu6
HMFHiDiBjxAkSgqEKFA+N9an56dXRbnq3MXnL1waEX9dEvHv/d/Zz8TxpCMv
wwO+HF+Br8Qjvhpfg6/F1+Hr8Q34Rjzhm/DN+BZ8K74N347vwHfiu/Dd+B58
L74P34/P4HR0wfEAOY4HyXE8RI7jYXIcj5DjeJQcx2PkOB4nx/EEOY4nyXE8
RY7jaXIcZ8lxPEOO41lyHPPRCRfccDxHHxfccDxPHxfccLxAHxfccLxIHxfc
cLxEHxfccLxMHxfccLxCHxfccLxKHxfccLxGHxfccLye/v79zz/Onsv//XcS
Lq/Tx/EG+7jghuNN+rjghuMt+rjghuNt+rjghuMd+rjghiMfPeKEMy644oY7
jnfZxwlnXHDFDXcc59jHCWdccMUNdxzn2ccJZ1zOH7+XihvvO4732McJZ1xw
xQ13HBfYxwlnXHDFDXcc77OPE8644Iob7jg+YB8nnHHBFTfccXzIPk4444Ir
brjj+Ih9nHDGBVfccMfxMfs44YwLrrjhjuMT9nHCGRdcccMdx6fs44QzLrji
hjuOz9jHCWdccMUNdxyfs48TzrjgihvuOC6yjxPOuOCKG+44lqMHPOIJJzzj
jBdc8AlXvOKGN9zxjuOLowc84gknPOOMF1zwCVe84oY33PGO48ujBzziCSc8
44wXXPAJV7zihjfc8Y7jq6MHPOIJJzzjjBdc8AlXvOKGN9zxjuProwc84gkn
POOMF1zwCVe84oY33PGO45ujBzziCSc844wXXPAJV7zihjfc8Y7j26MHPOIJ
JzzjjBdc8AlXvOKGN9zxjuO7owc84gknPOOMF1zwCVe84oY33PGO4/ujBzzi
CSc844wXXPAJV7zihjfc8Y7jh6MHPOIJJzzjjBdc8AlXvOKGN9zxjuPHowc8
4gknPOOMF1zwCVe84oY33PGO46ejBzziCSc844wXXPAJV7zihjfc8Y7j56MH
POIJJzzjjBdc8AlXvOKGN9zxjuOXowc84gknPOOMF1zwCVe84oY33PGO49ej
BzziCSc844wXXPAJV7zihjfc8Y7jt6MHPOIJp//9D0SsJlM=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1nmsHlMYx/FDRKQRmYhI0cgoqcY6ltqKPpbaqoytqqhz33vfu9/3Dqqq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       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd17nO3UQYBuAPKkoXFBQUBiGEEEJm38mwrwETdsIy/CQsYYkhAcIW5hKO
xA1MS3cugGIu4YgrmEswEhWiQOhHQn6msR69fvVWlu3rjs6fOntlRPx5RcS/
1+OznojtSVtehQd8Nb4GX4tHfD2+Ad+Ib8I341vwrXjCt+Hb8R34TnwXvhvf
g+/F9+H78QP4QfwQfhifwGnrguMRchyPkuN4jBzH4+Q4niDH8SQ5jqfIcTxN
juMZchzPkuN4jhzH8+Q4TpLjeIEcx4vkOOatEy644XiJPi644ThFHxfccLxM
HxfccLxCHxfccLxKHxfccLxGHxfccLxOHxfccLxBHxfccLxJHxfccLxFHxfc
cJymj8vp9Nflc79d/OXS8Xutkcfb9HHBDcc79HHBDce79HHBDcd79HHBDUfe
esQJZ1xwxQ13HO+zjxPOuOCKG+44jtjHCWdccMUNdxwfsI8TzrjgihvuOM6w
fyb9/esfv588Wo6fl4QzLvQrbrjjOMs+TjjjgituuOP4kH2ccMYFV9xwx/ER
+zjhjAuuuOGO42P2ccIZF1xxwx3HJ+zjhDMuuOKGO45z7OOEMy644oY7jk/Z
xwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHBFTfccXzBPk4444IrbrjjOM8+
TjjjgituuONYth7wiCec8IwzXnDBO1zxHjd8wB2vOL7cesAjnnDCM854wQXv
cMV73PABd7zi+GrrAY94wgnPOOMFF7zDFe9xwwfc8YrjwtYDHvF0Yfs/kS78
9z2Ujz1zf8YLLniHK97jhg+44xXHxa0HPOIJJzzjjBdc8A5XvMcNH3DHK46v
tx7wiCec8IwzXnDBO1zxHjd8wB2vOL7ZesAjnnDCM854wQXvcMV73PABd7zi
+HbrAY94wgnPOOMFF7zDFe9xwwfc8Yrj0tYDHvGEE55xxgsueIcr3uOGD7jj
Fcd3Ww94xBNOeMYZL7jgHa54jxs+4I5XHN9vPeARTzjhGWe84IJ3uOI9bviA
O15x/LD1gEc84YRnnPGCC97hive44QPueMXx49YDHvGEE55xxgsueIcr3uOG
D7jjFcdPWw94xBNOeMYZL7jgHa54jxs+4I5XHJe3HvCIJ5zwjDNecME7XPEe
N3zAHa84ft56wCOecPrf/wAubS87
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DnuHjUcBuAfVJRTUFBQDAghhBAa9p2YfQ0MYd/NH8IOmYQ9bD7CdwS3
dHMEH+ETJ/ARBomSAqFEQvO4sR69evW2lq87OXfm7JUR8fcVEf/dl852KvYn
7XkVHvDV+Bp8LR7x9fgGfCO+Cd+Mb8G34gnfhm/Hd+A78V34bnwPvhffh+/H
D+AH8UP4YXwKp70LjkfIcTxKjuMxchyPk+N4ghzHk+Q4niLH8TQ5jmfIcTxL
juM5chzPk+M4TY7jBXIcL5LjmPdOuOCG4yX6uOCG4wx9XHDD8TJ9XHDD8Qp9
XHDD8Sp9XHDD8Rp9XHDD8Tp9XHDD8QZ9XHDD8SZ9XHDD8RZ9XHDD8TZ9XHDD
8Q59XHDD8S59XHDD8R59XHDD8T59XHDDkfceccIZF1xxwx3HB+zjhDMuuOKG
O44T9nHCGRdcccMdx4fs44QzLrjihjuOj9jHCWdccMUNdxxn2ccJZ1xwxQ13
HB+zjxPOuOCKG+44PmEfJ5xxwRU33HF8yj5OOOOCK2644/iMfZxwxgVX3HDH
8Tn7OOGMC6644Y7jC/ZxwhkXXHHDHceX7OOEMy644oY7jq/YxwlnXHDFDXcc
X7OPE8644Iob7jjOsY8TzrjgihvuOJa9BzziCSc844wXXPABV7ziho+44w3H
+b0HPOIJJzzjjBdc8AFXvOKGj7jj7Xz654+//jx9ki//81y47OWShwv7fLyw
70844RlnvOCCD7jiFTd8xB1vOL7Ze8AjnnDCM854wQUfcMUrbviIO95wfLv3
gEc84YRnnPGCCz7gilfc8BF3vOH4bu8Bj3jCCc844wUXfMAVr7jhI+54w/H9
3gMe8YQTnnHGCy74gCteccNH3PGG44e9BzziCSc844wXXPABV7ziho+44w3H
j3sPeMQTTnjGGS+44AOueMUNH3HHG46f9h7wiCec8IwzXnDBB1zxihs+4o43
HBf3HvCIp4v790Iin3HGCy74gCteccNH3PGG4+e9BzziCSc844wXXPABV7zi
ho+44w3HL3sPeMQTTnjGGS+44AOueMUNH3HHG45f9x7wiCec8IwzXnDBB1zx
ihs+4o43HL/tPeARTzjhGWe84IIPuOIVN3zEHW84ft97wCOecPrf/wJMeyZz

       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DcO5kQYBuAPKkoXFBQUBiGEEEImZ3bIccEsOQ9LzgaWnOYIPsK0dP8R
5ggWJ5gjGImSAqEtkJ+vGT169ert56rzX557/9KI+PuSiP/ei7efieOlIy/D
A74cX4GvxCO+Gl+Dr8XX4evxDfhGPOGb8M34Fnwrvg3fju/Ad+K78N34Hnwv
vg/fj8/gdHTB8QA5jgfJcTxEjuNhchyPkON4lBzHY+Q4HifH8QQ5jifJcTxF
juNpchxnyXE8Q47jWXIc89EJF9xwPEcfF9xwnKOPC244nqePC244XqCPC244
XqSPC244XqKPC244XqaPC244XqGPC244XqWPC244XqOPC244XqePC2443qCP
C2443qSPC2443qKPC2443qaPC2448tEjTjjjgituuON4h32ccMYFV9xwx3Ge
fZxwxgVX3HDH8S77OOGMC6644Y7jPfZxwhkXXHHDHcf77OOEMy644oY7jg/Y
xwlnXHDFDXccH7KPE8644Iob7jg+Yh8nnHHBFTfccXzMPk4444Irbrjj+IR9
nHDGBVfccMfxKfs44YwLrrjhjuMz9nHCGRdcccMdx+fs44QzLrjihjuOL9jH
CWdccMUNdxxfso8TzrjgihvuOJajBzziCSc844wXXPCKKz7hhjfc8Y7jq6MH
POIJJzzjjBdc8IorPuGGN9zxjuProwc84gknPOOMF1zwiis+4YY33PGO45uj
BzziCSc844wXXPCKKz7hhjfc8Y7jwtEDHvF0If3zx19/nj2fL/4TJvIZZ7zg
gldc8Qk3vOGOdxzfHj3gEU844RlnvOCCV1zxCTe84Y53HN8dPeARTzjhGWe8
4IJXXPEJN7zhjncc3x894BFPOOEZZ7zggldc8Qk3vOGOdxw/HD3gEU844Rln
vOCCV1zxCTe84Y53HD8ePeARTzjhGWe84IJXXPEJN7zhjnccPx094BFPOOEZ
Z7zggldc8Qk3vOGOdxw/Hz3gEU844RlnvOCCV1zxCTe84Y53HL8cPeARTzjh
GWe84IJXXPEJN7zhjnccvx494BFPOOEZZ7zggldc8Qk3vOGOdxy/HT3gEU84
4RlnvOCCV1zxCTe84Y53HL8fPeARTzj9738B0oQYMQ==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DnrHVUYB+BXq5RTpLAQGUWCiMjEffe4xi1mEve4jdGoWTSjRs1ibk6h
lQoD9jKdBEQuVilEDn6Ci1/AsRKxuQErtRD53yDzTDM8/OY377zlmSsPHNt3
8NKI+POSiP/uW9f63phfac5tuMLb8WX4clzjq/DVeAe+Bl+Lr8PX4wbvxDfg
G/FN+GZ8C74V34Zvx3fgO/Fd+G58D74Xp7kzjvvIcdxPjuMBchwPkuN4iBzH
w+Q4dpHjeIQcx6PkOB4jx/E4OY4nyHHsJsfxJDmOPeQ42rkTzrjg2EsfZ1xw
7KOPMy44nqKPMy44nqaPMy44nqGPMy44nqWPMy44nqOPMy44nqePMy44XqCP
My449tPHGRccL9LHGRccL9HHGRccL9PHGRccr9DHGRccr9LHGRcc3dw1TrjD
GY+44AnHa8zHCXc44xEXPOE4wHyccIczHnHBE47XmY8T7nDGIy54wvEG83HC
Hc54xAVPOA4yHyfc4YxHXPCE403m44Q7nPGIC55wvMV8nHCHMx5xwROOt5mP
E+5wxiMueMJxiPk44Q7nQ+mfcxd+3n2g2zq3jLhcdN7yRB6HmY8T7nDGIy54
wnGE+TjhDucj6a/F4R+Of3Vis/8R9scTjqNz10eZjzuc8YgLnnC8M3eNE+5w
xiMu77A/jnc37jf7v8t83OGMR1zwhOPY3DVOuMMZj7jgCUc/d4Vr3OCEW9zh
Hmc84BEvccErPOE1jvfmrnCNG5xwizvc44wHPOIlLniFJ7zG8f7cFa5xgxNu
cYd7nPGAR7zEBa/whNc4Ppi7wjVucMIt7nCPMx7wiJe44BWe8BrH8bkrXOMG
J9ziDvc44wGPeIkLXuEJr3F8OHeFa9zghFvc4R5nPOARL3HBKzzhNY6P5q5w
jRuccIs73OOMBzziJS54hSe8xvHx3BWucYMTbnGHe5zxgEe8xAWv8ITXOE7M
XeEaNzjhFne4xxkPeMRLXPAKT3iN4+TcFa5xgxNucYd7nPGAR7zEBa/whNc4
Ts1d4Ro3OOEWd7jHGQ94xEtc8ApPeI3j9NwVrnGDE25xh3uc8YBHvMQFr/CE
1zg+mbvCNW5wwi3ucI8zHvCIl7jgFZ7wGseZuStc4wYn3OIO9zjjAY94iQte
neF/x5n5/4H1mXR6+3e7fj316eb8u5jn1WKe1+TNYn5+Tov5+bldsD/uccYD
HvGS7ymLdPL3HTu3ffvFllcXv2fY7L9I56/47I+957/e7L9I+9+485c9X36z
2f9s+vzob3+fu/D9Zv+zm+d/3Ox/dvO+stn/4vM/bfb/3/8CjcaccQ==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1bcOJjUYBdAPKsopKCgoBoQQQggNObMmx4Uh7xLNkvOQl+ySciRewC3d
/wAUfoRfPIEfYZCoEAVCywrNcWMdXV/d0ped+eTpty6MiD8viPj3Pne2E7E/
ac+L8IAvxpfgS/GIL8dX4CvxVfhqfA2+Fk/4Onw9vgHfiG/CN+Nb8K34Nnw7
vgPfie/Cd+MTOO1dcNxDjuNechz3keO4nxzHA+Q4HiTH8RA5jofJcTxCjuNR
chyPkeN4nBzHSXIcT5DjeJIcx7x3wgU3HE/RxwU3HE/TxwU3HM/QxwU3HM/S
xwU3HM/RxwU3HM/TxwU3HC/QxwU3HKfon0p//fj+b1/8cvbcP1BwO++f//sn
Tqe/f/3j95Nn1nNOp/d5OU3//Pv8X/9F9nHBDcdL9HHBDcfL9HHBDccr9HHB
Dcer9HHBDcdr9HHBDUfee8QJZ1xwxQ13HK+zjxPOuOCKG+44zrCPE8644Iob
7jjeYB8nnHHBFTfccbzJPk4444IrbrjjeIt9nHDGBVfccMfxNvs44YwLrrjh
juMd9nHCGRdcccMdx7vs44QzLrjihjuO99jHCWdccMUNdxzvs48Tzrjgihvu
OD5gHyecccEVN9xxfMg+TjjjgituuOP4iH2ccMYFV9xwx/Ex+zjhjAuuuOGO
4xP2ccIZF1xxwx3HsveARzzhhGec8YILXnHFB9zwEXe84fh07wGPeMIJzzjj
BRe84ooPuOEj7njD8dneAx7xhBOeccYLLnjFFR9ww0fc8Ybj870HPOIJJzzj
jBdc8IorPuCGj7jjDccXew94xBNOeMYZL7jgFVd8wA0fcccbji/3HvCIJ5zw
jDNecMErrviAGz7ijjccX+094BFPOOEZZ7zggldc8QE3fMQdbzi+3nvAI55w
wjPOeMEFr7jiA274iDvecJzde8AjnnDCM854wQWvuOIDbviIO95wfLP3gEc8
4YRnnPGCC15xxQfc8BF3vOH4du8Bj3jCCc844wUXvOKKD7jhI+54w/Hd3gMe
8YQTnnHGCy54xRUfcMNH3PGG4/u9BzziCSc844wXXPCKKz7gho+44w3HD3sP
eMQTTnjGGS+44BVXfMANH3HHG44f9x7wiCec8IwzXnDBK674gBs+4o43HD/t
PeARTzj9738AoFUzAw==
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1TkO7jQYBdAPKsoUFBQUASGEEEJhnnlmniHMM5gHjxlemGfwErIEt3T/
EryEiBV4CUGipEAIEMpxYx1dXV25SS47e/6ZcxdGxB8XRPx9/3P2M3E86ciL
8IAvxpfgS/GIL8dX4CvxVfhqfA2+Fk/4Onw9vgHfiG/CN+Nb8K34Nnw7vgPf
ie/Cd+MzOB1dcNxDjuNechz3keO4nxzHA+Q4HiTH8RA5jofJcTxCjuNRchyP
keN4nBzHE+Q4niTH8RQ5jvnohAtuOJ6mjwtuOJ6hjwtuOJ6ljwtuOJ6jjwtu
OJ6njwtuOF6gjwtuOF6kjwtuOF5Kf/76+29PnF3++e4nXHD7z/nf/8TL7OOC
G45X6OOCG45X6eOCG47XeP9r9HHD8Tr7uOCG4w36uOCG4036uOCGIx894oQz
LrjihjuOt9jHCWdccMUNdxxn2ccJZ1xwxQ13HG+zjxPOuOCKG+443mEfJ5xx
wRU33HGcYx8nnHHBFTfccbzLPk4444IrbrjjeI99nHDGBVfccMfxPvs44YwL
rrjhjuMD9nHCGRdcccMdx4fs44QzLrjihjuOj9jHCWdccMUNdxwfs48Tzrjg
ihvuOD5hHyecccEVN9xxfMo+TjjjgituuOM4zz5OOOOCK26441iOHvCIJ5zw
jDNecMErrviEG95wxzuOz44e8IgnnPCMM15wwSuu+IQb3nDHO47Pjx7wiCec
8IwzXnDBK674hBvecMc7ji+OHvCIJ5zwjDNecMErrviEG95wxzuOL48e8Ign
nPCMM15wwSuu+IQb3nDHO46vjh7wiCec8IwzXnDBK674hBvecMc7jq+PHvCI
J5zwjDNecMErrviEG95wxzuOb44e8IgnnPCMM15wwSuu+IQb3nDHO45vjx7w
iCec8IwzXnDBK674hBvecMc7ju+OHvCIJ5zwjDNecMErrviEG95wxzuO748e
8IgnnPCMM15wwSuu+IQb3nDHO44fjh7wiCec8IwzXnDBK674hBvecMc7jh+P
HvCIJ5zwjDNecMErrviEG95wxzuOn44e8IgnnPCMM15wwSuu+IQb3nDHO46f
jx7wiCec8IwzXnDBK674hBvecMc7jl+OHvCIJ5z+91/AFStJ
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1ruvNVUZB+AXKgqKKSgsCBmJIUQJGVBQbrLkfhHZoCgg8K1zDiDX7wz3
j4uwCo0UkOygCcYQGSlQEkJ2QUGIIauwoNzhH2Aojc0msTIWhJz5ouuZZufJ
b971m5lMZu1v7h/e/sCpEfHvUyK+/j06dldGe6SWp+EOn4G/gc/EPT4bfwuf
g8/F38bn4fPxgC/AF+Lv4u/hi/DF+Pv4B/gSfCm+DF+Or8A/xFfi1Lrg+BE5
jqvIcVxNjuMachzXkuO4jhzH9eQ4biDHcSM5jpvIcdxMjuPH5DhuIcfxE3Ic
t5LjWLVOuOCK4zbmccEVx+3M44Irjp8yjwuuOH7GPC644riDeVxwxfFz5nHB
FccvmMcFVxx3Mo8LrjjuYh4XXHHczTwuuOL4JfO44IrjHuZxwRXHvczjguu9
6T8vP/L3p39/Ytln70v/fe/Lz27Zz0dOJz0euZBX8ji2uCzzx9r1C3k9ll48
44Prv3jhN8t8Ts//85wLTnv/tSP3ecn/sKx3Mn/ryDkv6/9xWT+nu++/7PNb
X//rkaeT+d+Wvpy+Tt88/s6RZ9aLvfTWP/rNkw/9ZenfSx+d9dt/3fbRn5f+
vfTxjaef+p3fvbv076VLPvz02U/e/tPSv7fc33rp32vvp+4t/W8s/Xvt9cd+
636/XS/tt88z77fPs+Bpv32+Fc84Dlr3B/QftPeTD5breXXpZ346aK+3HrTv
y3zQvk9xf4r/P3qccMYFT7jiGccD9OOEMy54whXPOB6kHyecccETrnjG8Sv6
ccIZFzzhimccD9GPE8644AlXPON4mH6ccMYFT7jiGccj9OOEMy54whXPOB6l
HyecccETrnjG8Rj9OOGMC55wxTOOx+nHCWdc8IQrnnEcpx8nnHHBE654Ps7+
f9juH/0h3/9D9p/D9vtd8ITrIf04xtYd7vGAE17hjEdc8BpPeIMr3uIZ73A8
0brDPR5wwiuc8YgLXuMJb3DFWzzjHY4nW3e4xwNOeIUzHnHBazzhDa54i2e8
w/FU6w73eMAJr3DGIy54jSe8wRVv8Yx3OJ5u3eEeDzjhFc54xAWv8YQ3uOIt
nvEOxzOtO9zjASe8whmPuOA1nvAGV7zFM97heLZ1h3s84IRXOOMRF7zGE97g
ird4xjscz7XucI8HnPAKZzzigtd4whtc8RbPeIfjRPt/ocP9ifb8ASe8whmP
uOA1nvAGV7zFM97heL51h3s84IRXOOMRF7zGE97gird4xjscL7TucI8HnPAK
Zzzigtd4whtc8RbPeIfjxdYd7vGAE17hjEdc8BpPeIMr3uIZ73C81LrDPR5w
wiuc8YgLXuMJb3DFWzzjHY5ft+5wjwec8ApnPOKC13jCG1zxFs94h+Pl1h3u
8YATXuGMR1zwGk94gyve4hnvcLzSusM9HnD6n78CuaHn7g==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1jkKJkUYBuBPI8MODAwMWhEREWn33Sn3dbQd970cddydVkcdt7GO8IMX
qNSsD2BQR/jxBHWEFozEQGQQ6aeS4uHlrTetq06fPfX+pRHx5yUR/94Xz3Yi
9ifteRke8OX4CnwlHvHV+Bp8Lb4OX49vwDfiCd+Eb8a34Fvxbfh2fAe+E9+F
78b34Hvxffh+fAKnvQuOB8hxPEiO4yFyHA+T43iEHMej5DgeI8fxODmOJ8hx
PEmO4ylyHE+T4zhJjuMZchzPkuOY90644IbjOfq44IbjFH1ccMPxPH1ccMPx
An1ccMPxIn1ccMPxEn1ccMPxMn1ccMPxCn1ccMPxKn1ccMPxGn1ccMPxOn1c
cMPxBn1ccMPxJn1ccMPxFn1ccMPxNn1ccMOR9x5xwhkXXHHDHcc77OOEMy64
4oY7jtPs44QzLrjihjuOd9nHCWdccMUNdxzvsY8TzrjgihvuON5nHyecccEV
N9xxnGEfpzPprwsf/3bul/MX/8X5TPr71z9+P3k6X3T5z8tFV/KGO+/HB+zj
hDMuuOKGO44P2ccJZ1xwxQ13HB+xjxPOuOCKG+44PmYfJ5xxwRU33HF8wj5O
OOOCK2644/iUfZxwxgVX3HDH8Rn7OOGMC6644Y7jc/ZxwhkXXHHDHcdZ9nHC
GRdcccMdx7L3gEc84YRnnPGCCz7gilfc8BF3vOH4Yu8Bj3jCCc844wUXfMAV
r7jhI+54w/Hl3gMe8YQTnnHGCy74gCteccNH3PGG46u9BzziCSc844wXXPAB
V7ziho+44w3Hub0HPOIJJzzjjBdc8AFXvOKGj7jjDcfXew94xBNOeMYZL7jg
A654xQ0fcccbjm/2HvCIJ5zwjDNecMEHXPGKGz7ijjcc3+494BFPOOEZZ7zg
gg+44hU3fMQdbzjO7z3gEU844RlnvOCCD7jiFTd8xB1vOL7be8AjnnDCM854
wQUfcMUrbviIO95wfL/3gEc84YRnnPGCCz7gilfc8BF3vOH4Ye8Bj3jCCc84
4wUXfMAVr7jhI+54w/Hj3gMe8YQTnnHGCy74gCteccNH3PGG46e9BzziCSc8
44wXXPABV7ziho+44w3Hhb0HPOIJJzzjjBdc8AFXvOKGj7jjDcfPew94xBNO
//sfdTAqvw==
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1VuoFVUcx/GVRIj0MA8iQhKTiFhGjd3MzPxbmfecczye+2WdfY5lZjqp
WV6yFRUWFU0XupjUiBloEVOZmUmstEJ6iE0vEhFNSERUsIUkujx0tv4Ptb7z
svnwX7/5r7VmZu1LautbV40xxvx+njHN33NXY64JLwk5Fo7g8fBEeBIcw5Ph
KfBUeBp8GXw5fAWcwDPgq+Cr4Wvga+Hr4Jnw9fAs+AZ4NnwjPAe+CZ4LS2gH
m3mow+Zm1GFzC+qwuRV12MxHHTa3oQ6bBfLXjjVHNz3/wLn32i2Qf/af/npZ
zel7vlCOLLpwzPSdL2p9odZzrS+S3Z/F5YbVe7S+SLb8PHXG2Ld3a31xaLdY
Zh08sfmT13dpfYlsG//Ogh+2vqD1Jbj/Up3f41pfGs7HLEN9md7vUa3fHq7H
wWY51r8c+VTH23OWFONhn2J+LVp/WfMtcvjix35pOfya5lH3sGmVi678bsoF
D+/TfKvM/n750y+te07zrci3hvthVoT7L6N+SvMrkEfdtIX9pC18Pm7Umebb
wv0wK8O6wG4l9g827aGlHe9Tu+73m5pvl2+++mPFqX1vab5Dxp3cm80Z96Hm
O6R7uLkiteuQS3ufOXZm2lHNd8i3fzYbHtd8pzS7Tzz/C813yvSdE0ZaaN11
ysbVz/62fe7nmu/U7+FTzXfJGyPdT+71mu+SX1uab4DWXZc84r/cM/+Q3s93
hf1Mt65vtH+3HGhuX3RC891y/My0kRWM9u/W53VM8z3h/aUH/Xvk1L5XR2as
430P8r3heqVX2s4GdD2uV56YZ3+sT/5Y871y9vFMOqL5Pp3vYc336XoOab5P
7/++5vv0+zuo+X7dDx0v/eHzdP36fXyg+f6wnxmQxc12Ez7S/EA4XzeA5z8Q
vh/Gyq5XmpfmY6vvh85XYGvlybU//b3/9Ht6f7iwsnRmcwal9kO+suF+mMFw
fDyoz+9d7T+oz0vvb2E3iP6Dev4e0P6D4flSDeL8qYXff1wLz2+pheedren3
XWh/jC9q4fnha+H5X2G8GUL/IZxnQ2HeDuF8Qr6A/VB43lVD+H8YDs+reBj/
B8Ni/n9Z2MEF7OEKNqtCx7DAFnZwAXu4gs0d6A8LbGEHF7CHK9jcif6wwBZ2
cAF7uILNavSHBbawgwvYwxVs7kJ/WGALO7iAPVzBZg36wwJb2MEF7OEKNnej
PyywhR1cwB6uYLMW/WGBLezgAvZwBZt70B8W2MIOLmAPV7BZh/6wwBZ2cAF7
uILNevSHBbawgwvYwxVsstARHMMJLHAKWziDHZzDBVzCHq7DFdyAzb2hIziG
E1jgFLZwBjs4hwu4hD1chyu4AZsNoSM4hhNY4BS2cAY7OIcLuIQ9XIcruAGb
jaEjOIYTWOAUtnAGOziHC7iEPVyHK7gBm02hIziGE1jgFLZwBjs4hwu4hD1c
hyu4AZv7QkdwDCewwCls4Qx2cA4XcAl7uA5XcAM2m0NHcAwnsMApbOEMdnAO
F3AJe7gOV3ADNveHjuAYTmCBU9jCGezgHC7gEvZwHa7gBmweCB3BMZzAAqew
hTPYwTlcwCXs4TpcwQ3YbAkdwTGcwAKnsIUz2ME5XMAl7OE6XMEN2GwNHcEx
nMACp7CFM9jBOVzAJezhOlzBDdhsCx3BMZzAAqewhTPYwTlcwCXs4TpcwQ3Y
bA8dwTGcwAKnsIUz2ME5XMAl7OE6XMEN2DwYOoJjOIEFTmELZ7CDc7iAS9jD
dbiCG7DZETqCYziBBU5hC2ewg3O4gEvYw3W4ghuweSh0BMdwAst//he00esL

       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdmXvMHGUVxl8JMQ0hZkKIqdCYoZKm3mCrYq219gAid9kWxPr1Nt+tX0Xs
zt7v+w1Bo0SNqygqog43sVhxbQypeGGAioBaFyUxhBiHGGOIGheFICqJO7vP
Jj7P/tP8vvOec95zec/MvD1robBz+STn3Auvci77d/obbXf8M8Y1wp7w6cJr
hdcJ+8Lrhc8W3iC8UfhNwm8RPkc4J7xJ+G3Cbxd+h/B5wu8U3iz8LuEtwu8W
3ir8HuFtwu8V3i5szJGwO1/kwu4CkQu7C0Uu7N4ncmF3kciF3ftFLuwuFrmw
u0Tkwu5SkQu7y0Qu7C4XubC7QuTC7kqRC7sPiFzYXSVyYZdnNuFIOMnbfw8/
/5srF0LMiR3gYMomHO0QfWG3U/wLR8KJsLta9IUj4UTYXSP6wpFwIuw+KPrC
kXAi7K4VfeFIOBF2HxJ94Ug4EXa7RF84Ek6E3YdFXzgSToTdnOjPWfO5DZvW
HPkM+mfOtv7hqs9++dAXppzM2QOXnnrSmz95C/pvN/otRv/ttqdPvHT1H+/+
DvR327971/24cvO3ob/bnnk5+8Od0N9jZ577+7NffcPd0N9jx17/ib/sOHYf
9PfYri0/eKz20+9BX+RuL8ttL/uL9rL9ZK/d+tXsdxj6+2yi/s17ob+P9xft
Q/x3QH8f23P7Jf798P8V6O/nfCUidwHr+wGvt4DXB7I+Eo4DqVdg7dPvu/jZ
1hennM7WR/A/z/PCn+f5YsLBPOx9HP7n2V48j/1+Cv5FPxV/boHl/gLbtwW2
F4g8Eo4XuH8TsZ8uiP9F2G/A/yLr2yLnM1iEfh/+Fzm/8Uz/Nvhf5Pqki1L/
Ja63v8T6tsT2gyWpv3C8xP2bLHG/p0t223F/UDp4O/wv8378ZZyvb8D/Ms7H
rfC/LP6XOT+x2EuWOb5U1rsDXF//ANfDDkj/HZDnm3AsnAinYt+tSP2FbUX6
b4X7PVqR/pP1yQrHm8p6d1DiPyjnTzg4aO7/f5FwLJwIp8LuI8y+sAkHwpFw
LJwIp8LuOvEvbMKBcCQcCyfCqbD7qPgXNuFAOBKOhRPhVNhdL/6FTTgQjoRj
4UQ4FXYfE//CJhwIR8KxcCKcCrtD4l/YhAPhSDgWToTTQ3L+Czzv/YI8zwv8
vA8Kdlk2zl77Q5z/gj0+no5nnPsTnP+C3Zg8cftF9z+C81+wf4ytebsex/kv
2LOtbAA8Af+hnTWexp//2y+n7IVW3HbK7+4Mf4X9hHZXmP1hOOVcaP8av119
7TjYQnvhlacaz214csr50Eb3PHr55pvAQWhrjqybW9r66ymHob1xz+cefnEj
/EUh3p8g74cWn5EFDP1Y5APxn4Q22X4H8mGI5wv009AumQQMHoUW/Gm4/pmX
TyD+Iut7RXsoS98/Z/EXOR+5Iutb0bzJBsF50Q9kfVi0KzbfdP74b4i/iHqD
+6Ifi/9BEfUGJ0W74UsXfvr6P/8C8Re5HmmR8z+SeF1J6l/ifPslm66b1V/k
VuJ652V9ULLXnXzta956FPsNS3i+Ix9RybLdbD8P3C9x/WKRD2S/ScmuydrB
h79hifsnlf2OSpxfV5b6ly0/flqediPs+WX2lyvb5Liuw/mxsj25PnvjgTxf
5voEZe73sGybJgVBvaIyn8e+2IvL3D+Dsk26Zz30E7E3LHO+0jLen2B/JPtz
Fe5fr8L+fJHnKlxPq3B/5SvS/xWOLxR7UYX7u1/heRNXuL8HFbtgskHMs6TC
8Q0rnO+0wvGORO6qeD+FPa/K+fSrlk3bp0/8HPFXOR6r4nsT6/NV7pdAOKzy
fqMq17Nf5fMRy/4GVcz/WfxV7sdh1Y5+/e/jE4n9prLfkfhzNa6fV+N4/Brb
z9XYv9Xs3mx8eY8h/hrHF8j6sIbn2c8Qfw3v548i/pr9dUeWgYcQfw3zMkH8
Nbt5bdaADyP+mv02e7xtOY74RZ7WMA9hbyTs6ug32PfqLPfrNin/S3ie5uqW
deu2U5Bfq9vOScFm8df5eRvUOb6wLvHX8X6O/fbrNhlnA3Bcx/cU/A9EP6nb
HePT9spT8D+s2xsmCshHWrfyZCBg/ahup01eELAf1+B+8Rq8X1841+B4rcH5
yDfYftDg/ggbPN+iBvdLv4H3odn8a/B5HDRk/sn6YYP7PRX/o4YtTAbQLP4m
x+M1OR6/aY+8uHE8MZC/XNPGh2VcsVn9m5y/fFPq35T+F/2oyfXpN7m+cZP3
O2jyPEiaHO+wyflJmzw/R00+364l86/F/vwWx5drSfwtji8v9gKRhy2uR9Ti
ed4X+7H4H4j9RORD2X/a4nyOWjxfXJvPt9eW89/m+ZNr433iQcTfxvMQ79/5
NvL7I8TfRrzHEH8b7//gqI35+gDib2MeHEX8beTjHsTf5u+DpM33KUNZn7b5
PmbUxvf/XYi/w/a8Dt//+B3+/sh15L5S5PkO8jVA/MJhx8bN+J/DzyO+qIN6
fB/xdyzLztqT70f8Hb5fHcz2dwTxdzhfww7q8V3E3+H72lFH7l+7fF/kdeU+
rMvfZ7ku36dYl+9j8l3+vguEwy7fp0Rdvo/pi/24y/d9g67c74j9oew/FR5J
vK7Hcq/H/eL3uL9yPda3HvdLvsf9FPQ4nrAn95c93n+/x/mJhQc9uV/rcf6G
sr90Ft+3EH+P/3/ArXK/eKuYnzi//iqf79wq/GMe2Crenx7c/j+3yozK
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DnKLkUYBeBXI8MODAwMWhEREWnn2VvOs7bzrOWv11lvO89aS/iWUKlZ
L6GW0LiCWkILhgYiBtJPJcXD4XCSgoa+4uzCc+cvjoi/Lor49/7v7OfieNKR
l+ABX4ovw5fjEV+Jr8JX42vwtfg6fD2e8A34RnwTvhnfgm/Ft+Hb8R34TnwX
vhvfg+/F53A6uuC4jxzH/eQ4HiDH8SA5jofIcTxMjuMRchyPkuN4jBzH4+Q4
niDH8SQ5jqfIcTxNjuMZchzz0QkX3HA8Sx8X3HA8Rx8X3HA8Tx8X3HC8QB8X
3HC8SB8X3HC8RB8X3HC8TB8X3HC8Qh8X3HC8mv7+/c8/njrL/3030qv0ccPx
Gvu44Ibjdfq44IbjDfq44IbjTfq44IbjLfq44Ibjbfq44IYjHz3ihDMuuOKG
O4532McJZ1xwxQ13HGfs43R2fN+ZvOCKG+443mUfJ5xxwRU33HG8xz5OOOOC
K2644zjPPk4444IrbrjjeJ99nHDGBVfccMfxAfs44YwLrrjhjuND9nHCGRdc
ccMdx0fs44QzLrjihjuOj9nHCWdccMUNdxyfsI8TzrjgihvuOD5lHyecccEV
N9xxfMY+TjjjgituuOP4nH2ccMYFV9xwx3GBfZxwxgVX3HDHsRw94BFPOOEZ
Z7zggk+44hU3vOGOdxxfHD3gEU844RlnvOCCT7jiFTe84Y53HF8ePeARTzjh
GWe84IJPuOIVN7zhjnccXx094BFPOOEZZ7zggk+44hU3vOGOdxxfHz3gEU84
4RlnvOCCT7jiFTe84Y53HN8cPeARTzjhGWe84IJPuOIVN7zhjncc3x494BFP
OOEZZ7zggk+44hU3vOGOdxzfHT3gEU844RlnvOCCT7jiFTe84Y53HN8fPeAR
TzjhGWe84IJPuOIVN7zhjnccPxw94BFPOOEZZ7zggk+44hU3vOGOdxw/Hj3g
EU844RlnvOCCT7jiFTe84Y53HD8dPeARTzjhGWe84IJPPx3/N1XyFTe84Y53
HD8fPeARTzjhGWe84IJPuOIVN7zhjnccvxw94BFPOOEZZ7zggk+44hU3vOGO
dxy/Hj3gEU844RlnvOCCT7jiFTe84Y53HL8dPeARTzj9738AUzghnQ==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DcO7kQUBeALFaULCgoKgxBCCCGTMww5PjCPnIdHjs/ER2aW4CVMS+cl
zBJ+sYJZgpEoKRACCfm7zejT0dHp54pz58++d3FE/HlRxD/vv7ffF8dLR16C
B3wpvgxfjkd8Jb4KX42vwdfi6/D1eMI34BvxTfhmfAu+Fd+Gb8d34DvxXfhu
fA++F9+H09EFx/3kOB4gx/EgOY6HyHE8TI7jEXIcj5LjeIwcx+PkOJ4gx/Ek
OY6nyHGcIcfxNDmOZ8hxzEcnXHDD8Sx9XHDDcZY+LrjheI4+LrjheJ4+Lrjh
eIE+LrjheJE+LrjheIk+LrjheJk+LrjheIU+LrjheJU+LrjheI0+LrjheJ0+
LrjheIM+LrjheJM+LrjheIs+LrjhyEePOOGMC6644Y7jbfZxwhkXXHHDHcc5
9nHCGRdcccMdxzvs44QzLrjihjuOd9nHCWdccMUNdxzvsY8TzrjgihvuON5n
HyecccEVN9xxfMA+TjjjgituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO42P2
ccIZF1xxwx3HJ+zjhDMuuOKGO45P2ccJZ1xwxQ13HJ+xjxPOuOCKG+44Pmcf
J5xxwRU33HGcZx8nnHHBFTfccSxHD3jEE054xhkvuOAVV7zhhk+44x3HF0cP
eMQTTnjGGS+44BVXvOGGT7jjHceXRw94xBNOeMYZL7jgFVe84YZPuOMdx1dH
D3jEE054xhkvuOAVV7zhhk+44x3H10cPeMQTTnjGGS+44BVXvOGGT7jjHcc3
Rw94xBNOeMYZL7jgFVe84YZPuOMdx7dHD3jEE054xhkvuOAVV7zhhk+44x3H
haMHPOIJJzzjjBdc8Ior3nDDJ9zxfiH99dsfv585l//75//umA94xBNOeMYZ
L7jgFVe84YZPuOMdx/dHD3jEE054xhkvuOAVV7zhhk+44x3HD0cPeMQTTnjG
GS+44BVXvOGGT7jjHcePRw94xBNOeMYZL7jgFVe84YZPuOMdx09HD3jEE054
xhkvuOAVV7zhhk+44x3Hz0cPeMQTTnjGGS+44BVXvOGGT7jjHccvRw94xBNO
eMYZL7jgFVe84YZPuOMdx69HD3jEE07/+28nBRgx
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2TcO5kQYBuAPKkoXFBQUBiGEEEImZ3bIGcyS87CwZFiTM8wRfIRp6f4j
zBEsTjBHMBIlBUJbID9fM3r06tV7gLnq3IWz5y+NiL8vifjvvXj7mTheOvIy
PODL8RX4Sjziq/E1+Fp8Hb4e34BvxBO+Cd+Mb8G34tvw7fgOfCe+C9+N78H3
4vvw/fgMTkcXHA+Q43iQHMdD5DgeJsfxCDmOR8lxPEaO43FyHE+Q43iSHMdT
5DieJsfxDDmOZ8lxPEeOYz464YIbjufp44IbjrP0ccENxwv0ccENx4v0ccEN
x0v0ccENx8v0ccENxyv0ccENx6v0ccENx2v0ccENx+v0ccENxxv0ccENx5v0
ccENx1v0ccENx9v0ccENxzv0ccENRz56xAlnXHDFDXcc77KPE8644Iob7jjO
sY8TzrjgihvuON5jHyecccEVN9xxvM8+TjjjgituuOM4zz5OOOOCK2644/iA
fZxwxgVX3HDH8SH7OOGMC6644Y7jI/ZxwhkXXHHDHcfH7OOEMy644oY7jk/Y
xwlnXHDFDXccn7KPE8644Iob7jg+Yx8nnHHBFTfccXzOPk4444Irbrjj+IJ9
nHDGBVfccMdxgX2ccMYFV9xwx7EcPeARTzjhGWe84IJXXPEJN7zhjnccXx49
4BFPOOEZZ7zggldc8Qk3vOGOdxxfHT3gEU844RlnvOCCV1zxCTe84Y53HF8f
PeARTzjhGWe84IJXXPEJN7zhjncc3xw94BFPOOEZZ7zggldc8Qk3vOGOdxzf
Hj3gEU844RlnvOCCV1zxCTe84Y53HN8dPeARTzjhGWe84IJXXPEJN7zhjncc
3x894BFPOOEZZ7zggldc8Qk3vOGOdxw/HD3gEU844RlnvOCCV1zxCTe84Y53
HD8ePeDxx/TPH3/9+cy5fPFfZCJPeMYZL7jgFVd8wg1vuOMdx09HD3jEE054
xhkvuOAVV3zCDW+44x3Hz0cPeMQTTnjGGS+44BVXfMINb7jjHccvRw94xBNO
eMYZL7jgFVd8wg1vuOMdx69HD3jEE054xhkvuOAVV3zCDW+44x3Hb0cPeMQT
TnjGGS+44BVXfMINb7jjHcfvRw94xBNO//tfjosYMQ==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1TcO5kQYBuAPKkoXFBQUBiGEEEImZ3bIGUyOC8PCkmFNzjBH8BGmpfMR
5gi/OMEcwUiUFAhtgfx8zejRq1dvOVedu/DC+Usj4u9LIv57L95+Jo6XjrwM
D/hyfAW+Eo/4anwNvhZfh6/HN+Ab8YRvwjfjW/Ct+DZ8O74D34nvwnfje/C9
+D58Pz6D09EFxwPkOB4kx/EQOY6HyXE8Qo7jUXIcj5HjeJwcxxPkOJ4kx/EU
OY6nyXE8Q47jWXIcz5HjmI9OuOCG43n6uOCG4wX6uOCG40X6uOCG4yX6uOCG
42X6uOCG4xX6uOCG41X6uOCG4zX6uOCG43X6uOCG4w36uOCG4036uOCG4y36
uOCG4yx9XM6mf/74689nzuWL/2ojj7fp44Ibjnfo44Ibjnz0iBPOuOCKG+44
3mUfJ5xxwRU33HGcYx8nnHHBFTfccbzHPk4444IrbrjjeJ99nHDGBVfccMdx
nn2ccMYFV9xwx/EB+zjhjAuuuOGO40P2ccIZF1xxwx3HR+zjhDMuuOKGO46P
2ccJZ1xwxQ13HJ+wjxPOuOCKG+44PmUfJ5xxwRU33HF8xj5OOOOCK2644/ic
fZxwxgVX3HDH8QX7OOGMC6644Y7jAvs44YwLrrjhjmM5esAjnnDCM854wQWv
uOINN3zCHe84vjx6wCOecMIzznjBBa+44g03fMId7zi+OnrAI55wwjPOeMEF
r7jiDTd8wh3vOL4+esAjnnDCM854wQWvuOINN3zCHe84vjl6wCOecMIzznjB
Ba+44g03fMId7zi+PXrAI55wwjPOeMEFr7jiDTd8wh3vOL47esAjnnDCM854
wQWvuOINN3zCHe84vj96wCOecMIzznjBBa+44g03fMId7zh+OHrAI55wwjPO
eMEFr7jiDTd8wh3vOH48esAjnnDCM854wQWvuOINN3zCHe84fjp6wCOecMIz
znjBBa+44g03fMId7zh+PnrAI55wwjPOeMEFr7jiDTd8wh3vOH45esAjnnDC
M854wQWvuOINN3zCHe84fj16wCOecMIzznjBBa+44g03fMId7zh+O3rAI55w
wjPOeMEFr7jiDTd8wh3vOH4/esAjnnD63/8CMfcYMQ==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2TcO50QcBeAfVJQuKCgoDEIIIYRMzuyQ44JZch6WnE1mlzRH8BGmpfsf
YY5gcYI5gpEoKRCiQP6mGX168/Tc+6rzX557/9KI+OuSiH/v/85+Jo4nHXkZ
HvDl+Ap8JR7x1fgafC2+Dl+Pb8A34gnfhG/Gt+Bb8W34dnwHvhPfhe/G9+B7
8X34fnwGp6MLjgfIcTxIjuMhchwPk+N4hBzHo+Q4HiPH8Tg5jifIcTxJjuMp
chxPk+M4S47jGXIcz5LjmI9OuOCG4zn6uOCG4xx9XHDD8Tx9XHDD8QJ9XHDD
8SJ9XHDD8RJ9XHDD8TJ9XHDD8Qp9XHDD8Sp9XHDD8Rp9XHDD8Tp9XHDD8QZ9
XHDD8SZ9XHDD8RZ9XHDD8TZ9XHDDkY8eccIZF1xxwx3HO+zjhDMuuOKGO47z
7OOEMy644oY7jnfZxwlnXHDFDXcc77GPE8644Iob7jjeZx8nnHHBFTfccXzA
Pk4444Irbrjj+JB9nHDGBVfccMfxEfs44YwLrrjhjuNj9nHCGRdcccMdxyfs
44QzLrjihjuOT9nHCWdccMUNdxyfsY8TzrjgihvuOD5nHyecccEVN9xxfME+
TjjjgituuOP4kn2ccMYFV9xwx7EcPeARTzjhGWe84IJXXPEJN7zhjnccXx09
4BFPOOEZZ7zggldc8Qk3vOGOdxxfHz3gEU844RlnvOCCV1zxCTe84Y53HN8c
PeARTzjhGWe84IJXXPEJN7zhjncc3x494BFPOOEZZ7zggldc8Qk3vOGOdxzf
HT3gEU844RlnvOCCV1zxCTe84Y53HN8fPeARTzjhGWe84IJXXPEJN7zhjncc
Pxw94BFPOOEZZ7zggldc8Qk3vOGOdxw/Hj3gEU844RlnvOCCV1zxCTe84Y53
HBeOHvCIJ5zwjDNecLmQ/v79zz/Ons///XdZceX9CTe84Y53HBePHvCIp4vH
70vkM854wQWvuOITbnjDHe84fjp6wCOecMIzznjBBa+44hNueMMd7zh+PnrA
I55wwjPOeMEFr7jiE254wx3vOH45esAjnnDCM854wQWvuOITbnjDHe84fj16
wCOecMIzznjBBa+44hNueMMd7zh+O3rAI55w+t//AKTaIZ0=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd01vIFlUUxvGVFyHSxVxIBElMImIHauxsZi7PZx21o1ntTMvMdDIzD2Ur
KCoiGigIQmp3RpOYysxMYhNdBEEM3UREtCMioi5GKqIT1Ff7I/Z/bj5+rO95
nzX73e/p67au2jBGRH4+QWTk73/PMFPyR3OOhQv9fe+mY9uf3Jly4/XP/cc/
XbbOJZ8CT9A9419f8PXuB5PL5KeSJ+q0Qx/teP+5Z5InwZP1809+Xf3Ny68l
T9Gji04ac9bDrySfqbu+nzx17MGDyWfrjyuPnPbQD28kn5P6DiVXOu6zF5sZ
495Jnpre50jyefrY5u/+2H/8zeTzdfFI3cnvJl+gX/w2Engr+ULd92HZbds4
2ncRfLGuWT/9qxWPj/Zdov+uO+Fo8jQ99dwvJ534wNvJl6b3O5w8HfnL9NFZ
7tt+4nvJM/TAyHEXo/tfjn1nok/z8zDFfFY6/2SbpWesfeKDX6YcS/PZ+s+H
//OVpPe32dh3Dj5/Dvafqx8/P+/wT3+NzufqyPTpLaPnPS8/P5uH73d+2u9A
ms/HeS/I74stSP2vpvnC/P7YwrTvS2m+KO3zQpovwv1bjPzi/P9lSdp3X5ov
wX1eqiO3c+WRZ9N8abp/j6T5svz3Zcvwe1qe25arZM+K3AZLnVthgwMsK5GH
DQ6wrEIeNjjAshp52OAAyxXIwwYHWK5EHjY4wHIV8rDBAZarkYcNDrBcgzxs
cIDlWuRhgwMsa5CHDQ6wXIc8bHCAZS3ysMEBluuRhw0OsNyAPGxwgOVG5GGD
Aywudwkr7GCDPRzgCMtN6IcVdrDBHg5whGUd+mGFHWywhwMcYbkZ/bDCDjbY
wwGOsKxHP6ywgw32cIAjLBvQDyvsYIM9HOAIyy3ohxV2sMEeDnCE5Vb0wwo7
2GAPBzjCshH9sMIONtjDAY6w3IZ+WGEHG+zhAEdYNqEfVtjBBns4wBGW29EP
K+xggz0c4AjLZvTDCjvYYA8HOMJyB/phhR1ssIcDHGHZgn5YYQcb7OEAR1i2
oh9W2MEGezjAEZYmdwGXcAUrXMMObmCDW9jDHRzgHo7wAMuduQu4hCtY4Rp2
cAMb3MIe7uAA93CEB1i25S7gEq5ghWvYwQ1scAt7uIMD3MMRHmC5K3cBl3AF
K1zDDm5gg1vYwx0c4B6O8ADL9twFXMIVrHANO7iBDW5hD3dwgHs4wgMsd+cu
4BKuYIVr2MENbHALe7iDA9zDER5g2ZG7gEu4ghWuYQc3sMEt7OEODnAPR3iA
5Z7cBVzCFaxwDTu4gQ1uYQ93cIB7OMIDLDtzF3AJV7DCNezgBja4hT3cwQHu
4QgPsOzKXcAlXMEK17CDG9jgFvZwBwe4hyM8wLI7dwGXcAUrXMMObmCDW9jD
HRzgHo7wAMue3AVcwhWscA07uIENbmEPd3CAezjCAyz35i7gEq5ghWvYwQ1s
cAt7uIMD3MMRHmC5L3cBl3AFK1zDDm5gg1vYwx0c4B6O8ADL3twFXMIVrHAN
O7iBDW5hD3dwgHs4wgMs9+cu4BKuYP3ffwP4oPIy
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2F/oFFUUwPGT+CARMQ8SPkhMfxDpH2NWZmYeSzNNc35aZmZ1My0z08l0
1z+787tQUVHRktEfk7qVQoLUBGJSUTe1sB5i6SWihyYkIuphiyL689D+3LvE
/c7L8uHMueeeneXc3T1nzeZl68aJyO+niYy9Dq7eHIkvjTkBTuCJ8CR4MpzC
58Lnw1PgqfAF8EXwJXAGT4MvhafDl8GXw1fAM+Ar4ZnwVfAs+Gp4NnwNPAfW
2BaWuYjDci3isFyHOCzzEIdlPuKwXI84LAsQh+UGxGFZiDgsixCH5UbEYVmM
OCxLEIflJsRhWYo4LHlshS3sYRlBPmxhD8sy5MMW9rAsRz5sYQ/LzciHLexh
uQX5sIU9LCuQD1vYw3Ir8mELe1hWIh+2sIflNuTDFvawrEI+bGEPy+3Ihy3s
YVmNfNjCHpY7kA9b2MNyJ/JhC3tY7kI+bGEPi4mdwgob2MIO9nANy92oDyts
YAs72MM1LGtQH1bYwBZ2sIdrWO5BfVhhA1vYwR6uYVmL+rCu1X8P/PrVkjVm
8L3QIG5hB3u4hmUd6sMKG9jCDvZwDcu9qA8rbGALO9jDNSz3oT6ssIEt7GAP
17CsR31YYQNb2MEermG5H/VhhQ1sYQd7uIZlA+rDChvYwg72cA3LA6gPK2xg
CzvYwzUsG1EfVtjAFnawh2tYHkR9WGEDW9jBHq5h2YT6sMIGtrCDPVzDshn1
YYUNbGEHe7iGpYidwCmcwQrnsIEL2MId2MEV7OEuXMM9WB6KncApnMEK57CB
C9jCHdjBFezhLlzDPVi2xE7gFM5ghXPYwAVs4Q7s4Ar2cBeu4R4sD8dO4BTO
YIVz2MAFbOEO7OAK9nAXruEeLFtjJ3AKZ7DCOWzgArZwB3ZwBXu4C9dwD5Zt
sRM4hTNY4Rw2cAFbuAM7uII93IVruLctfJ8vwv+8Dd018e0F3+98dOCkEcdT
OIO1Ef8+yBv6d7nhw627t4ffC0M/MXCBuB3mdwbu4H6H/VUNPXL2Yz+PHHl1
YA93Gzrru6XPvLjpjYFruDdcb1/ovxnHk2bYjwv9N3XmoRONj17bE/pvhv29
FPpv6vsLzxh34eMvhP4RN8P1nwv9N+P+bFN3/DRl2oSDT4f+m/H74bB+hXw/
vN+G/pvx86mb8fPpNePPg2yPncApnMEK57CBC9jCHdjBFezhLlzDPVh2xE7g
FM5ghXPYwAVs4Q7s4Ar2cBeu4R4sO2MncApnsMI5bOACtnAHdnAFe7gL13AP
ll2xEziFM1jhHDZwAVu4Azu4gj3chWu4B0srdgKncAYrnLcw/1vxfCoQty3M
/1aYz8+H+deK53vViuezH673Vph/LV0848m55ocqzL/heofC/GvpN1/+ufzk
/g/C/G/r7knjV5x58dEw/9s6ttqk8Z+F+d/W3/rVkpWfh/nf1mWnNnQizP+2
Lhobz2eFeN7WY39MXf3s0U9D/20979u/+js8Hvpvh/0E27b2F+8fMaFep62P
+C9en3/4WOgf+RX259vaL95vKdzfbeu+YvbpX7/pQ/9tnffUxh//OfBJ6B/1
pQzn07D/UqefusJ6aakn979yPK1CPCt1wsHJq9bO+jj0X+refnTL+rB+Xsbv
p0G8KHXlqQM15FvEO2U47w6H/kvtN9Pv6L3Qfxk/T1+Gz0N43t1SfxkZe0Dv
hv6H9d4J/Ze65+Wx60DofzR2Mhqf9+lofP5mo+G83hv6/9//ASt4XHQ=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1zcO5kQYBuAPKkoXFBQUBiGEEEImZ3bIccEsOQ9LjmtyhjmCjzAtnY8w
R/jFCeYIRqKkQGgL5OdrRo9evXrruer8hXPvXxoRf18S8d978fYzcbx05GV4
wJfjK/CVeMRX42vwtfg6fD2+Ad+IJ3wTvhnfgm/Ft+Hb8R34TnwXvhvfg+/F
9+H78Rmcji44HiDH8SA5jofIcTxMjuMRchyPkuN4jBzH4+Q4niDH8SQ5jqfI
cTxNjuMsOY5nyHE8S45jPjrhghuO5+jjghuOc/RxwQ3H8/RxwQ3HC/RxwQ3H
i/RxwQ3HS/RxwQ3Hy/RxwQ3HK/RxwQ3Hq/RxwQ3Ha/RxwQ3H6/RxwQ3HG/Rx
wQ3Hm/RxwQ3HW/RxwQ3H2/RxwQ1HPnrECWdccMUNdxzvsI8TzrjgihvuOM6z
jxPOuOCKG+443mUfJ5xxwRU33HG8xz5OOOOCK26443iffZxwxgVX3HDH8QH7
OOGMC6644Y7jQ/ZxwhkXXHHDHcdH7OOEMy644oY7jo/ZxwlnXHDFDXccn7CP
E8644Iob7jg+ZR8nnHHBFTfccXzGPk4444Irbrjj+Jx9nHDGBVfcPk///PHX
n2fP54v/2k4eX7CPE8644Iob7jgusI8TzrjgihvuOJajBzziCSc844wXXPCK
K95wwyfc8Y7jy6MHPOIJJzzjjBdc8Ior3nDDJ9zxjuOrowc84gknPOOMF1zw
iivecMMn3PGO4+ujBzziCSc844wXXPCKK95wwyfc8Y7jm6MHPOIJJzzjjBdc
8Ior3nDDJ9zxjuPbowc84gknPOOMF1zwiivecMMn3PGO47ujBzziCSc844wX
XPCKK95wwyfc8Y7j+6MHPOIJJzzjjBdc8Ior3nDDJ9zxjuOHowc84gknPOOM
F1zwiivecMMn3PGO48ejBzziCSc844wXXPCKK95wwyfc8Y7jp6MHPOIJJzzj
jBdc8Ior3nDDJ9zxjuPnowc84gknPOOMF1zwiivecMMn3PGO45ejBzziCSc8
44wXXPCKK95wwyfc8Y7j16MHPOIJJzzjjBdc8Ior3nDDJ9zxjuO3owc84gkn
POOMF1zwiivecMMn3PGO4/ejBzziCaf//S/a2xgx
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1zcOJzUcBeAfVJRTUFBQDAghhBAacgaT48Kw5GyWHHfIsCQfYY7glm6O
4CP8xQl8hEGipEBoCzSfG+vT09Nr7avOnT/7waUR8fclEf/dF8/+QBxPOvIy
PODL8RX4Sjziq/E1+Fp8Hb4e34BvxBO+Cd+Mb8G34tvw7fgOfCe+C9+N78H3
4vvw/fgBnI4uOB4kx/EQOY6HyXE8Qo7jUXIcj5HjeJwcxxPkOJ4kx/EUOY6n
yXE8Q47jDDmOZ8lxPEeOYz464YIbjufp44IbjrP0ccENxwv0ccENx4v0ccEN
x0v0ccENx8v0ccENxyv0ccENx6v0ccENx2v0ccENx+v0ccENxxv0ccENx5v0
ccENx1v0ccENx9v0ccENxzv0ccENRz56xAlnXHDFDXcc77KPE8644Iob7jjO
sY8TzrjgihvuON5jHyecccEVN9xxvM8+TjjjgituuOP4gH2ccMYFV9xwx/Eh
+zjhjAuuuOGO4yP2ccIZF1xxwx3Hx+zjhDMuuOKGO45P2McJZ1xwxQ13HJ+y
jxPOuOCKG+44PmMfJ5xxwRU33HF8zj5OOOOCK2644/iCfZxwxgVX3HDH8SX7
OOGMC6644Y7jPPs4nU///PHXn2fOLRf/5Zm84Iob7jiWowc84gknPOOMF1zw
iivecMMn3PGO46ujBzziCSc844wXXPCKK95wwyfc8Y7j66MHPOIJJzzjjBdc
8Ior3nDDJ9zxjuObowc84gknPOOMF1zwiivecMMn3PGO49ujBzziCSc844wX
XPCKK95wwyfc8Y7ju6MHPOIJJzzjjBdc8Ior3nDDJ9zxjuP7owc84gknPOOM
F1zwiivecMMn3PGO44ejBzziCSc844wXXPCKK95wwyfc8Y7jx6MHPOIJJzzj
jBdc8Ior3nDDJ9zxjuOnowc84gknPOOMF1zwiivecMMn3PGO48LRAx7xhBOe
ccYLLnjFFW+44dOF43u5k+84fj56wCOecMIzznjBBa+44g03fMId7zh+OXrA
I55wwjPOeMEFr7jiDTd8wh3vOH49esAjnnDCM854wQWvuOINN3zCHe84fjt6
wCOecMIzznjBBa+44g03fMId7zh+P3rAI55w+t//ApXwHQc=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2U3obGUdB/BfEiIicRYSiiEnERFNHcvSNPMxtWu+jnpT86Y+3nzP9Pia
ervzf4JEQYQBFy6UOCR3IZgc3GjY4tFcy+BGQqQjLiTcjCCE5iJ05gbnM5vh
w5fvfOecgcOZme/uve/q2w6JiM++EfHV8+axPi+mjzTlYbjBR+Kj8Hdwi4/D
x+MT8In4JPw9fCqe4dPx9/EP8Bn4h/hH+Ex8Fv5x+vKlT9+9fG/efg5nk5+D
f4LPxT/F5+E0dcFxPjmOn5HjuIAcx4XkOC4ix/Fzchy7yHFcTI7jF+Q4LiHH
cSk5jsvIcVxOjuMKchxXkuOYT51wwRXHVfRxwRXH1fRxwRXHNfRxwRXHbvq4
4Irjl/RxwRXHtfRxwRXHdfRxwRXH9fRxwRXHr+jjgiuOG+jjgiuOPdvrZbe5
XqY90+tn2UMfx6/ZxwVXHDfSxwVXHDfRxwVXHDfTxwVXHHnqFiecccE9rnjE
cQv7OOGMC+5xxSOOvezjhDMuuMcVjzh+wz5OOOOCe1zxiONW9nHCGRfc44pH
HLexjxPOuOAeVzziuJ19nHDGBfe44hHHHezjhDMuuMcVjzjuZB8nnHHBPa54
xHEX+zjhjAvuccUjjrvZxwlnXHCPKx5x/JZ9nHDGBfe44hHHPezjhDMuuMcV
jzh+xz5OOOOCe1zxiONe9nHCGRfc44pHHPexjxPOuOAeVzzi6KZucItnOOE5
zrjDBS9xjwdc8QqPeI3j/qkb3OIZTniOM+5wwUvc4wFXvMIjXuN4YOoGt3iG
E57jjDtc8BL3eMAVr/CI1zgenLrBLZ7hhOc4Pzj9ftKRF7zEPR5wxSs84jWO
h6ZucItnOOE5zrjDBS9xjwdc8QqPeI3j4akb3OIZTniOM+5wwUvc4wFXvMIj
XuN4ZOoGt3iGE57jjDtc8BL3eMAVr/CI1zh+P3WDWzzDCc9xxh0ueIl7POCK
V3jEaxyPTt3gFs9wwnOccYcLXuIeD7jiFR7xGsdjUze4xTOc8Bxn3OGCl7jH
A654hUe8xvH41A1u8QwnPMcZd7jgJe7xgCte4RGvceybusEtnuGE5zjjDhe8
xD0ecMUrPOI1jj9M3eAWz3DCc5xxhwte4h4PuOIVHvEax/6pG9ziGU54jjPu
cMFL3OMBV7zan75Y3P33h559dHO/Oe5P+458ZdeHj/9p4/XB/Knt/4uL9Pqx
T3xy1et/3rhZpHP+deUzz937l43bRTr6m9d+65RX/7rx7GD+6vb39sX2/nbY
eL5Ih7/3Ynfu4a9tnBfpn+/855qPDryxvf9dpEuOOOTkJ7/9t+3v8wf7dePl
Ij19z8f/fenTtzbuD+5tPSzS+59/dQD/2Lgu0oVfF97ceLVIL7zdDg/cufW4
SLs/OvD82+329de8n9iZHk+zk4457YPjD/3jge3x76TH/n3C6Ye9/ML2+Hem
5zft/P/8/g8eVojY
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.843, 0.36100000000000004`, 0.337], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd13+MHVUVwPFLYwghxkwMIQQJGQshCCiDilh+2NPS8ht5LYiFbrd33+7b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       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.008333333333333333], Thickness[Large], LineBox[CompressedData["
1:eJxdmXusXFUVxrcNIY0xZkIaUrHqUBGJiEzFWmutXX3T99x7+7i9vb0997Zo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       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.008333333333333333], Thickness[Large], LineBox[CompressedData["
1:eJxd13usXEUdwPGREEMIMRtCTK0Ej5UgPlnEWmvF/nhUHqWwbREr1nqsve97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       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd00sPHlMABuCjKwuLWVhYWAyRRhCZulfRo6rVm466q8tR6lK0g6Ja6iwk
LEgmCImNs5WIfAsrETlLyy/+gLG0G4mVWIj0S2Se2UyevHnnzZzMXHHs1JHj
W0IIf10Uwn/3C9e8MyyvuOTFuMGX4svw5bjFV+Kr8FZ8Nb4GX4evxx3ehm/A
N+Kb8M34Fnwrvg1vx7fjHfgOfCe+C+/EcemMw93kOOwi3xX/+fbPXw8dGzbf
0T3x7/Mnfjr9+ccXnO+J7/6xddvF332yyXeT7970x01+bzx36fd7fz/7xSbH
YQ/5nrjjt8OffnXys02+d+m8l+ffF3/cd8mWaz/6cpPjsC9u/+GXt3/+5utN
vo/n79/sf7jJ9y/fJxzY+MwmP8D5HNw4bfKDnO8hzheH+8lxOEyOQ790xBlX
HB6gjzOuOByhjzOuODxIH2dccXiIPs644vAwfZxxxeER+jjjisOj9HHGFYfH
6OOMKw6P08cZVxyeoI8zrjgcpY8zrkf5/56kjzOuODxFH2dccXiaPs644vAM
fZxxxSEt3eKIE8644IonHJ5lH0eccMYFVzzhcIx9HHHCGRdc8YTDc+zjiBPO
uOCKJxyeZx9HnHDGBVc84XCcfRxxwhkXXPGEwwvs44gTzrjgiiccXmQfR5xw
xgVXPOHwEvs44oQzLrjiCYeX2ccRJ5xxwRVPOJxgH0eccMYFVzzh8Ar7OOKE
My644gmHV9nHESecccEVTzi8xj6OOOGMC654wuEk+zjihDMuuOIJh1Ps44gT
zrjgiicchqUb3OIOR9zjhAec8YgLXuGK13jCMw6vL93gFnc44h4nPOCMR1zw
Cle8xhOecXhj6Qa3uMMR9zjhAWc84oJXuOI1nvCMw5tLN7jFHY64xwkPOOMR
F7zCFa/xhGccTi/d4BZ3OOIeJzzgjEdc8ApXvMYTnnF4a+kGt7jDEfc44QFn
POKCV7jiNZ7wjMPbSze4xR2OuMcJDzjjERe8whWv8YRnHN5ZusEt7nDEPU54
wBmPuOAVrniNJzzjcGbpBre4wxH3OOEBZzzigle44jWe8IzDu0s3uMUdjrjH
CQ844xEXvMIVr/GEZxzOLt3gFnc44h4nPOCMR1zwCle8xhOecTi3dINb3OGI
e5zwgDMeccErXPEaT3jG4b2lG9ziDkfc44QHnPGIC17hitd4wjMO7y/d4BZ3
OOIeJzzgjEdc8ApXvMYTnnE4v3SDW9zhiHuc8IAzHnHBK1zxGk94xuGDpRvc
4g7H//0vcHRo1A==
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2TcOJzUcBeAfVJRTUFBQDAghhBAacmZNjgvDkrNZch4yS1h8hDmCW7r/
EXyEESfwEQaJkgIhCjSfG+vT09Pr3Piq81+ee//SiPjrkoh/7//OfiaOJx15
GR7w5fgKfCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfg
e/F9+H58BqejC44HyHE8SI7jIXIcD5PjeIQcx6PkOB4jx/E4OY4nyHE8SY7j
KXIcT5PjOEuO4xlyHM+S45iPTrjghuM5+rjghuMcfVxww/E8fVxww/ECfVxw
w/EifVxww/ESfVxww/EyfVxww/EKfVxww/EqfVxww/EafVxww/E6fVxww/EG
fVxww/EmfVxww/EWfVxww/E2fVxww5GPHnHCGRdcccMdxzvs44QzLrjihjuO
8+zjhDMuuOKGO4532ccJZ1xwxQ13HO+xjxPOuOCKG+443mcfJ5xxwRU33HF8
wD5OOOOCK2644/iQfZxwxgVX3HDH8RH7OOGMC6644Y7jY/ZxwhkXXHHDHccn
7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHBFTfccXzB
Pk4444Irbrjj+JJ9nHDGBVfccMexHD3gEU844RlnvOCCV1zxCTe84Y53HF8d
PeARTzjhGWe84IJXXPEJN7zhjnccXx894BFPOOEZZ7zggldc8Qk3vOGOdxzf
HD3gEU844RlnvOCCV1zxCTe84Y53HN8ePeARTzjhGWe84IJXXPEJN7zhjncc
3x094BFPOOEZZ7zggldc8Qk3vOGOdxzfHz3gEU844RlnvOCCV1zxCTe84Y53
HD8cPeARTzjhGWe84IJXXPEJN7zhjnccPx494BFPOOEZZ7zggldc8Qk3vOGO
dxwXjh7wiCec8IwzXnDBK674hBvecL+Q/v79zz/Ons///evs5PHT0QMe8YQT
nnHGCy54xRWfcMMb7njH8fPRAx7xhBOeccYLLnjFFZ9wwxvueMfxy9EDHvGE
E55xxgsueMUVn3DDG+54x/Hr0QMe8YQTnnHGCy54xRWfcMMb7njHcfHoAY94
wgnPF4/vTSZfcMErrviEG95wxzuO344e8IgnnP73P4pSHOc=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1zmuHUUYBeAfIsIOCAgIGoQQQgg184yLeTQ0Zp5MYTCDwbgB8zCTqSVc
iQ1USnYXQFBLuGIFtYRGIkIECD0k1F8lrU9HRyf81deduXDq7JUR8ecVEf9+
j996IrYvbXkVHvDV+Bp8LR7x9fgGfCO+Cd+Mb8G34gnfhm/Hd+A78V34bnwP
vhffh+/HD+AH8UP4YXwCp60LjkfIcTxKjuMxchyPk+N4ghzHk+Q4niLH8TQ5
jmfIcTxLjuM5chzPk+M4SY7jBXIcL5LjmLdOuOCG4yX6uOCG4xR9XHDD8TJ9
XHDD8Qp9XHDD8Sp9XHDD8Rp9XHDD8Tp9XHDD8QZ9XHDD8SZ9XHDD8RZ9XHDD
8TZ9XHDD8Q59XHDD8S59XHDDcZo+LrjheI8+LrjhyFuPOOGMC6644Y7jffZx
whkXXHHDHccZ9nHCGRdcccMdxwfs44QzLrjihjuOD9nHCWdccMUNdxxn2ccJ
Z1xwxQ13HB+xjxPOuOCKG+44PmYfJ5xxwRU33HF8wj5OOOOCK2644/iUfZxw
xgVX3HDHcY59nHDGBVfccMfxGfs44YwLrrjhjuNz9nHCGRdcccMdx3n2ccL5
fPr71z9+P3kmH/+nFvKKG+44vmAfJ5xxwRU33HFcYB8nnHHBFTfccSxbD3jE
E054xhkvuOAdrniPGz7gjlccX2494BFPOOEZZ7zggne44j1u+IA7XnF8tfWA
RzzhhGec8YIL3uGK97jhA+54xfH11gMe8YQTnnHGCy54hyve44YPuOMVx8Wt
BzziCSc844wXXPAOV7zHDR9wxyuOb7Ye8IgnnPCMM15wwTtc8R43fMAdrziO
th7wiKej9Nflc79d/OXS8f1NR//d4+XY89H2Pmf6Cy54hyve44YPuOMVx7db
D3jEE054xhkvuOAdrniPGz7gjlccl7Ye8IgnnPCMM15wwTtc8R43fMAdrzi+
23rAI55wwjPOeMEF73DFe9zwAXe84vh+6wGPeMIJzzjjBRe8wxXvccMH3PGK
44etBzziCSc844wXXPAOV7zHDR9wxyuOH7ce8IgnnPCMM15wwTtc8R43fMAd
rzh+2nrAI55wwjPOeMEF73DFe9zwAXe84ri89YBHPOGEZ5zxggve4Yr3uOED
7njF8fPWAx7xhNP//gegLyYJ
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1nuoFVUUx/GVRIhEzB8SVhKTiNjTsZeZmctepmnOVTMzq515zz3n3HOv
k5n5KNtBURHRAaGipAbMSrCazMrMbGf+Uf/EEIFERBMSIfXHCEb0gu717kvt
7/xz+LBmzW9m7ZnNOW/12iW9Y0TkxCkiw78jRz1HwkNDjoUjeDw8AZ4Ix/Ak
eDI8BZ4KXwBfBF8CJ/B0+FL4Mvhy+Ar4SngGfBU8E74angVfA8+Gr4XnwBra
wjIXdViuQx2W61GH5QbUYbkRdVhuQh2WeajDcjPqsMxHHZYFqMNyC+qwLEQd
lkWow3Ir6rAsRh2WNLTCFnaw9KAftrCDZQn6YQs7WJaiH7awg2UZ+mELO1hu
Qz9sYQfLcv171/GvF602I/uuwhZ2y9F/O/JhCztYVqAftrCD5Q70wxZ2sKxE
P2xhB8ud6Ict7GBZhX7Ywg6Wu9APW9jBcjf6YQs7WO5BP2xhB4sJHcMKG9jC
OezgCpZ7kQ8rbGAL57CDK1hWIx9W2MAWzmEHV7Dch3xYYQNbOIcdXMGyBvmw
wga2cA47uIKl1+9v2cj+FsPaq39ubR9Yv23jiM1o3fr9sVe3jH973o+bHx9x
Pnr+U36/7NX9808fc+GTz4+4gqXh/brPb+jKNbN+WPzsGz6/oWeduvyMi/e8
5fMbumLm3i82HHzH5zf015595z7xy7s+v6Gbjk2ZPnb3bp/f8Pe31+c3dMFw
3Jkf+fw+PXm5V/f7/D4du3vi0C186vP7fJ636dOFM56ea35yPr9PvxzqPnva
Jz4f/Q79FSxN/far35ce3fmxz2+G96dN3X44LtY1/fOZpj7T+fmvXcf3+Pym
Dp08dIn3fH7Tz/MDn9/Uk+OY6J+vauq4Izuy2eM+9PmtsD9uhfPSVjhf09Lv
/hheYH++bfn18tfLW+H9uZaeM+37yac99r7PbyG/7d+XfT6/rcPTLSf5eWhb
z1/13KHfph7w+e1w3rYdzjtv6/Dd9uw76PPbfn6f+XxY+sO8uN+/Pz5P+7H+
/brs6M6XD8ej64963h9e3/Xra0NPe2SHP7/q1+FpvTB4yOd3/Pw/9/mwdnTb
hOEPwJ9vOnrin282Hpvir287/vsYff86yO/473U0vxPOUwbC9YgHsP4DeP8G
/Hq96fMH/Puww+eP1l/0+QN+ntt9/oBfn1d8/qD//l7y+YPh/qGD4f5iBrH/
wDnsBsP9qxoM9zdZG/6/i9eq/P9Q2MAWzmEHV7BkoSM4hhNY4RQ2cAZbuAvn
cAE7uIQruIbl/tARHMMJrHAKGziDLdyFc7iAHVzCFVzDsi50BMdwAiucwgbO
YAt34RwuYAeXcAXXsDwQOoJjOIEVTmEDZ7CFu3AOF7CDS7iCa1jWh47gGE5g
hVPYwBls4S6cwwXs4BKu4BqWB0NHcAwnsMIpbOAMtnAXzuECdnAJV3ANy4bQ
ERzDCaxwChs4gy3chXO4gB1cwhVcw/JQ6AiO4QRWOIUNnMEW7sI5XMAOLuEK
rmHZGDqCYziBFU5hA2ewhbtwDhewg0u4gmtYNoWO4BhOYIVT2MAZbOEunMMF
7OASruAals2hIziGE1jhFDZwBlu4C+dwATu4hCu4hmVL6AiO4QRWOIUNnMEW
7sI5XMAOLuEKrmF5OHQEx3ACK5zCBs5gC3fhHC5gB5dwBdewPBI6gmM4gRVO
YQNnsIW7cA4XsINLuIJrWLaGjuAYTmCFU9jAGWzhLpzDBezgEq7gGpZHQ0dw
DCew/ud/ASZrYYQ=
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd0jsI3VQABuCjk2OGDg4iUUREROLbWh+nte+HTVuf9XWsrY+q7VVrra3W
Myi4CBcUFAcNiviCksHBQeSMTnJxEwcjji4RBFEcpDQg+bKEL//984fDveTA
0b2Hzg8h/HleCGfv567xjjC/4pwX4AqvwRfii3CNL8WX4cvxFfhKfBW+Gjf4
Gnwtvg5fj2/AN+Kb8M14Lb4Fr8O34tvw7fgOHOfOOKwnXx9PrTmz5deTb0z/
kw3xn9OHvz32zlvnnDfEf7/448ddB/KU3zl3vnP++7Bxet+7U75xyt+f8k1z
503x57/PPvhkyjdP+edTvjnuP7jul91vfzblW+Lar78//t1HX075lvjNxW/+
vuebM1O+dfq+fsq3xp9++Gvfb59+NeXbeP+2qf/hlG+PZ9feO/LxlG+f9j6Y
8h2czw7OZ+eUn5jynVOepnwX54/DXeQ47CbHoZ074owLDnvo44wLDnvp44wL
Dvvo44wLDnfTxxkXHO6hjzMuONxLH2dccLiPPs644HA/fZxxweEB+jjjgsN+
+jjjgsOD9HHGBYeH6OOMCw4P08cZFxweoY8zLjg8Sh9nXHBIc9c44oQz7nDB
Aw6PsY8jTjjjDhc84HCAfRxxwhl3uOABh8fZxxEnnHGHCx5wOMg+jjjhjDtc
8IDDIfZxxAln3OGCBxyeYB9HnHDGHS54wOFJ9nHECWfc4YIHHJ5iH0eccMYd
LnjA4Wn2ccQJZ9zhggccDrOPI0444w4XPODwDPs44oQz7nDBAw7Pso8jTjjj
Dhc84PAc+zjihDPucMEDDkfYxxEnnHGHCx5wOMo+jjjhjDtc8IDDYu4K17jB
Ebc44QXOeIk73OOCV3jAIw7Pz13hGjc44hYnvMAZL3GHe1zwCg94xOGFuStc
4wZH3OKEFzjjJe5wjwte4QGPOLw4d4Vr3OCIW5zwAme8xB3uccErPOARh2Nz
V7jGDY64xQkvcMZL3OEeF7zCAx5xeGnuCte4wRG3OOEFzniJO9zjgld4wCMO
x+eucI0bHHGLE17gjJe4wz0ueIUHPOLw8twVrnGDI25xwguc8RJ3uMcFr/CA
RxxOzF3hGjc44hYnvMAZL3GHe1zwCg94xOGVuStc4wZH3OKEFzjjJe5wjwte
4QGPOJycu8I1bnDELU54gTNe4g73uOAVHvCIw6m5K1zjBkfc4oQXOOMl7nCP
C17hAY84vDp3hWvc4IhbnPACZ7zEHe5xwSs84BGH1+aucI0bHHGLE17gjJe4
wz0ueIUHPOJweu4K17jBEbc44QXOeIk73OOCV3jAIw6vz13hGjc4/u//ALE7
eZ4=
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1zkO5zQcBeAfVJQpKCgoAkIIIYTCvjNmXwfCsO9mYNhhwr6Dj5AjuKXL
EXyEvziBjxAkSgqEKFA+N9an56dX+6rzF89duDQi/rok4t/7v7OfieNJR16G
B3w5vgJfiUd8Nb4GX4uvw9fjG/CNeMI34ZvxLfhWfBu+Hd+B78R34bvxPfhe
fB++H5/B6eiC4wFyHA+S43iIHMfD5DgeIcfxKDmOx8hxPE6O4wlyHE+S43iK
HMfT5DjOkuN4hhzHs+Q45qMTLrjheI4+LrjhOEcfF9xwPE8fF9xwvEAfF9xw
vEgfF9xwvEQfF9xwvEwfF9xwvEIfF9xwvEofF9xwvEYfF9xwvE4fF9xwvEEf
F9xwvEkfF9xwvEUfF9xwvE0fF9xw5KNHnHDGBVfccMfxDvs44YwLrrjhjuM8
+zjhjAuuuOGO4132ccIZF1xxwx3He+zjhDMuuOKGO44L7OOEMy644oY7jvfZ
xwlnXHDFDXccH7CPE8644Iob7jg+ZB8nnHHBFTfccXzEPk4444Irbrjj+Jh9
nHDGBVfccMfxCfs44YwLrrjhjuNT9nHCGRdcccMdx2fs44QzLrjihjuOz9nH
CWdccMUNdxwX2ccJZ1wupr9///OPs+fzf//2ihvvO47l6AGPeMIJzzjjBRe8
4oo33PAJd7zj+OLoAY94wgnPOOMFF7ziijfc8Al3vOP48ugBj3jCCc844wUX
vOKKN9zwCXe84/jq6AGPeMIJzzjjBRe84oo33PAJd7zj+ProAY94wgnPOOMF
F7ziijfc8Al3vOP45ugBj3jCCc844wUXvOKKN9zwCXe84/j26AGPeMIJzzjj
BRe84oo33PAJd7zj+O7oAY94wgnPOOMFF7ziijfc8Al3vOP4/ugBj3jCCc84
4wUXvOKKN9zwCXe84/jh6AGPeMIJzzjjBRe84oo33PAJd7zj+PHoAY94wgnP
OOMFF7ziijfc8Al3vOP46egBj3jCCc844wUXvOKKN9zwCXe84/j56AGPeMIJ
zzjjBRe84oo33PAJd7zj+OXoAY94wgnPOOMFF7ziijfc8Al3vOP49egBj3jC
Cc844wUXvOKKN9zwCXe84/jt6AGPeMLpf/8Dkt4c5w==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1zkKLkUUBeCrkWEHBgYGrYiIiLTzrOU8Pm2f81w+Z3362nnWWkIvoVKz
XkIt4ccV1BJaMDQQUZD+blJ8HA4nrivOXTj73sUR8edFEf+8/95+XxwvHXkJ
HvCl+DJ8OR7xlfgqfDW+Bl+Lr8PX4wnfgG/EN+Gb8S34Vnwbvh3fge/Ed+G7
8T34XnwfTkcXHPeT43iAHMeD5DgeIsfxMDmOR8hxPEqO4zFyHI+T43iCHMeT
5DieIsdxhhzH0+Q4niHHMR+dcMENx7P0ccENx1n6uOCG4zn6uOCG43n6uOCG
4wX6uOCG40X6uOCG4yX6uOCG42X6uOCG4xX6uOCG41X6uOCG4zX6uOCG43X6
uOCG4w36uOCG4036uOCG4y36uOCGIx894oQzLrjihjuOt9nHCWdccMUNdxzn
2McJZ1xwxQ13HO+wjxPOuOCKG+443mUfJ5xxwRU33HG8xz5OOOOCK26443if
fZxwxgVX3HDH8QH7OOGMC6644Y7jQ/ZxwhkXXHHDHcdH7OOEMy644oY7jo/Z
xwlnXHDFDXccn7CPE8644Iob7jjOs48Tzrjgihvu59Nfv/3x+5lzy3//zE/Z
xwlnXHDFDXccn7GPE8644Iob7jgusI8TzrjgihvuOJajBzziCSc844wXXPCK
K95wwyfc8Y7j86MHPOIJJzzjjBdc8Ior3nDDJ9zxjuOLowc84gknPOOMF1zw
iivecMMn3PGO48ujBzziCSc844wXXPCKK95wwyfc8Y7jq6MHPOIJJzzjjBdc
8Ior3nDDJ9zxjuProwc84gknPOOMF1zwiivecMMn3PGO45ujBzziCSc844wX
XPCKK95wwyfc8Y7j26MHPOIJJzzjjBdc8Ior3nDDJ9zxjuO7owc84gknPOOM
F1zwiivecMMn3PGO4/ujBzziCSc844wXXPCKK95wwyfc8Y7jh6MHPOIJJzzj
jBdc8Ior3nDDJ9zxjuPHowc84gknPOOMF1zwiivecMMn3PGO46ejBzziCSc8
44wXXPCKK95wwyfc8Y7j56MHPOIJJzzjjBdc8Ior3nDDJ9zxjuOXowc84gkn
POOMF1zwiivecMMn3PGO49ejBzziCaf//Tf3yBhB
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DkO5zQcBeAfVJQpKCgoAkIIIYTCvjNm3yEM+24Ghh0m7Dv4CDmCW7oc
wUf4ixP4CEGipEBoCpTPjfXp+en1vurchbPnL42Ivy+J+O++ePYzcTzpyMvw
gC/HV+Ar8Yivxtfga/F1+Hp8A74RT/gmfDO+Bd+Kb8O34zvwnfgufDe+B9+L
78P34zM4HV1wPECO40FyHA+R43iYHMcj5DgeJcfxGDmOx8lxPEGO40lyHE+R
43iaHMcz5DieJcfxHDmO+eiEC244nqePC244ztLHBTccL9DHBTccL9LHBTcc
L9HHBTccL9PHBTccr9DHBTccr9LHBTccr9HHBTccr9PHBTccb9DHBTccb9LH
BTccb9HHBTccb9PHBTcc79DHBTcc+egRJ5xxwRU33HG8yz5OOOOCK2644zjH
Pk4444IrbrjjeI99nHDGBVfccMfxPvs44YwLrrjhjuM8+zjhjAuuuOGO4wP2
ccIZF1xxwx3Hh+zjhDMuuOKGO46P2McJZ1xwxQ13HB+zjxPOuOCKG+44PmEf
J5xxwRU33HF8yj5OOOOCK2644/iMfZxwxgVX3HDH8Tn7OOGMC6644Y7jC/Zx
whkXXHHDHccF9nHCGRdcccMdx3L0gEc84YRnnPGCC15xxRtu+IQ73nF8efSA
RzzhhGec8YILXnHFG274hDvecXx19IBHPOGEZ5zxggteccUbbviEO95xfH30
gEc84YRnnPGCC15xxRtu+IQ73nF8c/SARzzhhGec8YILXnHFG274hDvecXx7
9IBHPOGEZ5y/Tf/88defz5zLF/9VF1x4v+KKN9zwCXe84/ju6AGPeMIJzzjj
BRe84oo33PAJd7zj+P7oAY94wgnPOOMFF7ziijfc8Al3vOP44egBj3jCCc84
4wUXvOKKN9zwCXe84/jx6AGPeMIJzzjjBRe84oo33PAJd7zj+OnoAY94wgnP
OOMFF7ziijfc8Al3vOP4+egBj3jCCc844wUXvOKKN9zwCXe84/jl6AGPeMIJ
zzjjBRe84oo33PAJd7zj+PXoAY94wgnPOOMFF7ziijfc8Al3vOP47egBj3jC
Cc844wUXvOKKN9zwCXe84/j96AGPeMLpf/8LkEMc5w==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DcO50QcBeAfVJQuKCgoDEIIIYRMzuyQ44LJGYYlZ5OXPEf4H2FaOh9h
jmBxgjmCkSgpEFoh5G+a0ac3T6+1fMW5L5597+KI+OuiiH/vC2c/E8eTjrwE
D/hSfBm+HI/4SnwVvhpfg6/F1+Hr8YRvwDfim/DN+BZ8K74N347vwHfiu/Dd
+B58Lz6D09EFx33kOO4nx/EAOY4HyXE8RI7jYXIcj5DjeJQcx2PkOB4nx/EE
OY4nyXGcJcfxFDmOp8lxzEcnXHDD8Qx9XHDD8Sx9XHDD8Rx9XHDD8Tx9XHDD
8QJ9XHDD8SJ9XHDD8RJ9XHDD8TJ9XHDD8Qp9XHDD8Sp9XHDD8Rp9XHDD8Tp9
XHDD8QZ9XHDD8SZ9XHDD8RZ9XHDDkY8eccIZF1xxwx3H2+zjhDMuuOKGO45z
7OOEMy644oY7jnfYxwlnXHDFDXcc77KPE8644Iob7jjeYx8nnHHBFTfccbzP
Pk4444Irbrjj+IB9nHDGBVfccMfxIfs44YwLrrjhjuMj9nHCGRdcccMdx8fs
44QzLrjihjuOT9jHCWdccMUNdxyfso8TzrjgihvuOD5jHyecccEVN9xxfM4+
TjjjgituuOP4gn2ccMYFV9xwx7EcPeARTzjheUl///7nH2fPLRf+I+T/nC94
4X3BJ1zxihvecMc7ji+PHvCIJ5zwjDNecMEnXPGKG95wxzuOr44e8IgnnPCM
M15wwSdc8Yob3nDHO46vjx7wiCec8IwzXnDBJ1zxihvecMc7jm+OHvCIJ5zw
jDNecMEnXPGKG95wxzuOb48e8IgnnPCMM15wwSdc8Yob3nDHO47vjh7wiCec
8IwzXnDBJ1zxihvecMc7ju+PHvCIJ5zwjDNecMEnXPGKG95wxzuO80cPeMQT
TnjGGS+4nD9+H5zIK15xwxvueMfxw9EDHvGEE55xxgsu+IQrXnHDG+54x/Hj
0QMe8YQTnnHGCy74hCteccMb7njH8dPRAx7xhBOeccYLLviEK15xwxvueMfx
89EDHvGEE55xxgsu+IQrXnHDG+54x/HL0QMe8YQTnnHGCy74hCteccMb7njH
8evRAx7xhBOeccYLLviEK15xwxvueMfx29EDHvGE0//+Bxz6Ia0=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DnuHjUcBuAfVJRTUFBQDAghhBAa9p2YfQ18hH0LJhB2yJCwrz7CHMEt
3XcEH2HECXyEQaKkQOivCM3jxnr06tUrt77u3IUz56+MiL+viPjvPjnbqdif
tOdVeMBX42vwtXjE1+Mb8I34JnwzvgXfiid8G74d34HvxHfhu/E9+F58H74f
P4AfxA/hh/EpnPYuOB4hx/EoOY7HyHE8To7jCXIcT5LjeIocx9PkOJ4hx/Es
OY7nyHE8T47jNDmOF8hxvEiO47B3wgU3HC/RxwU3HGfo44Ibjpfp44Ibjlfo
44Ibjlfp44Ibjtfo44Ibjtfp44Ibjjfo44Ibjjfp44Ibjrfo44Ibjrfp44Ib
jnfo44Ibjnfp44IbjrP0ccENx3v0ccENR957xAlnXHDFDXcc77OPE8644Iob
7jjOsY8TzrjgihvuOD5gHyecccEVN9xxfMg+TjjjgituuOM4zz5OOOOCK264
4/iIfZxwxgVX3HDH8TH7OOGMC6644Y7jE/ZxwhkXXHHDHcen7OOEMy644oY7
js/YxwlnXHDFDXccn7OPE8644Iob7ji+YB8nnHHBFTfccXzJPk4444Irbrjj
+Ip9nHDGBVfccMdxgX2ccMYFV9xwxzHvPeARTzjhA854xgUvuOIjbnjFHW84
vt57wCOecMIHnPGMC15wxUfc8Io73nBc3HvAI55wwgec8YwLXnDFR9wupn/+
+OvP0+fyyb/VetnlxJ18w3Fp7wGPeLrs+cTpEu/HGc+44AVXfMQNr7jjDcc3
ew94xBNO+IAznnHBC674iBtecccbjm/3HvCIJ5zwAWc844IXXPERN7zijjcc
3+094BFPOOEDznjGBS+44iNueMUdbzi+33vAI55wwgec8YwLXnDFR9zwijve
cPyw94BHPOGEDzjjGRe84IqPuOEVd7zh+HHvAY94wgkfcMYzLnjBFR9xwyvu
eMPx094DHvGEEz7gjGdc8IIrPuKGV9zxhuPnvQc84gknfMAZz7jgBVd8xA2v
uOMNxy97D3jEE074gDOeccELrviIG15xxxuOX/ce8IgnnPABZzzjghdc8RE3
vOKONxy/7T3gEU844QPOeMYFL7jiI254xR1vOH7fe8AjnnD63/8CqW45Ww==

       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2LnKHlUcBvC/VimnSGFhMYoEEZGJ+57jGrfoa9z3YzQuccmoMV8Wjaew
sLB4wRs4rSAyF2BxLuHFKxhLuxGsxELki8j8TjP8eHjm4bTnmhOnj5+8MiL+
vCLi3+/+WY7E+qQ1D+AOH8RX4atxj6/F1+FD+Hp8Q/r7xz9+PXYiX77HjeQ3
4QEfxjfjW/Ct+DZ8O74D34nvwnfje/C9+D58Pz6C09oFxwPkOB4kx/EQOY6H
yXE8Qo7jUXIcR8lxPEaO43FyHE+Q43iSHMdT5DiOkeN4mhzHM+Q4NmsnXHDD
8Sx9XHDDcZw+LrjheI4+LrjheJ4+LrjheIE+LrjheJE+LrjheIk+LrjheJk+
LrjheIU+LrjheJU+LrjheI0+LrjheJ0+LrjheIM+LrjheJM+LrjheIs+Lrjh
yGv3OOGMC6644RnH2+zjhDMuuOKGZxwn2McJZ1xwxQ3PON5hHyecccEVNzzj
eJd9nHDGBVfc8IzjJPs44YwLrrjhGcd77OOEMy644oZnHO+zjxPOuOCKG55x
fMA+TjjjgitueMbxIfs44YwLrrjhGccp9nHCGRdcccMzjo/YxwlnXHDFDc84
PmYfJ5xxwRU3POP4hH2ccMYFV9zwjONT9nHCGRdcccMzjtPs44QzLrjihmcc
49od7vGAE97gjEdc8BZXPOGGd3jGC47P1u5wjwec8AZnPOKCt7jiCTe8wzNe
cHy+dod7POCENzjjERe8xRVPuOEdnvGC44u1O9zjASe8wRmPuOAtrnjCDe/w
jBccZ9bucI8HnPAGZzzigre44gk3vMMzXnB8uXaHezzghDc44xEXvMUVT7jh
HZ7xguPs2h3u8YAT3uCMR1zwFlc8nV2/77b/XPa9O5v+unTqlzM/nNv3fDZd
PPjz0d8ufLvv5b/8u8vvw3vp/O+HDh/46ft9d3vrvN9b/2/Yu7w37jvtcX+c
8YgL3uKKJ9zwDs94wXFu7Q73eMAJb3DGIy54iyuecMM7POMFx/m1O9zjASe8
wRmPuOAtrnjCDe/wjBccF9bucI8HnPAGZzzigre44gk3vMMzXnBcXLvDPR5w
whuc8YgL3uKKJ9zwDs94wfHV2h3u8YAT3uCMR1zwFlc84YZ3eMYLjq/X7nCP
B5zwBmc84oK3uOIJN7zDM15wXFq7wz0ecMIbnPGIC97iiifc8A7PeMHxzdod
7vGA0//+BwjUPu0=
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd0DkKJkUYBuBPI8MODAwMWhEREWn3Xct913bftVzGZVym1VHHbawjNHiB
OkIfwKCO8B+hjtCBkZGIgvTzJcXDy8sLddUH5148c2lE/HlJxD/vv7c/EMdL
R16GB3w5vgJfiUd8Nb4GX4uvw9fjG/CNeMI34ZvxLfhWfBu+Hd+R/rp49o/z
v1/475/vJL8L343vwffi+/D9+AGcji44HiTH8RA5jofJcTxCjuNRchyPkeN4
nBzHE+Q4niTH8RQ5jqfJcTxDjuNZchzPkeN4nhzHfHTCBTccL9DHBTccL9LH
BTccL9HHBTccL9PHBTccr9DHBTccr9LHBTccr9HHBTccr9PHBTccb9DHBTcc
b9LHBTccb9HHBTccb9PHBTcc79DHBTcc79LHBTcc79HHBTcc+egRJ5xxwRU3
3HG8zz5OOOOCK2644/iAfZxwxgVX3HDH8SH7OOGMC6644Y7jI/ZxwhkXXHHD
HccZ9nHCGRdcccMdx8fs44QzLrjihjuOT9jHCWdccMUNdxyfso8Tzrjgihvu
OD5jHyecccEVN9xxnGUfJ5xxwRU33HF8zj5OOOOCK2644/iCfZxwxgVX3HDH
8SX7OOGMC6644Y7jK/ZxwhkXXHHDHcc59nHCGRdcccMdx3L0gEc84YRnnPGC
C15xxRtu+IQ73nF8ffSARzzhhGec8YILXnHFG274hDvecXxz9IBHPOGEZ5zx
ggteccUbbviEO95xfHv0gEc84YRnnPGCC15xxRtu+IQ73nGcP3rAI55wwjPO
eMEFr7jiDTd8wh3vOL47esAjnnDCM854wQWvuOINN3zCHe84vj96wCOecMIz
znjBBa+44g03fMId7zh+OHrAI55wwjPOeMEFr7jiDTd8wh3vOC4cPeARTzjh
GWe84IJXXPGGGz7hjnccPx494BFPOOEZZ7zggldc8YYbPuGOdxw/HT3gEU84
4RlnvOCCV1zxhhs+4Y53HD8fPeARTzjhGWe84IJXXPGGGz7hjnccvxw94BFP
OOEZZ7zggldc8YYbPuGOdxy/Hj3gEU844RlnvOCCV1zxhhs+4Y53HBePHvCI
J5zwjDNecMErrnjDDZ9wxzuO344e8IgnnP73360AF9c=
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2TcO7kQUBeALFaULCgoKgxBCCCGTMww5PjCPnIdHjs/kR54leAnT0nkJ
s4RfrGCWYCRKCoRAQv5uM/p0dHQWMFecO3/2vYsj4s+LIv55/739vjheOvIS
POBL8WX4cjziK/FV+Gp8Db4WX4evxxO+Ad+Ib8I341vwrfg2fDu+A9+J78J3
43vwvfg+nI4uOO4nx/EAOY4HyXE8RI7jYXIcj5DjeJQcx2PkOB4nx/EEOY4n
yXE8RY7jDDmOp8lxPEOOYz464YIbjmfp44IbjrP0ccENx3P0ccENx/P0ccEN
xwv0ccENx4v0ccENx0v0ccENx8v0ccENxyv0ccENx6v0ccENx2v0ccENx+v0
ccENxxv0ccENx5v0ccENx1v0ccENRz56xAlnXHDFDXccb7OPE8644Iob7jjO
sY8TzrjgihvuON5hHyecccEVN9xxvMs+TjjjgituuON4j32ccMYFV9xwx/E+
+zjhjAuuuOGO4wP2ccIZF1xxwx3Hh+zjhDMuuOKGO46P2McJZ1xwxQ13HB+z
jxPOuOCKG+44PmEfJ5xxwRU33HF8yj5OOOOCK2644/iMfZxwxgVX3HDH8Tn7
OOGMC6644Y7jPPs44YwLrrjhjmM5esAjnnDCM854wQWvuOINN3zCHe84vjh6
wCOecMIzznjBBa+44g03fMId7zi+PHrAI55wwjPOeMEFr7jiDTd8wh3vOL46
esAjnnDCM854wQWvuOINN3zCHe84vj56wCOecMIzznjBBa+44g03fMId7zi+
OXrAI55wwjPOeMEFr7jiDTd8wh3vOL49esAjnnDCM854wQWvuOINN3zCHe84
vjt6wCOecMIzznjBBa+44g03fMId7zguHD3gEU844RlnvOCCV1zxhhs+4Y73
C+mv3/74/cy5/N8/x/fHfMAjnnDCM854wQWvuOINN3zCHe84fjh6wCOecMIz
znjBBa+44g03fMId7zh+PHrAI55wwjPOeMEFr7jiDTd8wh3vOH46esAjnnDC
M854wQWvuOINN3zCHe84fj56wCOecMIzznjBBa+44g03fMId7zh+OXrAI55w
wjPOeMEFr7jiDTd8wh3vOH49esAjnnD6338DcLoYMQ==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd1TcO5kQYBuAPKkoXFBQUBiGEEEImZxhyXDBLjjssOa7JGeYIPsK0dD7C
HOEXJ5gjGImSAqEtkJ+vGT169eot56rzF86+f2lE/H1JxH/vxdsfiOOlIy/D
A74cX4GvxCO+Gl+Dr8XX4evxDfhGPOGb8M34Fnwrvg3fju/Ad+K78N34Hnwv
vg/fjx/A6eiC40FyHA+R43iYHMcj5DgeJcfxGDmOx8lxPEGO40lyHE+R43ia
HMcz5DjOkON4lhzHc+Q45qMTLrjheJ4+LrjhOEsfF9xwvEAfF9xwvEgfF9xw
vEQfF9xwvEwfF9xwvEIfF9xwvEofF9xwvEYfF9xwvE4fF9xwvEEfF9xwvEkf
F9xwvEUfF9xwvE0fF9xwnEv//PHXn2fO54v/djpHHzcc+egRJ5xxwRU33HG8
wz5OOOOCK2644zjPPk4444IrbrjjeJd9nHDGBVfccMfxHvs44YwLrrjhjuN9
9nHCGRdcccMdxwfs44QzLrjihjuOD9nHCWdccMUNdxwfsY8TzrjgihvuOD5m
HyecccEVN9xxfMI+TjjjgituuOP4lH2ccMYFV9xwx/EZ+zjhjAuuuOGO43P2
ccIZF1xxwx3HF+zjhDMuuOKGO44L7OOEMy644oY7juXoAY94wgnPOOMFF7zi
ijfc8Al3vOP48ugBj3jCCc844wUXvOKKN9zwCXe84/jq6AGPeMIJzzjjBRe8
4oo33PAJd7zj+ProAY94wgnPOOMFF7ziijfc8Al3vOP45ugBj3jCCc844wUX
vOKKN9zwCXe84/j26AGPeMIJzzjjBRe84oo33PAJd7zj+O7oAY94wgnPOOMF
F7ziijfc8Al3vOP4/ugBj3jCCc844wUXvOKKN9zwCXe84/jh6AGPeMIJzzjj
BRe84oo33PAJd7zj+PHoAY94wgnPOOMFF7ziijfc8Al3vOP46egBj3jCCc84
4wUXvOKKN9zwCXe84/j56AGPeMIJzzjjBRe84oo33PAJd7zj+OXoAY94wgnP
OOMFF7ziijfc8Al3vOP49egBj3jCCc844wUXvOKKN9zwCXe84/jt6AGPeMIJ
zzjjBRe84oo33PAJd7zj+P3oAY94wul//wttmRgx
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DcO7kQYBdAPKkoXFBQUBiGEEEImZ96QM5icYXjk7Ac8cpgl/EuYls5L
mCVYrGCWYCRKCoQAIZ9pRkdXd27lxped/fyZdy+MiD8uiPj7/ufsZ+J40pEX
4QFfjC/Bl+IRX46vwFfiq/DV+Bp8LZ7wdfh6fAO+Ed+Eb8a34Fvxbfh2fAe+
E9+F78ZncDq64LiHHMe95DjuI8dxPzmOB8hxPEiO4yFyHA+T43iEHMej5Dge
I8fxODmOJ8hxPEmO4ylyHPPRCRfccDxNHxfccDxDHxfccDxLHxfccDxHHxfc
cDxPHxfccLxAHxfccLxIHxfccLxEHxfccLxMHxfccLxCHxfccLxKHxfccLxG
HxfccLxOHxfccLxBHxfccLxJHxfccOSjR5xwxgVX3HDH8Rb7OOGMC6644Y7j
LPs44YwLrrjhjuNt9nHCGRdcccMdxzvs44QzLrjihjuOd9nHCWdccMUNdxzv
sY8TzrjgihvuON5nHyecccEVN9xxfMA+TjjjgituuOP4kH2ccMYFV9xwx/ER
+zjhjAuuuOGO42P2ccIZF1xxwx3HJ+zjhDMuuOKGO45P2ccJZ1xwxQ13HJ+x
jxPOuOCKG+44PmcfJ5xxwRU33HEsRw94xBNOeMYZL7jgE654xQ1vuOMdx7mj
BzziCSc844wXXPAJV7zihjfc8X4u/fnr7789cTb/+5/ni2M+4BFPOOEZZ7zg
gk+44hU3vOGOdxxfHj3gEU844RlnvOCCT7jiFTe84Y53HF8dPeARTzjhGWe8
4IJPuOIVN7zhjncc548e8IgnnPCMM17OH7+/8p+Xf3wir+QreeP9DXe84/j6
6AGPeMIJzzjjBRd8whWvuOENd7zj+OboAY94wgnPOOMFF3zCFa+44Q13vOP4
9ugBj3jCCc844wUXfMIVr7jhDXe84/ju6AGPeMIJzzjjBRd8whWvuOENd7zj
+P7oAY94wgnPOOMFF3zCFa+44Q13vOP44egBj3jCCc844wUXfMIVr7jhDXe8
4/jx6AGPeMIJzzjjBRd8whWvuOENd7zj+OnoAY94wgnPOOMFF3zCFa+44Q13
vOP4+egBj3jCCc844wUXfMIVr7jhDXe84/jl6AGPeMLpf/8FX/sv3w==
       
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxdzTcO6EQUBdAHFaULCgoKgxBCCCGTMww5g8kZhvDJ8E3OMEvwEmYJXsIs
wUuYJbhgAQhRIJ/XPB1dXd2rPrj44oVLI+LvSyL+/f/d8UCcL515GR7w5fgK
fCUe8dX4Gnwtvg5fj2/AN+IJ34RvxrfgW/Ft+HZ8B74T34Xvxvfge/F9+H78
AE5nFxwPkuN4iBzHw+Q4HiHH8Sg5jsfIcTxOjuMJchxPkuN4ihzH0+Q4niHH
8Sw5jufIcTxPjmM+O+GCG44X6OOCG44X6eOCG46X6OOCG46X6eOCG45X6OOC
G45X6eOCG47X6OOCG47X6eOCG4436OOCG4436eOCG4636OOCG4636eOCG453
6OOCG4536eOCG4736OOCG4589ogTzrjgihvuON5nHyecccEVN9xxfMA+Tjjj
gituuOP4kH2ccMYFV9xwx/ER+zjhjAuuuOGO4wL7OOGMC6644Y7jY/ZxwhkX
XHHDHccn7OOEMy644oY7jk/ZxwlnXHDFDXccn7GPE8644Iob7jg+Zx8nnHHB
FTfccXzBPk4444Irbrjj+JJ9nHDGBVfccMfxFfs44YwLrrjhjuNr9nHCGRdc
ccMdx0X2ccIZF1xxwx3HcvaARzzhhGec8YILXnHFG254xx0fOL45e8AjnnDC
M854wQWvuOINN7zjjg8c35494BFPOOEZZ7zggldc8YYb3nHHB47vzh7wiCec
8IwzXnDBK654ww3vuOMDx/dnD3jEE054xhkvuOAVV7zhhnfc8YHjh7MHPOIJ
JzzjjBdc8Ior3nDDO+74wPHj2QMe8YQTnnHGCy54xRVvuOEdd3zg+OnsAY94
wgnPOOMFF7ziijfc8I47PnD8fPaARzzhhGec8YILXnHFG254xx0fOH45e8Aj
nnDCM854wQWvuOINN7zjjg8cv5494BFPOOEZZ7zggldc8YYb3nHHB47fzh7w
iCec8IwzXnDBK654ww3vuOMDx+9nD3jEE054xhkvuOAVV7zhhnfc8YHjj7MH
POIJJzzjjBdc8Ior3nDDO+74wPHn2QMe8YQTnnHGCy54xRVvuOEdd3zg+Ovs
AY94wul//wOYgBN7
       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.502, 0.6779999999999999, 0.435], PointSize[
      0.011111111111111112`], Thickness[Large], LineBox[CompressedData["
1:eJxd2DcOJzUcBeAfVJRTUFBQDAghhBAacmZNjgvDkrNZch5yBh/hfwS3dHME
H2HECXyEQaKkQGiR0HxurE9PT69y4yvOf37u3Ysj4q+LIv69L5z9TBxPOvIS
POBL8WX4cjziK/FV+Gp8Db4WX4evxxO+Ad+Ib8I341vwrfg2fDu+A9+J78J3
43vwvfgMTkcXHPeR47ifHMcD5DgeJMfxEDmOh8lxPEKO41FyHI+R43icHMcT
5DieTH///ucfZ88vF95deZL8LH0cT5HjeJocx3x0wgU3HM/QxwU3HOfo44Ib
jmfp44Ibjufo44Ibjufp44Ibjhfo44Ibjhfp44Ibjpfo44Ibjpfp44Ibjlfo
44Ibjlfp44Ibjtfo44Ibjtfp44Ibjjfo44Ibjjfp44Ibjnz0iBPOuOCKG+44
3mIfJ5xxwRU33HGcZx8nnHHBFTfccbzNPk4444IrbrjjeId9nHDGBVfccMfx
Lvs44YwLrrjhjuM99nHCGRdcccMdx/vs44QzLrjihjuOD9jHCWdccMUNdxwf
so8TzrjgihvuOD5iHyecccEVN9xxfMw+TjjjgituuOP4hH2ccMYFV9xwx/Ep
+zjhjAuuuOGO4zP2ccIZF1xxwx3H5+zjhDMuuOKGO47l6AGPeMIJzzjjBRd8
whWvuOENd7zj+OLoAY94wgnPOOMFF3zCFa+44Q13vOP48ugBj3jCCc844wUX
fMIVr7jhDXe84/jq6AGPeMIJzzjjBRd8whWvuOENd7zj+ProAY94wgnPOOMF
F3zCFa+44Q13vOP45ugBj3jCCc844wUXfMIVr7jhDXe84/j26AGPeMIJzzjj
BRd8whWvuOENd7zj+O7oAY94wgnPOOMFF3zCFa+44Q13vOP4/ugBj3jCCc84
4wUXfMIVr7jhDXe84/jh6AGPeMIJzzjjBRd8whWvuOENd7zj+PHoAY94+vG/
/+p84b86kc844wUXfMIVr7jhDXe84/jp6AGPeMIJzzjjBRd8whWvuOENd7zj
+PnoAY94wgnPOOMFF3zCFa+44Q13vOP45egBj3jCCc844wUXfMIVr7jhDXe8
4/j16AGPeMIJzzjjBRd8whWvuOENd7zj+O3oAY94wul//wMk4xz3
       
       "]]}}, {}, {}, {{}, {}}}},
  AspectRatio->0.2,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Frequency\"", TraditionalForm], None}, {
     FormBox["\"generation\"", TraditionalForm], 
     FormBox[
     "\"SI/SC class freq. mutants/offsprings/adults\"", TraditionalForm]}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->1000,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 500}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7235263626098824`*^9, 3.723526442552845*^9, {3.723526561473535*^9, 
   3.723526569113062*^9}, 3.723526739882766*^9, 3.723531464453465*^9, 
   3.7243900780841227`*^9, 3.7243901316047773`*^9, 3.724390350970302*^9, 
   3.7243905337722883`*^9, 3.724392717048876*^9, 3.724392863644681*^9, 
   3.7256253936422853`*^9, 3.725625669236286*^9, 3.725625738899081*^9, 
   3.725625940119546*^9, 3.725626022285388*^9, 3.7256262929953823`*^9, 
   3.725626559646943*^9, 3.7256267147393837`*^9, 3.725628938350493*^9, {
   3.725629952955636*^9, 3.7256299628773108`*^9}, 3.725630412571598*^9, 
   3.72639058076606*^9, 3.726390810845553*^9, 3.726390951879085*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Self-incompatible events", "Subsubsection",
 CellChangeTimes->{{3.7235273242148447`*^9, 3.7235273274770613`*^9}, {
  3.7235315277617807`*^9, 3.723531534489622*^9}}],

Cell["\<\
Now we look at the S-alleles from their birth to death. We consider an event \
to start (or be born) when the first SI haplotype appeared in a class, which \
did not contain any SI haplotypes previously. The end of an event, also \
addressed as death, occurs when the last SI haplotype of a class disappears \
from the population. The events are summarized by the following figure, with \
time on the horizontal axis and the RNAse id on the vertical axis. A green \
line corresponds to the events that are long (lifetime >100 generations) \
while the gray events correspond to the short events (lifetime < 100 \
generations).\
\>", "Text",
 CellChangeTimes->{{3.723531474765293*^9, 3.723531495331356*^9}, {
  3.7235315393217278`*^9, 3.723531770938229*^9}, {3.7243901523380413`*^9, 
  3.724390167968058*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"PlotTabs", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t2", " ", "=", " ", "generations"}], ";"}], "\n", 
 RowBox[{"\t", 
  RowBox[{"P1", " ", "=", " ", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "@", "tbls"}], " ", ">", " ", "0"}], ",", "\n", 
     "     \t", 
     RowBox[{"Show", "[", 
      RowBox[{"tbls", ",", " ", 
       RowBox[{"ImageSize", " ", "->", " ", "1000"}], ",", " ", 
       RowBox[{"PlotRange", " ", "->", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "t2"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"0.5", ",", " ", 
            RowBox[{
             RowBox[{"RTypes", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", "0.5"}]}], 
           "}"}]}], "}"}]}], ",", " ", 
       RowBox[{"Frame", " ", "->", " ", "True"}], ",", " ", 
       RowBox[{"AxesOrigin", " ", "->", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0"}], "}"}]}], ",", "\n", "       \t", 
       RowBox[{"Frame", " ", "->", " ", "True"}], ",", "\n", "       \t", 
       RowBox[{"FrameLabel", " ", "->", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<SI class\>\"", ",", " ", "None"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
           "\"\<generation\>\"", ",", " ", 
            "\"\<SI class production and annihilation\>\""}], "}"}]}], 
         "}"}]}], ",", "\n", "       \t", 
       RowBox[{"AspectRatio", " ", "->", " ", "0.2"}]}], "]"}]}], "\n", 
    "    ", "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.723526619333449*^9, 3.7235266244400587`*^9}, {
  3.7235266581642027`*^9, 3.723526750017881*^9}, {3.72352678802527*^9, 
  3.723526815079976*^9}, {3.72562997045745*^9, 3.7256299718644447`*^9}, {
  3.725630368742433*^9, 3.725630374716051*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{9., 1.}, {10., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{11., 1.}, {15., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{17., 1.}, {19., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{25., 1.}, {29., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{30., 1.}, {31., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{34., 1.}, {51., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{55., 1.}, {62., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{77., 1.}, {78., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
      StyleBox[LineBox[{{80., 1.}, {500., 1.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
      StyleBox[LineBox[{{50., 2.}, {500., 2.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{310., 3.}, {314., 3.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{393., 3.}, {394., 3.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{294., 4.}, {295., 4.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{325., 4.}, {331., 4.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{129., 5.}, {130., 5.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{135., 5.}, {136., 5.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{156., 5.}, {157., 5.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{176., 5.}, {178., 5.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{222., 5.}, {223., 5.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{360., 5.}, {361., 5.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{210., 6.}, {211., 6.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{43., 7.}, {45., 7.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{90., 7.}, {91., 7.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{122., 7.}, {123., 7.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{152., 7.}, {156., 7.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{229., 7.}, {230., 7.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{439., 7.}, {440., 7.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{112., 8.}, {118., 8.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{262., 8.}, {269., 8.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{274., 8.}, {275., 8.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{5., 9.}, {6., 9.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{19., 9.}, {20., 9.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{195., 9.}, {197., 9.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
      StyleBox[LineBox[{{227., 9.}, {400., 9.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{316., 10.}, {317., 10.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{214., 11.}, {215., 11.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{287., 11.}, {288., 11.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{339., 11.}, {340., 11.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{475., 11.}, {478., 11.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{368., 12.}, {384., 12.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{450., 12.}, {451., 12.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{153., 14.}, {156., 14.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{216., 14.}, {217., 14.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{455., 14.}, {465., 14.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{249., 15.}, {250., 15.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{427., 15.}, {431., 15.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{249., 17.}, {267., 17.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{385., 17.}, {390., 17.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{428., 17.}, {500., 17.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{104., 18.}, {106., 18.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{156., 18.}, {158., 18.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
      StyleBox[LineBox[{{129., 19.}, {258., 19.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{110., 22.}, {111., 22.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{161., 22.}, {164., 22.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{307., 22.}, {309., 22.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{287., 24.}, {290., 24.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{419., 24.}, {420., 24.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{323., 25.}, {324., 25.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{204., 26.}, {208., 26.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{220., 26.}, {225., 26.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{238., 26.}, {241., 26.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{477., 26.}, {485., 26.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{491., 26.}, {500., 26.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{97., 27.}, {104., 27.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{96., 28.}, {100., 28.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{112., 28.}, {113., 28.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{119., 29.}, {160., 29.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{247., 29.}, {254., 29.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{384., 29.}, {386., 29.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{178., 30.}, {183., 30.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
      StyleBox[LineBox[{{46., 31.}, {162., 31.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{67., 32.}, {70., 32.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{105., 32.}, {195., 32.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
      StyleBox[LineBox[{{247., 32.}, {500., 32.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{100., 33.}, {101., 33.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{146., 33.}, {147., 33.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{441., 33.}, {442., 33.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{383., 35.}, {384., 35.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{402., 36.}, {403., 36.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{118., 37.}, {119., 37.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{408., 38.}, {410., 38.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{419., 38.}, {420., 38.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{4., 40.}, {61., 40.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{162., 44.}, {163., 44.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{351., 44.}, {383., 44.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{453., 44.}, {500., 44.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{238., 45.}, {239., 45.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{250., 47.}, {251., 47.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{429., 47.}, {430., 47.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{25., 49.}, {26., 49.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{108., 49.}, {110., 49.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{310., 49.}, {311., 49.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{477., 49.}, {500., 49.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
      StyleBox[LineBox[{{20., 50.}, {46., 50.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
      StyleBox[LineBox[{{110., 50.}, {257., 50.}}],
       FontFamily->"Helvetica",
       FontSize->16]}}, {}, {}, {{}, {}}}},
  AspectRatio->0.2,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{
   FontFamily -> "Helvetica", FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"SI class\"", TraditionalForm], None}, {
     FormBox["\"generation\"", TraditionalForm], 
     FormBox["\"SI class production and annihilation\"", TraditionalForm]}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->1000,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 500}, {0.5, 50.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.723526663166772*^9, 3.723526751697742*^9}, {
   3.723526789441078*^9, 3.723526831232533*^9}, 3.723532277495364*^9, {
   3.724390182993526*^9, 3.7243902009361353`*^9}, 3.724390354153227*^9, 
   3.7243905345202513`*^9, 3.724392723698678*^9, 3.724392868486104*^9, 
   3.7256257463636723`*^9, {3.7256260490796967`*^9, 3.725626054765688*^9}, 
   3.725626298903678*^9, 3.725626564629096*^9, 3.725626725409849*^9, 
   3.725627011356799*^9, 3.725628945963421*^9, 3.725629973745096*^9, 
   3.725630009315876*^9, 3.725630397660055*^9, {3.726390585852654*^9, 
   3.7263905926648417`*^9}, 3.726390953427186*^9}]
}, Open  ]],

Cell["\<\
We also compute the minimal completeness deficit of each class at each time. \
Completeness deficit is a number (0,1,2,...) which counts the number of \
missing SLFs that prevents the haplotype from fertilizing haplotypes from \
other SI classes. If the deficit is 0 the haplotype can fertilize all the \
other SI classes. Since at each time one class may consist of multiple SI \
haplotypes we take a minimum of all completeness deficits for all haplotypes \
in this class at this time. \
\>", "Text",
 CellChangeTimes->{{3.7235317846586*^9, 3.723532017812759*^9}, {
   3.7243914840793743`*^9, 3.724391503238727*^9}, {3.724391584554901*^9, 
   3.724391643654016*^9}, 3.724391895770186*^9, {3.7256267842942047`*^9, 
   3.72562681867697*^9}, {3.7256268891327*^9, 3.72562689261904*^9}}],

Cell[BoxData[
 RowBox[{"GetDeficit", ";"}]], "Input",
 CellChangeTimes->{{3.7243916615981703`*^9, 3.724391663390102*^9}, {
  3.7243917637949247`*^9, 3.724391764162766*^9}}],

Cell["\<\
This may be used to highlight (dark green) those parts of the events where a \
fully complete haplotype exists. \
\>", "Text",
 CellChangeTimes->{{3.723532155908346*^9, 3.723532212625345*^9}, {
   3.724390859518423*^9, 3.724390895709673*^9}, {3.724391469178138*^9, 
   3.7243914724822073`*^9}, 3.724391900391589*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"PlotTabsCompleteAll", ";"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PlotTabsComplete", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t2", " ", "=", " ", "generations"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"P2", " ", "=", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "@", "tbls"}], " ", ">", " ", "0"}], ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"complete", " ", "SI", " ", "segments"}], " ", "*)"}], "\n", 
       "\t", 
       RowBox[{"Show", "[", 
        RowBox[{"tbls", ",", " ", 
         RowBox[{"ImageSize", " ", "->", " ", "1000"}], ",", " ", 
         RowBox[{"PlotRange", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "t2"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"0.5", ",", " ", 
              RowBox[{
               RowBox[{"RTypes", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}]}], 
           "}"}]}], ",", " ", 
         RowBox[{"Frame", " ", "->", " ", "True"}], ",", " ", 
         RowBox[{"AxesOrigin", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0"}], "}"}]}], ",", "\n", "\t", 
         RowBox[{"Frame", " ", "->", " ", "True"}], ",", 
         RowBox[{"FrameLabel", " ", "->", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<SI class\>\"", ",", " ", "None"}], "}"}], ",", " ", 
            
            RowBox[{"{", 
             RowBox[{
             "\"\<generation\>\"", ",", " ", 
              "\"\<SI class production and annihilation\>\""}], "}"}]}], 
           "}"}]}], ",", "\n", "    ", 
         RowBox[{"ImageSize", " ", "->", " ", "1000"}], ",", " ", 
         RowBox[{"AspectRatio", " ", "->", " ", "0.2"}]}], "]"}]}], "\n", 
      "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.721556532508471*^9, 3.721556552775345*^9}, {
   3.721556657112185*^9, 3.721556730782426*^9}, {3.721556761219611*^9, 
   3.721556771507848*^9}, {3.7215632396143913`*^9, 3.721563259219243*^9}, {
   3.72156332778473*^9, 3.7215636864173403`*^9}, {3.721563763744746*^9, 
   3.721563813604109*^9}, {3.721975864072316*^9, 3.72197588334204*^9}, {
   3.721975941238207*^9, 3.721975976995048*^9}, {3.721976027256431*^9, 
   3.721976062943227*^9}, {3.721976284682016*^9, 3.721976292239152*^9}, {
   3.721976595951095*^9, 3.721976621300192*^9}, 3.721976658858593*^9, {
   3.721976986814464*^9, 3.721976987847515*^9}, {3.7219822523282967`*^9, 
   3.7219822598280697`*^9}, {3.721991911920877*^9, 3.7219919124470577`*^9}, {
   3.721991992655704*^9, 3.721992083944615*^9}, {3.7219925886998053`*^9, 
   3.7219925936961203`*^9}, {3.7235323387280073`*^9, 3.723532387653015*^9}, {
   3.72353243717691*^9, 3.723532476407552*^9}, 3.723532519254447*^9, {
   3.724391777459907*^9, 3.72439177967423*^9}, 3.72439183589213*^9, {
   3.7243918784086103`*^9, 3.7243918866417103`*^9}, 3.724392102373049*^9, {
   3.724392246018073*^9, 3.7243922501078873`*^9}, {3.724392290509892*^9, 
   3.724392305555459*^9}, 3.7256270447291517`*^9, {3.725627145934857*^9, 
   3.7256271556946697`*^9}, {3.7256289876134043`*^9, 3.725628989086341*^9}, {
   3.7256300316470337`*^9, 3.725630031981979*^9}, {3.725630359222672*^9, 
   3.7256303597008553`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"P1", ",", "P2"}], "]"}]], "Input",
 CellChangeTimes->{{3.721556532508471*^9, 3.721556552775345*^9}, {
   3.721556657112185*^9, 3.721556730782426*^9}, {3.721556761219611*^9, 
   3.721556771507848*^9}, {3.7215632396143913`*^9, 3.721563259219243*^9}, {
   3.72156332778473*^9, 3.7215636864173403`*^9}, {3.721563763744746*^9, 
   3.721563813604109*^9}, {3.721975864072316*^9, 3.72197588334204*^9}, {
   3.721975941238207*^9, 3.721975976995048*^9}, {3.721976027256431*^9, 
   3.721976062943227*^9}, {3.721976284682016*^9, 3.721976292239152*^9}, {
   3.721976595951095*^9, 3.721976621300192*^9}, 3.721976658858593*^9, {
   3.721976986814464*^9, 3.721976987847515*^9}, {3.7219822523282967`*^9, 
   3.7219822598280697`*^9}, {3.721991911920877*^9, 3.7219919124470577`*^9}, {
   3.721991992655704*^9, 3.721992083944615*^9}, {3.7219925886998053`*^9, 
   3.7219925936961203`*^9}, {3.7235323387280073`*^9, 3.723532387653015*^9}, {
   3.72353243717691*^9, 3.723532476407552*^9}, 3.723532519254447*^9, {
   3.724392309395378*^9, 3.724392334777314*^9}, 3.7243923880975246`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{9., 1.}, {10., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{11., 1.}, {15., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{17., 1.}, {19., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{25., 1.}, {29., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{30., 1.}, {31., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{34., 1.}, {51., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{55., 1.}, {62., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{77., 1.}, {78., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
       
       StyleBox[LineBox[{{80., 1.}, {500., 1.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
       
       StyleBox[LineBox[{{50., 2.}, {500., 2.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{310., 3.}, {314., 3.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{393., 3.}, {394., 3.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{294., 4.}, {295., 4.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{325., 4.}, {331., 4.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{129., 5.}, {130., 5.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{135., 5.}, {136., 5.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{156., 5.}, {157., 5.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{176., 5.}, {178., 5.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{222., 5.}, {223., 5.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{360., 5.}, {361., 5.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{210., 6.}, {211., 6.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{43., 7.}, {45., 7.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{90., 7.}, {91., 7.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{122., 7.}, {123., 7.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{152., 7.}, {156., 7.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{229., 7.}, {230., 7.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{439., 7.}, {440., 7.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{112., 8.}, {118., 8.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{262., 8.}, {269., 8.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{274., 8.}, {275., 8.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{5., 9.}, {6., 9.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{19., 9.}, {20., 9.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{195., 9.}, {197., 9.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
       
       StyleBox[LineBox[{{227., 9.}, {400., 9.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{316., 10.}, {317., 10.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{214., 11.}, {215., 11.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{287., 11.}, {288., 11.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{339., 11.}, {340., 11.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{475., 11.}, {478., 11.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{368., 12.}, {384., 12.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{450., 12.}, {451., 12.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{153., 14.}, {156., 14.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{216., 14.}, {217., 14.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{455., 14.}, {465., 14.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{249., 15.}, {250., 15.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{427., 15.}, {431., 15.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{249., 17.}, {267., 17.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{385., 17.}, {390., 17.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{428., 17.}, {500., 17.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{104., 18.}, {106., 18.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{156., 18.}, {158., 18.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
       
       StyleBox[LineBox[{{129., 19.}, {258., 19.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{110., 22.}, {111., 22.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{161., 22.}, {164., 22.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{307., 22.}, {309., 22.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{287., 24.}, {290., 24.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{419., 24.}, {420., 24.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{323., 25.}, {324., 25.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{204., 26.}, {208., 26.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{220., 26.}, {225., 26.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{238., 26.}, {241., 26.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{477., 26.}, {485., 26.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{491., 26.}, {500., 26.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{97., 27.}, {104., 27.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{96., 28.}, {100., 28.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{112., 28.}, {113., 28.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{119., 29.}, {160., 29.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{247., 29.}, {254., 29.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{384., 29.}, {386., 29.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{178., 30.}, {183., 30.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
       
       StyleBox[LineBox[{{46., 31.}, {162., 31.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{67., 32.}, {70., 32.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{105., 32.}, {195., 32.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
       
       StyleBox[LineBox[{{247., 32.}, {500., 32.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{100., 33.}, {101., 33.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{146., 33.}, {147., 33.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{441., 33.}, {442., 33.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{383., 35.}, {384., 35.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{402., 36.}, {403., 36.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{118., 37.}, {119., 37.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{408., 38.}, {410., 38.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{419., 38.}, {420., 38.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{4., 40.}, {61., 40.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{162., 44.}, {163., 44.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{351., 44.}, {383., 44.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{453., 44.}, {500., 44.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{238., 45.}, {239., 45.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{250., 47.}, {251., 47.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{429., 47.}, {430., 47.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{25., 49.}, {26., 49.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{108., 49.}, {110., 49.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{310., 49.}, {311., 49.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{477., 49.}, {500., 49.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {GrayLevel[0.5], PointSize[0.012833333333333334`], Thickness[0.002], 
       StyleBox[LineBox[{{20., 50.}, {46., 50.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.012833333333333334`], Thickness[0.003], 
       
       StyleBox[LineBox[{{110., 50.}, {257., 50.}}],
        FontFamily->"Helvetica",
        FontSize->16]}}, {}, {}, {{}, {}}}}, {{{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{96., 1.}}, {{96., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{97., 1.}}, {{97., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{98., 1.}}, {{98., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{99., 1.}}, {{99., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{100., 1.}}, {{100., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{101., 1.}}, {{101., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{102., 1.}}, {{102., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{103., 1.}}, {{103., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{104., 1.}}, {{104., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{105., 1.}}, {{105., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{106., 1.}}, {{106., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{107., 1.}}, {{107., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{108., 1.}}, {{108., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{110., 1.}}, {{110., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{111., 1.}}, {{111., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{112., 1.}}, {{112., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{113., 1.}}, {{113., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{114., 1.}}, {{114., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{115., 1.}}, {{115., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{260., 1.}}, {{260., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{261., 1.}}, {{261., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{262., 1.}}, {{262., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{263., 1.}}, {{263., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{267., 1.}}, {{267., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{268., 1.}}, {{268., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{269., 1.}}, {{269., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{270., 1.}}, {{270., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{271., 1.}}, {{271., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{272., 1.}}, {{272., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{273., 1.}}, {{273., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{274., 1.}}, {{274., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{275., 1.}}, {{275., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{276., 1.}}, {{276., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{277., 1.}}, {{277., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{278., 1.}}, {{278., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{279., 1.}}, {{279., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{280., 1.}}, {{280., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{281., 1.}}, {{281., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{282., 1.}}, {{282., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{283., 1.}}, {{283., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{284., 1.}}, {{284., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{285., 1.}}, {{285., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{286., 1.}}, {{286., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{287., 1.}}, {{287., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{288., 1.}}, {{288., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{289., 1.}}, {{289., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{290., 1.}}, {{290., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{291., 1.}}, {{291., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{292., 1.}}, {{292., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{293., 1.}}, {{293., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{294., 1.}}, {{294., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{295., 1.}}, {{295., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{296., 1.}}, {{296., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{297., 1.}}, {{297., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{298., 1.}}, {{298., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{299., 1.}}, {{299., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{300., 1.}}, {{300., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{301., 1.}}, {{301., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{302., 1.}}, {{302., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{303., 1.}}, {{303., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{304., 1.}}, {{304., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{305., 1.}}, {{305., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{306., 1.}}, {{306., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{307., 1.}}, {{307., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{308., 1.}}, {{308., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{309., 1.}}, {{309., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{310., 1.}}, {{310., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{311., 1.}}, {{311., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{312., 1.}}, {{312., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{313., 1.}}, {{313., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{314., 1.}}, {{314., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{315., 1.}}, {{315., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{316., 1.}}, {{316., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{317., 1.}}, {{317., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{318., 1.}}, {{318., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{319., 1.}}, {{319., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{320., 1.}}, {{320., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{321., 1.}}, {{321., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{322., 1.}}, {{322., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{323., 1.}}, {{323., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{324., 1.}}, {{324., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{325., 1.}}, {{325., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{326., 1.}}, {{326., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{327., 1.}}, {{327., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{328., 1.}}, {{328., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{329., 1.}}, {{329., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{330., 1.}}, {{330., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{331., 1.}}, {{331., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{332., 1.}}, {{332., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{333., 1.}}, {{333., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{334., 1.}}, {{334., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{335., 1.}}, {{335., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{336., 1.}}, {{336., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{337., 1.}}, {{337., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{338., 1.}}, {{338., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{339., 1.}}, {{339., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{340., 1.}}, {{340., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{341., 1.}}, {{341., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{342., 1.}}, {{342., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{343., 1.}}, {{343., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{344., 1.}}, {{344., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{345., 1.}}, {{345., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{346., 1.}}, {{346., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{347., 1.}}, {{347., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{348., 1.}}, {{348., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{349., 1.}}, {{349., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{350., 1.}}, {{350., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{351., 1.}}, {{351., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{352., 1.}}, {{352., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{353., 1.}}, {{353., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{354., 1.}}, {{354., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{355., 1.}}, {{355., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{356., 1.}}, {{356., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{357., 1.}}, {{357., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{358., 1.}}, {{358., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{359., 1.}}, {{359., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{360., 1.}}, {{360., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{361., 1.}}, {{361., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{362., 1.}}, {{362., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{363., 1.}}, {{363., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{364., 1.}}, {{364., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{365., 1.}}, {{365., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{366., 1.}}, {{366., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{367., 1.}}, {{367., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{368., 1.}}, {{368., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{369., 1.}}, {{369., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{370., 1.}}, {{370., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{371., 1.}}, {{371., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{372., 1.}}, {{372., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{373., 1.}}, {{373., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{374., 1.}}, {{374., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{375., 1.}}, {{375., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{376., 1.}}, {{376., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{377., 1.}}, {{377., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{378., 1.}}, {{378., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{379., 1.}}, {{379., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{380., 1.}}, {{380., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{381., 1.}}, {{381., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{382., 1.}}, {{382., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{383., 1.}}, {{383., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{384., 1.}}, {{384., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{385., 1.}}, {{385., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{386., 1.}}, {{386., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{387., 1.}}, {{387., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{388., 1.}}, {{388., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{389., 1.}}, {{389., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{390., 1.}}, {{390., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{391., 1.}}, {{391., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{392., 1.}}, {{392., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{393., 1.}}, {{393., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{394., 1.}}, {{394., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{395., 1.}}, {{395., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{396., 1.}}, {{396., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{397., 1.}}, {{397., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{398., 1.}}, {{398., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{399., 1.}}, {{399., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{400., 1.}}, {{400., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{401., 1.}}, {{401., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{402., 1.}}, {{402., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{403., 1.}}, {{403., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{404., 1.}}, {{404., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{405., 1.}}, {{405., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{406., 1.}}, {{406., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{407., 1.}}, {{407., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{408., 1.}}, {{408., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{409., 1.}}, {{409., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{410., 1.}}, {{410., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{411., 1.}}, {{411., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{412., 1.}}, {{412., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{413., 1.}}, {{413., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{414., 1.}}, {{414., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{415., 1.}}, {{415., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{416., 1.}}, {{416., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{417., 1.}}, {{417., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{418., 1.}}, {{418., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{419., 1.}}, {{419., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{420., 1.}}, {{420., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{421., 1.}}, {{421., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{422., 1.}}, {{422., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{423., 1.}}, {{423., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{424., 1.}}, {{424., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{425., 1.}}, {{425., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{426., 1.}}, {{426., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{427., 1.}}, {{427., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{428., 1.}}, {{428., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{429., 1.}}, {{429., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{430., 1.}}, {{430., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{431., 1.}}, {{431., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{432., 1.}}, {{432., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{433., 1.}}, {{433., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{437., 1.}}, {{437., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{438., 1.}}, {{438., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{439., 1.}}, {{439., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{440., 1.}}, {{440., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{441., 1.}}, {{441., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{442., 1.}}, {{442., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{443., 1.}}, {{443., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{444., 1.}}, {{444., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{445., 1.}}, {{445., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{446., 1.}}, {{446., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{447., 1.}}, {{447., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{448., 1.}}, {{448., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{449., 1.}}, {{449., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{450., 1.}}, {{450., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{451., 1.}}, {{451., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{452., 1.}}, {{452., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{453., 1.}}, {{453., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{454., 1.}}, {{454., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{455., 1.}}, {{455., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{456., 1.}}, {{456., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{457., 1.}}, {{457., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{458., 1.}}, {{458., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{459., 1.}}, {{459., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{460., 1.}}, {{460., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{475., 1.}}, {{475., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{476., 1.}}, {{476., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{477., 1.}}, {{477., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{478., 1.}}, {{478., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{479., 1.}}, {{479., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{480., 1.}}, {{480., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{481., 1.}}, {{481., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{482., 1.}}, {{482., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{483., 1.}}, {{483., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{484., 1.}}, {{484., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{485., 1.}}, {{485., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{486., 1.}}, {{486., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{487., 1.}}, {{487., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{488., 1.}}, {{488., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{489., 1.}}, {{489., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{490., 1.}}, {{490., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{491., 1.}}, {{491., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{492., 1.}}, {{492., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{493., 1.}}, {{493., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{494., 1.}}, {{494., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{495., 1.}}, {{495., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{496., 1.}}, {{496., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{497., 1.}}, {{497., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{498., 1.}}, {{498., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{499., 1.}}, {{499., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{500., 1.}}, {{500., 1.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{54., 2.}}, {{54., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{55., 2.}}, {{55., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{56., 2.}}, {{56., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{57., 2.}}, {{57., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{58., 2.}}, {{58., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{59., 2.}}, {{59., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{60., 2.}}, {{60., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{61., 2.}}, {{61., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{62., 2.}}, {{62., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{63., 2.}}, {{63., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{64., 2.}}, {{64., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{65., 2.}}, {{65., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{66., 2.}}, {{66., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{67., 2.}}, {{67., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{68., 2.}}, {{68., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{69., 2.}}, {{69., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{70., 2.}}, {{70., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{71., 2.}}, {{71., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{72., 2.}}, {{72., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{73., 2.}}, {{73., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{74., 2.}}, {{74., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{75., 2.}}, {{75., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{76., 2.}}, {{76., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{77., 2.}}, {{77., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{78., 2.}}, {{78., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{79., 2.}}, {{79., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{80., 2.}}, {{80., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{81., 2.}}, {{81., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{82., 2.}}, {{82., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{83., 2.}}, {{83., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{84., 2.}}, {{84., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{85., 2.}}, {{85., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{86., 2.}}, {{86., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{87., 2.}}, {{87., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{88., 2.}}, {{88., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{89., 2.}}, {{89., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{90., 2.}}, {{90., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{91., 2.}}, {{91., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{92., 2.}}, {{92., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{93., 2.}}, {{93., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{94., 2.}}, {{94., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{95., 2.}}, {{95., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{96., 2.}}, {{96., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{97., 2.}}, {{97., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{98., 2.}}, {{98., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{99., 2.}}, {{99., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{100., 2.}}, {{100., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{101., 2.}}, {{101., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{102., 2.}}, {{102., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{103., 2.}}, {{103., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{104., 2.}}, {{104., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{105., 2.}}, {{105., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{106., 2.}}, {{106., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{107., 2.}}, {{107., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{108., 2.}}, {{108., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{110., 2.}}, {{110., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{111., 2.}}, {{111., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{112., 2.}}, {{112., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{117., 2.}}, {{117., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{118., 2.}}, {{118., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{119., 2.}}, {{119., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{121., 2.}}, {{121., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{122., 2.}}, {{122., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{123., 2.}}, {{123., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{124., 2.}}, {{124., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{125., 2.}}, {{125., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{126., 2.}}, {{126., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{127., 2.}}, {{127., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{128., 2.}}, {{128., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{129., 2.}}, {{129., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{130., 2.}}, {{130., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{131., 2.}}, {{131., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{132., 2.}}, {{132., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{133., 2.}}, {{133., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{134., 2.}}, {{134., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{135., 2.}}, {{135., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{136., 2.}}, {{136., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{137., 2.}}, {{137., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{138., 2.}}, {{138., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{139., 2.}}, {{139., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{140., 2.}}, {{140., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{141., 2.}}, {{141., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{142., 2.}}, {{142., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{143., 2.}}, {{143., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{144., 2.}}, {{144., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{145., 2.}}, {{145., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{146., 2.}}, {{146., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{147., 2.}}, {{147., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{148., 2.}}, {{148., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{149., 2.}}, {{149., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{150., 2.}}, {{150., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{151., 2.}}, {{151., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{152., 2.}}, {{152., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{153., 2.}}, {{153., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{154., 2.}}, {{154., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{155., 2.}}, {{155., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{156., 2.}}, {{156., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{157., 2.}}, {{157., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{158., 2.}}, {{158., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{159., 2.}}, {{159., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{160., 2.}}, {{160., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{161., 2.}}, {{161., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{162., 2.}}, {{162., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{163., 2.}}, {{163., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{164., 2.}}, {{164., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{165., 2.}}, {{165., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{166., 2.}}, {{166., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{167., 2.}}, {{167., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{168., 2.}}, {{168., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{169., 2.}}, {{169., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{170., 2.}}, {{170., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{171., 2.}}, {{171., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{172., 2.}}, {{172., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{173., 2.}}, {{173., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{174., 2.}}, {{174., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{175., 2.}}, {{175., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{176., 2.}}, {{176., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{177., 2.}}, {{177., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{178., 2.}}, {{178., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{179., 2.}}, {{179., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{180., 2.}}, {{180., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{181., 2.}}, {{181., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{182., 2.}}, {{182., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{183., 2.}}, {{183., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{184., 2.}}, {{184., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{185., 2.}}, {{185., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{186., 2.}}, {{186., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{187., 2.}}, {{187., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{188., 2.}}, {{188., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{189., 2.}}, {{189., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{190., 2.}}, {{190., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{191., 2.}}, {{191., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{192., 2.}}, {{192., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{193., 2.}}, {{193., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{194., 2.}}, {{194., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{195., 2.}}, {{195., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{196., 2.}}, {{196., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{197., 2.}}, {{197., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{198., 2.}}, {{198., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{199., 2.}}, {{199., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{200., 2.}}, {{200., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{201., 2.}}, {{201., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{202., 2.}}, {{202., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{203., 2.}}, {{203., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{204., 2.}}, {{204., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{205., 2.}}, {{205., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{206., 2.}}, {{206., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{207., 2.}}, {{207., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{208., 2.}}, {{208., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{209., 2.}}, {{209., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{210., 2.}}, {{210., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{211., 2.}}, {{211., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{212., 2.}}, {{212., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{213., 2.}}, {{213., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{214., 2.}}, {{214., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{215., 2.}}, {{215., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{216., 2.}}, {{216., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{217., 2.}}, {{217., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{218., 2.}}, {{218., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{219., 2.}}, {{219., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{220., 2.}}, {{220., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{221., 2.}}, {{221., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{222., 2.}}, {{222., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{223., 2.}}, {{223., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{224., 2.}}, {{224., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{225., 2.}}, {{225., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{226., 2.}}, {{226., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{227., 2.}}, {{227., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{228., 2.}}, {{228., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{229., 2.}}, {{229., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{230., 2.}}, {{230., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{231., 2.}}, {{231., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{232., 2.}}, {{232., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{233., 2.}}, {{233., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{234., 2.}}, {{234., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{235., 2.}}, {{235., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{236., 2.}}, {{236., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{237., 2.}}, {{237., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{238., 2.}}, {{238., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{239., 2.}}, {{239., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{240., 2.}}, {{240., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{241., 2.}}, {{241., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{242., 2.}}, {{242., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{243., 2.}}, {{243., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{244., 2.}}, {{244., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{245., 2.}}, {{245., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{246., 2.}}, {{246., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{247., 2.}}, {{247., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{248., 2.}}, {{248., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{249., 2.}}, {{249., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{250., 2.}}, {{250., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{251., 2.}}, {{251., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{252., 2.}}, {{252., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{253., 2.}}, {{253., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{254., 2.}}, {{254., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{255., 2.}}, {{255., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{256., 2.}}, {{256., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{257., 2.}}, {{257., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{258., 2.}}, {{258., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{259., 2.}}, {{259., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{260., 2.}}, {{260., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{261., 2.}}, {{261., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{262., 2.}}, {{262., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{263., 2.}}, {{263., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{264., 2.}}, {{264., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{265., 2.}}, {{265., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{266., 2.}}, {{266., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{267., 2.}}, {{267., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{268., 2.}}, {{268., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{269., 2.}}, {{269., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{270., 2.}}, {{270., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{271., 2.}}, {{271., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{272., 2.}}, {{272., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{273., 2.}}, {{273., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{274., 2.}}, {{274., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{275., 2.}}, {{275., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{276., 2.}}, {{276., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{277., 2.}}, {{277., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{278., 2.}}, {{278., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{279., 2.}}, {{279., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{280., 2.}}, {{280., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{281., 2.}}, {{281., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{282., 2.}}, {{282., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{283., 2.}}, {{283., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{284., 2.}}, {{284., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{285., 2.}}, {{285., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{286., 2.}}, {{286., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{287., 2.}}, {{287., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{288., 2.}}, {{288., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{289., 2.}}, {{289., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{290., 2.}}, {{290., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{291., 2.}}, {{291., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{292., 2.}}, {{292., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{293., 2.}}, {{293., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{294., 2.}}, {{294., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{295., 2.}}, {{295., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{296., 2.}}, {{296., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{297., 2.}}, {{297., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{298., 2.}}, {{298., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{299., 2.}}, {{299., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{300., 2.}}, {{300., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{301., 2.}}, {{301., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{302., 2.}}, {{302., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{303., 2.}}, {{303., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{304., 2.}}, {{304., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{305., 2.}}, {{305., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{306., 2.}}, {{306., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{307., 2.}}, {{307., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{308., 2.}}, {{308., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{309., 2.}}, {{309., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{310., 2.}}, {{310., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{311., 2.}}, {{311., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{312., 2.}}, {{312., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{313., 2.}}, {{313., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{314., 2.}}, {{314., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{315., 2.}}, {{315., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{316., 2.}}, {{316., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{317., 2.}}, {{317., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{318., 2.}}, {{318., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{319., 2.}}, {{319., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{320., 2.}}, {{320., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{321., 2.}}, {{321., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{322., 2.}}, {{322., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{323., 2.}}, {{323., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{324., 2.}}, {{324., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{325., 2.}}, {{325., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{326., 2.}}, {{326., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{327., 2.}}, {{327., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{328., 2.}}, {{328., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{329., 2.}}, {{329., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{330., 2.}}, {{330., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{331., 2.}}, {{331., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{332., 2.}}, {{332., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{333., 2.}}, {{333., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{334., 2.}}, {{334., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{335., 2.}}, {{335., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{336., 2.}}, {{336., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{337., 2.}}, {{337., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{338., 2.}}, {{338., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{339., 2.}}, {{339., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{340., 2.}}, {{340., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{341., 2.}}, {{341., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{342., 2.}}, {{342., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{343., 2.}}, {{343., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{344., 2.}}, {{344., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{345., 2.}}, {{345., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{346., 2.}}, {{346., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{347., 2.}}, {{347., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{348., 2.}}, {{348., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{349., 2.}}, {{349., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{350., 2.}}, {{350., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{351., 2.}}, {{351., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{352., 2.}}, {{352., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{353., 2.}}, {{353., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{354., 2.}}, {{354., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{355., 2.}}, {{355., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{356., 2.}}, {{356., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{357., 2.}}, {{357., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{358., 2.}}, {{358., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{359., 2.}}, {{359., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{360., 2.}}, {{360., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{361., 2.}}, {{361., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{362., 2.}}, {{362., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{363., 2.}}, {{363., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{364., 2.}}, {{364., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{365., 2.}}, {{365., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{366., 2.}}, {{366., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{367., 2.}}, {{367., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{368., 2.}}, {{368., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{369., 2.}}, {{369., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{370., 2.}}, {{370., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{371., 2.}}, {{371., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{372., 2.}}, {{372., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{373., 2.}}, {{373., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{374., 2.}}, {{374., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{375., 2.}}, {{375., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{376., 2.}}, {{376., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{377., 2.}}, {{377., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{378., 2.}}, {{378., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{379., 2.}}, {{379., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{380., 2.}}, {{380., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{381., 2.}}, {{381., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{382., 2.}}, {{382., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{383., 2.}}, {{383., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{384., 2.}}, {{384., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{385., 2.}}, {{385., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{386., 2.}}, {{386., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{387., 2.}}, {{387., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{388., 2.}}, {{388., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{389., 2.}}, {{389., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{390., 2.}}, {{390., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{391., 2.}}, {{391., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{392., 2.}}, {{392., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{393., 2.}}, {{393., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{394., 2.}}, {{394., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{395., 2.}}, {{395., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{396., 2.}}, {{396., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{397., 2.}}, {{397., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{398., 2.}}, {{398., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{399., 2.}}, {{399., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{400., 2.}}, {{400., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{401., 2.}}, {{401., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{402., 2.}}, {{402., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{403., 2.}}, {{403., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{404., 2.}}, {{404., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{405., 2.}}, {{405., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{406., 2.}}, {{406., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{407., 2.}}, {{407., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{408., 2.}}, {{408., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{409., 2.}}, {{409., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{410., 2.}}, {{410., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{411., 2.}}, {{411., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{412., 2.}}, {{412., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{413., 2.}}, {{413., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{414., 2.}}, {{414., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{415., 2.}}, {{415., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{416., 2.}}, {{416., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{417., 2.}}, {{417., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{418., 2.}}, {{418., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{419., 2.}}, {{419., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{420., 2.}}, {{420., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{421., 2.}}, {{421., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{422., 2.}}, {{422., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{423., 2.}}, {{423., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{424., 2.}}, {{424., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{425., 2.}}, {{425., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{426., 2.}}, {{426., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{427., 2.}}, {{427., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{428., 2.}}, {{428., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{429., 2.}}, {{429., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{430., 2.}}, {{430., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{431., 2.}}, {{431., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{432., 2.}}, {{432., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{433., 2.}}, {{433., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{434., 2.}}, {{434., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{435., 2.}}, {{435., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{436., 2.}}, {{436., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{437., 2.}}, {{437., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{438., 2.}}, {{438., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{439., 2.}}, {{439., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{440., 2.}}, {{440., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{441., 2.}}, {{441., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{442., 2.}}, {{442., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{443., 2.}}, {{443., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{444., 2.}}, {{444., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{445., 2.}}, {{445., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{446., 2.}}, {{446., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{447., 2.}}, {{447., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{448., 2.}}, {{448., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{449., 2.}}, {{449., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{450., 2.}}, {{450., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{451., 2.}}, {{451., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{452., 2.}}, {{452., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{453., 2.}}, {{453., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{454., 2.}}, {{454., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{455., 2.}}, {{455., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{456., 2.}}, {{456., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{457., 2.}}, {{457., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{458., 2.}}, {{458., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{459., 2.}}, {{459., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{460., 2.}}, {{460., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{461., 2.}}, {{461., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{462., 2.}}, {{462., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{463., 2.}}, {{463., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{464., 2.}}, {{464., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{465., 2.}}, {{465., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{466., 2.}}, {{466., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{467., 2.}}, {{467., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{468., 2.}}, {{468., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{469., 2.}}, {{469., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{470., 2.}}, {{470., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{471., 2.}}, {{471., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{472., 2.}}, {{472., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{473., 2.}}, {{473., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{474., 2.}}, {{474., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{475., 2.}}, {{475., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{476., 2.}}, {{476., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{477., 2.}}, {{477., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{478., 2.}}, {{478., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{479., 2.}}, {{479., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{480., 2.}}, {{480., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{481., 2.}}, {{481., 2.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{233., 9.}}, {{233., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{234., 9.}}, {{234., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{235., 9.}}, {{235., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{236., 9.}}, {{236., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{237., 9.}}, {{237., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{238., 9.}}, {{238., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{239., 9.}}, {{239., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{240., 9.}}, {{240., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{241., 9.}}, {{241., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{242., 9.}}, {{242., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{243., 9.}}, {{243., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{244., 9.}}, {{244., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{245., 9.}}, {{245., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{246., 9.}}, {{246., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{247., 9.}}, {{247., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{248., 9.}}, {{248., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{249., 9.}}, {{249., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{250., 9.}}, {{250., 9.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{434., 17.}}, {{434., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{435., 17.}}, {{435., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{436., 17.}}, {{436., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{437., 17.}}, {{437., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{438., 17.}}, {{438., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{439., 17.}}, {{439., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{440., 17.}}, {{440., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{441., 17.}}, {{441., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{442., 17.}}, {{442., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{443., 17.}}, {{443., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{444., 17.}}, {{444., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{445., 17.}}, {{445., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{446., 17.}}, {{446., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{447., 17.}}, {{447., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{448., 17.}}, {{448., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{449., 17.}}, {{449., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{450., 17.}}, {{450., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{451., 17.}}, {{451., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{452., 17.}}, {{452., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{453., 17.}}, {{453., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{454., 17.}}, {{454., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{455., 17.}}, {{455., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{456., 17.}}, {{456., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{457., 17.}}, {{457., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{458., 17.}}, {{458., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{459., 17.}}, {{459., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{460., 17.}}, {{460., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{497., 17.}}, {{497., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{498., 17.}}, {{498., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{499., 17.}}, {{499., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{500., 17.}}, {{500., 17.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{133., 19.}}, {{133., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{134., 19.}}, {{134., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{135., 19.}}, {{135., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{136., 19.}}, {{136., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{137., 19.}}, {{137., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{138., 19.}}, {{138., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{139., 19.}}, {{139., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{140., 19.}}, {{140., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{141., 19.}}, {{141., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{142., 19.}}, {{142., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{143., 19.}}, {{143., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{144., 19.}}, {{144., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{145., 19.}}, {{145., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{146., 19.}}, {{146., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{147., 19.}}, {{147., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{148., 19.}}, {{148., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{149., 19.}}, {{149., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{150., 19.}}, {{150., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{151., 19.}}, {{151., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{152., 19.}}, {{152., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{153., 19.}}, {{153., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{154., 19.}}, {{154., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{155., 19.}}, {{155., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{156., 19.}}, {{156., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{157., 19.}}, {{157., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{158., 19.}}, {{158., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{159., 19.}}, {{159., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{160., 19.}}, {{160., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{161., 19.}}, {{161., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{162., 19.}}, {{162., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{163., 19.}}, {{163., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{164., 19.}}, {{164., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{165., 19.}}, {{165., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{166., 19.}}, {{166., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{167., 19.}}, {{167., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{168., 19.}}, {{168., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{169., 19.}}, {{169., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{170., 19.}}, {{170., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{171., 19.}}, {{171., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{172., 19.}}, {{172., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{173., 19.}}, {{173., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{174., 19.}}, {{174., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{175., 19.}}, {{175., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{176., 19.}}, {{176., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{177., 19.}}, {{177., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{178., 19.}}, {{178., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{179., 19.}}, {{179., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{180., 19.}}, {{180., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{181., 19.}}, {{181., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{182., 19.}}, {{182., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{183., 19.}}, {{183., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{184., 19.}}, {{184., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{185., 19.}}, {{185., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{186., 19.}}, {{186., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{187., 19.}}, {{187., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{188., 19.}}, {{188., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{189., 19.}}, {{189., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{190., 19.}}, {{190., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{191., 19.}}, {{191., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{192., 19.}}, {{192., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{193., 19.}}, {{193., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{194., 19.}}, {{194., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{195., 19.}}, {{195., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{196., 19.}}, {{196., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{197., 19.}}, {{197., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{198., 19.}}, {{198., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{199., 19.}}, {{199., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{200., 19.}}, {{200., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{201., 19.}}, {{201., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{202., 19.}}, {{202., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{203., 19.}}, {{203., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{204., 19.}}, {{204., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{205., 19.}}, {{205., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{206., 19.}}, {{206., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{207., 19.}}, {{207., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{208., 19.}}, {{208., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{209., 19.}}, {{209., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{210., 19.}}, {{210., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{211., 19.}}, {{211., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{212., 19.}}, {{212., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{213., 19.}}, {{213., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{214., 19.}}, {{214., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{215., 19.}}, {{215., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{216., 19.}}, {{216., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{217., 19.}}, {{217., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{218., 19.}}, {{218., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{219., 19.}}, {{219., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{220., 19.}}, {{220., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{221., 19.}}, {{221., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{222., 19.}}, {{222., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{223., 19.}}, {{223., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{224., 19.}}, {{224., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{225., 19.}}, {{225., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{226., 19.}}, {{226., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{227., 19.}}, {{227., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{228., 19.}}, {{228., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{229., 19.}}, {{229., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{230., 19.}}, {{230., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{231., 19.}}, {{231., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{232., 19.}}, {{232., 19.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{497., 26.}}, {{497., 26.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{498., 26.}}, {{498., 26.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{499., 26.}}, {{499., 26.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{500., 26.}}, {{500., 26.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{91., 31.}}, {{91., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{92., 31.}}, {{92., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{93., 31.}}, {{93., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{94., 31.}}, {{94., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{95., 31.}}, {{95., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{96., 31.}}, {{96., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{97., 31.}}, {{97., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{98., 31.}}, {{98., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{99., 31.}}, {{99., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{100., 31.}}, {{100., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{101., 31.}}, {{101., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{102., 31.}}, {{102., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{103., 31.}}, {{103., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{104., 31.}}, {{104., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{105., 31.}}, {{105., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{106., 31.}}, {{106., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{107., 31.}}, {{107., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{108., 31.}}, {{108., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{110., 31.}}, {{110., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{111., 31.}}, {{111., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{112., 31.}}, {{112., 31.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{109., 32.}}, {{109., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{113., 32.}}, {{113., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{114., 32.}}, {{114., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{115., 32.}}, {{115., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{116., 32.}}, {{116., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{251., 32.}}, {{251., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{252., 32.}}, {{252., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{253., 32.}}, {{253., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{254., 32.}}, {{254., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{255., 32.}}, {{255., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{256., 32.}}, {{256., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{257., 32.}}, {{257., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{258., 32.}}, {{258., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{259., 32.}}, {{259., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{260., 32.}}, {{260., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{261., 32.}}, {{261., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{262., 32.}}, {{262., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{263., 32.}}, {{263., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{264., 32.}}, {{264., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{265., 32.}}, {{265., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{266., 32.}}, {{266., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{267., 32.}}, {{267., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{268., 32.}}, {{268., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{269., 32.}}, {{269., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{270., 32.}}, {{270., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{271., 32.}}, {{271., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{272., 32.}}, {{272., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{273., 32.}}, {{273., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{274., 32.}}, {{274., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{275., 32.}}, {{275., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{276., 32.}}, {{276., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{277., 32.}}, {{277., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{278., 32.}}, {{278., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{279., 32.}}, {{279., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{280., 32.}}, {{280., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{281., 32.}}, {{281., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{282., 32.}}, {{282., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{283., 32.}}, {{283., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{284., 32.}}, {{284., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{285., 32.}}, {{285., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{286., 32.}}, {{286., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{287., 32.}}, {{287., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{288., 32.}}, {{288., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{289., 32.}}, {{289., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{290., 32.}}, {{290., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{291., 32.}}, {{291., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{292., 32.}}, {{292., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{293., 32.}}, {{293., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{294., 32.}}, {{294., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{295., 32.}}, {{295., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{296., 32.}}, {{296., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{297., 32.}}, {{297., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{298., 32.}}, {{298., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{299., 32.}}, {{299., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{300., 32.}}, {{300., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{301., 32.}}, {{301., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{302., 32.}}, {{302., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{303., 32.}}, {{303., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{304., 32.}}, {{304., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{305., 32.}}, {{305., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{306., 32.}}, {{306., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{307., 32.}}, {{307., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{308., 32.}}, {{308., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{309., 32.}}, {{309., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{310., 32.}}, {{310., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{311., 32.}}, {{311., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{312., 32.}}, {{312., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{313., 32.}}, {{313., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{314., 32.}}, {{314., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{315., 32.}}, {{315., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{316., 32.}}, {{316., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{317., 32.}}, {{317., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{318., 32.}}, {{318., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{319., 32.}}, {{319., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{320., 32.}}, {{320., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{321., 32.}}, {{321., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{322., 32.}}, {{322., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{323., 32.}}, {{323., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{324., 32.}}, {{324., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{325., 32.}}, {{325., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{326., 32.}}, {{326., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{327., 32.}}, {{327., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{328., 32.}}, {{328., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{329., 32.}}, {{329., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{330., 32.}}, {{330., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{331., 32.}}, {{331., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{332., 32.}}, {{332., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{333., 32.}}, {{333., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{334., 32.}}, {{334., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{335., 32.}}, {{335., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{336., 32.}}, {{336., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{337., 32.}}, {{337., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{338., 32.}}, {{338., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{339., 32.}}, {{339., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{340., 32.}}, {{340., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{341., 32.}}, {{341., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{342., 32.}}, {{342., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{343., 32.}}, {{343., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{344., 32.}}, {{344., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{345., 32.}}, {{345., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{346., 32.}}, {{346., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{347., 32.}}, {{347., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{348., 32.}}, {{348., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{349., 32.}}, {{349., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{350., 32.}}, {{350., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{351., 32.}}, {{351., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{352., 32.}}, {{352., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{353., 32.}}, {{353., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{354., 32.}}, {{354., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{355., 32.}}, {{355., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{356., 32.}}, {{356., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{357., 32.}}, {{357., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{358., 32.}}, {{358., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{359., 32.}}, {{359., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{360., 32.}}, {{360., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{361., 32.}}, {{361., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{362., 32.}}, {{362., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{363., 32.}}, {{363., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{364., 32.}}, {{364., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{365., 32.}}, {{365., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{366., 32.}}, {{366., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{367., 32.}}, {{367., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{368., 32.}}, {{368., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{369., 32.}}, {{369., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{370., 32.}}, {{370., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{371., 32.}}, {{371., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{372., 32.}}, {{372., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{373., 32.}}, {{373., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{374., 32.}}, {{374., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{375., 32.}}, {{375., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{376., 32.}}, {{376., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{377., 32.}}, {{377., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{378., 32.}}, {{378., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{379., 32.}}, {{379., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{380., 32.}}, {{380., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{381., 32.}}, {{381., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{382., 32.}}, {{382., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{383., 32.}}, {{383., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{384., 32.}}, {{384., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{385., 32.}}, {{385., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{386., 32.}}, {{386., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{387., 32.}}, {{387., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{388., 32.}}, {{388., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{389., 32.}}, {{389., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{390., 32.}}, {{390., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{391., 32.}}, {{391., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{392., 32.}}, {{392., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{393., 32.}}, {{393., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{394., 32.}}, {{394., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{395., 32.}}, {{395., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{396., 32.}}, {{396., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{397., 32.}}, {{397., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{398., 32.}}, {{398., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{399., 32.}}, {{399., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{400., 32.}}, {{400., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{401., 32.}}, {{401., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{402., 32.}}, {{402., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{403., 32.}}, {{403., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{404., 32.}}, {{404., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{405., 32.}}, {{405., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{406., 32.}}, {{406., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{407., 32.}}, {{407., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{408., 32.}}, {{408., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{409., 32.}}, {{409., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{410., 32.}}, {{410., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{411., 32.}}, {{411., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{412., 32.}}, {{412., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{413., 32.}}, {{413., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{414., 32.}}, {{414., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{415., 32.}}, {{415., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{416., 32.}}, {{416., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{417., 32.}}, {{417., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{418., 32.}}, {{418., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{419., 32.}}, {{419., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{420., 32.}}, {{420., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{421., 32.}}, {{421., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{422., 32.}}, {{422., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{423., 32.}}, {{423., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{424., 32.}}, {{424., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{425., 32.}}, {{425., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{426., 32.}}, {{426., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{427., 32.}}, {{427., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{428., 32.}}, {{428., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{429., 32.}}, {{429., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{430., 32.}}, {{430., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{431., 32.}}, {{431., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{432., 32.}}, {{432., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{433., 32.}}, {{433., 32.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{11., 40.}}, {{11., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{13., 40.}}, {{13., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{14., 40.}}, {{14., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{15., 40.}}, {{15., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{16., 40.}}, {{16., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{17., 40.}}, {{17., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{18., 40.}}, {{18., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{19., 40.}}, {{19., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{20., 40.}}, {{20., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{21., 40.}}, {{21., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{22., 40.}}, {{22., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{23., 40.}}, {{23., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{24., 40.}}, {{24., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{25., 40.}}, {{25., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{26., 40.}}, {{26., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{27., 40.}}, {{27., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{28., 40.}}, {{28., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{29., 40.}}, {{29., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{30., 40.}}, {{30., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{31., 40.}}, {{31., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{32., 40.}}, {{32., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{33., 40.}}, {{33., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{34., 40.}}, {{34., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{35., 40.}}, {{35., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{36., 40.}}, {{36., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{37., 40.}}, {{37., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{38., 40.}}, {{38., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{39., 40.}}, {{39., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{40., 40.}}, {{40., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{41., 40.}}, {{41., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{42., 40.}}, {{42., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{43., 40.}}, {{43., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{44., 40.}}, {{44., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{45., 40.}}, {{45., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{46., 40.}}, {{46., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{51., 40.}}, {{51., 40.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{461., 44.}}, {{461., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{462., 44.}}, {{462., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{463., 44.}}, {{463., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{464., 44.}}, {{464., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{465., 44.}}, {{465., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{466., 44.}}, {{466., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{467., 44.}}, {{467., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{468., 44.}}, {{468., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{469., 44.}}, {{469., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{470., 44.}}, {{470., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{471., 44.}}, {{471., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{472., 44.}}, {{472., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{473., 44.}}, {{473., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{474., 44.}}, {{474., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{475., 44.}}, {{475., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{476., 44.}}, {{476., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{477., 44.}}, {{477., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{478., 44.}}, {{478., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{479., 44.}}, {{479., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{480., 44.}}, {{480., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{481., 44.}}, {{481., 44.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{482., 49.}}, {{482., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{483., 49.}}, {{483., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{484., 49.}}, {{484., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{485., 49.}}, {{485., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{486., 49.}}, {{486., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{487., 49.}}, {{487., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{488., 49.}}, {{488., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{489., 49.}}, {{489., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{490., 49.}}, {{490., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{491., 49.}}, {{491., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{492., 49.}}, {{492., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{493., 49.}}, {{493., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{494., 49.}}, {{494., 49.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{117., 50.}}, {{117., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{118., 50.}}, {{118., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{119., 50.}}, {{119., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{121., 50.}}, {{121., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{122., 50.}}, {{122., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{123., 50.}}, {{123., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{124., 50.}}, {{124., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{125., 50.}}, {{125., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{126., 50.}}, {{126., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{127., 50.}}, {{127., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{128., 50.}}, {{128., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{129., 50.}}, {{129., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{130., 50.}}, {{130., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{131., 50.}}, {{131., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{132., 50.}}, {{132., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{133., 50.}}, {{133., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{134., 50.}}, {{134., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{135., 50.}}, {{135., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{136., 50.}}, {{136., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{137., 50.}}, {{137., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{138., 50.}}, {{138., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{139., 50.}}, {{139., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{140., 50.}}, {{140., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{141., 50.}}, {{141., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{142., 50.}}, {{142., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{143., 50.}}, {{143., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{144., 50.}}, {{144., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{145., 50.}}, {{145., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{146., 50.}}, {{146., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{147., 50.}}, {{147., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{148., 50.}}, {{148., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{149., 50.}}, {{149., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{150., 50.}}, {{150., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{151., 50.}}, {{151., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{152., 50.}}, {{152., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{153., 50.}}, {{153., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{154., 50.}}, {{154., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{155., 50.}}, {{155., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{156., 50.}}, {{156., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{157., 50.}}, {{157., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{158., 50.}}, {{158., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{159., 50.}}, {{159., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{160., 50.}}, {{160., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{161., 50.}}, {{161., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{162., 50.}}, {{162., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{163., 50.}}, {{163., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{164., 50.}}, {{164., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{165., 50.}}, {{165., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{166., 50.}}, {{166., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{167., 50.}}, {{167., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{168., 50.}}, {{168., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{169., 50.}}, {{169., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{170., 50.}}, {{170., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{171., 50.}}, {{171., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{172., 50.}}, {{172., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{173., 50.}}, {{173., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{174., 50.}}, {{174., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{175., 50.}}, {{175., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{176., 50.}}, {{176., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{177., 50.}}, {{177., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{178., 50.}}, {{178., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{179., 50.}}, {{179., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{180., 50.}}, {{180., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{181., 50.}}, {{181., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{182., 50.}}, {{182., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{183., 50.}}, {{183., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{184., 50.}}, {{184., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{185., 50.}}, {{185., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{186., 50.}}, {{186., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{187., 50.}}, {{187., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{188., 50.}}, {{188., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{189., 50.}}, {{189., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{190., 50.}}, {{190., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{191., 50.}}, {{191., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{192., 50.}}, {{192., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{193., 50.}}, {{193., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{194., 50.}}, {{194., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{195., 50.}}, {{195., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{196., 50.}}, {{196., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{197., 50.}}, {{197., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{198., 50.}}, {{198., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{199., 50.}}, {{199., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{200., 50.}}, {{200., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{201., 50.}}, {{201., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{202., 50.}}, {{202., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{203., 50.}}, {{203., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{204., 50.}}, {{204., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{205., 50.}}, {{205., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{206., 50.}}, {{206., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{207., 50.}}, {{207., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{208., 50.}}, {{208., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{209., 50.}}, {{209., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{210., 50.}}, {{210., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{211., 50.}}, {{211., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{212., 50.}}, {{212., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{213., 50.}}, {{213., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{214., 50.}}, {{214., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{215., 50.}}, {{215., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{216., 50.}}, {{216., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{217., 50.}}, {{217., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{218., 50.}}, {{218., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{219., 50.}}, {{219., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{220., 50.}}, {{220., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{221., 50.}}, {{221., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{222., 50.}}, {{222., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{223., 50.}}, {{223., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{224., 50.}}, {{224., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{225., 50.}}, {{225., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{226., 50.}}, {{226., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{227., 50.}}, {{227., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{228., 50.}}, {{228., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{229., 50.}}, {{229., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{230., 50.}}, {{230., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{231., 50.}}, {{231., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
      {RGBColor[0., 0.5, 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       StyleBox[GeometricTransformationBox[InsetBox[
          StyleBox["\[FilledSmallCircle]",
           StripOnInput->False,
           FontSize->8], {0., 0.}], {{{232., 50.}}, {{232., 50.}}}],
        FontFamily->"Helvetica",
        FontSize->16]}, {}}, {}, {}, {{}, {}}}}},
  AspectRatio->0.2,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{
   FontFamily -> "Helvetica", FontSize -> 16, FontColor -> GrayLevel[0]},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"SI class\"", TraditionalForm], None}, {
     FormBox["\"generation\"", TraditionalForm], 
     FormBox["\"SI class production and annihilation\"", TraditionalForm]}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->1000,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 500}, {0.5, 50.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7235272260468693`*^9, {3.7235272677645197`*^9, 3.7235272914224586`*^9}, 
   3.723527410260791*^9, 3.7235322723816442`*^9, 3.723532333885494*^9, 
   3.7235324971819353`*^9, 3.723532527611923*^9, 3.7243903759991913`*^9, 
   3.724390879863594*^9, 3.72439146235323*^9, 3.724391568142518*^9, 
   3.72439180953055*^9, 3.7243918633258867`*^9, 3.7243922828900833`*^9, {
   3.7243923665699997`*^9, 3.724392390736925*^9}, 3.724392775946763*^9, 
   3.725627069691636*^9, 3.725627168659952*^9, 3.725628995481884*^9, {
   3.7256300371126842`*^9, 3.725630062247963*^9}, {3.725630385237952*^9, 
   3.725630403535748*^9}, 
   3.726390989945623*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
We consider every single SI class in the analysis of completeness above and \
compute the deficit with respect to all the other classes, no matter how \
frequent. Of course, this way a very rare haplotype may cause incompleteness. \
This is an issue when mutation rate is strong or when the space of RNase or \
SLF types is large, which results in many infrequent SI classes. This can be \
fixed by considering completeness deficit of an SI class with respect to only \
those other classes, which exceed some threshold frequency (here chosen as \
5%). Changing the function \[OpenCurlyDoubleQuote]PlotTabsCompleteAll\
\[CloseCurlyDoubleQuote] into \[OpenCurlyDoubleQuote]PlotTabsComplete\
\[CloseCurlyDoubleQuote] and running the last part of the code again will \
reflect this change. Of course, if there are no frequent SI classes the \
deficit would automatically be zero.\
\>", "Text",
 CellChangeTimes->{{3.724391903733184*^9, 3.724392205821835*^9}, {
  3.724392425297625*^9, 3.7243924476487637`*^9}, {3.725627125846244*^9, 
  3.725627137036274*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Compatibility graphs", "Subsubsection",
 CellChangeTimes->{{3.7235274728575068`*^9, 3.7235274775360527`*^9}}],

Cell["\<\
Here we look at all SI classes and plot the compatibility graph at the \
selected times. The label of the vortex corresponds to the id of the \
SLF/SRNase and presence of an arrow from vortex i to vortex j means that \
there is a haplotype in the i-th SI class that can fertilize SI haplotypes in \
the j-th class. \
\>", "Text",
 CellChangeTimes->{{3.723532547481049*^9, 3.723532548111442*^9}, {
  3.723532644654202*^9, 3.723532821636827*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"times", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"100", ",", "250", ",", "400", ",", "500"}], "}"}]}], ";"}], "\n", 
 RowBox[{"P3", " ", "=", " ", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"PlotGraphFull", "[", 
       RowBox[{"i", ",", "0", ",", "15"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "times"}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.723527085394528*^9, 3.72352708800914*^9}, {
   3.723527445192548*^9, 3.723527453953558*^9}, {3.723527490281125*^9, 
   3.723527526334058*^9}, {3.723527559060204*^9, 3.7235275592419243`*^9}, {
   3.7235325559137774`*^9, 3.7235326350815163`*^9}, {3.7243904343294487`*^9, 
   3.72439043679764*^9}, {3.72562720865176*^9, 3.725627218146283*^9}, 
   3.725627280810804*^9, {3.725627314184527*^9, 3.725627342470406*^9}, {
   3.7256274358136187`*^9, 3.7256274407395887`*^9}, {3.725629010590736*^9, 
   3.725629188823471*^9}, {3.725630074814996*^9, 3.72563015869837*^9}, {
   3.725630243657908*^9, 3.725630244207863*^9}, {3.725630339182973*^9, 
   3.725630339724987*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 3, 4, 
           5}, {{{1, 1}, {1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 1}, {2, 2}, {2, 
            3}, {2, 4}, {2, 5}, {3, 1}, {3, 2}, {3, 3}, {3, 4}, {3, 5}, {4, 
            1}, {4, 2}, {4, 3}, {4, 4}, {4, 5}, {5, 1}, {5, 2}, {5, 3}, {5, 
            4}, {5, 5}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {
              DirectedEdge[1, 2], 
              DirectedEdge[4, 1], 
              DirectedEdge[2, 1], 1, 
              DirectedEdge[2, 4], 
              DirectedEdge[4, 2], 
              DirectedEdge[5, 1], 
              DirectedEdge[3, 2], 
              DirectedEdge[5, 4], 5, 
              DirectedEdge[3, 1], 
              DirectedEdge[2, 3], 
              DirectedEdge[5, 2], 
              DirectedEdge[1, 4], 2, 3, 4}, GraphLayout -> 
            "CircularEmbedding", ImageSize -> 300, 
            VertexLabels -> {3 -> Placed[27, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 5 -> Placed[33, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 4 -> Placed[31, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
              0.3090169943749484}, {-1.1773240070119189`, 
              0.06535665735105772}, {-1.5039431270758212`, 
              0.07772245240178871}, {-1.6663699011406923`, 
              0.2285147109371452}, {-1.4824391459584527`, 
              0.7945953681417371}, {-1.2623996596715157`, 
              0.8211168055442488}, {-0.9908908088883361, 
              0.6391390419989417}, {-0.9510565162951538, 0.3090169943749484}},
              
              SplineDegree->7], 0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
               0.3090169943749484}, {-0.5855705398076599, \
-0.1902634019172318}, {-0.5877852522924726, -0.8090169943749468}}], 
               0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
              0.3090169943749484}, {0.0022147124848122704`, 
              0.003048290223133676}, {
              0.5877852522924738, -0.8090169943749481}}], 
              0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
               0.3090169943749484}, {2.318502671227544*^-15, 
               0.6218018826808711}, {0.9510565162951533, 
               0.30901699437494634`}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
              0.3090169943749484}, {-0.5891540198833977, 
              0.8109009413406443}, {-7.044813998280222*^-16, 1.}}], 
              0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.9532712287799651, -0.30973659808272175`}, {-0.9510565162951538, 
               0.3090169943749484}}], 0.29389262614623635`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.42597100090985435`, -1.0995053508427064`}, {-0.5386624296594575, \
-1.4063173525061574`}, {-0.7322670232737409, -1.5141970238936495`}, \
{-1.2138039919168429`, -1.1643399373676513`}, {-1.1710314370838573`, \
-0.9468743752197922}, {-0.9140594502282935, -0.7448883349846707}, \
{-0.5877852522924726, -0.8090169943749468}},
              SplineDegree->7], 0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-6.8696375443778745`*^-16, -0.615705302234522}, {
               0.5877852522924738, -0.8090169943749481}}], 
               0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.002214712484815569, 0.00304829022314191}, {0.9510565162951533, 
               0.30901699437494634`}}], 0.29389262614623635`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.5913687323682062, 0.1921473488827045}, {-7.044813998280222*^-16, 1.}}], 
              0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.5877852522924738, -0.8090169943749481}, \
{-0.36548597648749076`, -0.503048290223179}, {-0.9510565162951538, 
               0.3090169943749484}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.5877852522924738, -0.8090169943749481}, {
               2.0179560286610026`*^-15, -1.0023286865153453`}, \
{-0.5877852522924726, -0.8090169943749468}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{
              0.5877852522924738, -0.8090169943749481}, {
              0.9140594502282947, -0.744888334984672}, {
              1.1710314370838586`, -0.9468743752197939}, {
              1.2138039919168437`, -1.164339937367653}, {
              0.7322670232737416, -1.5141970238936506`}, {
              0.5386624296594582, -1.4063173525061585`}, {
              0.42597100090985535`, -1.0995053508427075`}, {
              0.5877852522924738, -0.8090169943749481}},
              SplineDegree->7], 0.29389262614623635`], 
             ArrowBox[BezierCurveBox[{{
              0.5877852522924738, -0.8090169943749481}, {
              0.5855705398076626, -0.1902634019172155}, {0.9510565162951533, 
              0.30901699437494634`}}], 0.29389262614623635`], 
             ArrowBox[BezierCurveBox[{{
              0.5877852522924738, -0.8090169943749481}, \
{-0.003583480075737248, -0.001164343257672478}, {-7.044813998280222*^-16, 
              1.}}], 0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.9510565162951533, 
               0.30901699437494634`}, {
               
               1.37392750887558*^-15, -0.003767893930942978}, \
{-0.9510565162951538, 0.3090169943749484}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.9510565162951533, 
               0.30901699437494634`}, {
               0.365485976487494, -0.5030482902231461}, {-0.5877852522924726, \
-0.8090169943749468}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{0.9510565162951533, 
              0.30901699437494634`}, {
              0.9532712287799662, -0.30973659808281107`}, {
              0.5877852522924738, -0.8090169943749481}}], 
              0.29389262614623635`], 
             ArrowBox[BezierCurveBox[{{0.9510565162951533, 
              0.30901699437494634`}, {0.9908908088889828, 
              0.6391390419988614}, {1.2623996596719154`, 
              0.8211168055440035}, {1.4824391459586521`, 
              0.7945953681415161}, {1.6663699011407251`, 
              0.22851471093743908`}, {1.5039431270760018`, 
              0.07772245240221953}, {1.1773240070123965`, 
              0.0653566573514997}, {0.9510565162951533, 0.30901699437494634`}},
              SplineDegree->7], 0.29389262614623635`], 
             ArrowBox[BezierCurveBox[{{0.9510565162951533, 
              0.30901699437494634`}, {0.3619024964117562, 
              0.4981160530343753}, {-7.044813998280222*^-16, 1.}}], 
              0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
               1.}, {-0.3619024964117612, 
               0.49811605303448775`}, {-0.9510565162951538, 
               0.3090169943749484}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               0.0035834800757328805`, -0.00116434325766434}, \
{-0.5877852522924726, -0.8090169943749468}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
              0.5913687323682104, 0.19214734888272117`}, {
              0.5877852522924738, -0.8090169943749481}}], 
              0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               0.5891540198833967, 0.8109009413405348}, {0.9510565162951533, 
               0.30901699437494634`}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
              1.}, {-0.30165525119502673`, 
              1.139897986477015}, {-0.39082554002031483`, 
              1.4543524697797259`}, {-0.29760621346103033`, 
              1.6554268821823452`}, {0.29760621346102867`, 
              1.6554268821823452`}, {0.3908255400203132, 1.454352469779726}, {
              0.3016552511950253, 
              1.139897986477015}, {-7.044813998280222*^-16, 1.}},
              SplineDegree->7], 0.29389262614623635`]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.9510565162951538, 0.3090169943749484},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.5877852522924726, -0.8090169943749468},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.5877852522924738, -0.8090169943749481}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["27",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.5877852522924738, -0.8090169943749481},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.9510565162951533, 0.30901699437494634}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["31",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.9510565162951533, 0.30901699437494634},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-7.044813998280222*^-16, 1.}, 0.29389262614623635]}, 
              InsetBox[
               StyleBox["33",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-7.216449660063518*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {194.4, -189.}, {
     Center, Center}, {360.00000000000006, 360.}], InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 3, 4, 5, 6, 7, 
           8}, {{{1, 1}, {1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 
            8}, {2, 1}, {2, 2}, {2, 3}, {2, 4}, {2, 5}, {2, 6}, {2, 7}, {2, 
            8}, {3, 1}, {3, 2}, {3, 3}, {3, 4}, {3, 5}, {3, 6}, {3, 7}, {3, 
            8}, {4, 1}, {4, 2}, {4, 3}, {4, 4}, {4, 5}, {4, 6}, {4, 7}, {4, 
            8}, {5, 1}, {5, 2}, {5, 3}, {5, 4}, {5, 5}, {5, 6}, {5, 7}, {5, 
            8}, {6, 1}, {6, 2}, {6, 3}, {6, 4}, {6, 5}, {6, 6}, {6, 7}, {6, 
            8}, {7, 1}, {7, 2}, {7, 3}, {7, 4}, {7, 5}, {7, 6}, {7, 7}, {7, 
            8}, {8, 1}, {8, 2}, {8, 3}, {8, 4}, {8, 5}, {8, 6}, {8, 7}, {8, 
            8}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {
              DirectedEdge[6, 3], 
              DirectedEdge[8, 1], 
              DirectedEdge[3, 2], 1, 
              DirectedEdge[1, 2], 3, 
              DirectedEdge[4, 2], 
              DirectedEdge[3, 5], 
              DirectedEdge[5, 1], 
              DirectedEdge[7, 5], 
              DirectedEdge[4, 5], 4, 
              DirectedEdge[2, 7], 5, 
              DirectedEdge[4, 3], 
              DirectedEdge[4, 1], 
              DirectedEdge[7, 3], 
              DirectedEdge[5, 2], 
              DirectedEdge[2, 5], 6, 
              DirectedEdge[1, 5], 2, 
              DirectedEdge[8, 2], 
              DirectedEdge[2, 3], 
              DirectedEdge[6, 1], 
              DirectedEdge[3, 1], 
              DirectedEdge[8, 3], 
              DirectedEdge[7, 1], 
              DirectedEdge[6, 5], 7, 
              DirectedEdge[6, 2], 
              DirectedEdge[7, 2], 8, 
              DirectedEdge[8, 5], 
              DirectedEdge[1, 7], 
              DirectedEdge[8, 4], 
              DirectedEdge[2, 1]}, GraphLayout -> "CircularEmbedding", 
            ImageSize -> 300, VertexLabels -> {5 -> Placed[19, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 6 -> Placed[29, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 4 -> Placed[17, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 7 -> Placed[32, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 8 -> Placed[47, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 3 -> Placed[9, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[BezierCurveBox[{{-0.707106781186548, 
              0.7071067811865482}, {-1.0056512591926898`, 
              0.5977389087788091}, {-1.278551413974935, 
              0.7500588251673536}, {-1.351474761730618, 
              0.9490377096662467}, {-0.9490377096662466, 
              1.3514747617306182`}, {-0.7500588251673534, 
              1.2785514139749354`}, {-0.5977389087788089, 
              1.0056512591926903`}, {-0.707106781186548, 0.7071067811865482}},
              
              SplineDegree->7], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.707106781186548, 
               0.7071067811865482}, {-0.7372762231567102, 
               0.3053898108467154}, {-1., 1.0106430996148606`*^-15}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-0.707106781186548, 
              0.7071067811865482}, {-0.4745524463134194, 
              0.}, {-0.7071067811865471, -0.7071067811865468}}], 
              0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{-0.707106781186548, 
              0.7071067811865482}, {-0.07283547597359119, \
-0.03016944197017134}, {6.049014748177263*^-16, -1.}}], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.707106781186548, 
               0.7071067811865482}, {0.23255433487312963`, 
               0.23255433487311392`}, {
               0.7071067811865481, -0.7071067811865483}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-0.707106781186548, 
              0.7071067811865482}, {0.2627237768432906, 0.6342713052129526}, {
              1., -1.133107779529596*^-15}}], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.707106781186548, 
               0.7071067811865482}, {1.9750207940086477`*^-15, 
               0.9396611160598152}, {0.707106781186547, 0.7071067811865467}}],
                0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-0.707106781186548, 
              0.7071067811865482}, {-0.401716970339826, 
              0.969830558030226}, {-7.044813998280222*^-16, 1.}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-1., 
               1.0106430996148606`*^-15}, {-0.9698305580298378, 
               0.40171697033978293`}, {-0.707106781186548, 
               0.7071067811865482}}], 0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-1., 
              1.0106430996148606`*^-15}, {-1.1337680606604836`, \
-0.28843758910739753`}, {-1.4344440564819754`, -0.3737006933526737}, \
{-1.6267079687289456`, -0.2845659685154399}, {-1.6267079687289459`, 
              0.2845659685154417}, {-1.4344440564819754`, 
              0.3737006933526756}, {-1.1337680606604836`, 
              0.28843758910739953`}, {-1., 1.0106430996148606`*^-15}},
              SplineDegree->7], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-1., 
               1.0106430996148606`*^-15}, {-0.7372762231567095, \
-0.30538981084681366`}, {-0.7071067811865471, -0.7071067811865468}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-1., 
              
              1.0106430996148606`*^-15}, {-0.3355592528168865, \
-0.3355592528168676}, {6.049014748177263*^-16, -1.}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-1., 
               1.0106430996148606`*^-15}, {-0.030169441970157775`, \
-0.07283547597359634}, {0.7071067811865481, -0.7071067811865483}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-1., 
              1.0106430996148606`*^-15}, {-2.619049313794079*^-15, 
              0.32888149436623304`}, {1., -1.133107779529596*^-15}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-1., 
               1.0106430996148606`*^-15}, {-0.26272377684329523`, 
               0.6342713052129755}, {0.707106781186547, 0.7071067811865467}}],
                0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-1., 
              1.0106430996148606`*^-15}, {-0.6644407471831179, 
              0.6644407471831388}, {-7.044813998280222*^-16, 1.}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, \
{-0.9396611160596762, -2.960866404568794*^-14}, {-0.707106781186548, 
               0.7071067811865482}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, \
{-0.9698305580298394, -0.40171697033965614`}, {-1., 
               1.0106430996148606`*^-15}}], 0.19134171618254475`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, \
{-0.597738908778808, -1.0056512591926887`}, {-0.7500588251673526, \
-1.2785514139749339`}, {-0.9490377096662456, -1.3514747617306169`}, \
{-1.351474761730617, -0.9490377096662453}, {-1.278551413974934, \
-0.7500588251673522}, {-1.0056512591926892`, -0.5977389087788076}, \
{-0.7071067811865471, -0.7071067811865468}},
              SplineDegree->7], 0.19134171618254475`], 
             ArrowBox[
              BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, \
{-0.30538981084672145`, -0.7372762231568868}, {6.049014748177263*^-16, -1.}}],
               0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, \
{-8.157694583948772*^-16, -0.4745524463134708}, {
               0.7071067811865481, -0.7071067811865483}}], 
               0.19134171618254475`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, {
              0.03016944197015737, -0.07283547597359605}, {
              1., -1.133107779529596*^-15}}], 0.19134171618254475`], 
             ArrowBox[
              BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, \
{-0.23255433487312768`, 0.23255433487311733`}, {0.707106781186547, 
              0.7071067811865467}}], 0.19134171618254475`], 
             ArrowBox[
              BezierCurveBox[{{-0.7071067811865471, -0.7071067811865468}, \
{-0.6342713052129557, 0.2627237768433166}, {-7.044813998280222*^-16, 1.}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               6.049014748177263*^-16, -1.}, {-0.6342713052129543, \
-0.26272377684324405`}, {-0.707106781186548, 0.7071067811865482}}], 
               0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               6.049014748177263*^-16, -1.}, {-0.664440747183115, \
-0.6644407471831193}, {-1., 1.0106430996148606`*^-15}}], 
               0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               6.049014748177263*^-16, -1.}, {-0.40171697033982695`, \
-0.9698305580299305}, {-0.7071067811865471, -0.7071067811865468}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{6.049014748177263*^-16, -1.}, {
              0.28843758910739903`, -1.1337680606604839`}, {
              0.3737006933526749, -1.4344440564819758`}, {
              0.28456596851544086`, -1.626707968728946}, \
{-0.28456596851544075`, -1.6267079687289454`}, {-0.3737006933526745, \
-1.4344440564819751`}, {-0.28843758910739803`, -1.1337680606604834`}, {
              6.049014748177263*^-16, -1.}},
              SplineDegree->7], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{6.049014748177263*^-16, -1.}, {
               0.3053898108467231, -0.7372762231567166}, {
               0.7071067811865481, -0.7071067811865483}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{6.049014748177263*^-16, -1.}, {
              0.3355592528168837, -0.3355592528168928}, {
              1., -1.133107779529596*^-15}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{6.049014748177263*^-16, -1.}, {
              0.07283547597359066, -0.03016944197015923}, {0.707106781186547, 
              0.7071067811865467}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{
              6.049014748177263*^-16, -1.}, {-0.3288814943662324, 
              0.}, {-7.044813998280222*^-16, 1.}}], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.7071067811865481, -0.7071067811865483}, \
{-0.2325543348731319, -0.23255433487311836`}, {-0.707106781186548, 
               0.7071067811865482}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.7071067811865481, -0.7071067811865483}, \
{-0.26272377684329007`, -0.6342713052129472}, {-1., 
               1.0106430996148606`*^-15}}], 0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{
              0.7071067811865481, -0.7071067811865483}, \
{-2.0608912633133716`*^-15, -0.9396611160597559}, {-0.7071067811865471, \
-0.7071067811865468}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{
              0.7071067811865481, -0.7071067811865483}, {
              0.401716970339824, -0.9698305580299855}, {
              6.049014748177263*^-16, -1.}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{
              0.7071067811865481, -0.7071067811865483}, {
              1.0056512591926898`, -0.5977389087788092}, {
              1.278551413974935, -0.7500588251673538}, {
              1.351474761730618, -0.9490377096662469}, {
              0.9490377096662466, -1.3514747617306184`}, {
              0.7500588251673534, -1.2785514139749354`}, {
              0.5977389087788089, -1.0056512591926903`}, {
              0.7071067811865481, -0.7071067811865483}},
              SplineDegree->7], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{
              0.7071067811865481, -0.7071067811865483}, {
              0.7372762231567073, -0.3053898108467077}, {
              1., -1.133107779529596*^-15}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{
              0.7071067811865481, -0.7071067811865483}, {0.47455244631341936`,
               2.960866404568794*^-14}, {0.707106781186547, 
              0.7071067811865467}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{
              0.7071067811865481, -0.7071067811865483}, {0.07283547597359323, 
              0.030169441970155083`}, {-7.044813998280222*^-16, 1.}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
               0.03016944197015757, 0.07283547597359634}, {-0.707106781186548,
                0.7071067811865482}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
               2.619049313794079*^-15, -0.32888149436623304`}, {-1., 
               1.0106430996148606`*^-15}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
               0.26272377684329523`, -0.6342713052129625}, \
{-0.7071067811865471, -0.7071067811865468}}], 0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
              0.6644407471831172, -0.6644407471831759}, {
              6.049014748177263*^-16, -1.}}], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
               0.9698305580298376, -0.4017169703397324}, {
               0.7071067811865481, -0.7071067811865483}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
              1.1337680606604832`, 0.2884375891073975}, {1.434444056481975, 
              0.37370069335267403`}, {1.6267079687289454`, 
              0.28456596851544036`}, {
              1.626707968728946, -0.28456596851544125`}, {
              1.4344440564819758`, -0.37370069335267536`}, {
              1.1337680606604836`, -0.2884375891073993}, {
              1., -1.133107779529596*^-15}},
              SplineDegree->7], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
              0.7372762231567094, 0.3053898108466649}, {0.707106781186547, 
              0.7071067811865467}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{1., -1.133107779529596*^-15}, {
              0.33555925281688204`, 
              0.3355592528168704}, {-7.044813998280222*^-16, 1.}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.707106781186547, 
               0.7071067811865467}, {1.8032798553992*^-15, 
               0.4745524463134427}, {-0.707106781186548, 
               0.7071067811865482}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.707106781186547, 
               0.7071067811865467}, {-0.030169441970156058`, 
               0.07283547597359503}, {-1., 1.0106430996148606`*^-15}}], 
               0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.707106781186547, 
               0.7071067811865467}, {
               0.23255433487312865`, -0.23255433487311147`}, \
{-0.7071067811865471, -0.7071067811865468}}], 0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{0.707106781186547, 
              0.7071067811865467}, {
              0.6342713052129556, -0.26272377684330794`}, {
              6.049014748177263*^-16, -1.}}], 0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.707106781186547, 
               0.7071067811865467}, {0.9396611160596762, 0.}, {
               0.7071067811865481, -0.7071067811865483}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{0.707106781186547, 
              0.7071067811865467}, {0.9698305580298361, 
              0.40171697033973197`}, {1., -1.133107779529596*^-15}}], 
              0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{0.707106781186547, 
              0.7071067811865467}, {0.5977389087788078, 
              1.0056512591926885`}, {0.7500588251673522, 
              1.2785514139749337`}, {0.9490377096662453, 
              1.3514747617306166`}, {1.3514747617306169`, 
              0.9490377096662452}, {1.278551413974934, 0.7500588251673521}, {
              1.005651259192689, 0.5977389087788075}, {0.707106781186547, 
              0.7071067811865467}},
              SplineDegree->7], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{0.707106781186547, 
              0.7071067811865467}, {0.30538981084672084`, 
              0.7372762231566644}, {-7.044813998280222*^-16, 1.}}], 
              0.19134171618254475`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
               1.}, {-0.3053898108467223, 
               0.7372762231569373}, {-0.707106781186548, 
               0.7071067811865482}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
               1.}, {-0.3355592528168827, 0.3355592528169012}, {-1., 
               1.0106430996148606`*^-15}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
               1.}, {-0.07283547597359051, 
               0.030169441970212273`}, {-0.7071067811865471, \
-0.7071067811865468}}], 0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               0.3288814943662324, 0.}, {6.049014748177263*^-16, -1.}}], 
               0.19134171618254475`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               0.634271305212954, 0.26272377684329695`}, {
               0.7071067811865481, -0.7071067811865483}}], 
               0.19134171618254475`]}, 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
              0.6644407471831149, 0.6644407471831193}, {
              1., -1.133107779529596*^-15}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
              0.40171697033982706`, 0.9698305580301326}, {0.707106781186547, 
              0.7071067811865467}}], 0.19134171618254475`], 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
              1.}, {-0.28843758910739914`, 
              1.1337680606604839`}, {-0.3737006933526751, 
              1.4344440564819756`}, {-0.2845659685154411, 
              1.626707968728946}, {0.2845659685154405, 1.6267079687289456`}, {
              0.3737006933526743, 1.4344440564819751`}, {0.28843758910739786`,
               1.1337680606604834`}, {-7.044813998280222*^-16, 1.}},
              SplineDegree->7], 0.19134171618254475`]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.707106781186548, 0.7071067811865482}, 
                0.19134171618254475]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.707106781186548, 0.7071067811865482},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-1., 1.0106430996148606*^-15}, 0.19134171618254475]}, 
              InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-1., 9.992007221626409*^-16},
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.7071067811865471, -0.7071067811865468}, 
                0.19134171618254475]}, InsetBox[
               StyleBox["9",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.7071067811865471, -0.7071067811865468},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{6.049014748177263*^-16, -1.}, 0.19134171618254475]}, 
              InsetBox[
               StyleBox["17",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {6.106226635438361*^-16, -1.},
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.7071067811865481, -0.7071067811865483}, 
                0.19134171618254475]}, InsetBox[
               StyleBox["19",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.7071067811865481, -0.7071067811865483},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{1., -1.133107779529596*^-15}, 0.19134171618254475]}, 
              InsetBox[
               StyleBox["29",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {1., -1.1379786002407855*^-15},
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.707106781186547, 0.7071067811865467}, 
                0.19134171618254475]}, InsetBox[
               StyleBox["32",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.707106781186547, 0.7071067811865467},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-7.044813998280222*^-16, 1.}, 0.19134171618254475]}, 
              InsetBox[
               StyleBox["47",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-6.938893903907228*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {583.2, -189.}, {
     Center, Center}, {360.00000000000006, 360.}], InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 
           3}, {{{1, 1}, {1, 2}, {1, 3}, {2, 1}, {2, 2}, {2, 3}, {3, 1}, {3, 
            2}, {3, 3}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {1, 
              DirectedEdge[2, 1], 
              DirectedEdge[3, 1], 
              DirectedEdge[1, 3], 
              DirectedEdge[3, 2], 
              DirectedEdge[1, 2], 
              DirectedEdge[2, 3], 3, 2}, GraphLayout -> "CircularEmbedding", 
            ImageSize -> 300, VertexLabels -> {3 -> Placed[32, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[
              BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.8335209013159648, -0.862800581520903}, {-1.082998038973717, \
-1.119628759025554}, {-1.3248123036375836`, -1.1413261322732748`}, \
{-1.6508235763704866`, -0.5766580440596917}, {-1.5111259676106341`, \
-0.37808943448719007`}, {-1.163967672655071, -0.29044998436447517`}, \
{-0.8660254037844384, -0.4999999999999994}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, {
               7.470730829510974*^-15, -0.2151802710442648}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.6796738226668952, 0.3924098644779064}, {1.8369701987210297`*^-16, 1.}}], 
               0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               3.778300649407852*^-15, -0.7848197289558226}, \
{-0.8660254037844384, -0.4999999999999994}}], 0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{
              0.8660254037844389, -0.5000000000000012}, {
              1.1639676726554826`, -0.29044998436506153`}, {
              1.51112596761073, -0.37808943448769694`}, {
              1.6508235763704553`, -0.576658044060018}, {
              1.3248123036378483`, -1.1413261322730874`}, {
              1.0829980389742018`, -1.1196287590253862`}, {
              0.8335209013166767, -0.862800581520969}, {
              0.8660254037844389, -0.5000000000000012}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               0.18635158111754763`, 0.10759013552211703`}, {
               1.8369701987210297`*^-16, 1.}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
               1.}, {-0.18635158111754363`, 
               0.10759013552215828`}, {-0.8660254037844384, \
-0.4999999999999994}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 1.}, {
               0.6796738226668931, 0.3924098644778326}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
              1.}, {-0.33046715705303475`, 
              1.1532065938293599`}, {-0.42815434043523065`, 
              1.4976954721364832`}, {-0.3260313848148471, 
              1.7179750434668788`}, {0.3260313848148485, 
              1.7179750434668781`}, {0.42815434043523176`, 
              1.4976954721364826`}, {0.3304671570530353, 
              1.1532065938293594`}, {1.8369701987210297`*^-16, 1.}},
              SplineDegree->7], 0.4330127018922192]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.8660254037844384, -0.49999999999999933},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.8660254037844389, -0.5000000000000012}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.8660254037844388, -0.5000000000000012},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{1.8369701987210297*^-16, 1.}, 0.4330127018922192]}, 
              InsetBox[
               StyleBox["32",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {1.6653345369377348*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {972., -189.}, {Center, Center}, {360., 360.}], 
    InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 3, 4, 5, 6, 
           7}, {{{1, 1}, {1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {2, 
            1}, {2, 2}, {2, 3}, {2, 4}, {2, 5}, {2, 6}, {2, 7}, {3, 1}, {3, 
            2}, {3, 3}, {3, 4}, {3, 5}, {3, 6}, {3, 7}, {4, 1}, {4, 2}, {4, 
            3}, {4, 4}, {4, 5}, {4, 6}, {4, 7}, {5, 1}, {5, 2}, {5, 3}, {5, 
            4}, {5, 5}, {5, 6}, {5, 7}, {6, 1}, {6, 2}, {6, 3}, {6, 4}, {6, 
            5}, {6, 6}, {6, 7}, {7, 1}, {7, 2}, {7, 3}, {7, 4}, {7, 5}, {7, 
            6}, {7, 7}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {
              DirectedEdge[1, 4], 
              DirectedEdge[6, 3], 
              DirectedEdge[1, 6], 
              DirectedEdge[3, 2], 1, 
              DirectedEdge[1, 2], 3, 
              DirectedEdge[4, 2], 
              DirectedEdge[3, 5], 
              DirectedEdge[5, 1], 
              DirectedEdge[4, 5], 4, 
              DirectedEdge[2, 6], 5, 
              DirectedEdge[4, 3], 
              DirectedEdge[4, 1], 
              DirectedEdge[7, 3], 
              DirectedEdge[5, 2], 
              DirectedEdge[2, 4], 6, 
              DirectedEdge[1, 3], 
              DirectedEdge[1, 5], 2, 
              DirectedEdge[5, 4], 
              DirectedEdge[3, 4], 
              DirectedEdge[2, 3], 
              DirectedEdge[6, 1], 
              DirectedEdge[3, 1], 
              DirectedEdge[7, 1], 
              DirectedEdge[6, 5], 7, 
              DirectedEdge[6, 2], 
              DirectedEdge[7, 2], 
              DirectedEdge[7, 6], 
              DirectedEdge[1, 7], 
              DirectedEdge[2, 1]}, GraphLayout -> "CircularEmbedding", 
            ImageSize -> 300, VertexLabels -> {5 -> Placed[32, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 6 -> Placed[44, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 4 -> Placed[26, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 7 -> Placed[49, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 3 -> Placed[17, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[BezierCurveBox[{{-0.7818314824680302, 
              0.6234898018587343}, {-1.0692009156393085`, 
              0.4799105893669824}, {-1.3604265598113654`, 
              0.6019695470733851}, {-1.4561517704070126`, 
              0.7934969047689089}, {-1.0976265326222006`, 
              1.2430733330021528`}, {-0.889600302393494, 
              1.1923669998055664`}, {-0.7057978152605058, 
              0.9356036638256594}, {-0.7818314824680302, 0.6234898018587343}},
              
              SplineDegree->7], 0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.7818314824680302, 
               0.6234898018587343}, {-0.7392610598025626, 
               0.1687315127707274}, {-0.9749279121818235, \
-0.22252093395631342`}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.7818314824680302, 
               0.6234898018587343}, {-0.3571744880874909, \
-0.08152274612460324}, {-0.43388373911755757`, -0.9009688679024187}}], 
               0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.7818314824680302, 
               0.6234898018587343}, {0.07670925103006968, 
               0.06117358637760765}, {
               0.43388373911755884`, -0.9009688679024196}}], 
               0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.7818314824680302, 
               0.6234898018587343}, {0.23566685237926213`, 
               0.4893672614283778}, {
               0.9749279121818237, -0.2225209339563155}}], 
               0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.7818314824680302, 
               0.6234898018587343}, {1.7174093860944768`*^-15, 
               0.8806197081553352}, {0.7818314824680294, 
               0.6234898018587326}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.7818314824680302, 
               0.6234898018587343}, {-0.4528293595384262, 
               0.9403098540775142}, {-7.044813998280222*^-16, 1.}}], 
               0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.9749279121818235, -0.22252093395631342`}, \
{-1.0174983348472895`, 0.23223735513180202`}, {-0.7818314824680302, 
               0.6234898018587343}}], 0.21694186955877884`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.9749279121818235, -0.22252093395631342`}, \
{-1.041845074575405, -0.5367155786562581}, {-1.3188508296087742`, \
-0.6883024404166935}, {-1.528276640196406, -0.6437280694261036}, \
{-1.6562328160969941`, -0.08311543310658884}, {-1.4868867753765196`, 
              0.047911141227753085`}, {-1.1715421394799361`, 
              0.031524390749534004`}, {-0.9749279121818235, \
-0.22252093395631342`}},
              SplineDegree->7], 0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.9749279121818235, -0.22252093395631342`}, \
{-0.5928413404667514, -0.47277519285151104`}, {-0.43388373911755757`, \
-0.9009688679024187}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.9749279121818235, -0.22252093395631342`}, \
{-0.15895760134919465`, -0.33007886034941547`}, {
               0.43388373911755884`, -0.9009688679024196}}], 
               0.21694186955877884`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.9749279121818235, -0.22252093395631342`}, \
{-6.869637544377878*^-16, 0.09811481470139602}, {
              0.9749279121818237, -0.2225209339563155}}], 
              0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.9749279121818235, -0.22252093395631342`}, \
{-0.23566685237926496`, 0.4893672614284027}, {0.7818314824680294, 
               0.6234898018587326}}], 0.21694186955877884`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.9749279121818235, -0.22252093395631342`}, \
{-0.688496211917687, 0.5490574073506427}, {-7.044813998280222*^-16, 1.}}], 
              0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.43388373911755757`, -0.9009688679024187}, \
{-0.8585407334980966, -0.19595631991908294`}, {-0.7818314824680302, 
               0.6234898018587343}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.43388373911755757`, -0.9009688679024187}, \
{-0.8159703108326314, -0.6507146090073023}, {-0.9749279121818235, \
-0.22252093395631342`}}], 0.21694186955877884`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.43388373911755757`, -0.9009688679024187}, \
{-0.2299586425904941, -1.1491839689485905`}, {-0.2841535250570917, \
-1.4602686514616237`}, {-0.44957802875598163`, -1.596212677683396}, \
{-0.9676620080583658, -1.3467165828405627`}, {-0.9645171795385246, \
-1.13262278390423}, {-0.7550913375671198, -0.8962933915418516}, \
{-0.43388373911755757`, -0.9009688679024187}},
              SplineDegree->7], 0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.43388373911755757`, -0.9009688679024187}, \
{-6.032400468656833*^-15, -0.7582725354004564}, {
               0.43388373911755884`, -0.9009688679024196}}], 
               0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.43388373911755757`, -0.9009688679024187}, {
               0.15895760134919798`, -0.3300788603494277}, {
               0.9749279121818237, -0.2225209339563155}}], 
               0.21694186955877884`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.43388373911755757`, -0.9009688679024187}, \
{-0.07670925103006844, 0.061173586377545344`}, {0.7818314824680294, 
              0.6234898018587326}}], 0.21694186955877884`], 
             ArrowBox[
              BezierCurveBox[{{-0.43388373911755757`, -0.9009688679024187}, \
{-0.5295386105684977, 0.12086373229988744`}, {-7.044813998280222*^-16, 1.}}], 
              0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.43388373911755884`, -0.9009688679024196}, \
{-0.4246569943805399, -0.33865265242119075`}, {-0.7818314824680302, 
               0.6234898018587343}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.43388373911755884`, -0.9009688679024196}, \
{-0.38208657171507104`, -0.7934109415093544}, {-0.9749279121818235, \
-0.22252093395631342`}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.43388373911755884`, -0.9009688679024196}, {
               1.5027332128326631`*^-15, -1.043665200404678}, \
{-0.43388373911755757`, -0.9009688679024187}}], 0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{
              0.43388373911755884`, -0.9009688679024196}, {
              0.7550913375671211, -0.8962933915418526}, {
              0.9645171795385259, -1.1326227839042313`}, {
              0.9676620080583667, -1.3467165828405638`}, {
              0.4495780287559825, -1.596212677683397}, {
              0.28415352505709257`, -1.460268651461624}, {
              0.22995864259049525`, -1.1491839689485912`}, {
              0.43388373911755884`, -0.9009688679024196}},
              SplineDegree->7], 0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.43388373911755884`, -0.9009688679024196}, {
               0.592841340466752, -0.4727751928515918}, {
               0.9749279121818237, -0.2225209339563155}}], 
               0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{
              0.43388373911755884`, -0.9009688679024196}, {
              0.3571744880874891, -0.08152274612463141}, {0.7818314824680294, 
              0.6234898018587326}}], 0.21694186955877884`], 
             ArrowBox[BezierCurveBox[{{
              0.43388373911755884`, -0.9009688679024196}, \
{-0.09565487145093902, -0.021832600202306814`}, {-7.044813998280222*^-16, 
              1.}}], 0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               
               0.9749279121818237, -0.2225209339563155}, \
{-0.04257042266547175, -0.08839839352597385}, {-0.7818314824680302, 
               0.6234898018587343}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.9749279121818237, -0.2225209339563155}, \
{-4.894616750369233*^-15, -0.5431566826140191}, {-0.9749279121818235, \
-0.22252093395631342`}}], 0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{
              0.9749279121818237, -0.2225209339563155}, {
              0.3820865717150722, -0.7934109415093323}, \
{-0.43388373911755757`, -0.9009688679024187}}], 0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.9749279121818237, -0.2225209339563155}, {
               0.8159703108326306, -0.6507146090071999}, {
               0.43388373911755884`, -0.9009688679024196}}], 
               0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{
              0.9749279121818237, -0.2225209339563155}, {1.1715421394799361`, 
              0.03152439074953217}, {1.4868867753765196`, 
              0.04791114122775164}, {
              1.6562328160969944`, -0.08311543310659006}, {
              1.528276640196407, -0.6437280694261049}, {
              1.3188508296087753`, -0.6883024404166953}, {
              1.0418450745754058`, -0.5367155786562599}, {
              0.9749279121818237, -0.2225209339563155}},
              SplineDegree->7], 0.21694186955877884`], 
             ArrowBox[BezierCurveBox[{{
              0.9749279121818237, -0.2225209339563155}, {0.7392610598025638, 
              0.16873151277076032`}, {0.7818314824680294, 
              0.6234898018587326}}], 0.21694186955877884`], 
             ArrowBox[BezierCurveBox[{{
              0.9749279121818237, -0.2225209339563155}, {0.2864317002641364, 
              0.2284216586930043}, {-7.044813998280222*^-16, 1.}}], 
              0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.7818314824680294, 
               0.6234898018587326}, {1.7603446207468366`*^-15, 
               0.3663598955620636}, {-0.7818314824680302, 
               0.6234898018587343}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.7818314824680294, 
               0.6234898018587326}, {
               0.04257042266546708, -0.0883983935259647}, \
{-0.9749279121818235, -0.22252093395631342`}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.7818314824680294, 
               0.6234898018587326}, {
               0.4246569943805408, -0.338652652421239}, \
{-0.43388373911755757`, -0.9009688679024187}}], 0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{0.7818314824680294, 
              0.6234898018587326}, {
              0.8585407334980978, -0.19595631991906395`}, {
              0.43388373911755884`, -0.9009688679024196}}], 
              0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.7818314824680294, 
               0.6234898018587326}, {1.017498334847292, 
               0.23223735513166224`}, {
               0.9749279121818237, -0.2225209339563155}}], 
               0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{0.7818314824680294, 
              0.6234898018587326}, {0.7057978152605052, 0.9356036638256578}, {
              0.8896003023934935, 1.1923669998055646`}, {1.0976265326222001`, 
              1.243073333002151}, {1.4561517704070117`, 0.7934969047689069}, {
              1.3604265598113645`, 0.6019695470733832}, {1.0692009156393076`, 
              0.4799105893669806}, {0.7818314824680294, 0.6234898018587326}},
              SplineDegree->7], 0.21694186955877884`], 
             ArrowBox[BezierCurveBox[{{0.7818314824680294, 
              0.6234898018587326}, {0.3290021229296012, 
              0.6831799477807057}, {-7.044813998280222*^-16, 1.}}], 
              0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
               1.}, {-0.3290021229296057, 
               0.6831799477808721}, {-0.7818314824680302, 
               0.6234898018587343}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
               1.}, {-0.2864317002641348, 
               0.22842165869293984`}, {-0.9749279121818235, \
-0.22252093395631342`}}], 0.21694186955877884`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               
               0.0956548714509381, -0.021832600202311554`}, \
{-0.43388373911755757`, -0.9009688679024187}}], 0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
              0.5295386105684972, 0.12086373229989524`}, {
              0.43388373911755884`, -0.9009688679024196}}], 
              0.21694186955877884`], 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
              0.6884962119176871, 0.5490574073506426}, {
              0.9749279121818237, -0.2225209339563155}}], 
              0.21694186955877884`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               0.45282935953843134`, 0.9403098540779186}, {0.7818314824680294,
                0.6234898018587326}}], 0.21694186955877884`]}, 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
              1.}, {-0.29142665950223606`, 
              1.1351542952047828`}, {-0.3775733428311541, 
              1.4389461876759775`}, {-0.2875149174180437, 
              1.6332025252856455`}, {0.28751491741804314`, 
              1.633202525285645}, {0.37757334283115335`, 1.438946187675977}, {
              0.2914266595022348, 
              1.1351542952047824`}, {-7.044813998280222*^-16, 1.}},
              SplineDegree->7], 0.21694186955877884`]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.7818314824680302, 0.6234898018587343}, 
                0.21694186955877884]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.7818314824680302, 0.6234898018587343},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.9749279121818235, -0.22252093395631342}, 
                0.21694186955877884]}, InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.9749279121818235, -0.22252093395631342},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.43388373911755757, -0.9009688679024187}, 
                0.21694186955877884]}, InsetBox[
               StyleBox["17",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.43388373911755757, -0.9009688679024188},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.43388373911755884, -0.9009688679024196}, 
                0.21694186955877884]}, InsetBox[
               StyleBox["26",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.43388373911755884, -0.9009688679024197},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.9749279121818237, -0.2225209339563155}, 
                0.21694186955877884]}, InsetBox[
               StyleBox["32",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.9749279121818237, -0.2225209339563155},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.7818314824680294, 0.6234898018587326}, 
                0.21694186955877884]}, InsetBox[
               StyleBox["44",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.7818314824680294, 0.6234898018587326},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-7.044813998280222*^-16, 1.}, 0.21694186955877884]}, 
              InsetBox[
               StyleBox["49",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-6.938893903907228*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {1360.8000000000002, -189.}, {Center, Center}, 
     {359.9999999999998, 360.}]}, {}},
  ContentSelectable->True,
  ImageSize->1000,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.723527479256488*^9, 3.723527526825736*^9}, 
   3.723527559663825*^9, {3.7235325504325027`*^9, 3.723532579672928*^9}, {
   3.72353262175069*^9, 3.723532635822876*^9}, 3.72353282440268*^9, 
   3.7243904293749247`*^9, 3.724392465939537*^9, 3.7243927818013372`*^9, 
   3.724392873003024*^9, {3.725627265642943*^9, 3.725627283098754*^9}, {
   3.725627322276849*^9, 3.725627343125039*^9}, 3.725627441593519*^9, {
   3.725629004022951*^9, 3.725629189383581*^9}, {3.725630067536976*^9, 
   3.7256301591471643`*^9}, 3.725630245398493*^9, 3.725630340393804*^9, 
   3.726390990424667*^9}]
}, Open  ]],

Cell["\<\
The second argument of the function PlotGraphFull is the threshold frequency. \
By changing this from value 0 to value 0.05 we will limit the SI classes in \
consideration only to those which at a given time have total frequency at \
least 5%. Changing the argument will reduce the number of vortices in the \
compatibility graphs and these graphs will thus not be sensitive to rare SI \
haplotypes that only persist in the population for a very short time.\
\>", "Text",
 CellChangeTimes->{{3.723532845149427*^9, 3.723533046217125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P4", " ", "=", " ", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"PlotGraphFull", "[", 
       RowBox[{"i", ",", "0.05", ",", "15"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "times"}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.723532834364831*^9, 3.72353283511692*^9}, {
  3.725627400429984*^9, 3.7256274051960793`*^9}, {3.7256291934243107`*^9, 
  3.725629193567305*^9}, {3.725630163980298*^9, 3.725630164370118*^9}, {
  3.725630248081592*^9, 3.725630248231833*^9}, {3.725630334831121*^9, 
  3.7256303353649187`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 
           3}, {{{1, 1}, {1, 2}, {1, 3}, {2, 1}, {2, 2}, {2, 3}, {3, 1}, {3, 
            2}, {3, 3}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {1, 
              DirectedEdge[2, 1], 
              DirectedEdge[3, 1], 
              DirectedEdge[1, 3], 
              DirectedEdge[3, 2], 
              DirectedEdge[1, 2], 
              DirectedEdge[2, 3], 3, 2}, GraphLayout -> "CircularEmbedding", 
            ImageSize -> 300, VertexLabels -> {3 -> Placed[31, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[
              BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.8335209013159648, -0.862800581520903}, {-1.082998038973717, \
-1.119628759025554}, {-1.3248123036375836`, -1.1413261322732748`}, \
{-1.6508235763704866`, -0.5766580440596917}, {-1.5111259676106341`, \
-0.37808943448719007`}, {-1.163967672655071, -0.29044998436447517`}, \
{-0.8660254037844384, -0.4999999999999994}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, {
               7.470730829510974*^-15, -0.2151802710442648}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.6796738226668952, 0.3924098644779064}, {1.8369701987210297`*^-16, 1.}}], 
               0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               3.778300649407852*^-15, -0.7848197289558226}, \
{-0.8660254037844384, -0.4999999999999994}}], 0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{
              0.8660254037844389, -0.5000000000000012}, {
              1.1639676726554826`, -0.29044998436506153`}, {
              1.51112596761073, -0.37808943448769694`}, {
              1.6508235763704553`, -0.576658044060018}, {
              1.3248123036378483`, -1.1413261322730874`}, {
              1.0829980389742018`, -1.1196287590253862`}, {
              0.8335209013166767, -0.862800581520969}, {
              0.8660254037844389, -0.5000000000000012}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               0.18635158111754763`, 0.10759013552211703`}, {
               1.8369701987210297`*^-16, 1.}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
               1.}, {-0.18635158111754363`, 
               0.10759013552215828`}, {-0.8660254037844384, \
-0.4999999999999994}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 1.}, {
               0.6796738226668931, 0.3924098644778326}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
              1.}, {-0.33046715705303475`, 
              1.1532065938293599`}, {-0.42815434043523065`, 
              1.4976954721364832`}, {-0.3260313848148471, 
              1.7179750434668788`}, {0.3260313848148485, 
              1.7179750434668781`}, {0.42815434043523176`, 
              1.4976954721364826`}, {0.3304671570530353, 
              1.1532065938293594`}, {1.8369701987210297`*^-16, 1.}},
              SplineDegree->7], 0.4330127018922192]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.8660254037844384, -0.49999999999999933},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.8660254037844389, -0.5000000000000012}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.8660254037844388, -0.5000000000000012},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{1.8369701987210297*^-16, 1.}, 0.4330127018922192]}, 
              InsetBox[
               StyleBox["31",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {1.6653345369377348*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {194.4, -189.}, {
     Center, Center}, {360.00000000000006, 360.}], InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 
           3}, {{{1, 1}, {1, 2}, {1, 3}, {2, 1}, {2, 2}, {2, 3}, {3, 1}, {3, 
            2}, {3, 3}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {1, 
              DirectedEdge[2, 1], 
              DirectedEdge[3, 1], 
              DirectedEdge[3, 2], 
              DirectedEdge[1, 2], 
              DirectedEdge[2, 3], 3, 2}, GraphLayout -> "CircularEmbedding", 
            ImageSize -> 300, VertexLabels -> {3 -> Placed[9, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[
              BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.8335209013159648, -0.862800581520903}, {-1.082998038973717, \
-1.119628759025554}, {-1.3248123036375836`, -1.1413261322732748`}, \
{-1.6508235763704866`, -0.5766580440596917}, {-1.5111259676106341`, \
-0.37808943448719007`}, {-1.163967672655071, -0.29044998436447517`}, \
{-0.8660254037844384, -0.4999999999999994}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, {
               7.470730829510974*^-15, -0.2151802710442648}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             ArrowBox[
              BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.6796738226668952, 0.3924098644779064}, {1.8369701987210297`*^-16, 1.}}], 
              0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               3.778300649407852*^-15, -0.7848197289558226}, \
{-0.8660254037844384, -0.4999999999999994}}], 0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{
              0.8660254037844389, -0.5000000000000012}, {
              1.1639676726554826`, -0.29044998436506153`}, {
              1.51112596761073, -0.37808943448769694`}, {
              1.6508235763704553`, -0.576658044060018}, {
              1.3248123036378483`, -1.1413261322730874`}, {
              1.0829980389742018`, -1.1196287590253862`}, {
              0.8335209013166767, -0.862800581520969}, {
              0.8660254037844389, -0.5000000000000012}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               0.18635158111754763`, 0.10759013552211703`}, {
               1.8369701987210297`*^-16, 1.}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
               1.}, {-0.18635158111754363`, 
               0.10759013552215828`}, {-0.8660254037844384, \
-0.4999999999999994}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 1.}, {
               0.6796738226668931, 0.3924098644778326}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
              1.}, {-0.33046715705303475`, 
              1.1532065938293599`}, {-0.42815434043523065`, 
              1.4976954721364832`}, {-0.3260313848148471, 
              1.7179750434668788`}, {0.3260313848148485, 
              1.7179750434668781`}, {0.42815434043523176`, 
              1.4976954721364826`}, {0.3304671570530353, 
              1.1532065938293594`}, {1.8369701987210297`*^-16, 1.}},
              SplineDegree->7], 0.4330127018922192]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.8660254037844384, -0.49999999999999933},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.8660254037844389, -0.5000000000000012}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.8660254037844388, -0.5000000000000012},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{1.8369701987210297*^-16, 1.}, 0.4330127018922192]}, 
              InsetBox[
               StyleBox["9",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {1.6653345369377348*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {583.2, -189.}, {
     Center, Center}, {360.00000000000006, 360.}], InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 
           3}, {{{1, 1}, {1, 2}, {1, 3}, {2, 1}, {2, 2}, {2, 3}, {3, 1}, {3, 
            2}, {3, 3}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {1, 
              DirectedEdge[2, 1], 
              DirectedEdge[3, 1], 
              DirectedEdge[1, 3], 
              DirectedEdge[3, 2], 
              DirectedEdge[1, 2], 
              DirectedEdge[2, 3], 3, 2}, GraphLayout -> "CircularEmbedding", 
            ImageSize -> 300, VertexLabels -> {3 -> Placed[32, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[
              BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.8335209013159648, -0.862800581520903}, {-1.082998038973717, \
-1.119628759025554}, {-1.3248123036375836`, -1.1413261322732748`}, \
{-1.6508235763704866`, -0.5766580440596917}, {-1.5111259676106341`, \
-0.37808943448719007`}, {-1.163967672655071, -0.29044998436447517`}, \
{-0.8660254037844384, -0.4999999999999994}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, {
               7.470730829510974*^-15, -0.2151802710442648}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.8660254037844384, -0.4999999999999994}, \
{-0.6796738226668952, 0.3924098644779064}, {1.8369701987210297`*^-16, 1.}}], 
               0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               3.778300649407852*^-15, -0.7848197289558226}, \
{-0.8660254037844384, -0.4999999999999994}}], 0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{
              0.8660254037844389, -0.5000000000000012}, {
              1.1639676726554826`, -0.29044998436506153`}, {
              1.51112596761073, -0.37808943448769694`}, {
              1.6508235763704553`, -0.576658044060018}, {
              1.3248123036378483`, -1.1413261322730874`}, {
              1.0829980389742018`, -1.1196287590253862`}, {
              0.8335209013166767, -0.862800581520969}, {
              0.8660254037844389, -0.5000000000000012}},
              SplineDegree->7], 0.4330127018922192], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.8660254037844389, -0.5000000000000012}, {
               0.18635158111754763`, 0.10759013552211703`}, {
               1.8369701987210297`*^-16, 1.}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
               1.}, {-0.18635158111754363`, 
               0.10759013552215828`}, {-0.8660254037844384, \
-0.4999999999999994}}], 0.4330127018922192]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 1.}, {
               0.6796738226668931, 0.3924098644778326}, {
               0.8660254037844389, -0.5000000000000012}}], 
               0.4330127018922192]}, 
             ArrowBox[BezierCurveBox[{{1.8369701987210297`*^-16, 
              1.}, {-0.33046715705303475`, 
              1.1532065938293599`}, {-0.42815434043523065`, 
              1.4976954721364832`}, {-0.3260313848148471, 
              1.7179750434668788`}, {0.3260313848148485, 
              1.7179750434668781`}, {0.42815434043523176`, 
              1.4976954721364826`}, {0.3304671570530353, 
              1.1532065938293594`}, {1.8369701987210297`*^-16, 1.}},
              SplineDegree->7], 0.4330127018922192]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.8660254037844384, -0.49999999999999933},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.8660254037844389, -0.5000000000000012}, 
                0.4330127018922192]}, InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.8660254037844388, -0.5000000000000012},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{1.8369701987210297*^-16, 1.}, 0.4330127018922192]}, 
              InsetBox[
               StyleBox["32",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {1.6653345369377348*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {972., -189.}, {Center, Center}, {360., 360.}], 
    InsetBox[
     FormBox[
      GraphicsBox[
       NamespaceBox["NetworkGraphics",
        DynamicModuleBox[{Typeset`graph = HoldComplete[
          
          Graph[{1, 2, 3, 4, 
           5}, {{{1, 1}, {1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 1}, {2, 2}, {2, 
            3}, {2, 4}, {2, 5}, {3, 1}, {3, 2}, {3, 3}, {3, 4}, {3, 5}, {4, 
            1}, {4, 2}, {4, 3}, {4, 4}, {4, 5}, {5, 1}, {5, 2}, {5, 3}, {5, 
            4}, {5, 5}}, Null}, {EdgeStyle -> {
              RGBColor[1, 1, 1]}, GraphHighlight -> {
              DirectedEdge[1, 2], 
              DirectedEdge[4, 1], 
              DirectedEdge[2, 1], 1, 
              DirectedEdge[2, 4], 
              DirectedEdge[5, 1], 
              DirectedEdge[4, 2], 
              DirectedEdge[3, 2], 
              DirectedEdge[5, 4], 
              DirectedEdge[4, 3], 5, 
              DirectedEdge[3, 5], 
              DirectedEdge[3, 1], 
              DirectedEdge[2, 3], 
              DirectedEdge[1, 5], 
              DirectedEdge[1, 3], 
              DirectedEdge[5, 2], 
              DirectedEdge[4, 5], 
              DirectedEdge[1, 4], 2, 
              DirectedEdge[3, 4], 3, 4}, GraphLayout -> "CircularEmbedding", 
            ImageSize -> 300, VertexLabels -> {3 -> Placed[17, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 5 -> Placed[32, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 4 -> Placed[26, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 2 -> Placed[2, {
                 Rational[1, 2], 
                 Rational[1, 2]}], 1 -> Placed[1, {
                 Rational[1, 2], 
                 Rational[1, 2]}]}, VertexLabelStyle -> {
              Directive[15, 
               GrayLevel[1], Bold]}, VertexSize -> {0.5}, VertexStyle -> {
              RGBColor[0.9, 0.9, 0.9]}}]]}, 
         TagBox[GraphicsGroupBox[{
            {RGBColor[1, 1, 1], Opacity[0.7], Arrowheads[Medium], 
             ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
              0.3090169943749484}, {-1.1773240070119189`, 
              0.06535665735105772}, {-1.5039431270758212`, 
              0.07772245240178871}, {-1.6663699011406923`, 
              0.2285147109371452}, {-1.4824391459584527`, 
              0.7945953681417371}, {-1.2623996596715157`, 
              0.8211168055442488}, {-0.9908908088883361, 
              0.6391390419989417}, {-0.9510565162951538, 0.3090169943749484}},
              
              SplineDegree->7], 0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
               0.3090169943749484}, {-0.5855705398076599, \
-0.1902634019172318}, {-0.5877852522924726, -0.8090169943749468}}], 
               0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
               0.3090169943749484}, {0.0022147124848122704`, 
               0.003048290223133676}, {
               0.5877852522924738, -0.8090169943749481}}], 
               0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
               0.3090169943749484}, {2.318502671227544*^-15, 
               0.6218018826808711}, {0.9510565162951533, 
               0.30901699437494634`}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-0.9510565162951538, 
               0.3090169943749484}, {-0.5891540198833977, 
               0.8109009413406443}, {-7.044813998280222*^-16, 1.}}], 
               0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.9532712287799651, -0.30973659808272175`}, {-0.9510565162951538, 
               0.3090169943749484}}], 0.29389262614623635`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.42597100090985435`, -1.0995053508427064`}, {-0.5386624296594575, \
-1.4063173525061574`}, {-0.7322670232737409, -1.5141970238936495`}, \
{-1.2138039919168429`, -1.1643399373676513`}, {-1.1710314370838573`, \
-0.9468743752197922}, {-0.9140594502282935, -0.7448883349846707}, \
{-0.5877852522924726, -0.8090169943749468}},
              SplineDegree->7], 0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-6.8696375443778745`*^-16, -0.615705302234522}, {
               0.5877852522924738, -0.8090169943749481}}], 
               0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[
               BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.002214712484815569, 0.00304829022314191}, {0.9510565162951533, 
               0.30901699437494634`}}], 0.29389262614623635`]}, 
             ArrowBox[
              BezierCurveBox[{{-0.5877852522924726, -0.8090169943749468}, \
{-0.5913687323682062, 0.1921473488827045}, {-7.044813998280222*^-16, 1.}}], 
              0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.5877852522924738, -0.8090169943749481}, \
{-0.36548597648749076`, -0.503048290223179}, {-0.9510565162951538, 
               0.3090169943749484}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.5877852522924738, -0.8090169943749481}, {
               2.0179560286610026`*^-15, -1.0023286865153453`}, \
{-0.5877852522924726, -0.8090169943749468}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{
              0.5877852522924738, -0.8090169943749481}, {
              0.9140594502282947, -0.744888334984672}, {
              1.1710314370838586`, -0.9468743752197939}, {
              1.2138039919168437`, -1.164339937367653}, {
              0.7322670232737416, -1.5141970238936506`}, {
              0.5386624296594582, -1.4063173525061585`}, {
              0.42597100090985535`, -1.0995053508427075`}, {
              0.5877852522924738, -0.8090169943749481}},
              SplineDegree->7], 0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.5877852522924738, -0.8090169943749481}, {
               0.5855705398076626, -0.1902634019172155}, {0.9510565162951533, 
               0.30901699437494634`}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{
               0.5877852522924738, -0.8090169943749481}, \
{-0.003583480075737248, -0.001164343257672478}, {-7.044813998280222*^-16, 
               1.}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.9510565162951533, 
               0.30901699437494634`}, {
               1.37392750887558*^-15, -0.003767893930942978}, \
{-0.9510565162951538, 0.3090169943749484}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.9510565162951533, 
               0.30901699437494634`}, {
               0.365485976487494, -0.5030482902231461}, {-0.5877852522924726, \
-0.8090169943749468}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.9510565162951533, 
               0.30901699437494634`}, {
               0.9532712287799662, -0.30973659808281107`}, {
               0.5877852522924738, -0.8090169943749481}}], 
               0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{0.9510565162951533, 
              0.30901699437494634`}, {0.9908908088889828, 
              0.6391390419988614}, {1.2623996596719154`, 
              0.8211168055440035}, {1.4824391459586521`, 
              0.7945953681415161}, {1.6663699011407251`, 
              0.22851471093743908`}, {1.5039431270760018`, 
              0.07772245240221953}, {1.1773240070123965`, 
              0.0653566573514997}, {0.9510565162951533, 0.30901699437494634`}},
              SplineDegree->7], 0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{0.9510565162951533, 
               0.30901699437494634`}, {0.3619024964117562, 
               0.4981160530343753}, {-7.044813998280222*^-16, 1.}}], 
               0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
               1.}, {-0.3619024964117612, 
               0.49811605303448775`}, {-0.9510565162951538, 
               0.3090169943749484}}], 0.29389262614623635`]}, 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               0.0035834800757328805`, -0.00116434325766434}, \
{-0.5877852522924726, -0.8090169943749468}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
              0.5913687323682104, 0.19214734888272117`}, {
              0.5877852522924738, -0.8090169943749481}}], 
              0.29389262614623635`], 
             {Hue[1, 1, 0.7], Opacity[1], 
              ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 1.}, {
               0.5891540198833967, 0.8109009413405348}, {0.9510565162951533, 
               0.30901699437494634`}}], 0.29389262614623635`]}, 
             ArrowBox[BezierCurveBox[{{-7.044813998280222*^-16, 
              1.}, {-0.30165525119502673`, 
              1.139897986477015}, {-0.39082554002031483`, 
              1.4543524697797259`}, {-0.29760621346103033`, 
              1.6554268821823452`}, {0.29760621346102867`, 
              1.6554268821823452`}, {0.3908255400203132, 1.454352469779726}, {
              0.3016552511950253, 
              1.139897986477015}, {-7.044813998280222*^-16, 1.}},
              SplineDegree->7], 0.29389262614623635`]}, 
            {RGBColor[0.9, 0.9, 0.9], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["1",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.9510565162951538, 0.3090169943749484},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["2",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-0.5877852522924726, -0.8090169943749468},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.5877852522924738, -0.8090169943749481}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["17",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.5877852522924738, -0.8090169943749481},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{0.9510565162951533, 0.30901699437494634}, 
                0.29389262614623635]}, InsetBox[
               StyleBox["26",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {0.9510565162951533, 0.30901699437494634},
               
               BaseStyle->"Graphics"]}, {
              {Hue[1, 1, 0.7], EdgeForm[{Hue[1, 1, 0.7], Opacity[1]}], 
               DiskBox[{-7.044813998280222*^-16, 1.}, 0.29389262614623635]}, 
              InsetBox[
               StyleBox["32",
                StripOnInput->False,
                LineColor->GrayLevel[1],
                FrontFaceColor->GrayLevel[1],
                BackFaceColor->GrayLevel[1],
                GraphicsColor->GrayLevel[1],
                FontSize->15,
                FontWeight->Bold,
                FontColor->GrayLevel[1]], {-7.216449660063518*^-16, 1.},
               BaseStyle->"Graphics"]}}}],
          MouseAppearanceTag["NetworkGraphics"]],
         AllowKernelInitialization->False]],
       DefaultBaseStyle->{
        "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
         Hue[0.8, 1., 0.6]},
       FormatType->TraditionalForm,
       FrameTicks->None,
       ImageSize->300],
      TraditionalForm], {1360.8000000000002, -189.}, {
     Center, Center}, {359.9999999999998, 360.}]}, {}},
  ContentSelectable->True,
  ImageSize->1000,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.723532836499342*^9, 3.7235330719245768`*^9, 3.724392485394491*^9, 
   3.724392785683806*^9, 3.7243928758412647`*^9, 3.725627406886572*^9, 
   3.725627445506*^9, {3.725629041543148*^9, 3.725629194148402*^9}, {
   3.7256300899292507`*^9, 3.725630127016958*^9}, 3.725630165094754*^9, 
   3.725630279377733*^9, 3.725630336332568*^9, 3.7263909906354*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Understanding the events: completeness deficit and pathways on the cube\
\>", "Subsubsection",
 CellChangeTimes->{{3.723528192717649*^9, 3.7235281976755743`*^9}, {
  3.72352931148553*^9, 3.723529367404108*^9}}],

Cell["\<\
Now we want to understand how the S-alleles arise and disappear. Recall that \
the events are defined as the SI classes from the time of their appearance \
(birth) to their disappearance (death) and that the RNase class includes all \
SI haplotypes within that class. We summarize information about every event \
throughout the simulation using the following measures:
 
(1) first SI haplotype in the class, 
(2) time at which this haplotype appeared (birth of the SI class), 
(3) time at which the first haplotype with the smallest deficit of the whole \
class appeared
(4) time at which the last haplotype, corresponding to the same event, \
disappeared (death of the class)
(5) initial deficit
(6) minimal deficit
(7) final deficit
(8) duration of the event
(9) last haplotype of the class
(10) maximal frequency of the class
(11) first haplotype that reached minimal completeness deficit

We remark that the first SI haplotype and its SI descendants may not be able \
to survive all the way to the terminal time of the class and the class may \
survive for a very long time simply because new SI haplotypes appear de novo \
due to a mutation from a different class or from a SC haplotype of the same \
class. Similarly, the last haplotype of the class may have no SI ancestors \
tracing back all the way to the birth of the event. Finally, the haplotype \
with the minimal deficit may be unrelated to the founder or to the last \
survivor of the SI class. Thus, to understand how a successful class \
typically arises it is not enough to look at the pathways leading to the \
appearance of the first/last haplotype of this class. Instead, we try to \
understand the pathways leading to the haplotype with the smallest \
completeness deficit. \
\>", "Text",
 CellChangeTimes->{{3.7235282058610983`*^9, 3.723528583074677*^9}, {
  3.7235290412143087`*^9, 3.72352914219596*^9}, {3.7235291733992653`*^9, 
  3.7235292641105957`*^9}, {3.723529374452071*^9, 3.723530173636672*^9}, {
  3.723533279794787*^9, 3.7235332805686607`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GetMasterList", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MasterList", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"1", ";;", "10"}], ",", ";;"}], "]"}], "]"}], "//", 
  "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.72353308011417*^9, 3.723533093665127*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "6", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "2", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "80", "93", "500", "1", "0", "1",
       "422", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "49", ",", "17", ",", "36", ",", "46", ",", "32", ",", "44", 
        ",", "19", ",", "31", ",", "2", ",", "26", ",", "9", ",", "20", ",", 
        "21", ",", "40", ",", "13"}], "}"}], "0.274`", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "41", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "31", ",", "2", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "10", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "2", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "77", "77", "77", "1", "1", "1", 
      "2", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "10", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "2", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "0.002`", "0"},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "22", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "55", "55", "61", "2", "2", "2", 
      "8", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "22", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "0.016`", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "22", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "21", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "34", "45", "50", "1", "0", "2", 
      "18", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "48", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "20", ",",
         "21", ",", "40", ",", "23"}], "}"}], "0.016`", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "25", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "20", ",",
         "21", ",", "40", ",", "23"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "36", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "30", "30", "30", "1", "1", "1", 
      "2", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "36", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "0.002`", "0"},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "45", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "25", "27", "28", "2", "0", "0", 
      "5", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "40", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "20", ",",
         "21", ",", "40", ",", "23"}], "}"}], "0.008`", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "40", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "20", ",",
         "21", ",", "40", ",", "23"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "25", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "17", "17", "18", "0", "0", "0", 
      "3", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "25", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "0.002`", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "25", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "24", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "11", "11", "14", "0", "0", "0", 
      "5", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "24", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}], "0.01`", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "24", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "40", ",", "23"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
       "1", ",", "24", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "47", ",", "23"}], "}"}], "9", "9", "9", "1", "1", "1", 
      "2", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "24", ",", "4", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "4", ",", "16", ",", "38", ",", "20", ",", 
        "21", ",", "47", ",", "23"}], "}"}], "0.002`", "0"},
     {
      RowBox[{"{", 
       RowBox[{
       "2", ",", "1", ",", "31", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "20", ",",
         "21", ",", "27", ",", "23"}], "}"}], "50", "61", "500", "1", "0", 
      "3", "452", 
      RowBox[{"{", 
       RowBox[{
       "2", ",", "1", ",", "17", ",", "26", ",", "12", ",", "42", ",", "42", 
        ",", "44", ",", "34", ",", "50", ",", "16", ",", "9", ",", "20", ",", 
        "21", ",", "27", ",", "23"}], "}"}], "0.35000000000000003`", 
      RowBox[{"{", 
       RowBox[{
       "2", ",", "1", ",", "31", ",", "36", ",", "46", ",", "42", ",", "42", 
        ",", "19", ",", "34", ",", "50", ",", "16", ",", "38", ",", "20", ",",
         "21", ",", "27", ",", "23"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.723533095524495*^9, 3.724392507153233*^9, 
  3.7243928860105543`*^9, 3.725627511685145*^9, 3.725627766853813*^9, 
  3.725629201745122*^9, 3.725630172414384*^9, 3.726390992852682*^9}]
}, Open  ]],

Cell["\<\
To understand what constitutes a successful event we obtain the \
characteristics of the events and look at the relationship between the \
minimal completeness deficit of an event and its success, which is measured \
either by a lifetime of the class or by the maximal frequency reached. The \
light color corresponds to the events with a short lifetime (<100 \
generations) while the dark dots correspond to the long events (>100 \
generations).\
\>", "Text",
 CellChangeTimes->{{3.723533234360879*^9, 3.72353331944656*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"class", " ", "=", " ", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Position", "[", 
     RowBox[{
      RowBox[{"MasterList", "[", 
       RowBox[{"[", 
        RowBox[{";;", ",", "10"}], "]"}], "]"}], ",", 
      RowBox[{"n_", " ", "/;", " ", 
       RowBox[{"n", "<=", " ", "0.05"}]}]}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"    ", 
  RowBox[{
   RowBox[{"P21", " ", "=", " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"MasterList", "[", 
           RowBox[{"[", 
            RowBox[{"class", ",", "6"}], "]"}], "]"}], "+", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"RandomVariate", "[", 
             RowBox[{"NormalDistribution", "[", 
              RowBox[{"0", ",", "0.05"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{
               RowBox[{"MasterList", "[", 
                RowBox[{"[", 
                 RowBox[{"class", ",", "6"}], "]"}], "]"}], "//", 
               "Length"}]}], "}"}]}], "]"}]}], "\n", "    ", ",", 
         RowBox[{"Log10", "@", 
          RowBox[{"MasterList", "[", 
           RowBox[{"[", 
            RowBox[{"class", ",", "8"}], "]"}], "]"}]}]}], "}"}], 
       "\[Transpose]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.5"}], ",", "4.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], "\n", "\t", ",", 
      RowBox[{"PlotMarkers", "->", 
       RowBox[{"{", 
        RowBox[{"\[FilledSmallCircle]", ",", "15"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Darker", "[", 
        RowBox[{"Blue", ",", "0"}], "]"}]}], ",", 
      RowBox[{"Frame", "->", "True"}], ",", " ", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", 
         RowBox[{"-", "10"}]}], "}"}]}], ",", "\n", "\t", 
      RowBox[{"FrameLabel", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Log10(lifetime)\>\"", ",", "None"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<Minimal Completeness Deficit\>\"", ",", "None"}], " ", 
          "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\t"}], "\n", 
 RowBox[{"\t", 
  RowBox[{
   RowBox[{"P22", " ", "=", " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"MasterList", "[", 
           RowBox[{"[", 
            RowBox[{"class", ",", "6"}], "]"}], "]"}], "+", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"RandomVariate", "[", 
             RowBox[{"NormalDistribution", "[", 
              RowBox[{"0", ",", "0.05"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{
               RowBox[{"MasterList", "[", 
                RowBox[{"[", 
                 RowBox[{"class", ",", "6"}], "]"}], "]"}], "//", 
               "Length"}]}], "}"}]}], "]"}]}], "\n", "\t", ",", 
         RowBox[{"MasterList", "[", 
          RowBox[{"[", 
           RowBox[{"class", ",", "10"}], "]"}], "]"}]}], "}"}], 
       "\[Transpose]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.5"}], ",", "4.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.25"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "\n", "\t", ",", 
      RowBox[{"PlotMarkers", "->", 
       RowBox[{"{", 
        RowBox[{"\[FilledSmallCircle]", ",", "15"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Darker", "[", 
        RowBox[{"Red", ",", "0"}], "]"}]}], ",", 
      RowBox[{"Frame", "->", "True"}], ",", 
      RowBox[{"FrameLabel", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Frequency\>\"", ",", "None"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<Minimal Completeness Deficit\>\"", ",", "None"}], " ", 
          "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", "\t\t"}], "\n", 
 RowBox[{"\t", 
  RowBox[{
   RowBox[{"class", " ", "=", " ", 
    RowBox[{"Flatten", "@", 
     RowBox[{"Position", "[", 
      RowBox[{
       RowBox[{"MasterList", "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", "10"}], "]"}], "]"}], ",", 
       RowBox[{"n_", " ", "/;", " ", 
        RowBox[{"n", ">=", " ", "0.05"}]}]}], "]"}]}]}], ";"}], "\n"}], "\n", 

 RowBox[{"    ", 
  RowBox[{
   RowBox[{"Q21", " ", "=", " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"MasterList", "[", 
           RowBox[{"[", 
            RowBox[{"class", ",", "6"}], "]"}], "]"}], "+", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"RandomVariate", "[", 
             RowBox[{"NormalDistribution", "[", 
              RowBox[{"0", ",", "0.05"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{
               RowBox[{"MasterList", "[", 
                RowBox[{"[", 
                 RowBox[{"class", ",", "6"}], "]"}], "]"}], "//", 
               "Length"}]}], "}"}]}], "]"}]}], "\n", "    ", ",", 
         RowBox[{"Log10", "@", 
          RowBox[{"MasterList", "[", 
           RowBox[{"[", 
            RowBox[{"class", ",", "8"}], "]"}], "]"}]}]}], "}"}], 
       "\[Transpose]"}], ",", 
      RowBox[{"PlotRange", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.2"}], ",", 
           RowBox[{
            RowBox[{"Max", "[", 
             RowBox[{"MasterList", "[", 
              RowBox[{"[", 
               RowBox[{";;", ",", "6"}], "]"}], "]"}], "]"}], "+", "0.4"}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{"Max", "[", 
             RowBox[{"Log10", "@", 
              RowBox[{"MasterList", "[", 
               RowBox[{"[", 
                RowBox[{"class", ",", "8"}], "]"}], "]"}]}], "]"}], "+", 
            "0.2"}]}], "}"}]}], "}"}]}], "\n", "\t", ",", 
      RowBox[{"PlotMarkers", "->", 
       RowBox[{"{", 
        RowBox[{"\[FilledSmallCircle]", ",", "15"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Darker", "[", 
        RowBox[{"Blue", ",", "0.75"}], "]"}]}], ",", 
      RowBox[{"Frame", "->", "True"}], ",", "\n", "\t", 
      RowBox[{"FrameLabel", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Log10(lifetime)\>\"", ",", "None"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<Minimal Completeness Deficit\>\"", ",", "None"}], " ", 
          "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\t"}], "\n", 
 RowBox[{"\t", 
  RowBox[{
   RowBox[{"Q22", " ", "=", " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"MasterList", "[", 
           RowBox[{"[", 
            RowBox[{"class", ",", "6"}], "]"}], "]"}], "+", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"RandomVariate", "[", 
             RowBox[{"NormalDistribution", "[", 
              RowBox[{"0", ",", "0.05"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{
               RowBox[{"MasterList", "[", 
                RowBox[{"[", 
                 RowBox[{"class", ",", "6"}], "]"}], "]"}], "//", 
               "Length"}]}], "}"}]}], "]"}]}], "\n", "\t", ",", 
         RowBox[{"MasterList", "[", 
          RowBox[{"[", 
           RowBox[{"class", ",", "10"}], "]"}], "]"}]}], "}"}], 
       "\[Transpose]"}], ",", 
      RowBox[{"PlotRange", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.2"}], ",", 
           RowBox[{
            RowBox[{"Max", "[", 
             RowBox[{"MasterList", "[", 
              RowBox[{"[", 
               RowBox[{"class", ",", "6"}], "]"}], "]"}], "]"}], "+", 
            "0.4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"Max", "[", 
            RowBox[{"MasterList", "[", 
             RowBox[{"[", 
              RowBox[{"class", ",", "10"}], "]"}], "]"}], "]"}]}], "}"}]}], 
        "}"}]}], "\n", "\t", ",", 
      RowBox[{"PlotMarkers", "->", 
       RowBox[{"{", 
        RowBox[{"\[FilledSmallCircle]", ",", "15"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Darker", "[", 
        RowBox[{"Red", ",", "0.6"}], "]"}]}], ",", 
      RowBox[{"Frame", "->", "True"}], ",", 
      RowBox[{"FrameLabel", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Frequency\>\"", ",", "None"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<Minimal Completeness Deficit\>\"", ",", "None"}], " ", 
          "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"P", " ", "=", " ", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{"P21", ",", "Q21"}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{"P22", ",", "Q22"}], "]"}]}], "}"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.723533148484624*^9, {3.723533328176631*^9, 3.723533328659932*^9}, {
   3.725630180267798*^9, 3.725630180417822*^9}, {3.72563034635176*^9, 
   3.725630346677434*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {
         {RGBColor[0, 0, 1], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          StyleBox[GeometricTransformationBox[InsetBox[
             StyleBox["\[FilledSmallCircle]",
              StripOnInput->False,
              FontSize->15], {0., 0.}], CompressedData["
1:eJxFU2tMkmEURp2BwUSmZaZ0oQleyrW0Mi+9bFqzWWo4a2ZiXvjhbMNKkrLQ
tJmlaVFaTpOUjcTZvKGZuMxNRYhGmWbrqmHkVOAjxTQv5A953x/vj7PznHOe
8zzn3ZnCZXHscDgca+3ZrD3btdeJ2yeSF+iB5Yooxjn8AyjQOtooEixg9YBx
wUM3A37ez+JPUJKBQBkterxpDrAf99+hfzVA/MHtObLNs1nAJqz59HyiDmxz
Stt/ObsVrIxEVzBufwcJofFJd/Zmw7yCX949Ksdg/cZQrF3IRnFzEe1EVY0B
4ndweuLiJTMAqPlEInEarPoPPrgVg2Na8UaVqsKhEcXhdtkrpE9G2M+duqdQ
qbNAPiXjwtgwDRnif5T6JZdI8DAOolFzvImoX2Vhequ/WdZjjen1H4u/xwph
/LLHsJFLRfh/qpxlNYHAtPIvDWkYiCKj/BFF3uCWrSbI71Xv8DabvvoeKz+y
7KQLJxHx735brFhqwKAf72tZnqYWPNOqh5Q/w1uelML6sl6fKkfKc1j/Zt/x
VJdGpG9+Hp6uakL9r2aeqWkMfLi+jxbIL3B++5QhfmKXcK8bUUgffVYF49oo
8l8lKWQRvBF+KsnzUL0bjvnoeuT+6aZZ0BDZUPSrUg+4/THniqUY6OJgbUGV
YojXMRYrBcDqhxZoBMF0NU0O/a8jDVLYLc5wvkTeJhhzXdPjWfalJ7pJ4DCe
Rj6q0QOn3qW4Ad4cULCVUbvNeKZVj1z7hV/Ci7XQ/w41a+TzFwzGIX7i8vNm
K38tcLP1zOh4aYH8UtvHyOpTSD9/qklTl2qE+Orqoq+6u0jP9JPHDit5xvX+
BvCa2Vxu6bJAfDp92W1Wi/hHU7lTFBG6d8/MoaYIMvL7XoFXJyOAAPfnJZfk
4bvLIF78tyNX1oH2SQgzhPuSUH38O31KmkwPtgfxwfDCIvA7y20RmcRw/lnH
cbc4Bgb5yXdUNw1x0P5Pgtw3RBah+X17hnwpLkiPiOC+lPpidN9TuwKySquQ
HoEjUhonAfV7NO2ucdWh+8lYHUi7xzZC/iSl3WVprAkYuiaOjEQugJZGV4fQ
cnR/kiGcIu8E4jNtTvYgklDevgarW/yzCvvP7W3NEMah+bznPHq+/gX8L2Nm
sn3NzWr4n33CDhD6n2JAMCZv/qabB/8BraSPYA==
            "]],
           FontFamily->"Helvetica",
           FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
         {RGBColor[0., 0., 0.25], AbsolutePointSize[6], AbsoluteThickness[
          1.6], 
          StyleBox[GeometricTransformationBox[InsetBox[
             StyleBox["\[FilledSmallCircle]",
              StripOnInput->False,
              FontSize->15], {0., 0.}], {{{0.044943023386099144`, 
            2.625312450961674}}, {{0.026813745581860865`, 
            2.655138434811382}}, {{0.029993687578950684`, 
            2.2405492482826}}, {{-0.029460980026437038`, 
            1.8692317197309762`}}, {{-0.04664959246076213, 
            2.113943352306837}}, {{2.0095636229895453`, 
            1.0413926851582251`}}, {{-0.013845320676544266`, 
            2.0681858617461617`}}, {{-0.04627359915448963, 
            2.406540180433955}}, {{-0.021609720709062488`, 
            1.9590413923210936`}}, {{-0.049325624892071256`, 
            1.7634279935629373`}}, {{-0.032617697317828306`, 
            1.6901960800285136`}}, {{1.0246831713552536`, 
            1.3979400086720377`}}, {{0.05584769122404179, 
            2.1702617153949575`}}, {{1.0088608323863946`, 
            1.4313637641589874`}}}],
           FontFamily->"Helvetica",
           FontSize->16]}, {}}, {}, {}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{-10., -10.},
      BaseStyle->{
       FontFamily -> "Helvetica", FontSize -> 16, FontColor -> GrayLevel[0]},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox["\"Log10(lifetime)\"", TraditionalForm], None}, {
         FormBox["\"Minimal Completeness Deficit\"", TraditionalForm], None}},
      
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-0.5, 4.5}, {0, 5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          StyleBox[GeometricTransformationBox[InsetBox[
             StyleBox["\[FilledSmallCircle]",
              StripOnInput->False,
              FontSize->15], {0., 0.}], CompressedData["
1:eJxTTMoPSmVmYGAIAmJGIGYC4paDe2JT+9/b/1n58ZJvUoJ97pT1vkZqDA4Q
/gT7RfZPLWbULLKH8Vcov0uymPEBrn5VnAXXV/m2/RB+g/1m4/Nru/oy4fJC
VRLGVQor7KtF1rk/rGqxn9P7wmqb/ke4/I2CjInsMQjzWEL1S3tqYPIF9mL5
nBekLr+xh5nP9POa8FJWmPsS7P/ySOZsMP0P15+yTXvR9EyEeV1LKzNE7/+H
m/fqRNfkI5ICcP2hitpMdq3scP7/al/+/boI88O6vPPPOfbsh+n/t/dPWEvt
uv0wefFJjzQ9NiHsXyUZFWu6ht3hV13WnpLJFfbfuC+WbatCyDdEPpIS6vsA
d88FsxUT2cz74OYVMyetEVj6Hi7/N8g2knPze7j/Q/4fbo6+yA6PH5YH3oKb
++fCzU8u+nHQ1GkXnC+ioOan+QNhX9SG1TLT1N7B5Z+rcc9O6qyB+6/I95F2
WgkiPTR8XsFRoMkBDw+Tn1kxh+4j5I/yCvz+9+KdPcy/ZQoXZC40/YfyO+zf
Zv3ZnWf+Ae7+o7ZM5t5RG+D6y0LPmtqd44eb352/+2lCfNN+mHkfl6+cdVBc
xAHmvsn5nz7sEUXYn54Vr6ht9gGePhX2iUeq70S418G83+569Ra4erMV67Oc
m97C3WvydpqG2BlEeD8J6nVnfv0PLj/5iMGOm1MQ4ce8aEaRpjtCfeo/98Km
BYj0ptey+9I55o/w9H495nhXmCwD3P2e01fM9Ff6ADf/dEjPJ50ziPhdcCjt
0LP893D/HFBds77Gjx2u3/CWRdrTCxvg9gsp3N1eWoKIT4X+ZXdamt7B9cv5
bvLVZYPFzwr7J6/E1fzmrIfbf6rEcFnZyndw84J9ruyxF0ekf9vTXma37BDh
qXH1xk2+AIR9k3jepq2+iUjf17w9Pvz2RYSH5ufaQ8GPEfIsgcr7lz9FxN86
6ZPT/r14C+dLpzzh2X3vPTT8lthbpW9R22CByJ9tdkueCB9F8NneuFzbK88B
Dx+pQr9JXE6I/F7f+FXDUx4R/oVnxG70pS+Gp/eA74LLvHYFwvPfEzkPWd6m
D/azZoLASnsATKi4xQ==
            "]],
           FontFamily->"Helvetica",
           FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
         {RGBColor[0.4, 0., 0.], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          StyleBox[GeometricTransformationBox[InsetBox[
             StyleBox["\[FilledSmallCircle]",
              StripOnInput->False,
              FontSize->15], {0., 0.}], {{{-0.09450338587679488, 
            0.274}}, {{-0.014556303442255404`, 0.35000000000000003`}}, {{
            0.004349784899980852, 0.18}}, {{-0.07175367271778037, 0.178}}, {{
            0.06552005590363018, 0.324}}, {{2.0003693463977084`, 0.148}}, {{
            0.011168682976965112`, 0.188}}, {{0.009306739544845576, 
            0.274}}, {{0.037477757149629684`, 
            0.062}}, {{-0.046786917705901786`, 0.11}}, {{0.06332421906471739, 
            0.198}}, {{0.9908637715480481, 0.152}}, {{-0.028208792363490057`, 
            0.292}}, {{1.0929683481128991`, 0.05}}}],
           FontFamily->"Helvetica",
           FontSize->16]}, {}}, {}, {}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{-1., 0.},
      BaseStyle->{
       FontFamily -> "Helvetica", FontSize -> 16, FontColor -> GrayLevel[0]},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox["\"Frequency\"", TraditionalForm], None}, {
         FormBox["\"Minimal Completeness Deficit\"", TraditionalForm], None}},
      
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-0.5, 4.5}, {0, 0.25}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->1000,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.723533952815119*^9, 3.7243925172005663`*^9, 
  3.72439289220584*^9, 3.725627824580328*^9, 3.725629225147564*^9, 
  3.725630180856619*^9, 3.725630347400084*^9, 3.726390993020955*^9}]
}, Open  ]],

Cell[TextData[{
 "Finally we look only on the successful events, i.e. those which had a \
lifetime >100 generations. For each event we look at the first haplotype \
reaching the smallest compatibility deficit and trace its ancestors. Each of \
these ancestors is then attributed a node on the mutation cube, depending on \
whether it has the ancestral/new RNase and SLF. The nodes are labeled 1-8 in \
the following way:\n\n",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztnUuIHce9h2VJjh7WSBNFKNeWLDQ3URzkoBhErjybKCZDTIJlQexxsrhg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     "], {{0, 285}, {399,
      0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJyVlwdUU1kax+976Y0WiICU0JsgnQBSQg9FkA42QhKSUEJModmVwREYCyoi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       "], "RGB", "XYZ"], Interleaving -> True, 
     MetaInformation -> 
     Association[
      "Comments" -> 
       Association[
        "XML:com.adobe.xmp" -> 
         "<x:xmpmeta xmlns:x=adobe:ns:meta/ x:xmptk=XMP Core 5.4.0> <rdf:RDF \
xmlns:rdf=http://www.w3.org/1999/02/22-rdf-syntax-ns#><rdf:Description \
rdf:about=xmlns:exif=http://ns.adobe.com/exif/1.0/> \
<exif:PixelXDimension>399</exif:PixelXDimension> \
<exif:PixelYDimension>285</exif:PixelYDimension></rdf:Description> \
</rdf:RDF></x:xmpmeta>"]]],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSizeRaw->{399, 285},
   PlotRange->{{0, 399}, {0, 285}}]], "Input"]
}], "Text",
 CellChangeTimes->{{3.723530205315431*^9, 3.72353041459142*^9}, {
  3.7235333364073*^9, 3.723533343813772*^9}, {3.72562789570269*^9, 
  3.725627901245475*^9}, {3.7256285598834057`*^9, 3.725628569209611*^9}, {
  3.7256286000835133`*^9, 3.725628602393736*^9}, {3.725628635145638*^9, 
  3.7256286543598127`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GetLegend", ";"}], "\n", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Node 1:\>\"", ",", "l1", ",", "\"\<\\nNode 2:\>\"", ",", "l2", ",", 
   "\"\<\\nNode 3:\>\"", ",", "l3", ",", "\"\<\\nNode 4:\>\"", ",", "l4", 
   ",", "\"\<\\nNode 5:\>\"", ",", "l5", ",", "\"\<\\nNode 6:\>\"", ",", "l6",
    ",", "\"\<\\nNode 7:\>\"", ",", "l7", ",", "\"\<\\nNode 8:\>\"", ",", 
   "l8"}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.723533656887122*^9, 3.723533862616313*^9}, 
   3.723533898127274*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Node 1:\"\>", "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {GrayLevel[0], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], EdgeForm[{RGBColor[0.6, 0.6, 0.6], 
         Thickness[Large]}], PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}], "\[InvisibleSpace]", "\<\"\\nNode 2:\"\>", 
   "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {GrayLevel[0], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{RGBColor[0.6, 0.6, 0.6], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}], "\[InvisibleSpace]", "\<\"\\nNode 3:\"\>", 
   "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {GrayLevel[0], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[0], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], EdgeForm[{RGBColor[0.6, 0.6, 0.6], 
         Thickness[Large]}], PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}], "\[InvisibleSpace]", "\<\"\\nNode 4:\"\>", 
   "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {GrayLevel[0], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[0], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{RGBColor[0.6, 0.6, 0.6], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}], "\[InvisibleSpace]", "\<\"\\nNode 5:\"\>", 
   "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], EdgeForm[{RGBColor[0.6, 0.6, 0.6], 
         Thickness[Large]}], PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}], "\[InvisibleSpace]", "\<\"\\nNode 6:\"\>", 
   "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{RGBColor[0.6, 0.6, 0.6], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}], "\[InvisibleSpace]", "\<\"\\nNode 7:\"\>", 
   "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[0], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], EdgeForm[{RGBColor[0.6, 0.6, 0.6], 
         Thickness[Large]}], PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}], "\[InvisibleSpace]", "\<\"\\nNode 8:\"\>", 
   "\[InvisibleSpace]", 
   GraphicsBox[{{}, {InsetBox[
       GraphicsBox[
        {RGBColor[0.6, 0.6, 0.6], DiskBox[{0, 0}]},
        ImageSize->10], {5.375, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[0], EdgeForm[{GrayLevel[0], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {16.125, -5.25}, ImageScaled[{0.5, 0.5}], {10, 10.}], 
      InsetBox[
       GraphicsBox[
        {GrayLevel[1], EdgeForm[{RGBColor[0.6, 0.6, 0.6], Thickness[Large]}], 
         PolygonBox[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]},
        ImageSize->10], {26.875, -5.25}, 
       ImageScaled[{0.5, 0.5}], {10, 10.}]}, {}},
    ContentSelectable->True,
    ImageSize->{44.25, 22.5},
    PlotRangePadding->{6, 5}]}],
  SequenceForm["Node 1:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          GrayLevel[0], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          RGBColor[0.6, 0.6, 0.6], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True], "\nNode 2:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          GrayLevel[0], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True], "\nNode 3:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          GrayLevel[0], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[0], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          RGBColor[0.6, 0.6, 0.6], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True], "\nNode 4:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          GrayLevel[0], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[0], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True], "\nNode 5:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          RGBColor[0.6, 0.6, 0.6], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          RGBColor[0.6, 0.6, 0.6], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True], "\nNode 6:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          RGBColor[0.6, 0.6, 0.6], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True], "\nNode 7:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          RGBColor[0.6, 0.6, 0.6], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[0], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          RGBColor[0.6, 0.6, 0.6], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True], "\nNode 8:", 
   Graphics[{{}, {{
       Inset[
        Graphics[{
          RGBColor[0.6, 0.6, 0.6], 
          Disk[{0, 0}]}, ImageSize -> 10], {5.375, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            GrayLevel[0]]], 
          GrayLevel[0], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        16.125, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}], 
       Inset[
        Graphics[{
          EdgeForm[
           Directive[
            Thickness[Large], 
            RGBColor[0.6, 0.6, 0.6]]], 
          GrayLevel[1], 
          Polygon[{{0, 0}, {0, 1}, {1, 1}, {1, 0}}]}, ImageSize -> 10], {
        26.875, -5.25}, 
        ImageScaled[{0.5, 0.5}], {10, 10.}]}}, {}}, 
    ImageSize -> {44.25, 22.5}, PlotRangePadding -> {6, 5}, ContentSelectable -> 
    True]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7235337403745604`*^9, 3.723533752955386*^9}, {
   3.723533798839451*^9, 3.723533814090954*^9}, {3.7235338929393797`*^9, 
   3.72353389962815*^9}, 3.7243925379776287`*^9, 3.7256278692325907`*^9, 
   3.725627907906604*^9, 3.7256286126664267`*^9, 3.726390993142454*^9}]
}, Open  ]],

Cell["\<\
We collect all the paths that represent appearance of novel S-alleles. All \
paths, projected onto a cube can be summarized as sequences of vortex labels:\
\
\>", "Text",
 CellChangeTimes->{{3.7235334387801847`*^9, 3.7235334938867197`*^9}, {
  3.7256286878308363`*^9, 3.72562873277219*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eventsT", " ", "=", " ", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Position", "[", 
     RowBox[{
      RowBox[{"MasterList", "[", 
       RowBox[{"[", 
        RowBox[{";;", ",", "8"}], "]"}], "]"}], ",", 
      RowBox[{"n_", " ", "/;", " ", 
       RowBox[{"n", ">=", " ", "100"}]}]}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MasterListTest", " ", "=", " ", 
   RowBox[{"MasterList", "[", 
    RowBox[{"[", 
     RowBox[{"eventsT", ",", ";;"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GetPaths", ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Ancestral SLF: \>\"", ",", 
   RowBox[{
   "pathCode", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<New SLF: \>\"", ",", 
   RowBox[{
   "pathCode", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Summary of paths: \>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"AllPaths", "//", "MatrixForm"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7235280471431932`*^9, 3.7235280779765873`*^9}, {
   3.723528140895115*^9, 3.72352815809826*^9}, 3.723533058864923*^9, {
   3.723533380493326*^9, 3.7235334326690283`*^9}, {3.725628745741725*^9, 
   3.725628786388791*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ancestral SLF: \"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["Ancestral SLF: ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.725628748217497*^9, 3.725628768419372*^9}, 
   3.725629237428854*^9, 3.725630191201128*^9, 3.726390993269298*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"New SLF: \"\>", "\[InvisibleSpace]", "3"}],
  SequenceForm["New SLF: ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{{3.725628748217497*^9, 3.725628768419372*^9}, 
   3.725629237428854*^9, 3.725630191201128*^9, 3.7263909932741117`*^9}],

Cell[BoxData["\<\"Summary of paths: \"\>"], "Print",
 CellChangeTimes->{{3.725628748217497*^9, 3.725628768419372*^9}, 
   3.725629237428854*^9, 3.725630191201128*^9, 3.726390993281658*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{"{", 
        RowBox[{"4", ",", "8"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{"2", ",", "4", ",", "8"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "8"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{"4", ",", "8"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "3", ",", "4", ",", "8"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "4", ",", "8"}], "}"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.725628748217497*^9, 3.725628768419372*^9}, 
   3.725629237428854*^9, 3.725630191201128*^9, 3.726390993289462*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mathematica definitions", "Section",
 CellChangeTimes->{{3.723447213447701*^9, 3.723447250618928*^9}, {
  3.724388886983568*^9, 3.7243888871745768`*^9}, {3.7243899976974916`*^9, 
  3.7243899982239437`*^9}}],

Cell[CellGroupData[{

Cell["Initialize", "Subsection"],

Cell[CellGroupData[{

Cell["Options", "Subsubsection",
 CellChangeTimes->{{3.723527715288473*^9, 3.723527716551379*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListPlot", ",", " ", 
    RowBox[{"BaseStyle", " ", "->", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", " ", "->", " ", "\"\<Helvetica\>\""}], ",", " ", 
       
       RowBox[{"FontSize", " ", "->", " ", "16"}], ",", 
       RowBox[{"FontColor", "\[Rule]", " ", "Black"}]}], "}"}]}]}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Histogram", ",", " ", 
    RowBox[{"BaseStyle", " ", "->", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", " ", "->", " ", "\"\<Helvetica\>\""}], ",", " ", 
       
       RowBox[{"FontSize", " ", "->", " ", "16"}], ",", 
       RowBox[{"FontColor", "\[Rule]", " ", "Black"}]}], "}"}]}]}], "]"}], 
  ";"}]}], "Code",
 CellChangeTimes->{{3.7235277322407103`*^9, 3.723527733375142*^9}, {
  3.723527904027339*^9, 3.723527935496855*^9}, {3.726390357150868*^9, 
  3.726390358861061*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["VisualizeD", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"visualizeD", "[", "m_", "]"}], ":=", 
  RowBox[{"Module", "[", "\n", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dims", "=", 
       RowBox[{"Dimensions", "[", "m", "]"}]}], ",", "sorted"}], "}"}], ",", 
    "\n", 
    RowBox[{
     RowBox[{"sorted", "=", 
      RowBox[{"Sort", "[", "m", "]"}]}], ";", "\n", 
     RowBox[{"Show", "[", "\n", 
      RowBox[{"MatrixPlot", "[", 
       RowBox[{"m", ",", 
        RowBox[{"ColorFunction", "->", "\"\<ThermometerColors\>\""}], ",", 
        RowBox[{"MaxPlotPoints", "->", "\[Infinity]"}], ",", 
        RowBox[{"AspectRatio", "->", 
         RowBox[{"1", "/", "GoldenRatio"}]}], ",", 
        RowBox[{"ImageSize", "->", "200"}], ",", 
        RowBox[{"FrameTicks", "->", "None"}], ",", 
        RowBox[{"FrameLabel", "->", 
         RowBox[{"{", 
          RowBox[{"\"\<Individual\>\"", ",", "\"\<Genotype\>\""}], "}"}]}]}], 
       "]"}], "\n", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "popsize"}], "}"}]}], "}"}], "]"}]}], "}"}], 
         "]"}], ",", "\n", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Dashed", ",", "Black", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"FTypes", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "+", "1"}], ",", "0"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"FTypes", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "+", "1"}], ",", 
                "popsize"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], "*)"}], 
      
      RowBox[{"(*", 
       RowBox[{",", "\n", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Fnumber", "+", "2"}], ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Fnumber", "+", "2"}], ",", "popsize"}], "}"}]}], 
             "}"}], "]"}]}], "}"}], "]"}]}], "*)"}], "\n", "]"}]}]}], "\n", 
   "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["CreateInitialPopulationRandom", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "All", " ", "haplotypes", " ", "have", " ", "the", " ", "same", " ", 
      "R"}], "=", "1"}], ",", " ", 
    RowBox[{
     RowBox[{"the", " ", "first", " ", "F"}], "=", 
     RowBox[{
     "1", " ", "and", " ", "the", " ", "rest", " ", "is", " ", "random"}]}]}],
    " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"CreateInitialPopulationRandom", "[", 
     RowBox[{"popsize_", ",", "Fnumber_", ",", "Rnumber_", ",", "Snumber_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"uniqs1", ",", "uniqs2"}], "}"}], ",", "\n", 
      RowBox[{
       RowBox[{"uniqs", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"RandomChoice", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"1", "/", "Fnumber"}], ",", "Fnumber"}], "]"}], "->", 
            RowBox[{"Range", "[", "Fnumber", "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "popsize"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "Snumber"}], "}"}]}], "]"}]}], ";", 
       "\n", 
       RowBox[{"uniqs1", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Flatten", "@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"RandomChoice", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"1", ",", "0.0"}], "}"}], "->", " ", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}]}], ",", "1"}], "]"}], ",", 
               RowBox[{"{", "popsize", "}"}], ",", 
               RowBox[{"{", "1", "}"}]}], "]"}]}], "}"}], "~", "Join", "~", 
           RowBox[{"(", 
            RowBox[{"uniqs", "\[Transpose]"}], ")"}]}], ")"}], 
         "\[Transpose]"}]}], ";", "\n", 
       RowBox[{"uniqs2", " ", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Flatten", "@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"RandomChoice", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"1", ",", "0.0"}], "}"}], "->", " ", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}]}], ",", "1"}], "]"}], ",", 
               RowBox[{"{", "popsize", "}"}], ",", 
               RowBox[{"{", "1", "}"}]}], "]"}]}], "}"}], "~", "Join", "~", 
           RowBox[{"(", 
            RowBox[{"uniqs", "\[Transpose]"}], ")"}]}], ")"}], 
         "\[Transpose]"}]}], ";", "\n", 
       RowBox[{
        RowBox[{"uniqs1", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", "2"}], "]"}], "]"}], " ", "=", " ", "1"}], ";", 
       " ", 
       RowBox[{"(*", 
        RowBox[{"make", " ", "sure", " ", "it", " ", "is", " ", "SC"}], 
        "*)"}], "\n", 
       RowBox[{
        RowBox[{"uniqs2", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", "2"}], "]"}], "]"}], " ", "=", " ", "1"}], ";", 
       "\n", 
       RowBox[{"uniqs", " ", "=", " ", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"uniqs1", "\[Transpose]"}], ",", 
           RowBox[{"uniqs2", "\[Transpose]"}]}], "]"}], "\[Transpose]"}]}], 
       ";", "\n", "uniqs"}]}], "\n", "]"}]}], "\n"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["CreateInitialPopulationRandom1", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "All", " ", "haplotypes", " ", "have", " ", "the", " ", "same", " ", 
      "R"}], "=", "1"}], ",", " ", 
    RowBox[{
     RowBox[{"the", " ", "first", " ", "F"}], "=", 
     RowBox[{
     "1", " ", "and", " ", "the", " ", "rest", " ", "is", " ", "random", " ", 
      "but", " ", "all", " ", "haps", " ", "are", " ", "the", " ", 
      "same"}]}]}], " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"CreateInitialPopulationRandom1", "[", 
     RowBox[{"popsize_", ",", "Fnumber_", ",", "Rnumber_", ",", "Snumber_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"uniqs1", ",", "uniqs2"}], "}"}], ",", "\n", "\t", 
      RowBox[{
       RowBox[{"uniqs", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", "\n", "\t", 
       RowBox[{"tab", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"RandomChoice", "[", 
           RowBox[{
            RowBox[{"ConstantArray", "[", 
             RowBox[{
              RowBox[{"1", "/", "Fnumber"}], ",", "Fnumber"}], "]"}], "->", 
            RowBox[{"Range", "[", "Fnumber", "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "Snumber"}], "}"}]}], "]"}]}], ";", 
       "\n", "\t", 
       RowBox[{"Do", "[", " ", 
        RowBox[{
         RowBox[{"AppendTo", "[", 
          RowBox[{"uniqs", ",", "tab"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "popsize"}], "}"}]}], "]"}], ";", "\n", 
       "\t", 
       RowBox[{"uniqs1", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Flatten", "@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"RandomChoice", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"1", ",", "0.0"}], "}"}], "->", " ", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}]}], ",", "1"}], "]"}], ",", 
               RowBox[{"{", "popsize", "}"}], ",", 
               RowBox[{"{", "1", "}"}]}], "]"}]}], "}"}], "~", "Join", "~", 
           RowBox[{"(", 
            RowBox[{"uniqs", "\[Transpose]"}], ")"}]}], ")"}], 
         "\[Transpose]"}]}], ";", "\n", "\t", 
       RowBox[{"uniqs2", " ", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Flatten", "@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"RandomChoice", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"1", ",", "0.0"}], "}"}], "->", " ", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}]}], ",", "1"}], "]"}], ",", 
               RowBox[{"{", "popsize", "}"}], ",", 
               RowBox[{"{", "1", "}"}]}], "]"}]}], "}"}], "~", "Join", "~", 
           RowBox[{"(", 
            RowBox[{"uniqs", "\[Transpose]"}], ")"}]}], ")"}], 
         "\[Transpose]"}]}], ";", "\n", "\t", 
       RowBox[{
        RowBox[{"uniqs1", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", "2"}], "]"}], "]"}], " ", "=", " ", "1"}], ";", 
       " ", 
       RowBox[{"(*", 
        RowBox[{"make", " ", "sure", " ", "it", " ", "is", " ", "SC"}], 
        "*)"}], "\n", "\t", 
       RowBox[{
        RowBox[{"uniqs2", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", "2"}], "]"}], "]"}], " ", "=", " ", "1"}], ";", 
       "\n", "\t", 
       RowBox[{"uniqs", " ", "=", " ", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"uniqs1", "\[Transpose]"}], ",", 
           RowBox[{"uniqs2", "\[Transpose]"}]}], "]"}], "\[Transpose]"}]}], 
       ";", "\n", "\t", "uniqs"}]}], "\n", "]"}]}], "\n"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["ColorSchemes", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"c01", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"58.4", "/", "100"}], ",", " ", 
     RowBox[{"38.8", "/", "100"}], ",", " ", 
     RowBox[{"23.9", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c02", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"62.4", "/", "100"}], ",", " ", 
     RowBox[{"63.5", "/", "100"}], ",", " ", 
     RowBox[{"63.1", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c03", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"58.0", "/", "100"}], ",", " ", 
     RowBox[{"41.6", "/", "100"}], ",", " ", 
     RowBox[{"61.2", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c04", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"84.3", "/", "100"}], ",", " ", 
     RowBox[{"36.1", "/", "100"}], ",", " ", 
     RowBox[{"33.7", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c05", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"96.1", "/", "100"}], ",", " ", 
     RowBox[{"71.8", "/", "100"}], ",", " ", 
     RowBox[{"40.8", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c06", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"50.2", "/", "100"}], ",", " ", 
     RowBox[{"67.8", "/", "100"}], ",", " ", 
     RowBox[{"43.5", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c07", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"29.0", "/", "100"}], ",", " ", 
     RowBox[{"50.2", "/", "100"}], ",", " ", 
     RowBox[{"67.1", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c08", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"56.1", "/", "100"}], ",", " ", 
     RowBox[{"57.3", "/", "100"}], ",", " ", 
     RowBox[{"56.9", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c09", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"51.4", "/", "100"}], ",", " ", 
     RowBox[{"34.5", "/", "100"}], ",", " ", 
     RowBox[{"54.5", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c10", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"81.2", "/", "100"}], ",", " ", 
     RowBox[{"27.5", "/", "100"}], ",", " ", 
     RowBox[{"23.5", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c11", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"94.9", "/", "100"}], ",", " ", 
     RowBox[{"67.8", "/", "100"}], ",", " ", 
     RowBox[{"31.0", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c12", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"42.7", "/", "100"}], ",", " ", 
     RowBox[{"62.7", "/", "100"}], ",", " ", 
     RowBox[{"36.1", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c13", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"18.8", "/", "100"}], ",", " ", 
     RowBox[{"43.5", "/", "100"}], ",", " ", 
     RowBox[{"61.6", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c14", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"18.4", "/", "100"}], ",", " ", 
     RowBox[{"8.8", "/", "100"}], ",", " ", 
     RowBox[{"23.9", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c15", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"12.4", "/", "100"}], ",", " ", 
     RowBox[{"53.5", "/", "100"}], ",", " ", 
     RowBox[{"3.1", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c16", " ", "=", " ", 
   RowBox[{"RGBColor", "[", 
    RowBox[{
     RowBox[{"18.0", "/", "100"}], ",", " ", 
     RowBox[{"41.6", "/", "100"}], ",", " ", 
     RowBox[{"81.2", "/", "100"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"apple13", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "c01", ",", " ", "c02", ",", " ", "c03", ",", " ", "c04", ",", " ", "c05",
      ",", " ", "c06", ",", " ", "c07", ",", " ", "c08", ",", " ", "c09", ",",
      " ", "c10", ",", " ", "c11", ",", " ", "c12", ",", " ", "c13", ",", " ",
      "c14", ",", " ", "c15", ",", " ", "c16"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "apple13", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"Rectangle", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "i"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"i", "+", "1"}], ")"}]}]}], "}"}]}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "16"}], "}"}]}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "18"}]}], "]"}], "*)"}]}]}], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"discreteColors", "[", "n_", "]"}], " ", ":=", " ", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"partL", " ", "=", " ", 
       RowBox[{"Ceiling", "[", 
        RowBox[{"Sqrt", "[", "n", "]"}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"Partition", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Lighter", "[", 
              RowBox[{
               RowBox[{"Darker", "[", 
                RowBox[{
                 RowBox[{"Hue", "[", "c", "]"}], ",", " ", ".1"}], "]"}], ",",
                " ", ".25"}], "]"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"c", ",", " ", "0", ",", " ", 
               RowBox[{"1", " ", "-", " ", 
                RowBox[{"1", "/", "n"}]}], ",", " ", 
               RowBox[{"1", "/", "n"}]}], "}"}]}], "]"}], ",", " ", "partL", 
           ",", " ", "partL", ",", " ", "1", ",", " ", "0"}], "]"}], "]"}], 
        "]"}], ",", " ", "0"}], "]"}]}], "]"}]}], "\n"}]], "Code"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Main simulation", "Subsection"],

Cell[CellGroupData[{

Cell["SortDiploid", "Subsubsection"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
   "Sorts", " ", "the", " ", "diploid", " ", "genome", " ", "so", " ", "that",
     " ", "it", " ", "is", " ", "lexicographically", " ", "ordered"}], " ", 
   "-", " ", 
   RowBox[{
   "this", " ", "way", " ", "there", " ", "is", " ", "no", " ", "ambiguity", 
    " ", "in"}]}], "*)"}]], "Code"],

Cell[BoxData[
 RowBox[{"SortDiploid", " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"un1", ",", " ", "un2", ",", " ", "u"}], "}"}], ",", "\n", "  ", 
    
    RowBox[{
     RowBox[{"un1", " ", "=", " ", 
      RowBox[{"uniqs", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", 
         RowBox[{";;", " ", 
          RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], "]"}]}], ";", 
     "\n", "  ", 
     RowBox[{"un2", " ", "=", " ", 
      RowBox[{"uniqs", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", 
         RowBox[{
          RowBox[{"Snumber", " ", "+", " ", "2"}], " ", ";;"}]}], "]"}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{
        RowBox[{"u", " ", "=", " ", 
         RowBox[{"Sort", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"un1", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", " ", 
            RowBox[{"un2", "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], "}"}], "]"}]}], ";", "\n", 
        "   ", 
        RowBox[{
         RowBox[{"un1", "[", 
          RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", 
         RowBox[{"u", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "   ", 
        RowBox[{
         RowBox[{"un2", "[", 
          RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", 
         RowBox[{"u", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\n", "   ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", "un1"}]}], "}"}]}], "]"}], ";", "\n", "  ", 
     RowBox[{"uniqs", " ", "=", " ", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"un1", "\[Transpose]"}], ",", " ", 
         RowBox[{"un2", "\[Transpose]"}]}], "]"}], "\[Transpose]"}]}]}]}], 
   "\n", "  ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["RmutateStore ", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RmutateStore", "[", 
     RowBox[{"Rnumber_", ",", " ", "Snumber_", ",", " ", "time_"}], "]"}], 
    " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\n", "   ", "\n", "   \t", 
      RowBox[{
       RowBox[{"RmutNum1", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"BinomialDistribution", "[", 
          RowBox[{"popsize", ",", " ", "\[Mu]R"}], "]"}], "]"}]}], ";", "\n", 
       "   \t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"RmutNum1", " ", ">", " ", "0"}], ",", "\n", "       ", 
         RowBox[{
          RowBox[{"RmutIndexFrom1", " ", "=", " ", 
           RowBox[{"RandomSample", "[", 
            RowBox[{
             RowBox[{"Range", "[", "popsize", "]"}], ",", " ", "RmutNum1"}], 
            "]"}]}], ";", "\n", "       ", 
          RowBox[{"HapFrom1", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", "RmutIndexFrom1", "]"}], "]"}]}], ";", "\n", 
          "       ", 
          RowBox[{"RmutIndexTo1", " ", "=", " ", 
           RowBox[{"Flatten", "@", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"RandomSample", "[", 
               RowBox[{
                RowBox[{"Delete", "[", 
                 RowBox[{
                  RowBox[{"Range", "[", "Rnumber", "]"}], ",", " ", 
                  RowBox[{"uniqs", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"RmutIndexFrom1", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], ",", " ", "1"}], "]"}], 
                   "]"}]}], "]"}], ",", " ", "1"}], "]"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"k", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "@", "RmutIndexFrom1"}]}], "}"}]}], 
             "]"}]}]}], ";", "\n", "       ", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"RmutIndexFrom1", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", " ", "1"}], "]"}], 
              "]"}], " ", "=", " ", 
             RowBox[{"RmutIndexTo1", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "@", "RmutIndexFrom1"}]}], "}"}]}], "]"}], 
          ";", "\n", "       ", 
          RowBox[{"haps", " ", "=", " ", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{";;", " ", 
                 RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], 
             ",", " ", 
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{
                 RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}]}], 
               "]"}], "]"}]}], "]"}]}], ";", "\n", "   \t", 
          RowBox[{"HapTo1", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", "RmutIndexFrom1", "]"}], "]"}]}], ";", "\n", "   \t",
           "\n", "   \t", 
          RowBox[{"MutationFrom", " ", "=", " ", 
           RowBox[{"MutationFrom", "~", "Join", "~", "HapFrom1"}]}], ";", 
          "\n", "   \t", 
          RowBox[{"MutationTo", " ", "=", " ", 
           RowBox[{"MutationTo", "~", "Join", "~", "HapTo1"}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationTime", " ", "=", " ", 
           RowBox[{"MutationTime", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Length", "@", "HapTo1"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationType", " ", "=", " ", 
           RowBox[{"MutationType", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"1", ",", " ", 
              RowBox[{"Length", "@", "HapTo1"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationPosition", " ", "=", " ", 
           RowBox[{"MutationPosition", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"1", ",", " ", 
              RowBox[{"Length", "@", "HapFrom1"}]}], "]"}]}]}], ";"}]}], " ", 
        "\n", "   \t", "]"}], ";", "\n", "   \t       ", "\n", "       ", 
       RowBox[{"RmutNum2", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"BinomialDistribution", "[", 
          RowBox[{"popsize", ",", " ", "\[Mu]R"}], "]"}], "]"}]}], ";", "\n", 
       "       ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"RmutNum2", " ", ">", " ", "0"}], ",", "\n", "       ", 
         RowBox[{
          RowBox[{"RmutIndexFrom2", " ", "=", " ", 
           RowBox[{"RandomSample", "[", 
            RowBox[{
             RowBox[{"Range", "[", "popsize", "]"}], ",", " ", "RmutNum2"}], 
            "]"}]}], ";", "\n", "       ", 
          RowBox[{"HapFrom2", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", 
             RowBox[{"popsize", " ", "+", " ", "RmutIndexFrom2"}], "]"}], 
            "]"}]}], ";", "\n", "       ", 
          RowBox[{"RmutIndexTo2", " ", "=", " ", 
           RowBox[{"Flatten", "@", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"RandomSample", "[", 
               RowBox[{
                RowBox[{"Delete", "[", 
                 RowBox[{
                  RowBox[{"Range", "[", "Rnumber", "]"}], ",", " ", 
                  RowBox[{"uniqs", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"RmutIndexFrom2", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], ",", " ", "1"}], "]"}], 
                   "]"}]}], "]"}], ",", " ", "1"}], "]"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"k", ",", " ", "1", ",", " ", 
                RowBox[{"Length", "@", "RmutIndexFrom2"}]}], "}"}]}], 
             "]"}]}]}], ";", "\n", "       ", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"RmutIndexFrom2", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
                RowBox[{"Snumber", " ", "+", " ", "2"}]}], "]"}], "]"}], " ", 
             "=", " ", 
             RowBox[{"RmutIndexTo2", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "@", "RmutIndexFrom2"}]}], "}"}]}], "]"}], 
          ";", "\n", "       ", 
          RowBox[{"haps", " ", "=", " ", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{";;", " ", 
                 RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], 
             ",", " ", 
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{
                 RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}]}], 
               "]"}], "]"}]}], "]"}]}], ";", "\n", "   \t", 
          RowBox[{"HapTo2", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", 
             RowBox[{"popsize", " ", "+", " ", "RmutIndexFrom2"}], "]"}], 
            "]"}]}], ";", "\n", "\n", "\t   ", 
          RowBox[{"MutationFrom", " ", "=", " ", 
           RowBox[{"MutationFrom", "~", "Join", "~", "HapFrom2"}]}], ";", 
          "\n", "   \t", 
          RowBox[{"MutationTo", " ", "=", " ", 
           RowBox[{"MutationTo", "~", "Join", "~", "HapTo2"}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationTime", " ", "=", " ", 
           RowBox[{"MutationTime", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Length", "@", "HapTo2"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationType", " ", "=", " ", 
           RowBox[{"MutationType", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"1", ",", " ", 
              RowBox[{"Length", "@", "HapTo2"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationPosition", " ", "=", " ", 
           RowBox[{"MutationPosition", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"1", ",", " ", 
              RowBox[{"Length", "@", "HapFrom2"}]}], "]"}]}]}], ";"}]}], " ", 
        "\n", "   \t", "]"}], ";"}]}], "   ", "\n", "      ", "]"}]}], ";"}], 
  "\n"}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["FmutateStore ", "Subsubsection"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{
    RowBox[{"FmutateStore", "[", 
     RowBox[{"Fnumber_", ",", " ", "Snumber_", ",", " ", "time_"}], "]"}], 
    " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\n", "       ", 
      RowBox[{
       RowBox[{"pairs", " ", "=", " ", 
        RowBox[{"Tuples", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Range", "[", "popsize", "]"}], ",", " ", 
           RowBox[{"Range", "[", "Snumber", "]"}]}], "}"}], "]"}]}], ";", 
       "\n", "   ", "\n", "   \t", 
       RowBox[{"HapFrom", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", "\n", "   \t", "\n", "   \t", 
       RowBox[{"FmutNum1", " ", "=", " ", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"BinomialDistribution", "[", 
          RowBox[{
           RowBox[{"popsize", " ", "Snumber"}], ",", " ", "\[Mu]F"}], "]"}], 
         "]"}]}], ";", "\n", "   \t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"FmutNum1", " ", ">", " ", "1"}], ",", "\n", "       ", 
         RowBox[{
          RowBox[{"FmutIndexFrom1", " ", "=", " ", 
           RowBox[{"RandomSample", "[", 
            RowBox[{"pairs", ",", " ", "FmutNum1"}], "]"}]}], ";", "\n", 
          "       ", 
          RowBox[{"HapFrom1", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", 
             RowBox[{"FmutIndexFrom1", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "]"}], 
            "]"}]}], ";", "\n", "   \t", 
          RowBox[{"FmutIndexTo1", " ", "=", " ", 
           RowBox[{"Flatten", "@", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"RandomSample", "[", "\n", "       \t", 
               RowBox[{
                RowBox[{"Delete", "[", 
                 RowBox[{
                  RowBox[{"Range", "[", "Fnumber", "]"}], ",", " ", "\n", 
                  "        \t\t", 
                  RowBox[{"If", "[", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Length", "@", 
                    RowBox[{"Position", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", "Fnumber", "]"}], ",", " ", 
                    RowBox[{"uniqs", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"FmutIndexFrom1", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"1", " ", "+", " ", 
                    RowBox[{"FmutIndexFrom1", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "2"}], "]"}], "]"}]}]}], "]"}], 
                    "]"}]}], " ", "]"}]}], " ", "==", " ", "0"}], ",", " ", 
                    RowBox[{"{", "}"}], ",", "\n", "         \t\t", 
                    RowBox[{"uniqs", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"FmutIndexFrom1", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"1", " ", "+", " ", 
                    RowBox[{"FmutIndexFrom1", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "2"}], "]"}], "]"}]}]}], "]"}], 
                    "]"}]}], "]"}]}], "]"}], "\n", "       \t", ",", " ", 
                "1"}], "]"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"k", ",", " ", "1", ",", " ", "FmutNum1"}], "}"}]}], 
             "]"}]}]}], ";", "\n", "   \t", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"FmutIndexFrom1", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"FmutIndexFrom1", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "2"}], "]"}], "]"}]}]}], "]"}], 
              "]"}], " ", "=", " ", 
             RowBox[{"FmutIndexTo1", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "@", "FmutIndexFrom1"}]}], "}"}]}], "]"}], 
          ";", "\n", "       ", 
          RowBox[{"haps", " ", "=", " ", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{";;", " ", 
                 RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], 
             ",", " ", 
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{
                 RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}]}], 
               "]"}], "]"}]}], "]"}]}], ";", "\n", "   \t", 
          RowBox[{"HapTo1", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", 
             RowBox[{"FmutIndexFrom1", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "]"}], 
            "]"}]}], ";", "\n", "   \t", "\n", "   \t", 
          RowBox[{"MutationFrom", " ", "=", " ", 
           RowBox[{"MutationFrom", "~", "Join", "~", "HapFrom1"}]}], ";", 
          "\n", "   \t", 
          RowBox[{"MutationTo", " ", "=", " ", 
           RowBox[{"MutationTo", "~", "Join", "~", "HapTo1"}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationTime", " ", "=", " ", 
           RowBox[{"MutationTime", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Length", "@", "HapTo1"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationType", " ", "=", " ", 
           RowBox[{"MutationType", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"2", ",", " ", 
              RowBox[{"Length", "@", "HapTo1"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationPosition", " ", "=", " ", 
           RowBox[{"MutationPosition", "~", "Join", "~", 
            RowBox[{"FmutIndexFrom1", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}]}], ";"}]}], 
        " ", "\n", "\n", "\t   ", "]"}], ";", "\n", "         ", "\n", 
       "       ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"FmutNum2", " ", ">", " ", "1"}], ",", "     ", "\n", 
         "       ", 
         RowBox[{
          RowBox[{"FmutNum2", " ", "=", " ", 
           RowBox[{"RandomVariate", "[", 
            RowBox[{"BinomialDistribution", "[", 
             RowBox[{
              RowBox[{"popsize", " ", "Snumber"}], ",", " ", "\[Mu]F"}], 
             "]"}], "]"}]}], ";", "\n", "       ", 
          RowBox[{"FmutIndexFrom2", " ", "=", " ", 
           RowBox[{"RandomSample", "[", 
            RowBox[{"pairs", ",", " ", "FmutNum2"}], "]"}]}], ";", "\n", 
          "   \t", 
          RowBox[{"HapFrom2", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", 
             RowBox[{"popsize", " ", "+", " ", 
              RowBox[{"FmutIndexFrom2", "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}]}], ";", "\n", "   \t", 
          RowBox[{"FmutIndexTo2", " ", "=", " ", 
           RowBox[{"Flatten", "@", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"RandomSample", "[", "\n", "       \t", 
               RowBox[{
                RowBox[{"Delete", "[", 
                 RowBox[{
                  RowBox[{"Range", "[", "Fnumber", "]"}], ",", " ", "\n", 
                  "        \t\t", 
                  RowBox[{"If", "[", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Length", "@", 
                    RowBox[{"Position", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", "Fnumber", "]"}], ",", " ", 
                    RowBox[{"uniqs", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"FmutIndexFrom2", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"2", " ", "+", " ", "Snumber", " ", "+", "  ", 
                    RowBox[{"FmutIndexFrom2", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "2"}], "]"}], "]"}]}]}], "]"}], 
                    "]"}]}], " ", "]"}]}], " ", "==", " ", "0"}], ",", " ", 
                    RowBox[{"{", "}"}], ",", "\n", "         \t\t", 
                    RowBox[{"uniqs", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"FmutIndexFrom2", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"1", " ", "+", " ", 
                    RowBox[{"FmutIndexFrom2", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "2"}], "]"}], "]"}]}]}], "]"}], 
                    "]"}]}], "]"}]}], "\n", "        \t", "]"}], "\n", 
                "       \t", ",", " ", "1"}], "]"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"k", ",", " ", "1", ",", " ", "FmutNum2"}], "}"}]}], 
             "]"}]}]}], ";", "\n", "   \t", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"FmutIndexFrom2", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                RowBox[{"2", " ", "+", " ", "Snumber", " ", "+", " ", 
                 RowBox[{"FmutIndexFrom2", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "2"}], "]"}], "]"}]}]}], "]"}], 
              "]"}], " ", "=", " ", 
             RowBox[{"FmutIndexTo2", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "@", "FmutIndexFrom2"}]}], "}"}]}], "]"}], 
          ";", "\n", "       ", 
          RowBox[{"haps", " ", "=", " ", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{";;", " ", 
                 RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], 
             ",", " ", 
             RowBox[{"uniqs", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{
                 RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}]}], 
               "]"}], "]"}]}], "]"}]}], ";", "\n", "   \t", 
          RowBox[{"HapTo2", " ", "=", " ", 
           RowBox[{"haps", "[", 
            RowBox[{"[", 
             RowBox[{"popsize", " ", "+", " ", 
              RowBox[{"FmutIndexFrom2", "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}]}], ";", "\n", "   \t", "\n", "   \t", 
          RowBox[{"MutationFrom", " ", "=", " ", 
           RowBox[{"MutationFrom", "~", "Join", "~", "HapFrom2"}]}], ";", 
          "\n", "   \t", 
          RowBox[{"MutationTo", " ", "=", " ", 
           RowBox[{"MutationTo", "~", "Join", "~", "HapTo2"}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationTime", " ", "=", " ", 
           RowBox[{"MutationTime", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Length", "@", "HapTo2"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationType", " ", "=", " ", 
           RowBox[{"MutationType", "~", "Join", "~", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"2", ",", " ", 
              RowBox[{"Length", "@", "HapTo2"}]}], "]"}]}]}], ";", "\n", 
          "   \t", 
          RowBox[{"MutationPosition", " ", "=", " ", 
           RowBox[{"MutationPosition", "~", "Join", "~", 
            RowBox[{"FmutIndexFrom2", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}]}], ";"}]}], 
        " ", "\n", "\n", "\t   ", "]"}], ";"}]}], "\n", "   ", "\n", "      ",
      "]"}]}], ";"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["select_s", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"select_s", "[", 
   RowBox[{"\[Alpha]_", ",", " ", "\[Delta]_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"types", " ", "=", " ", 
      RowBox[{
       RowBox[{"Tally", "[", "uniqs", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", "\n", 
     "  ", 
     RowBox[{"Ntypes", " ", "=", " ", 
      RowBox[{"Length", "[", "types", "]"}]}], ";", "\n", "  ", 
     RowBox[{"freqTypes", " ", "=", " ", 
      RowBox[{
       RowBox[{"N", "@", " ", 
        RowBox[{
         RowBox[{"Tally", "[", "uniqs", "]"}], "[", 
         RowBox[{"[", 
          RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
       "popsize"}]}], ";", "\n", "  ", "\n", "  ", 
     RowBox[{"FertilizingPairs", " ", "=", " ", 
      RowBox[{"Tuples", "[", 
       RowBox[{
        RowBox[{"Range", "[", "Ntypes", "]"}], ",", " ", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"RealizedFertilizations", " ", "=", " ", 
      RowBox[{"RandomChoice", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ArrayReshape", "[", 
          RowBox[{
           RowBox[{"TransitionMatrix", "[", 
            RowBox[{"\[Alpha]", ",", " ", "\[Delta]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"(", "Ntypes", ")"}], "^", "2"}], "}"}]}], "]"}], " ", "->",
          " ", "FertilizingPairs"}], ",", " ", "popsize"}], "]"}]}], ";", 
     "\n", "  ", 
     RowBox[{"AncestorId", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"RandomChoice", "[", 
         RowBox[{"RealizedFertilizations", "[", 
          RowBox[{"[", 
           RowBox[{"pollen", ",", " ", ";;"}], "]"}], "]"}], "]"}], ",", " ", 
        
        RowBox[{"{", 
         RowBox[{"pollen", ",", " ", "1", ",", " ", "popsize"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"uniqs", " ", "=", " ", 
      RowBox[{"Sort", "[", 
       RowBox[{"types", "[", 
        RowBox[{"[", "AncestorId", "]"}], "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"uniqs", " ", "=", " ", 
      RowBox[{"Sort", "@", "uniqs"}]}]}]}], "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["CompatibilityMatrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompatibilityMatrixDfast", " ", ":=", " ", "\n", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "   ", 
     RowBox[{"Table", "[", "\n", "    ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Boole", "@", 
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"typesf", "[", 
             RowBox[{"[", 
              RowBox[{"idm", ",", " ", 
               RowBox[{"2", " ", ";;", " ", 
                RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], 
            ",", " ", 
            RowBox[{"typesf", "[", 
             RowBox[{"[", 
              RowBox[{"idf", ",", " ", "1"}], "]"}], "]"}]}], "]"}]}], " ", 
         RowBox[{
          RowBox[{"Boole", "@", 
           RowBox[{"MemberQ", "[", 
            RowBox[{
             RowBox[{"typesf", "[", 
              RowBox[{"[", 
               RowBox[{"idm", ",", " ", 
                RowBox[{"2", " ", ";;", " ", 
                 RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], 
             ",", " ", 
             RowBox[{"typesf", "[", 
              RowBox[{"[", 
               RowBox[{"idf", ",", " ", 
                RowBox[{"Snumber", " ", "+", " ", "2"}]}], "]"}], "]"}]}], 
            "]"}]}], "/", "2"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"Boole", "@", 
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"typesf", "[", 
             RowBox[{"[", 
              RowBox[{"idm", ",", " ", 
               RowBox[{
                RowBox[{"3", " ", "+", " ", "Snumber"}], " ", ";;"}]}], "]"}],
              "]"}], ",", " ", 
            RowBox[{"typesf", "[", 
             RowBox[{"[", 
              RowBox[{"idf", ",", " ", "1"}], "]"}], "]"}]}], "]"}]}], " ", 
         RowBox[{
          RowBox[{"Boole", "@", 
           RowBox[{"MemberQ", "[", 
            RowBox[{
             RowBox[{"typesf", "[", 
              RowBox[{"[", 
               RowBox[{"idm", ",", " ", 
                RowBox[{
                 RowBox[{"3", " ", "+", " ", "Snumber"}], " ", ";;"}]}], 
               "]"}], "]"}], ",", " ", 
             RowBox[{"typesf", "[", 
              RowBox[{"[", 
               RowBox[{"idf", ",", " ", 
                RowBox[{"Snumber", " ", "+", " ", "2"}]}], "]"}], "]"}]}], 
            "]"}]}], "/", "2"}]}]}], "\n", "    ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"idf", ",", " ", "1", ",", " ", "Ntypesf"}], "}"}], ",", " ", 
       
       RowBox[{"{", 
        RowBox[{"idm", ",", " ", "1", ",", " ", "Ntypesf"}], "}"}]}], "]"}]}],
     "\n", "   ", "]"}]}], ";"}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["OutcrossingProbMatrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OutcrossingProbMatrixDFast", "[", "\[Alpha]_", "]"}], " ", ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"Mf", " ", "=", " ", 
      RowBox[{"DiagonalMatrix", "[", "freqTypesf", "]"}]}], ";", "\n", "  ", 
     RowBox[{"Mm", " ", "=", " ", "Mf"}], ";", "\n", "  ", 
     RowBox[{"denom", " ", "=", " ", 
      RowBox[{"DiagonalMatrix", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"MC", ".", "freqTypesf"}], ")"}]}], " ", "+", " ", 
          RowBox[{"\[Alpha]", " ", "MCdiag"}]}], " ", 
         RowBox[{"(*", 
          RowBox[{"+", " ", 
           RowBox[{"10", "^", 
            RowBox[{"-", "2"}]}]}], "*)"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Position", "[", 
         RowBox[{"denom", ",", 
          RowBox[{"10.", "^", "2"}]}], "]"}]}], ";"}], "*)"}], "\n", "  ", 
     RowBox[{"OutMat", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
       RowBox[{"denom", ".", 
        RowBox[{"(", 
         RowBox[{"Mf", ".", "MC", ".", "Mm"}], ")"}]}]}]}], ";", "\n", "  ", 
     RowBox[{"(*", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "@", "p"}], ">", "0"}], ",", "\n", "  ", 
        RowBox[{
         RowBox[{
          RowBox[{"OutMat", "\[LeftDoubleBracket]", 
           RowBox[{
            RowBox[{"p", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"p", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
           "\[RightDoubleBracket]"}], "=", "0"}], ";"}]}], "\n", "  ", "]"}], 
      "*)"}], "\n", "  ", "OutMat"}]}], "\n", "  ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["SelfingProbMatrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SelfingProbMatrixDFast", "[", 
   RowBox[{"\[Alpha]_", ",", " ", "\[Delta]_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"Mf", " ", "=", " ", 
      RowBox[{"DiagonalMatrix", "[", "freqTypesf", "]"}]}], ";", "\n", "  ", 
     RowBox[{"Mm", " ", "=", " ", "Mf"}], ";", "\n", "  ", 
     RowBox[{"denom", " ", "=", " ", 
      RowBox[{"DiagonalMatrix", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"MC", ".", "freqTypesf"}], ")"}]}], " ", "+", " ", 
          RowBox[{"\[Alpha]", " ", "MCdiag"}]}], 
         RowBox[{"(*", 
          RowBox[{"+", " ", 
           RowBox[{"10", "^", 
            RowBox[{"-", "2"}]}]}], "*)"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Position", "[", 
         RowBox[{"denom", ",", 
          RowBox[{"10.", "^", "2"}]}], "]"}]}], ";"}], "*)"}], "\n", "  ", 
     RowBox[{"OutMat", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[Delta]"}], ")"}], " ", "\[Alpha]", " ", 
       RowBox[{"denom", ".", 
        RowBox[{"DiagonalMatrix", "[", 
         RowBox[{"Mf", ".", "MCdiag"}], "]"}]}]}]}], ";", "\n", "  ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Length", "@", "p"}], ")"}], "\[NotEqual]", " ", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"OutMat", "\[LeftDoubleBracket]", 
           RowBox[{
            RowBox[{"p", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"p", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
           "\[RightDoubleBracket]"}], "=", "0"}]}], "]"}], ";"}], "*)"}], 
     "\n", "  ", "OutMat"}]}], "\n", "  ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["TransitionMatrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"TransitionMatrixDFast", "[", 
     RowBox[{"\[Alpha]_", ",", " ", "\[Delta]_"}], "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"OutcrossingProbMatrixDFast", "[", "\[Alpha]", "]"}], " ", "+", 
     " ", 
     RowBox[{"SelfingProbMatrixDFast", "[", 
      RowBox[{"\[Alpha]", ",", " ", "\[Delta]"}], "]"}]}]}], ";"}], 
  " "}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["FindAncestors", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindAncestors", "[", 
   RowBox[{"idf_", ",", " ", "idm_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"typem", " ", "=", " ", 
      RowBox[{"typesf", "[", 
       RowBox[{"[", "idm", "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"typef", " ", "=", " ", 
      RowBox[{"typesf", "[", 
       RowBox[{"[", "idf", "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"Rf", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"typef", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
        RowBox[{"typef", "[", 
         RowBox[{"[", 
          RowBox[{"Snumber", " ", "+", " ", "2"}], "]"}], "]"}]}], "}"}]}], 
     ";", "\n", "  ", 
     RowBox[{"Ancestors", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "  ", 
     RowBox[{"If", " ", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"typem", "[", 
              RowBox[{"[", 
               RowBox[{"2", " ", ";;", " ", 
                RowBox[{"1", " ", "+", " ", "Snumber"}]}], "]"}], "]"}], ",", 
             " ", 
             RowBox[{"Rf", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"typem", "[", 
              RowBox[{"[", 
               RowBox[{"2", " ", ";;", " ", 
                RowBox[{"1", " ", "+", " ", "Snumber"}]}], "]"}], "]"}], ",", 
             " ", 
             RowBox[{"Rf", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}]}], " ", "!=", 
        " ", "0"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"Ancestors", ",", " ", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"typem", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", 
               RowBox[{"1", " ", "+", " ", "Snumber"}]}], "]"}], "]"}], ",", 
            " ", 
            RowBox[{"typef", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", 
               RowBox[{"1", " ", "+", " ", "Snumber"}]}], "]"}], "]"}]}], 
           "]"}]}], "]"}], ";", "\n", "   ", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"Ancestors", ",", " ", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"typem", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", 
               RowBox[{"1", " ", "+", " ", "Snumber"}]}], "]"}], "]"}], ",", 
            " ", 
            RowBox[{"typef", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}], "]"}], 
             "]"}]}], "]"}]}], "]"}], ";"}]}], "\n", "    ", "]"}], ";", "\n",
      "  ", 
     RowBox[{"If", " ", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"typem", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"3", " ", "+", " ", "Snumber"}], " ", ";;"}], "]"}], 
              "]"}], ",", " ", 
             RowBox[{"Rf", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"typem", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"3", " ", "+", " ", "Snumber"}], " ", ";;"}], "]"}], 
              "]"}], ",", " ", 
             RowBox[{"Rf", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}]}], " ", "!=", 
        " ", "0"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"Ancestors", ",", " ", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"typem", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}], "]"}], 
             "]"}], ",", " ", 
            RowBox[{"typef", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", 
               RowBox[{"1", " ", "+", " ", "Snumber"}]}], "]"}], "]"}]}], 
           "]"}]}], "]"}], ";", "\n", "   ", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"Ancestors", ",", " ", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"typem", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}], "]"}], 
             "]"}], ",", " ", 
            RowBox[{"typef", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}], "]"}], 
             "]"}]}], "]"}]}], "]"}], ";"}]}], "\n", "    ", "]"}], ";", "\n",
      "  ", "Ancestors"}]}], "\n", "  ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["SelfIncompatibleTypes", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SelfIncompatibleTypes", "[", "Rnumber_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"SI", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", 
     RowBox[{"SI01", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{
        RowBox[{"SItypes", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", " ", 
           RowBox[{"{", "Rnumber", "}"}]}], "]"}]}], ";", "\n", "   ", 
        RowBox[{"SItypes01", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", " ", 
           RowBox[{"{", "popsize", "}"}]}], "]"}]}], ";", "\n", "   ", 
        RowBox[{
         RowBox[{"Do", "[", "\n", "     ", 
          RowBox[{
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "@", 
                RowBox[{"Position", "[", 
                 RowBox[{
                  RowBox[{"Uniqs", "[", 
                   RowBox[{"[", 
                    RowBox[{"time", ",", " ", "row", ",", " ", 
                    RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
                  RowBox[{"Uniqs", "[", 
                   RowBox[{"[", 
                    RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
                   "]"}]}], "]"}]}], " ", "==", " ", "0"}], ",", "\n", 
              "       ", 
              RowBox[{
               RowBox[{
                RowBox[{"SItypes", "[", 
                 RowBox[{"[", 
                  RowBox[{"Uniqs", "[", 
                   RowBox[{"[", 
                    RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
                   "]"}], "]"}], "]"}], " ", "=", " ", 
                RowBox[{
                 RowBox[{"SItypes", "[", 
                  RowBox[{"[", 
                   RowBox[{"Uniqs", "[", 
                    RowBox[{"[", 
                    RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
                    "]"}], "]"}], "]"}], " ", "+", " ", "1"}]}], ";", "\n", 
               "       ", 
               RowBox[{
                RowBox[{"SItypes01", "[", 
                 RowBox[{"[", "row", "]"}], "]"}], " ", "=", " ", "1"}]}]}], 
             "]"}], ";"}], "\n", "     ", ",", " ", 
           RowBox[{"{", 
            RowBox[{"row", ",", " ", "1", ",", " ", "popsize"}], "}"}]}], 
          "]"}], "\n", "    ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"SI", ",", " ", "SItypes"}], "]"}]}], ";", "\n", "   ", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"SI01", ",", " ", "SItypes01"}], "]"}], ";"}], "\n", "   ", 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"time", ",", " ", "1", ",", " ", "generations"}], "}"}]}], 
      "]"}], ";", "\n", "  ", 
     RowBox[{"SIhaplotypeNum", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Count", "[", 
         RowBox[{
          RowBox[{"SI", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
          RowBox[{"x_", " ", "/;", " ", 
           RowBox[{"x", " ", "!=", " ", "0"}]}]}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "generations"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"{", 
      RowBox[{"SI", ",", " ", "SI01", ",", " ", "SIhaplotypeNum"}], "}"}]}]}],
    "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["AvgSIHaplotypeNum", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AvgSIHaplotypeNum", "[", "N_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    ", 
    RowBox[{
     RowBox[{"uniqs", " ", "=", " ", 
      RowBox[{"CreateInitialPopulation", "[", 
       RowBox[{"N", ",", " ", "Fnumber"}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"Uniqs", " ", "=", " ", 
      RowBox[{"{", "uniqs", "}"}]}], ";", "\n", "    ", "\n", "    ", 
     RowBox[{
      RowBox[{"Do", "[", "\n", "        ", 
       RowBox[{
        RowBox[{
         RowBox[{"Rmutate", "[", "Rnumber", "]"}], ";", "\n", "        ", 
         RowBox[{"Fmutate", "[", "Fnumber", "]"}], ";", "\n", "        ", 
         "select", ";", "\n", "        ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"Uniqs", ",", " ", "uniqs"}], "]"}], ";"}], "\n", 
        "        ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"k", ",", " ", "1", ",", " ", "generations"}], "}"}]}], 
       "]"}], "\n", "      ", "\n", "      ", 
      RowBox[{"SelfIncompatibleTypes", "[", "Rnumber", "]"}]}], ";", "\n", 
     "    ", 
     RowBox[{"MeanSI", " ", "=", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{"SIhaplotypeNum", "[", 
        RowBox[{"[", 
         RowBox[{"50", " ", ";;"}], "]"}], "]"}], "]"}]}]}]}], "\n", "    ", 
   "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["FreqEq", "Subsubsection"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Computes", " ", 
    RowBox[{"Subscript", "[", 
     RowBox[{"p", ",", " ", "\[Nu]\[Nu]"}], "]"}]}], ",", " ", 
   RowBox[{
   "probability", " ", "of", " ", "type", " ", "212", " ", "212.", " ", "If", 
    " ", "we", " ", "want"}]}], "*)"}]], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FreqEq", "[", 
   RowBox[{"\[Alpha]_", ",", " ", "\[Delta]_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"E\[Nu]1", "[", "p_", "]"}], " ", ":=", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Alpha]", "/", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "p"}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Alpha]", "/", "2"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"p", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}], 
             ")"}]}]}], ")"}]}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", "\[Delta]"}], ")"}], "/", "2"}]}], " ", 
       "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "p"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"p", " ", "+", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}], 
            ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Alpha]", "/", "2"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"p", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}], 
             ")"}]}]}], ")"}]}], " ", 
        RowBox[{"1", "/", "2"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", "p", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}]}]}], ";", 
     "\n", "  ", 
     RowBox[{
      RowBox[{"E\[Nu]\[Nu]", "[", "p_", "]"}], " ", ":=", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Alpha]", "/", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "p"}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Alpha]", "/", "2"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"p", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}], 
             ")"}]}]}], ")"}]}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", "\[Delta]"}], ")"}], "/", "2"}]}], " ", 
       "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "p"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"p", " ", "+", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}], 
            ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Alpha]", "/", "2"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"p", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}], 
             ")"}]}]}], ")"}]}], " ", 
        RowBox[{"1", "/", "2"}]}], " ", "+", " ", 
       RowBox[{"p", " ", "\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", "\[Delta]"}], ")"}]}], " ", "+", " ", 
       RowBox[{"p", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"p", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "p"}], ")"}], "/", "2"}]}], 
         ")"}]}]}]}], ";", "\n", "  ", 
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"p", "*", 
           RowBox[{"E\[Nu]1", "[", "p", "]"}]}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "p"}], ")"}], "*", 
           RowBox[{"E\[Nu]\[Nu]", "[", "p", "]"}]}]}], " ", "==", " ", "0"}], 
        ",", " ", "p"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"(*", 
      RowBox[{"pvec", " ", "=", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "/.", "sol"}], ")"}], "[", 
        RowBox[{"[", 
         RowBox[{"-", "2"}], "]"}], "]"}]}], "*)"}], "\n", "  ", 
     RowBox[{"pvec", " ", "=", " ", 
      RowBox[{"Min", "@", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"p", " ", "/.", " ", "sol"}], ")"}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"#", " ", ">", " ", "0"}], " ", "&&", " ", 
           RowBox[{"#", " ", "<=", " ", "1"}]}], " ", "&"}]}], "]"}]}]}]}]}], 
   "\n", "  ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["Indexes", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Indexes", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"SIHindex", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", 
     RowBox[{"SCHindex", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", 
     RowBox[{"SIGindex", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", 
     RowBox[{"SCGindex", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", 
     RowBox[{
      RowBox[{"Do", "[", "\n", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "@", 
            RowBox[{"Position", "[", 
             RowBox[{
              RowBox[{"TypesH", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", 
                 RowBox[{"2", ";;"}]}], "]"}], "]"}], ",", 
              RowBox[{"TypesH", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}]}], "]"}]}], "==", " ", 
           "0"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"SIHindex", ",", "k"}], "]"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"SCHindex", ",", "k"}], "]"}]}], "]"}], "\n", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "@", "TypesH"}]}], "}"}]}], "]"}], "\n", 
      RowBox[{"Do", "[", "\n", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Length", "@", 
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"TypesG", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", 
                   RowBox[{"2", ";;", 
                    RowBox[{"Fnumber", "+", "1"}]}]}], "]"}], "]"}], ",", 
                RowBox[{"TypesG", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", "1"}], "]"}], "]"}]}], "]"}]}], ")"}], 
            "*", 
            RowBox[{"(", 
             RowBox[{"Length", "@", 
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"TypesG", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", 
                   RowBox[{
                    RowBox[{"Fnumber", "+", "3"}], ";;"}]}], "]"}], "]"}], 
                ",", 
                RowBox[{"TypesG", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", 
                   RowBox[{"Fnumber", "+", "2"}]}], "]"}], "]"}]}], "]"}]}], 
             ")"}]}], "==", "0"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"SIGindex", ",", "k"}], "]"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"SCGindex", ",", "k"}], "]"}]}], "]"}], "\n", ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "@", "TypesG"}]}], "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"{", 
      RowBox[{"SIGindex", ",", "SCGindex", ",", "SIHindex", ",", "SCHindex"}],
       "}"}]}]}], "\n", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["CompatibilityHaplotypes", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompatibilityHaplotypes", "[", 
   RowBox[{"Fnumber_", ",", " ", "Rnumber_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"Haps", " ", "=", " ", 
       RowBox[{"Sort", "@", "Haps"}]}], ";"}], "*)"}], "\n", "  ", 
    RowBox[{
     RowBox[{"SIcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "Haps", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"SCcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "Haps", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{"time", ",", " ", "row", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
              "]"}]}], "]"}]}], " ", "==", " ", "0"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SIcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Haps", "[", 
               RowBox[{"[", 
                RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
               "]"}]}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SIcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Haps", "[", 
                RowBox[{"[", 
                 RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
                "]"}]}], "]"}], "]"}], " ", "+", " ", "1"}]}], ";"}], ",", 
         "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SCcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Haps", "[", 
               RowBox[{"[", 
                RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
               "]"}]}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SCcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Haps", "[", 
                RowBox[{"[", 
                 RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
                "]"}]}], "]"}], "]"}], " ", "+", " ", "1"}]}], ";"}]}], "\n", 
        "    ", "]"}], ",", "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"time", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", "Haps", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", "Haps", "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", "  ", 
     RowBox[{"{", 
      RowBox[{"SIcounts", ",", " ", "SCcounts"}], "}"}]}]}], "\n", "  ", 
   "]"}]}]], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompatibilityHaplotypesHaploid", "[", 
   RowBox[{"Fnumber_", ",", " ", "Rnumber_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"SIcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "Uniqs", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"SCcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "Uniqs", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Uniqs", "[", 
              RowBox[{"[", 
               RowBox[{"time", ",", " ", "row", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"Uniqs", "[", 
              RowBox[{"[", 
               RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
              "]"}]}], "]"}]}], " ", "==", " ", "0"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SIcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Uniqs", "[", 
               RowBox[{"[", 
                RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
               "]"}]}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SIcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Uniqs", "[", 
                RowBox[{"[", 
                 RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
                "]"}]}], "]"}], "]"}], " ", "+", " ", "1"}]}], ";"}], ",", 
         "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SCcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Uniqs", "[", 
               RowBox[{"[", 
                RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
               "]"}]}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SCcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Uniqs", "[", 
                RowBox[{"[", 
                 RowBox[{"time", ",", " ", "row", ",", " ", "1"}], "]"}], 
                "]"}]}], "]"}], "]"}], " ", "+", " ", "1"}]}], ";"}]}], "\n", 
        "    ", "]"}], ",", "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"time", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", "Uniqs", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", "Uniqs", "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", "  ", 
     RowBox[{"{", 
      RowBox[{"SIcounts", ",", " ", "SCcounts"}], "}"}]}]}], "\n", "  ", 
   "]"}]}]], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompatibilityHaplotypesHaploidPart", "[", 
   RowBox[{"Fnumber_", ",", " ", "Rnumber_", ",", " ", "tD_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"working", " ", "on", " ", 
      RowBox[{
       RowBox[{"this", " ", "!!"}], "!"}]}], " ", "*)"}], "\n", "  ", 
    RowBox[{
     RowBox[{"SIcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", 
            RowBox[{"Uniqs", "[", 
             RowBox[{"[", 
              RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"SCcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", 
            RowBox[{"Uniqs", "[", 
             RowBox[{"[", 
              RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Uniqs", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"Uniqs", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}]}], 
          " ", "==", " ", "0"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SIcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Uniqs", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                 ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SIcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Uniqs", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                  ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
             "]"}], " ", "+", " ", "1"}]}], ";"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SCcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Uniqs", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                 ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SCcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Uniqs", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                  ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
             "]"}], " ", "+", " ", "1"}]}], ";"}]}], "\n", "    ", "]"}], ",",
        "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"time", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", 
           RowBox[{"Uniqs", "[", 
            RowBox[{"[", 
             RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", 
           RowBox[{"Uniqs", "[", 
            RowBox[{"[", 
             RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", "  ", 
     RowBox[{"{", 
      RowBox[{"SIcounts", ",", " ", "SCcounts"}], "}"}]}]}], "\n", "  ", 
   "]"}]}]], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompatibilityHaplotypesDiploidPart", "[", 
   RowBox[{"Fnumber_", ",", " ", "Rnumber_", ",", " ", "tD_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"working", " ", "on", " ", 
      RowBox[{
       RowBox[{"this", " ", "!!"}], "!"}]}], " ", "*)"}], "\n", "  ", 
    RowBox[{
     RowBox[{"SIcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", 
            RowBox[{"Haps", "[", 
             RowBox[{"[", 
              RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"SCcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", 
            RowBox[{"Haps", "[", 
             RowBox[{"[", 
              RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"SIhaps", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", "\n", "  ", 
       RowBox[{"SChaps", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";"}], "*)"}], "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}]}], 
          " ", "==", " ", "0"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{"SIcounts", "[", 
           RowBox[{"[", 
            RowBox[{"time", ",", " ", 
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
           "]"}], " ", "=", " ", 
          RowBox[{
           RowBox[{"SIcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Haps", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                 ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}], " ", "+", " ", "1"}]}], ",", "\n", "    ", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"SIhaps", ",", 
             RowBox[{"Haps", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"tD", "-", "1", "+", "time"}], ",", "row"}], 
              "\[RightDoubleBracket]"}]}], "]"}], ","}], "*)"}], "\n", "    ", 
         RowBox[{
          RowBox[{"SCcounts", "[", 
           RowBox[{"[", 
            RowBox[{"time", ",", " ", 
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
           "]"}], " ", "=", " ", 
          RowBox[{
           RowBox[{"SCcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Haps", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"tD", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                 ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}], " ", "+", " ", "1"}]}], ","}], "\n", "    ", 
        RowBox[{"(*", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"SChaps", ",", 
           RowBox[{"Haps", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"tD", "-", "1", "+", "time"}], ",", "row"}], 
            "\[RightDoubleBracket]"}]}], "]"}], "*)"}], "\n", "    ", "]"}], 
       ",", "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"time", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", 
           RowBox[{"Haps", "[", 
            RowBox[{"[", 
             RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", 
           RowBox[{"Haps", "[", 
            RowBox[{"[", 
             RowBox[{"tD", " ", ";;"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", "  ", 
     RowBox[{"{", 
      RowBox[{"SIcounts", ",", " ", "SCcounts"}], 
      RowBox[{"(*", 
       RowBox[{",", "SIhaps", ",", "SChaps"}], "*)"}], "}"}]}]}], "\n", "  ", 
   "]"}]}]], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompatibilityHaplotypesDiploidPart2", "[", 
   RowBox[{
   "Fnumber_", ",", " ", "Rnumber_", ",", " ", "t1_", ",", " ", "t2_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"working", " ", "on", " ", 
      RowBox[{
       RowBox[{"this", " ", "!!"}], "!"}]}], " ", "*)"}], "\n", "  ", 
    RowBox[{
     RowBox[{"SIcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", 
            RowBox[{"Haps", "[", 
             RowBox[{"[", 
              RowBox[{"t1", " ", ";;", " ", "t2"}], "]"}], "]"}], "]"}], "[", 
           
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"SCcounts", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", 
            RowBox[{"Haps", "[", 
             RowBox[{"[", 
              RowBox[{"t1", " ", ";;", " ", "t2"}], "]"}], "]"}], "]"}], "[", 
           
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "Rnumber"}], "}"}]}], 
       "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"t1", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"Haps", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"t1", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}]}], 
          " ", "==", " ", "0"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SIcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Haps", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"t1", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                 ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SIcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Haps", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"t1", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                  ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
             "]"}], " ", "+", " ", "1"}]}], ";"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"SCcounts", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", " ", 
              RowBox[{"Haps", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"t1", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                 ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
            "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"SCcounts", "[", 
             RowBox[{"[", 
              RowBox[{"time", ",", " ", 
               RowBox[{"Haps", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"t1", " ", "-", " ", "1", " ", "+", " ", "time"}], 
                  ",", " ", "row", ",", " ", "1"}], "]"}], "]"}]}], "]"}], 
             "]"}], " ", "+", " ", "1"}]}], ";"}]}], "\n", "    ", "]"}], ",",
        "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"time", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", 
           RowBox[{"Haps", "[", 
            RowBox[{"[", 
             RowBox[{"t1", " ", ";;", " ", "t2"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Dimensions", "[", 
           RowBox[{"Haps", "[", 
            RowBox[{"[", 
             RowBox[{"t1", " ", ";;", " ", "t2"}], "]"}], "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", "  ", 
     RowBox[{"{", 
      RowBox[{"SIcounts", ",", " ", "SCcounts"}], "}"}]}]}], "\n", "  ", 
   "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["MatingStructure", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatingStructure", " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{"(*", " ", 
     RowBox[{"remove", " ", "SC", " ", "types"}], " ", "*)"}], "\n", "  ", 
    RowBox[{
     RowBox[{"typesA", " ", "=", " ", 
      RowBox[{"Tally", "[", 
       RowBox[{"Sort", "@", "haps"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", "\n", "   ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"typesA", "[", 
              RowBox[{"[", 
               RowBox[{"row", ",", " ", "1", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"typesA", "[", 
              RowBox[{"[", 
               RowBox[{"row", ",", " ", "1", ",", " ", "1"}], "]"}], "]"}]}], 
            "]"}]}], " ", "!=", " ", "0"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{"typesA", " ", "=", " ", 
           RowBox[{"Drop", "[", 
            RowBox[{"typesA", ",", " ", 
             RowBox[{"{", "row", "}"}]}], "]"}]}], ";"}]}], "\n", "    ", 
        "]"}], ",", "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", 
         RowBox[{"Length", "@", "typesA"}], ",", " ", "1", ",", " ", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}], ";", "\n", "  ", 
     RowBox[{"typesSI", " ", "=", " ", 
      RowBox[{"typesA", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"freksSI", " ", "=", " ", 
      RowBox[{"typesA", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], ";", "\n", "  ", 
     "\n", "  ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"typesSI", "//", 
        RowBox[{"MatrixForm", "\n", "  ", "freksSI"}]}], "//", 
       RowBox[{"MatrixForm", "\n", "  ", 
        RowBox[{"Length", "@", "typesSI"}]}]}], "*)"}], "\n", "  ", "\n", 
     "  ", 
     RowBox[{"(*", 
      RowBox[{"Length", "@", "typesSI"}], "*)"}], "\n", "  ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Length", "@", "typesSI"}], ")"}], " ", "==", " ", "0"}], 
       ",", " ", 
       RowBox[{"CompatibilityStructure", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0"}], "}"}]}]}], "]"}], ";", "\n", "  ", 
     "\n", "  ", 
     RowBox[{"Hapclasses", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Tally", "@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Tally", "[", 
             RowBox[{"Sort", "@", "typesSI"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ")"}]}], ")"}], 
       "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"Hapclassnumbers", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Tally", "@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Tally", "[", 
             RowBox[{"Sort", "@", "typesSI"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ")"}]}], ")"}], 
       "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"(*", " ", 
      RowBox[{"Length", "@", "Hapclasses"}], "*)"}], "\n", "  ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"Length", "@", "Hapclasses"}], ")"}], " ", "==", " ", "1"}], 
       ",", " ", 
       RowBox[{"CompatibilityStructure", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0"}], "}"}]}]}], "]"}], ";", "\n", "  ", 
     "\n", "  ", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", " ", 
          RowBox[{"Length", "@", "Hapclasses"}], ")"}], " ", ">", " ", "1"}], 
        ",", "\n", "    ", 
        RowBox[{
         RowBox[{"CompatibilityStructure", " ", "=", " ", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"0", ",", " ", 
            RowBox[{"{", 
             RowBox[{"2", ",", " ", 
              RowBox[{"Length", "@", "Hapclasses"}]}], "}"}]}], "]"}]}], ";", 
         "\n", "    ", 
         RowBox[{"CompHap", " ", "=", " ", 
          RowBox[{"Table", "[", "\n", "      ", 
           RowBox[{
            RowBox[{"Boole", "@", 
             RowBox[{"MemberQ", "[", 
              RowBox[{
               RowBox[{"typesSI", "[", 
                RowBox[{"[", 
                 RowBox[{"idm", ",", " ", 
                  RowBox[{"2", " ", ";;", " ", 
                   RowBox[{"1", " ", "+", " ", "Fnumber"}]}]}], "]"}], "]"}], 
               ",", " ", 
               RowBox[{"typesSI", "[", 
                RowBox[{"[", 
                 RowBox[{"idf", ",", " ", "1"}], "]"}], "]"}]}], "]"}]}], " ",
             "\n", "      ", ",", " ", 
            RowBox[{"{", 
             RowBox[{"idf", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "@", "typesSI"}]}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"idm", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "@", "typesSI"}]}], "}"}]}], "]"}]}], ";", 
         "\n", "    ", "\n", "    ", 
         RowBox[{
          RowBox[{"CompatibilityStructure", "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], " ", "=", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Hapclasses", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
            RowBox[{"N", "@", 
             RowBox[{"Mean", "[", 
              RowBox[{"Mean", "[", 
               RowBox[{
                RowBox[{"Drop", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"CompHap", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", " ", ";;", " ", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], 
                   "\[Transpose]"}], ",", " ", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", " ", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], 
                "\[Transpose]"}], "]"}], "]"}]}]}], "}"}]}], ";", "\n", 
         "    ", "\n", "    ", "\n", "    ", 
         RowBox[{"Do", "[", "\n", "     ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"CompatibilityStructure", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "i"}], "]"}], "]"}], " ", "=", 
             " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Hapclasses", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
               RowBox[{"N", "@", 
                RowBox[{"Mean", "[", 
                 RowBox[{"Mean", "[", 
                  RowBox[{
                   RowBox[{"Drop", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"CompHap", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", " ", 
                    RowBox[{"i", " ", "-", " ", "1"}]}], "]"}], "]"}]}], " ", 
                    "+", " ", "1"}], " ", ";;", " ", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", " ", "i"}], "]"}], "]"}]}]}], "]"}], "]"}], 
                    "\[Transpose]"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", " ", 
                    RowBox[{"i", " ", "-", " ", "1"}]}], "]"}], "]"}]}], " ", 
                    "+", " ", "1"}], ",", " ", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", " ", "i"}], "]"}], "]"}]}]}], "}"}]}], 
                    "]"}], "\[Transpose]"}], "]"}], "]"}]}]}], "}"}]}], ";"}],
            "\n", "     ", ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", "2", ",", " ", 
             RowBox[{"Length", "@", "Hapclasses"}]}], "}"}]}], "]"}], ";"}]}],
        "\n", "    ", "]"}], "\n", "   ", "\n", "   ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"CompHap", "//", 
         RowBox[{"MatrixForm", "\n", "   ", 
          RowBox[{"Length", "@", "Hapclasses"}], "\n", "   ", 
          "CompatibilityStructure"}]}], "//", "MatrixForm"}], "*)"}], "\n", 
      "   ", "\n", "   ", "CompatibilityStructure"}]}]}], "\n", "  ", 
   "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GenToHap", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GenToHap", "[", 
    RowBox[{"typesf_", ",", " ", "freqTypesf_", ",", " ", "Snumber_"}], "]"}],
    " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "    ", 
     RowBox[{
      RowBox[{"A", " ", "=", " ", 
       RowBox[{"Sort", "@", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"typesf", "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", 
                 RowBox[{"1", " ", ";;", " ", 
                  RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], "]"}], 
              "\[Transpose]"}], ",", " ", "freqTypesf"}], "]"}], 
           "\[Transpose]"}], ",", " ", 
          RowBox[{
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"typesf", "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", 
                 RowBox[{
                  RowBox[{"Snumber", " ", "+", " ", "2"}], " ", ";;"}]}], 
                "]"}], "]"}], "\[Transpose]"}], ",", " ", "freqTypesf"}], 
            "]"}], "\[Transpose]"}]}], "]"}]}]}], ";", " ", "\n", "    ", 
      RowBox[{"TL", " ", "=", " ", 
       RowBox[{"Tally", "[", 
        RowBox[{"A", "[", 
         RowBox[{"[", 
          RowBox[{";;", " ", ",", " ", 
           RowBox[{"1", " ", ";;", " ", 
            RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], "]"}], 
        "]"}]}], ";", " ", "\n", "    ", 
      RowBox[{"Hps", " ", "=", " ", 
       RowBox[{"TL", "[", 
        RowBox[{"[", 
         RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", "\n", 
      "    ", 
      RowBox[{"Hfrs", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"Length", "@", "Hps"}]}], "]"}]}], ";", "\n", "    ", "\n", 
      "    ", 
      RowBox[{"ind", " ", "=", " ", "1"}], ";", "\n", "    ", 
      RowBox[{"Do", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"Do", "[", "\n", "        ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Hfrs", "[", 
             RowBox[{"[", "i", "]"}], "]"}], " ", "=", " ", 
            RowBox[{
             RowBox[{"Hfrs", "[", 
              RowBox[{"[", "i", "]"}], "]"}], " ", "+", " ", 
             RowBox[{"A", "[", 
              RowBox[{"[", 
               RowBox[{"ind", ",", " ", 
                RowBox[{"Snumber", " ", "+", " ", "2"}]}], "]"}], "]"}]}]}], 
           ";", "\n", "        ", 
           RowBox[{"ind", " ", "=", " ", 
            RowBox[{"ind", " ", "+", " ", "1"}]}], ";"}], "\n", "        ", 
          ",", " ", 
          RowBox[{"{", 
           RowBox[{"j", ",", " ", "ind", ",", " ", 
            RowBox[{"ind", " ", "+", " ", 
             RowBox[{"TL", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", " ", "2"}], "]"}], "]"}], " ", "-", " ", 
             "1"}]}], "}"}]}], "]"}], "\n", "      ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", 
          RowBox[{"Length", "@", "Hps"}]}], "}"}]}], "]"}], ";", "\n", "    ", 
      RowBox[{"Hfrs", " ", "=", " ", 
       RowBox[{"Hfrs", "/", "2"}]}], ";", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}]}]}], "\n", "    ", "]"}]}], 
  "\n"}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GenToClass", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GenToClass", "[", 
    RowBox[{"typesf_", ",", " ", "freqTypesf_", ",", " ", "Snumber_"}], "]"}],
    " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "    ", 
     RowBox[{
      RowBox[{"A", " ", "=", " ", 
       RowBox[{"Sort", "@", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"typesf", "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", 
                 RowBox[{"1", " ", ";;", " ", 
                  RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], "]"}], 
              "\[Transpose]"}], ",", " ", "freqTypesf"}], "]"}], 
           "\[Transpose]"}], ",", " ", 
          RowBox[{
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"typesf", "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", 
                 RowBox[{
                  RowBox[{"Snumber", " ", "+", " ", "2"}], " ", ";;"}]}], 
                "]"}], "]"}], "\[Transpose]"}], ",", " ", "freqTypesf"}], 
            "]"}], "\[Transpose]"}]}], "]"}]}]}], ";", " ", "\n", "    ", 
      RowBox[{"TL", " ", "=", " ", 
       RowBox[{"Tally", "[", 
        RowBox[{"A", "[", 
         RowBox[{"[", 
          RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "]"}]}], ";", " ",
       "\n", "    ", 
      RowBox[{"Hps", " ", "=", " ", 
       RowBox[{"TL", "[", 
        RowBox[{"[", 
         RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", "\n", 
      "    ", 
      RowBox[{"Hfrs", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"Length", "@", "Hps"}]}], "]"}]}], ";", "\n", "    ", "\n", 
      "    ", 
      RowBox[{"ind", " ", "=", " ", "1"}], ";", "\n", "    ", 
      RowBox[{"Do", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"Do", "[", "\n", "        ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Hfrs", "[", 
             RowBox[{"[", "i", "]"}], "]"}], " ", "=", " ", 
            RowBox[{
             RowBox[{"Hfrs", "[", 
              RowBox[{"[", "i", "]"}], "]"}], " ", "+", " ", 
             RowBox[{"A", "[", 
              RowBox[{"[", 
               RowBox[{"ind", ",", " ", 
                RowBox[{"Snumber", " ", "+", " ", "2"}]}], "]"}], "]"}]}]}], 
           ";", "\n", "        ", 
           RowBox[{"ind", " ", "=", " ", 
            RowBox[{"ind", " ", "+", " ", "1"}]}], ";"}], "\n", "        ", 
          ",", " ", 
          RowBox[{"{", 
           RowBox[{"j", ",", " ", "ind", ",", " ", 
            RowBox[{"ind", " ", "+", " ", 
             RowBox[{"TL", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", " ", "2"}], "]"}], "]"}], " ", "-", " ", 
             "1"}]}], "}"}]}], "]"}], "\n", "      ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", 
          RowBox[{"Length", "@", "Hps"}]}], "}"}]}], "]"}], ";", "\n", "    ", 
      RowBox[{"Hfrs", " ", "=", " ", 
       RowBox[{"Hfrs", "/", "2"}]}], ";", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}]}]}], "\n", "    ", "]"}]}], 
  "\n"}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GenToClassCI", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GenToClassCI", "[", 
   RowBox[{"typesf_", ",", " ", "freqTypesf_", ",", " ", "Snumber_"}], "]"}], 
  " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    ", 
    RowBox[{
     RowBox[{"A", " ", "=", " ", 
      RowBox[{"Sort", "@", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"typesf", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{"1", " ", ";;", " ", 
                 RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], "]"}], 
             "\[Transpose]"}], ",", " ", "freqTypesf"}], "]"}], 
          "\[Transpose]"}], ",", " ", 
         RowBox[{
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"typesf", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", 
                RowBox[{
                 RowBox[{"Snumber", " ", "+", " ", "2"}], " ", ";;"}]}], 
               "]"}], "]"}], "\[Transpose]"}], ",", " ", "freqTypesf"}], 
           "]"}], "\[Transpose]"}]}], "]"}]}]}], ";", "\n", "    ", 
     RowBox[{"TL", " ", "=", " ", 
      RowBox[{"Tally", "[", 
       RowBox[{"A", "[", 
        RowBox[{"[", 
         RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "]"}]}], ";", "\n",
      "    ", 
     RowBox[{"Hps", " ", "=", " ", 
      RowBox[{"TL", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"HpsI", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", 
     RowBox[{"HpsC", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "    ", 
     RowBox[{"Hfrs", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"Length", "@", "Hps"}]}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"HfrsI", " ", "=", " ", "Hfrs"}], ";", " ", 
     RowBox[{"HfrsC", " ", "=", " ", "Hfrs"}], ";", "\n", "    ", "\n", 
     "    ", 
     RowBox[{"ind", " ", "=", " ", "1"}], ";", "\n", "    ", 
     RowBox[{"Do", "[", "\n", "      ", 
      RowBox[{
       RowBox[{"Do", "[", "\n", "        ", "\n", "        ", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "@", 
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"A", "[", 
                 RowBox[{"[", 
                  RowBox[{"ind", ",", " ", 
                   RowBox[{"2", " ", ";;", " ", 
                    RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], "]"}],
                 ",", " ", 
                RowBox[{"A", "[", 
                 RowBox[{"[", 
                  RowBox[{"ind", ",", " ", "1"}], "]"}], "]"}]}], "]"}]}], 
             " ", "==", " ", "0"}], ",", 
            RowBox[{"(*", "SI", "*)"}], "\n", "          ", 
            RowBox[{
             RowBox[{"AppendTo", "[", 
              RowBox[{"HpsI", ",", " ", 
               RowBox[{"A", "[", 
                RowBox[{"[", 
                 RowBox[{"ind", ",", " ", 
                  RowBox[{";;", " ", 
                   RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], 
                "]"}]}], "]"}], ";", "\n", "          ", 
             RowBox[{
              RowBox[{"HfrsI", "[", 
               RowBox[{"[", "i", "]"}], "]"}], " ", "=", " ", 
              RowBox[{
               RowBox[{"HfrsI", "[", 
                RowBox[{"[", "i", "]"}], "]"}], " ", "+", " ", 
               RowBox[{"A", "[", 
                RowBox[{"[", 
                 RowBox[{"ind", ",", " ", 
                  RowBox[{"Snumber", " ", "+", " ", "2"}]}], "]"}], "]"}]}]}],
              ";"}], "\n", "          ", ",", "\n", "          ", 
            RowBox[{
             RowBox[{"AppendTo", "[", 
              RowBox[{"HpsC", ",", " ", 
               RowBox[{"A", "[", 
                RowBox[{"[", 
                 RowBox[{"ind", ",", " ", 
                  RowBox[{";;", " ", 
                   RowBox[{"Snumber", " ", "+", " ", "1"}]}]}], "]"}], 
                "]"}]}], "]"}], ";", "\n", "          ", 
             RowBox[{
              RowBox[{"HfrsC", "[", 
               RowBox[{"[", "i", "]"}], "]"}], " ", "=", " ", 
              RowBox[{
               RowBox[{"HfrsC", "[", 
                RowBox[{"[", "i", "]"}], "]"}], " ", "+", " ", 
               RowBox[{"A", "[", 
                RowBox[{"[", 
                 RowBox[{"ind", ",", " ", 
                  RowBox[{"Snumber", " ", "+", " ", "2"}]}], "]"}], "]"}]}]}],
              ";"}]}], "\n", "          ", "]"}], ";", "\n", "        ", "\n",
           "        ", 
          RowBox[{"ind", " ", "=", " ", 
           RowBox[{"ind", " ", "+", " ", "1"}]}], ";"}], "\n", "        ", 
         ",", " ", 
         RowBox[{"{", 
          RowBox[{"j", ",", " ", "ind", ",", " ", 
           RowBox[{"ind", " ", "+", " ", 
            RowBox[{"TL", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", " ", "2"}], "]"}], "]"}], " ", "-", " ", 
            "1"}]}], "}"}]}], "]"}], "\n", "      ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", "Hps"}]}], "}"}]}], "]"}], ";", "\n", "    ", 
     
     RowBox[{"HfrsI", " ", "=", " ", 
      RowBox[{"HfrsI", "/", "2"}]}], ";", " ", 
     RowBox[{"HfrsC", " ", "=", " ", 
      RowBox[{"HfrsC", "/", "2"}]}], ";", "\n", "    ", 
     RowBox[{"{", 
      RowBox[{
      "HpsC", ",", " ", "HfrsC", ",", " ", "HpsI", ",", " ", "HfrsI"}], 
      "}"}]}]}], "\n", "    ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["ReproductionFreq", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ReproductionFreq", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "      \t", 
     RowBox[{
      RowBox[{"Rnumber", " ", "=", " ", 
       RowBox[{"Types", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
      RowBox[{"Fnumber", " ", "=", " ", 
       RowBox[{"Types", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "      \t", 
      RowBox[{"mutFreqGen", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqGen", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqGen", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "      \t", 
      RowBox[{"mutFreqHap", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqHap", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqHap", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "      \t", 
      RowBox[{"mutFreqClass", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqClass", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqClass", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "      \t", 
      RowBox[{"mutFreqClassC", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqClassC", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqClassC", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "      \t", 
      RowBox[{"mutFreqClassI", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqClassI", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqClassI", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "      \t", 
      RowBox[{"Do", "[", "\n", "        \t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"uniqs", " ", "=", " ", 
          RowBox[{"Uniqs", "[", 
           RowBox[{"[", 
            RowBox[{"kk", ",", " ", ";;", " ", ",", " ", ";;"}], "]"}], 
           "]"}]}], ";", "\n", "        \t\t", 
         RowBox[{"uniqsM", " ", "=", " ", 
          RowBox[{"UniqsM", "[", 
           RowBox[{"[", 
            RowBox[{"kk", ",", " ", ";;", " ", ",", " ", ";;"}], "]"}], 
           "]"}]}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"after", " ", "mutation", " ", "step"}], " ", "*)"}], "\n", 
         "        \t\t", 
         RowBox[{"typesf", " ", "=", " ", 
          RowBox[{
           RowBox[{"Tally", "[", 
            RowBox[{"Sort", "@", "uniqs"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"typesfM", " ", "=", " ", 
          RowBox[{
           RowBox[{"Tally", "[", 
            RowBox[{"Sort", "@", "uniqsM"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
         "\n", "        \t\t", 
         RowBox[{"Ntypesf", " ", "=", " ", 
          RowBox[{"Length", "[", "typesf", "]"}]}], ";", " ", 
         RowBox[{"NtypesfM", " ", "=", " ", 
          RowBox[{"Length", "[", "typesfM", "]"}]}], ";", "\n", 
         "        \t\t", 
         RowBox[{"freqTypesf", " ", "=", " ", 
          RowBox[{
           RowBox[{"N", "@", " ", 
            RowBox[{
             RowBox[{"Tally", "[", 
              RowBox[{"Sort", "@", "uniqs"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
           "popsize"}]}], ";", " ", "\n", "        \t\t", 
         RowBox[{"freqTypesfM", " ", "=", " ", 
          RowBox[{
           RowBox[{"N", "@", " ", 
            RowBox[{
             RowBox[{"Tally", "[", 
              RowBox[{"Sort", "@", "uniqsM"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
           "popsize"}]}], ";", " ", "\n", "        \t\t", 
         RowBox[{"MC", " ", "=", " ", "CompatibilityMatrixDfast"}], ";", " ", 
         "\n", "        \t\t", 
         RowBox[{"reprodMatrix", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"freqTypesf", "*", "MC"}], ")"}], "\[Transpose]"}], 
             "*", "freqTypesf"}], ")"}], "\[Transpose]"}]}], " ", ";", " ", 
         "\n", "        \t\t", 
         RowBox[{"reprodMatrix", " ", "=", " ", 
          RowBox[{"reprodMatrix", "/", 
           RowBox[{"(", 
            RowBox[{"Total", "@", 
             RowBox[{"Total", "@", "reprodMatrix"}]}], ")"}]}]}], " ", ";", 
         " ", "\n", "        \t\t", 
         RowBox[{"Gfrs", " ", "=", " ", 
          RowBox[{
           RowBox[{"Total", "[", 
            RowBox[{"reprodMatrix", " ", "+", " ", 
             RowBox[{"reprodMatrix", "\[Transpose]"}]}], "]"}], "/", "2"}]}], 
         ";", "\n", "        ", "\n", "        \t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqGen", " ", ",", " ", "freqTypesfM"}], "]"}], ";", 
         " ", 
         RowBox[{"(*", " ", 
          RowBox[{
          "genotype", " ", "frequencies", " ", "after", " ", "mutation"}], 
          " ", "*)"}], "\n", "        \t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqGen", " ", ",", " ", "Gfrs"}], "]"}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{
          "genotype", " ", "frequencies", " ", "after", " ", "reproduction"}],
           " ", "*)"}], "\n", "        \t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqGen", " ", ",", " ", "freqTypesf"}], "]"}], ";", 
         " ", 
         RowBox[{"(*", " ", 
          RowBox[{
          "genotype", " ", "frequencies", " ", "after", " ", "viability", " ",
            "selection"}], " ", "*)"}], "\n", "        ", "\n", 
         "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToHap", "[", 
           RowBox[{"typesfM", ",", " ", "freqTypesfM", ",", " ", "Fnumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqHap", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "haplotype", " ", "frequencies", " ", "after", " ", "mutation"}], 
          " ", "*)"}], "\n", "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToHap", "[", 
           RowBox[{"typesf", ",", " ", "Gfrs", ",", " ", "Fnumber"}], "]"}]}],
          ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqHap", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "haplotype", " ", "frequencies", " ", "after", " ", 
           "reproduction"}], " ", "*)"}], "\n", "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToHap", "[", 
           RowBox[{"typesf", ",", " ", "freqTypesf", ",", " ", "Fnumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqHap", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "haplotype", " ", "frequencies", " ", "after", " ", "viability", 
           " ", "selection"}], " ", "*)"}], "\n", "        ", "\n", 
         "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToClass", "[", 
           RowBox[{"typesfM", ",", " ", "freqTypesfM", ",", " ", "Fnumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqClass", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "class", " ", "frequencies", " ", "after", " ", "mutation"}], " ", 
          "*)"}], "\n", "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToClass", "[", 
           RowBox[{"typesf", ",", " ", "Gfrs", ",", " ", "Fnumber"}], "]"}]}],
          ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqClass", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "class", " ", "frequencies", " ", "after", " ", "reproduction"}], 
          " ", "*)"}], "\n", "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToClass", "[", 
           RowBox[{"typesf", ",", " ", "freqTypesf", ",", " ", "Fnumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqClass", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "class", " ", "frequencies", " ", "after", " ", "viability", " ", 
           "selection"}], " ", "*)"}], "\n", "        ", "\n", "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "HpsC", ",", " ", "HfrsC", ",", " ", "HpsI", ",", " ", "HfrsI"}], 
           "}"}], " ", "=", " ", 
          RowBox[{"GenToClassCI", "[", 
           RowBox[{"typesfM", ",", " ", "freqTypesfM", ",", " ", "Fnumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqClassC", " ", ",", " ", "HfrsC"}], "]"}], ";", " ", 
         
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqClassI", " ", ",", " ", "HfrsI"}], "]"}], ";", "\n",
          "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "HpsC", ",", " ", "HfrsC", ",", " ", "HpsI", ",", " ", "HfrsI"}], 
           "}"}], " ", "=", " ", 
          RowBox[{"GenToClassCI", "[", 
           RowBox[{"typesf", ",", " ", "Gfrs", ",", " ", "Fnumber"}], "]"}]}],
          ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqClassC", " ", ",", " ", "HfrsC"}], "]"}], ";", 
         " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqClassI", " ", ",", " ", "HfrsI"}], "]"}], ";", 
         "\n", "        \t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "HpsC", ",", " ", "HfrsC", ",", " ", "HpsI", ",", " ", "HfrsI"}], 
           "}"}], " ", "=", " ", 
          RowBox[{"GenToClassCI", "[", 
           RowBox[{"typesf", ",", " ", "freqTypesf", ",", " ", "Fnumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqClassC", " ", ",", " ", "HfrsC"}], "]"}], ";", 
         " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqClassI", " ", ",", " ", "HfrsI"}], "]"}], ";"}], 
        "\n", "        \t", ",", " ", 
        RowBox[{"{", 
         RowBox[{"kk", ",", " ", "1", ",", " ", "generations"}], "}"}]}], 
       "]"}], ";", "\n", "      ", 
      RowBox[{"{", 
       RowBox[{
       "reprodFreqGen", ",", " ", "adultFreqGen", ",", " ", "reprodFreqHap", 
        ",", " ", "adultFreqHap", ",", " ", "reprodFreqClass", ",", " ", 
        "adultFreqClass", ",", " ", "reprodFreqClassC", ",", " ", 
        "reprodFreqClassI", ",", " ", "adultFreqClassC", " ", ",", " ", 
        "adultFreqClassI", ",", " ", "mutFreqGen", ",", " ", "mutFreqHap", 
        ",", " ", "mutFreqClass", " ", ",", " ", "mutFreqClassC", ",", " ", 
        "mutFreqClassI"}], "}"}]}]}], "\n", "      ", "]"}]}], ";"}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["OutputFreq", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OutputFreq", "[", "time_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"time", " ", "=", " ", "300"}], ";"}], "*)"}], "\n", "    ", 
    RowBox[{
     RowBox[{"typesA", " ", "=", " ", 
      RowBox[{"Tally", "[", 
       RowBox[{"Sort", "@", 
        RowBox[{"Haps", "[", 
         RowBox[{"[", "time", "]"}], "]"}]}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"all", " ", "types"}], ",", " ", 
       RowBox[{
        RowBox[{"template", " ", "for", " ", "self"}], "-", 
        "incompatibles"}]}], " ", "*)"}], "\n", "    ", 
     RowBox[{"typesB", " ", "=", " ", "typesA"}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"template", " ", "for", " ", "compatibles"}], " ", "*)"}], "\n",
      "    ", "\n", "    ", 
     RowBox[{"Do", "[", 
      RowBox[{"(*", " ", 
       RowBox[{
       "leaves", " ", "just", " ", "SI", " ", "haplotypes", " ", "in", " ", 
        "typesA", " ", "and", " ", "SC", " ", "haplotypes", " ", "in", " ", 
        "typesSC"}], " ", "*)"}], "\n", "      \t", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"typesA", "[", 
              RowBox[{"[", 
               RowBox[{"row", ",", " ", "1", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"typesA", "[", 
              RowBox[{"[", 
               RowBox[{"row", ",", " ", "1", ",", " ", "1"}], "]"}], "]"}]}], 
            "]"}]}], " ", "!=", " ", "0"}], ",", "\n", "        \t\t", 
         RowBox[{
          RowBox[{"typesA", " ", "=", " ", 
           RowBox[{"Drop", "[", 
            RowBox[{"typesA", ",", " ", 
             RowBox[{"{", "row", "}"}]}], "]"}]}], ";"}], ",", "\n", 
         "        \t\t", 
         RowBox[{"typesB", " ", "=", " ", 
          RowBox[{"Drop", "[", 
           RowBox[{"typesB", ",", " ", 
            RowBox[{"{", "row", "}"}]}], "]"}]}]}], "\n", "        \t", "]"}],
        ",", "\n", "      ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", 
         RowBox[{"Length", "@", "typesA"}], ",", " ", "1", ",", " ", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}], ";", "\n", "    ", "\n", 
     "    ", 
     RowBox[{"typesSI", " ", "=", " ", 
      RowBox[{"typesA", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"these", " ", "are", " ", "the", " ", "SI", " ", "types"}], " ",
       "*)"}], "\n", "    ", 
     RowBox[{"typesSC", " ", "=", " ", 
      RowBox[{"typesB", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"these", " ", "are", " ", "the", " ", "SI", " ", "types"}], " ",
       "*)"}], "\n", "    ", "\n", "    ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "@", "typesSI"}], " ", ">", " ", "0"}], ",", "\n", 
       "      ", "\n", "      \t", 
       RowBox[{
        RowBox[{"freksSC", " ", "=", " ", 
         RowBox[{"typesB", "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "these", " ", "are", " ", "their", " ", "repeat", " ", "sizes"}], 
         " ", "*)"}], "\n", "      \t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Total", "@", "freksSC"}], " ", ">", " ", "0"}], ",", " ", 
          
          RowBox[{
           RowBox[{"freksSC", " ", "=", " ", 
            RowBox[{
             RowBox[{"N", "@", "freksSC"}], "/", 
             RowBox[{"Total", "[", "freksSC", "]"}]}]}], ";"}]}], "]"}], ";", 
        "\n", "      ", "\n", "      \t", 
        RowBox[{"HapclassesSC", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Tally", "@", 
            RowBox[{"(", 
             RowBox[{"typesSC", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ")"}]}], 
           ")"}], "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "which", " ", "haplotype", " ", "classes", " ", "are", " ", 
          "present", " ", "at", " ", "given", " ", "time"}], " ", "*)"}], 
        "\n", "      \t", 
        RowBox[{"HapclassnumbersSC", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Tally", "@", 
            RowBox[{"(", 
             RowBox[{"typesSC", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ")"}]}], 
           ")"}], "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], ";", 
        RowBox[{"(*", " ", 
         RowBox[{
         "how", " ", "many", " ", "haplotypes", " ", "each", " ", "class", 
          " ", "contains"}], " ", "*)"}], "\n", "      ", "\n", "      \t", 
        RowBox[{"SCclasstypes", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"typesB", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
           RowBox[{"typesB", "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "}"}]}], ";",
         "\n", "      ", "\n", "      \t", 
        RowBox[{"SCfreq", " ", "=", " ", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", " ", "RTypes"}], "]"}]}], ";", "\n", "      \t", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"SCfreq", "[", 
             RowBox[{"[", 
              RowBox[{"SCclasstypes", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", " ", "i"}], "]"}], "]"}], "]"}], "]"}], " ",
             "=", " ", 
            RowBox[{
             RowBox[{"SCfreq", "[", 
              RowBox[{"[", 
               RowBox[{"SCclasstypes", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", " ", "i"}], "]"}], "]"}], "]"}], "]"}], 
             " ", "+", " ", 
             RowBox[{"SCclasstypes", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "i"}], "]"}], "]"}]}]}], ";"}], "\n", 
          "        \t", ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "1", ",", " ", 
            RowBox[{
             RowBox[{"Dimensions", "[", "SCclasstypes", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
        "      ", "\n", "      ", "\n", "      \t", 
        RowBox[{"freksSI", " ", "=", " ", 
         RowBox[{"typesA", "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "these", " ", "are", " ", "their", " ", "repeat", " ", "sizes"}], 
         " ", "*)"}], "\n", "      \t", 
        RowBox[{"freksSI", " ", "=", " ", 
         RowBox[{
          RowBox[{"N", "@", "freksSI"}], "/", 
          RowBox[{"Total", "[", "freksSI", "]"}]}]}], ";", "\n", "      ", 
        "\n", "      \t", 
        RowBox[{"HapclassesSI", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Tally", "@", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Tally", "[", 
                RowBox[{"Sort", "@", "typesSI"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ")"}]}], 
           ")"}], "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "which", " ", "haplotype", " ", "classes", " ", "are", " ", 
          "present", " ", "at", " ", "given", " ", "time"}], " ", "*)"}], 
        "\n", "      \t", 
        RowBox[{"HapclassnumbersSI", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Tally", "@", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Tally", "[", 
                RowBox[{"Sort", "@", "typesSI"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ")"}]}], 
           ")"}], "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], ";", 
        RowBox[{"(*", " ", 
         RowBox[{
         "how", " ", "many", " ", "haplotypes", " ", "each", " ", "class", 
          " ", "contains"}], " ", "*)"}], "\n", "      ", "\n", "      \t", 
        RowBox[{"SIclasstypes", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"typesA", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
           RowBox[{"typesA", "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "}"}]}], ";",
         "\n", "      ", "\n", "      \t", 
        RowBox[{"SIfreq", " ", "=", " ", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", " ", "RTypes"}], "]"}]}], ";", "\n", "      \t", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"SIfreq", "[", 
             RowBox[{"[", 
              RowBox[{"SIclasstypes", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", " ", "i"}], "]"}], "]"}], "]"}], "]"}], " ",
             "=", " ", 
            RowBox[{
             RowBox[{"SIfreq", "[", 
              RowBox[{"[", 
               RowBox[{"SIclasstypes", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", " ", "i"}], "]"}], "]"}], "]"}], "]"}], 
             " ", "+", " ", 
             RowBox[{"SIclasstypes", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "i"}], "]"}], "]"}]}]}], ";"}], "\n", 
          "        \t", ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "1", ",", " ", 
            RowBox[{
             RowBox[{"Dimensions", "[", "SIclasstypes", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
        "      ", "\n", "      \t", 
        RowBox[{"FreqOut", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Flatten", "@", 
            RowBox[{"Range", "[", "RTypes", "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"N", "@", "SIfreq"}], "/", "popsize"}], "/", "2"}], ",", 
           " ", 
           RowBox[{
            RowBox[{
             RowBox[{"N", "@", "SCfreq"}], "/", "popsize"}], "/", "2"}]}], 
          "}"}]}], ";"}], "\n", "      \t", ",", " ", 
       RowBox[{
        RowBox[{"FreqOut", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Flatten", "@", 
            RowBox[{"Range", "[", "RTypes", "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"Flatten", "@", 
             RowBox[{"Range", "[", "RTypes", "]"}]}], "*", "0"}], ",", " ", 
           RowBox[{
            RowBox[{"Flatten", "@", 
             RowBox[{"Range", "[", "RTypes", "]"}]}], "*", "0"}]}], "}"}]}], 
        ";"}]}], "]"}], ";", "\n", "    ", "FreqOut"}]}], "\n", "    ", 
   "]"}]}]], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OutputFreqAB", "[", 
   RowBox[{"time_", ",", " ", "Htype_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"time", " ", "=", " ", "50"}], ";", " ", 
      RowBox[{"Htype", " ", "=", " ", "1"}], ";"}], "*)"}], "\n", "    ", 
    RowBox[{
     RowBox[{"typesA", " ", "=", " ", 
      RowBox[{"Tally", "[", 
       RowBox[{"Sort", "@", 
        RowBox[{"Haps", "[", 
         RowBox[{"[", "time", "]"}], "]"}]}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"all", " ", "types"}], ",", " ", 
       RowBox[{
        RowBox[{"template", " ", "for", " ", "self"}], "-", 
        "incompatibles"}]}], " ", "*)"}], "\n", "    ", 
     RowBox[{"typesB", " ", "=", " ", "typesA"}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"template", " ", "for", " ", "compatibles"}], " ", "*)"}], "\n",
      "    ", "\n", "    ", 
     RowBox[{"Do", "[", 
      RowBox[{"(*", " ", 
       RowBox[{
       "leaves", " ", "just", " ", "SI", " ", "haplotypes", " ", "in", " ", 
        "typesA", " ", "and", " ", "SC", " ", "haplotypes", " ", "in", " ", 
        "typesSC"}], " ", "*)"}], "\n", "      \t", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"typesA", "[", 
              RowBox[{"[", 
               RowBox[{"row", ",", " ", "1", ",", " ", 
                RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"typesA", "[", 
              RowBox[{"[", 
               RowBox[{"row", ",", " ", "1", ",", " ", "1"}], "]"}], "]"}]}], 
            "]"}]}], " ", "!=", " ", "0"}], ",", "\n", "        \t\t", 
         RowBox[{
          RowBox[{"typesA", " ", "=", " ", 
           RowBox[{"Drop", "[", 
            RowBox[{"typesA", ",", " ", 
             RowBox[{"{", "row", "}"}]}], "]"}]}], ";"}], ",", "\n", 
         "        \t\t", 
         RowBox[{"typesB", " ", "=", " ", 
          RowBox[{"Drop", "[", 
           RowBox[{"typesB", ",", " ", 
            RowBox[{"{", "row", "}"}]}], "]"}]}]}], "\n", "        \t", "]"}],
        ",", "\n", "      ", 
       RowBox[{"{", 
        RowBox[{"row", ",", " ", 
         RowBox[{"Length", "@", "typesA"}], ",", " ", "1", ",", " ", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}], ";", "\n", "    ", "\n", 
     "    ", 
     RowBox[{"typesA2", " ", "=", " ", "typesA"}], ";", " ", 
     RowBox[{"(*", "SI", "*)"}], " ", 
     RowBox[{"typesB2", " ", "=", " ", "typesB"}], ";", " ", 
     RowBox[{"(*", "SC", "*)"}], "\n", "    ", 
     RowBox[{"LA", " ", "=", " ", 
      RowBox[{"Length", "[", "typesA2", "]"}]}], ";", " ", 
     RowBox[{"LB", " ", "=", " ", 
      RowBox[{"Length", "[", "typesB2", "]"}]}], ";", "\n", "    ", "\n", 
     "    ", "\n", "    ", 
     RowBox[{
      RowBox[{"Do", "[", "\n", "        ", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"typesA2", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
            RowBox[{"[", "k", "]"}], "]"}], " ", "!=", " ", "Htype"}], ",", 
          " ", 
          RowBox[{
           RowBox[{"typesA2", " ", "=", " ", 
            RowBox[{"Drop", "[", 
             RowBox[{"typesA2", ",", " ", 
              RowBox[{"{", "k", "}"}]}], "]"}]}], ";"}]}], "]"}], "\n", 
        "        ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"k", ",", " ", "LA", ",", " ", "1", ",", " ", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "\n", "      ", "\n", 
      "      ", 
      RowBox[{"Do", "[", "\n", "        ", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"typesB2", "[", 
              RowBox[{"[", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
            RowBox[{"[", "k", "]"}], "]"}], " ", "!=", " ", "Htype"}], ",", 
          " ", 
          RowBox[{
           RowBox[{"typesB2", " ", "=", " ", 
            RowBox[{"Drop", "[", 
             RowBox[{"typesB2", ",", " ", 
              RowBox[{"{", "k", "}"}]}], "]"}]}], ";"}]}], "]"}], "\n", 
        "        ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"k", ",", " ", "LB", ",", " ", "1", ",", " ", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "    ", "\n", 
     "    ", 
     RowBox[{"FreqOutA", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Flatten", "@", 
         RowBox[{"Range", "[", 
          RowBox[{"Length", "@", "typesA2"}], "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"N", "@", 
           RowBox[{"typesA2", "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
          "popsize"}], "/", "2"}]}], "}"}]}], ";", "\n", "    ", 
     RowBox[{"FreqOutB", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Flatten", "@", 
         RowBox[{"Range", "[", 
          RowBox[{"Length", "@", "typesB2"}], "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"N", "@", 
           RowBox[{"typesB2", "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
          "popsize"}], "/", "2"}]}], "}"}]}], ";", "\n", "    ", 
     RowBox[{"{", 
      RowBox[{
      "FreqOutA", ",", " ", "FreqOutB", ",", " ", "typesA2", ",", " ", 
       "typesB2"}], "}"}], ";"}]}], "\n", "    ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["CompStructTimeSimp", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "one", " ", "more", " ", "problem", " ", "when", " ", "low", " ", 
     "number", " ", "of", " ", "SC"}], ",", " ", 
    RowBox[{
    "the", " ", "vector", " ", "transposition", " ", "does", " ", "not", " ", 
     "work", " ", "well"}]}], "  ", "*)"}], "\n", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"CompStructTimeSimp", "[", "time_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\n", "\n", 
      RowBox[{
       RowBox[{"typesA", " ", "=", " ", 
        RowBox[{"Tally", "[", 
         RowBox[{"Sort", "@", 
          RowBox[{"Haps", "[", 
           RowBox[{"[", "time", "]"}], "]"}]}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"all", " ", "types"}], ",", " ", 
         RowBox[{
          RowBox[{"template", " ", "for", " ", "self"}], "-", 
          "incompatibles"}]}], " ", "*)"}], "\n", 
       RowBox[{"typesB", " ", "=", " ", "typesA"}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"template", " ", "for", " ", "compatibles"}], " ", "*)"}], 
       "\n", "\n", 
       RowBox[{"Do", "[", 
        RowBox[{"(*", " ", 
         RowBox[{
         "leaves", " ", "just", " ", "SI", " ", "haplotypes", " ", "in", " ", 
          "typesA", " ", "and", " ", "SC", " ", "haplotypes", " ", "in", " ", 
          "typesSC"}], " ", "*)"}], "\n", "\t", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "@", 
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"typesA", "[", 
                RowBox[{"[", 
                 RowBox[{"row", ",", "1", ",", 
                  RowBox[{"2", ";;"}]}], "]"}], "]"}], ",", 
               RowBox[{"typesA", "[", 
                RowBox[{"[", 
                 RowBox[{"row", ",", "1", ",", "1"}], "]"}], "]"}]}], "]"}]}],
             "!=", " ", "0"}], ",", "\n", "\t\t", 
           RowBox[{
            RowBox[{"typesA", " ", "=", " ", 
             RowBox[{"Drop", "[", 
              RowBox[{"typesA", ",", 
               RowBox[{"{", "row", "}"}]}], "]"}]}], ";"}], ",", "\n", "\t\t", 
           RowBox[{"typesB", " ", "=", " ", 
            RowBox[{"Drop", "[", 
             RowBox[{"typesB", ",", 
              RowBox[{"{", "row", "}"}]}], "]"}]}]}], "\n", "\t", "]"}], ",", 
         "\n", 
         RowBox[{"{", 
          RowBox[{"row", ",", 
           RowBox[{"Length", "@", "typesA"}], ",", "1", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], ";", "\n", "\n", 
       RowBox[{"typesSI", " ", "=", " ", 
        RowBox[{"typesA", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", "1"}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"these", " ", "are", " ", "the", " ", "SI", " ", "types"}], 
        " ", "*)"}], "\n", 
       RowBox[{"typesSC", " ", "=", " ", 
        RowBox[{"typesB", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", "1"}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"these", " ", "are", " ", "the", " ", "SI", " ", "types"}], 
        " ", "*)"}], "\n", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", " ", 
            RowBox[{"Length", "@", "typesSI"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"Length", "@", "typesSC"}], ")"}]}], "==", " ", "0"}], 
         ",", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"CompatibilityStructureF", " ", "=", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], ";", " ", 
            RowBox[{"CompatibilityStructureM", " ", "=", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}]}], ","}], "*)"}], "\n", 
         RowBox[{
          RowBox[{"CompatibilityStructureFC", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], ";", " ", 
          RowBox[{"CompatibilityStructureFI", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}]}]}], "\n", "]"}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"no", " ", "SI", " ", "or", " ", "SC", " ", "types"}], " ", 
        "*)"}], "\n", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", " ", 
           RowBox[{"Length", "@", "typesSI"}], ")"}], ">", " ", "0"}], ",", 
         "\n", "\t", 
         RowBox[{"(*", 
          RowBox[{"typesA", "//", "MatrixForm"}], "*)"}], "\n", "\t", 
         RowBox[{
          RowBox[{"freksSI", " ", "=", " ", 
           RowBox[{"typesA", "[", 
            RowBox[{"[", 
             RowBox[{";;", ",", "2"}], "]"}], "]"}]}], ";", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "these", " ", "are", " ", "their", " ", "repeat", " ", "sizes"}], 
           " ", "*)"}], "\n", "\t", 
          RowBox[{"freksSI", " ", "=", " ", 
           RowBox[{
            RowBox[{"N", "@", "freksSI"}], "/", 
            RowBox[{"Total", "[", "freksSI", "]"}]}]}], ";", "\n", "\t", 
          RowBox[{"Hapclasses", " ", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Tally", "@", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Tally", "[", 
                  RowBox[{"Sort", "@", "typesSI"}], "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{";;", ",", "1"}], "]"}], "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{";;", ",", "1"}], "]"}], "]"}], ")"}]}], ")"}], "[", 
            
            RowBox[{"[", 
             RowBox[{";;", ",", "1"}], "]"}], "]"}]}], ";", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
           "which", " ", "haplotype", " ", "classes", " ", "are", " ", 
            "present", " ", "at", " ", "given", " ", "time"}], " ", "*)"}], 
          "\n", "\t", 
          RowBox[{"Hapclassnumbers", " ", "=", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Tally", "@", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Tally", "[", 
                  RowBox[{"Sort", "@", "typesSI"}], "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{";;", ",", "1"}], "]"}], "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{";;", ",", "1"}], "]"}], "]"}], ")"}]}], ")"}], "[", 
            
            RowBox[{"[", 
             RowBox[{";;", ",", "2"}], "]"}], "]"}]}], ";", 
          RowBox[{"(*", " ", 
           RowBox[{"what", " ", "is", " ", "their", " ", "multiplicity"}], 
           " ", "*)"}], "\n", "\n", "\n", "\t", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", " ", 
              RowBox[{"Length", "@", "Hapclasses"}], ")"}], "==", " ", "1"}], 
            ",", "\n", "\t\t", 
            RowBox[{
             RowBox[{"CompatibilityStructureF", " ", "=", " ", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}], ";", " ", 
             RowBox[{"CompatibilityStructureM", " ", "=", " ", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}], ";"}]}], "\n", "\t", "]"}], 
          ";", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"one", " ", "SI", " ", "haplotype", " ", "class"}], " ", 
            "-", " ", "unviable"}], " ", "*)"}], "\n", "\n", "\t", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", " ", 
              RowBox[{"Length", "@", "Hapclasses"}], ")"}], ">", "1"}], ",", 
            "\n", "\t\t", 
            RowBox[{
             RowBox[{"CompatibilityStructureF", " ", "=", " ", 
              RowBox[{"ConstantArray", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", 
                 RowBox[{"2", ",", 
                  RowBox[{"Length", "@", "Hapclasses"}]}], "}"}]}], "]"}]}], 
             ";", " ", 
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{"matrix", " ", "of", " ", "size", " ", 
                RowBox[{"(", 
                 RowBox[{"#", " ", "SI", " ", "classes"}], ")"}], "*", "2"}], 
               " ", "-", " ", 
               RowBox[{
               "what", " ", "%", " ", "of", " ", "males", " ", "can", " ", 
                "pollinate", " ", "this", " ", "female"}]}], " ", "*)"}], 
             "\n", "\t\t", 
             RowBox[{"CompatibilityStructureM", " ", "=", " ", 
              RowBox[{"ConstantArray", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", 
                 RowBox[{"2", ",", 
                  RowBox[{"Length", "@", "Hapclasses"}]}], "}"}]}], "]"}]}], 
             ";", " ", 
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{"matrix", " ", "of", " ", "size", " ", 
                RowBox[{"(", 
                 RowBox[{"#", " ", "SI", " ", "classes"}], ")"}], "*", "2"}], 
               " ", "-", " ", 
               RowBox[{
               "what", " ", "%", " ", "of", " ", "females", " ", "can", " ", 
                "be", " ", "pollinated", " ", "by", " ", "this", " ", 
                "male"}]}], " ", "*)"}], "\n", "\t\t", 
             RowBox[{"CompHap", " ", "=", " ", 
              RowBox[{"Table", "[", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{"Boole", "@", 
                 RowBox[{"MemberQ", "[", 
                  RowBox[{
                   RowBox[{"typesSI", "[", 
                    RowBox[{"[", 
                    RowBox[{"idm", ",", 
                    RowBox[{"2", ";;", 
                    RowBox[{"1", "+", 
                    RowBox[{"SLength", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}]}], "]"}], "]"}], ",", 
                   RowBox[{"typesSI", "[", 
                    RowBox[{"[", 
                    RowBox[{"idf", ",", "1"}], "]"}], "]"}]}], "]"}]}], " ", 
                "\n", "\t\t\t", ",", 
                RowBox[{"{", 
                 RowBox[{"idf", ",", "1", ",", 
                  RowBox[{"Length", "@", "typesSI"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"idm", ",", "1", ",", 
                  RowBox[{"Length", "@", "typesSI"}]}], "}"}]}], "]"}]}], ";",
              " ", 
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{
               "full", " ", "SI", " ", "haplotype", " ", "compatibility", " ",
                 "matrix"}], " ", "-", " ", 
               RowBox[{
               "zero", " ", "blocks", " ", "on", " ", "the", " ", 
                "diagonal"}]}], " ", "*)"}], "\n", "\t\t", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Print", "[", 
                RowBox[{"CompHap", "//", "MatrixForm"}], "]"}], ";"}], "*)"}],
              "\n", "\n", "\t\t", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"freksSInorm", " ", "=", " ", "freksSI"}], ";"}], 
              "*)"}], "\n", "\t\t", 
             RowBox[{"freksSInorm", " ", "=", " ", 
              RowBox[{"freksSI", "/", 
               RowBox[{"Total", "[", "freksSI", "]"}]}]}], ";", " ", 
             RowBox[{"(*", " ", 
              RowBox[{
              "normalized", " ", "frequencies", " ", "of", " ", "the", " ", 
               "SI", " ", "types"}], " ", "*)"}], "\n", "\t\t", 
             RowBox[{"freksSInormF", " ", "=", " ", 
              RowBox[{
               RowBox[{"N", "@", "freksSInorm"}], "/", 
               RowBox[{"Total", "[", 
                RowBox[{"freksSInorm", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ";;", 
                   RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "]"}]}]}],
              ";", " ", 
             RowBox[{"(*", " ", 
              RowBox[{
              "frequencies", " ", "of", " ", "the", " ", "SI", " ", "types", 
               " ", "normalized", " ", "to", " ", "the", " ", "first", " ", 
               "class", " ", 
               RowBox[{"(", 
                RowBox[{">", "1"}], ")"}]}], " ", "*)"}], "\n", "\t\t", 
             RowBox[{"freksSInormM", " ", "=", " ", 
              RowBox[{
               RowBox[{"N", "@", "freksSInorm"}], "/", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"Total", "[", 
                  RowBox[{"freksSInorm", "[", 
                   RowBox[{"[", 
                    RowBox[{"1", ";;", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], 
                ")"}]}]}], ";", 
             RowBox[{"(*", " ", 
              RowBox[{
              "frequencies", " ", "of", " ", "the", " ", "SI", " ", "types", 
               " ", "normalized", " ", "to", " ", "the", " ", "other", " ", 
               "classes", " ", 
               RowBox[{"(", 
                RowBox[{">", "1"}], ")"}]}], " ", "*)"}], "\n", "\n", "\t\t", 
             
             RowBox[{
              RowBox[{"CompatibilityStructureF", "[", 
               RowBox[{"[", 
                RowBox[{";;", ",", "1"}], "]"}], "]"}], " ", "=", " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Hapclasses", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"N", "@", 
                 RowBox[{"Total", "[", 
                  RowBox[{
                   RowBox[{"Total", "[", 
                    RowBox[{"Drop", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"CompHap", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ";;", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], 
                    "\[Transpose]"}], ")"}], "*", "freksSInormM"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                   "*", 
                   RowBox[{"freksSInormF", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ";;", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], 
                  "]"}]}]}], "}"}]}], ";", "\n", "\t\t", 
             RowBox[{
              RowBox[{"CompatibilityStructureM", "[", 
               RowBox[{"[", 
                RowBox[{";;", ",", "1"}], "]"}], "]"}], " ", "=", " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Hapclasses", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"N", "@", 
                 RowBox[{"Total", "[", 
                  RowBox[{
                   RowBox[{"Total", "[", 
                    RowBox[{"Drop", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"CompHap", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", ",", 
                    RowBox[{"1", ";;", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], "]"}], ")"}], 
                    "*", "freksSInormM"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
                   "*", 
                   RowBox[{"freksSInormF", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ";;", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], 
                  "]"}]}]}], "}"}]}], ";", "\n", "\t\t", 
             RowBox[{"Do", "[", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{
                RowBox[{"freksSInorm2", " ", "=", " ", 
                 RowBox[{"freksSInorm", "/", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"Total", "@", 
                    RowBox[{"freksSInorm", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "]"}], "]"}]}]}], 
                   ")"}]}]}], ";", "\n", "\t\t\t", 
                RowBox[{
                 RowBox[{"freksSInorm2", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "]"}], "]"}], " ", 
                 "=", " ", 
                 RowBox[{
                  RowBox[{"freksSInorm", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "]"}], "]"}], "/", 
                  
                  RowBox[{"(", 
                   RowBox[{"Total", "@", 
                    RowBox[{"freksSInorm", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "]"}], "]"}]}], 
                   ")"}]}]}], ";", "\n", "\t\t\t", 
                RowBox[{
                 RowBox[{"CompatibilityStructureF", "[", 
                  RowBox[{"[", 
                   RowBox[{";;", ",", "i"}], "]"}], "]"}], " ", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Hapclasses", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   RowBox[{"N", "@", 
                    RowBox[{"Total", "[", 
                    RowBox[{
                    RowBox[{"Total", "[", 
                    RowBox[{"Drop", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"CompHap", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "]"}], "]"}], 
                    "\[Transpose]"}], ")"}], "*", "freksSInorm2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], 
                    ",", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "}"}]}], "]"}], 
                    "]"}], "*", 
                    RowBox[{"freksSInorm2", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "]"}], "]"}]}], 
                    "]"}]}]}], "}"}]}], ";", "\n", "\t\t\t", 
                RowBox[{
                 RowBox[{"CompatibilityStructureM", "[", 
                  RowBox[{"[", 
                   RowBox[{";;", ",", "i"}], "]"}], "]"}], " ", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Hapclasses", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   RowBox[{"N", "@", 
                    RowBox[{"Total", "[", 
                    RowBox[{
                    RowBox[{"Total", "[", 
                    RowBox[{"Drop", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"CompHap", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}]}], "]"}], "]"}], 
                    ")"}], "*", "freksSInorm2"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], 
                    ",", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "}"}]}], "]"}], 
                    "]"}], "*", 
                    RowBox[{"freksSInorm2", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", 
                    RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "+", "1"}], ";;", 
                    RowBox[{"Total", "@", 
                    RowBox[{"Hapclassnumbers", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", "i"}], "]"}], "]"}]}]}], "]"}], "]"}]}], 
                    "]"}]}]}], "}"}]}], ";"}], "\n", "\n", "\t\t", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "2", ",", 
                 RowBox[{"Length", "@", "Hapclasses"}]}], "}"}]}], "]"}], 
             ";"}]}], "\n", "\t", "]"}], ";"}]}], "\n", "]"}], ";", "\n", 
       "\n", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"CStructureTimeF", ",", "CompatibilityStructureF"}], "]"}], 
       ";", "\n", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"CStructureTimeM", ",", "CompatibilityStructureM"}], "]"}], 
       ";"}]}], "\n", "\n", "]"}]}], "\n"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["RunAD", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunAD", "[", "uniqs_", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  \t", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", "=", " ", "alp"}], ";", " ", 
     RowBox[{"\[Delta]", " ", "=", " ", "del"}], ";", " ", "\n", "  \t", 
     RowBox[{"T1", " ", "=", " ", 
      RowBox[{
       RowBox[{"Timing", "[", 
        RowBox[{"RunSIDiploidSimult", "[", "uniqs", "]"}], "]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", "\n", 
     "  \t", "GetSIClasses", ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"{", 
       RowBox[{"SItypesTime", ",", "SItypesTimeCount"}], "}"}], " ", "*)"}], 
     "\n", "  \t", "GetBDTimes", ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"{", 
       RowBox[{
       "TimeBirth", ",", "TimeDeath", ",", "FlagBirth", ",", "FlagDeath", ",",
         "FlagNewSI"}], "}"}], " ", "*)"}], "\n", "  \t", "GetBornHaps", ";", 
     " ", 
     RowBox[{"(*", " ", "BornHaps", " ", "*)"}], "\n", "  \t", "GetDeadHaps", 
     ";", " ", 
     RowBox[{"(*", " ", "DeadHaps", " ", "*)"}], "\n", "  \t", 
     RowBox[{"GetAncestors", "[", 
      RowBox[{"TimeBirth", ",", " ", "BornHaps"}], "]"}], ";"}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"{", 
     RowBox[{
     "ancestorHap", ",", "ancestorType", ",", "ancestorComp", ",", 
      "ancestorFreq", ",", "ancestorSIfreq", ",", "ancestorFreqs", ",", 
      "freqF"}], "}"}], " ", "*)"}], "\n", "]"}]}]], "Code",
 CellChangeTimes->{{3.723525881357983*^9, 3.7235258872212477`*^9}, {
   3.723525922298133*^9, 3.7235259711977663`*^9}, {3.725625599102076*^9, 
   3.725625650436536*^9}, 3.725626076330167*^9, {3.726390611369123*^9, 
   3.7263906276191263`*^9}, {3.726390661057941*^9, 3.726390668585596*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["RunSIDiploidSimult", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"simplified", " ", "compatibility", " ", "function"}], " ", "-", 
    " ", 
    RowBox[{"returns", " ", "only", " ", "two", " ", "statistics"}]}], " ", 
   "*)"}], "\n", 
  RowBox[{
   RowBox[{"RunSIDiploidSimult", "[", "uniqsin_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "    \t", 
     RowBox[{
      RowBox[{"rep", " ", "=", " ", "1"}], ";", " ", 
      RowBox[{"tD", " ", "=", " ", "1"}], ";", " ", "\n", "\t\t", 
      RowBox[{"Tavg", " ", "=", " ", "1"}], ";", " ", 
      RowBox[{"thresh2", " ", "=", " ", 
       RowBox[{"1", "/", "popsize"}]}], ";", "\n", "\t\t", 
      RowBox[{"freqStore", " ", "=", " ", "1000"}], ";", " ", "\n", "    \t", 
      "\n", "    \t", 
      RowBox[{"P", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    \t", 
      RowBox[{"InvasionFreq", " ", "=", " ", "0"}], ";", "\n", "    \t", 
      RowBox[{"InvasionTypes", " ", "=", " ", "0"}], ";", "\n", "    \t", 
      RowBox[{"CStructure", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    ", "\n", "    \t", 
      RowBox[{"uniqs", " ", "=", " ", "uniqsin"}], ";", "\n", "    \t\t", 
      RowBox[{"Rnumber", " ", "=", " ", 
       RowBox[{"RTypes", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "    \t\t", 
      RowBox[{"Fnumber", " ", "=", " ", 
       RowBox[{"FTypes", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "    \t\t", 
      RowBox[{"Snumber", " ", "=", " ", 
       RowBox[{"SLength", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "    ", "\n", "    \t\t", 
      RowBox[{"haps", " ", "=", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"uniqs", "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", 
            RowBox[{";;", " ", 
             RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], ",", 
         " ", 
         RowBox[{"uniqs", "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", " ", 
            RowBox[{
             RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}]}], "]"}], 
          "]"}]}], "]"}]}], ";", "\n", "    \t\t", 
      RowBox[{"Uniqs", " ", "=", " ", 
       RowBox[{"{", "uniqs", "}"}]}], ";", " ", "\n", "    \t\t", 
      RowBox[{"Haps", " ", "=", " ", 
       RowBox[{"{", "haps", "}"}]}], ";", " ", "\n", "    \t\t", 
      RowBox[{"UniqsM", " ", "=", " ", 
       RowBox[{"{", "uniqs", "}"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"after", " ", "mutation"}], " ", "*)"}], "\n", "    ", "\n", 
      "    \t\t", 
      RowBox[{"mutFreqGen", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqGen", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqGen", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    \t\t", 
      RowBox[{"mutFreqHap", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqHap", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqHap", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    \t\t", 
      RowBox[{"mutFreqClass", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqClass", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqClass", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    \t\t", 
      RowBox[{"mutFreqClassC", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqClassC", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqClassC", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    \t\t", 
      RowBox[{"mutFreqClassI", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"reprodFreqClassI", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"adultFreqClassI", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    ", "\n", "    \t\t", 
      RowBox[{"CStructureTimeF", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "female", " ", "compatibility", " ", "of", " ", "SI", " ", "among", 
        " ", "SI", " ", "types"}], " ", "*)"}], "\n", "    \t\t", 
      RowBox[{"CStructureTimeM", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "male", " ", "compatibility", " ", "of", " ", "SI", " ", "among", " ", 
        "SI", " ", "types"}], " ", "*)"}], "\n", "    \t\t", "\n", "    \t\t", 
      RowBox[{"uniqsStore", " ", "=", " ", 
       RowBox[{"{", "uniqs", "}"}]}], ";", "\n", "    \t\t", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"hapsStore", " ", "=", " ", 
         RowBox[{"{", "haps", "}"}]}], ";"}], "*)"}], "\n", "  ", "\n", 
      "  \t\t\t", 
      RowBox[{"MutationFrom", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "  \t\t\t", 
      RowBox[{"MutationTo", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "  \t\t\t", 
      RowBox[{"MutationTime", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "  \t\t\t", 
      RowBox[{"MutationType", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "  \t\t\t", 
      RowBox[{"MutationPosition", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "    \t\t", "\n", "    \t\t", 
      RowBox[{"Do", "[", "\n", "      \t\t\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", "kk", "]"}], ";"}], "*)"}], "\n", 
       "      \t\t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"uniqs", " ", "=", " ", 
          RowBox[{"Sort", "@", "SortDiploid"}]}], ";", "\n", "   \t\t\t   ", 
         RowBox[{"RmutateStore", "[", 
          RowBox[{"Rnumber", ",", " ", "Snumber", ",", " ", "kk"}], "]"}], 
         ";", "\n", "      \t\t\t", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"RmutateD", "[", 
            RowBox[{"Rnumber", ",", " ", "Snumber", ",", " ", "1"}], "]"}], 
           ";", " ", 
           RowBox[{"RmutateD", "[", 
            RowBox[{"Rnumber", ",", " ", "Snumber", ",", " ", "2"}], "]"}], 
           ";"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"R", "-", "mutation"}], " ", "*)"}], "*)"}], "\n", 
         "      \t\t\t", 
         RowBox[{"FmutateStore", "[", 
          RowBox[{"Rnumber", ",", " ", "Snumber", ",", " ", "kk"}], "]"}], 
         ";", "\n", "   \t\t\t   ", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"FmutateDFRS", "[", 
            RowBox[{"Rnumber", ",", " ", "Snumber", ",", " ", "1"}], "]"}], 
           ";", " ", 
           RowBox[{"FmutateDFRS", "[", 
            RowBox[{"Rnumber", ",", " ", "Snumber", ",", " ", "2"}], "]"}], 
           ";"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"F", "-", "mutation"}], " ", "*)"}], "*)"}], "\n", 
         "      \t\t\t", 
         RowBox[{"uniqs", " ", "=", " ", 
          RowBox[{"Sort", "@", "SortDiploid"}]}], ";", " ", "\n", 
         "      \t\t\t", 
         RowBox[{"uniqsM", " ", "=", " ", "uniqs"}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"UniqsM", ",", " ", "uniqsM"}], "]"}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"genotypes", " ", "after", " ", "mutation"}], " ", "*)"}], 
         "\n", "      \t\t\t", 
         RowBox[{"typesf", " ", "=", " ", 
          RowBox[{
           RowBox[{"Tally", "[", 
            RowBox[{"Sort", "@", "uniqs"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"(*", " ", "genotypes", " ", "*)"}], "\n", "      \t\t\t", 
         RowBox[{"Ntypesf", " ", "=", " ", 
          RowBox[{"Length", "[", "typesf", "]"}]}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"#", " ", "genotypes"}], " ", "*)"}], "\n", "      \t\t\t", 
         
         RowBox[{"freqTypesf", " ", "=", " ", 
          RowBox[{
           RowBox[{"N", "@", 
            RowBox[{
             RowBox[{"Tally", "[", 
              RowBox[{"Sort", "@", "uniqs"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
           "popsize"}]}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"genotype", " ", "freks"}], " ", "*)"}], "\n", 
         "      \t\t\t", "\n", "      \t\t\t", 
         RowBox[{"MC", " ", "=", " ", "CompatibilityMatrixDfast"}], ";", 
         RowBox[{"(*", 
          RowBox[{"MC", "//", "MatrixForm"}], "*)"}], "\n", "      \t\t\t", 
         RowBox[{"MCdiag", " ", "=", " ", 
          RowBox[{"Diagonal", "[", "MC", "]"}]}], ";", "\n", "      \t\t\t", 
         RowBox[{"Mf", " ", "=", " ", 
          RowBox[{"DiagonalMatrix", "[", "freqTypesf", "]"}]}], ";", "\n", 
         "      \t\t\t", 
         RowBox[{"Mm", " ", "=", " ", "Mf"}], ";", "\n", "      \t\t\t", 
         RowBox[{"denom", " ", "=", " ", 
          RowBox[{"DiagonalMatrix", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"MC", ".", "freqTypesf"}], ")"}]}], " ", "+", " ", 
              RowBox[{"\[Alpha]", " ", "MCdiag"}], " ", "+", " ", 
              RowBox[{"10", "^", 
               RowBox[{"-", "6"}]}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}]}], "]"}]}], ";", "\n", "      \t\t\t", 
         
         RowBox[{"p", " ", "=", " ", 
          RowBox[{"Position", "[", 
           RowBox[{"denom", ",", " ", 
            RowBox[{"10.", "^", "6"}]}], "]"}]}], ";", "\n", "      \t\t\t", 
         RowBox[{"OutMat", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "\[Alpha]"}], ")"}], " ", 
           RowBox[{"denom", ".", 
            RowBox[{"(", 
             RowBox[{"Mf", ".", "MC", ".", "Mm"}], ")"}]}]}]}], ";", "\n", 
         "      \t\t\t", 
         RowBox[{"SelMat", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "\[Delta]"}], ")"}], " ", "\[Alpha]", 
           " ", 
           RowBox[{"denom", ".", 
            RowBox[{"DiagonalMatrix", "[", 
             RowBox[{"Mf", ".", "MCdiag"}], "]"}]}]}]}], ";", "\n", "      ", 
         "\n", "      \t\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "@", "p"}], " ", ">", " ", "0"}], ",", "\n", 
           "        \t\t\t\t", 
           RowBox[{
            RowBox[{
             RowBox[{"OutMat", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"p", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                RowBox[{"p", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", " ", "1"}], "]"}], "]"}]}], "]"}], "]"}], 
             " ", "=", " ", "0"}], ";", "\n", "        \t\t\t\t", 
            RowBox[{
             RowBox[{"SelMat", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"p", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                RowBox[{"p", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", " ", "1"}], "]"}], "]"}]}], "]"}], "]"}], 
             " ", "=", " ", "0"}], ";"}]}], "\n", "        \t\t\t", "]"}], 
         ";", "\n", "      ", "\n", "      \t\t\t", 
         RowBox[{"TM", " ", "=", " ", 
          RowBox[{"OutMat", " ", "+", " ", "SelMat"}]}], ";", "\n", "      ", 
         "\n", "      \t\t\t", 
         RowBox[{"FertilizingPairsD", " ", "=", " ", 
          RowBox[{"Tuples", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", "Ntypesf", "]"}], ",", " ", 
             RowBox[{"Range", "[", "Ntypesf", "]"}]}], "}"}], "]"}]}], ";", 
         "\n", "      \t\t\t", 
         RowBox[{"RealizedFertilizations", " ", "=", " ", 
          RowBox[{"RandomChoice", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"ArrayReshape", "[", 
               RowBox[{"TM", ",", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"(", "Ntypesf", ")"}], "^", "2"}], "}"}]}], "]"}], 
              "/", 
              RowBox[{"Total", "[", 
               RowBox[{"ArrayReshape", "[", 
                RowBox[{"TM", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"(", "Ntypesf", ")"}], "^", "2"}], "}"}]}], "]"}], 
               "]"}]}], " ", "->", " ", "FertilizingPairsD"}], ",", " ", 
            "popsize"}], "]"}]}], ";", "\n", "      ", "\n", "      \t\t\t", 
         RowBox[{"uniqs", " ", "=", " ", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Flatten", "@", 
             RowBox[{"RandomChoice", "[", 
              RowBox[{
               RowBox[{"FindAncestors", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"RealizedFertilizations", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
                 RowBox[{
                  RowBox[{"RealizedFertilizations", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", " ", "1"}], 
              "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", "popsize"}], "}"}]}], 
           "]"}]}], ";", "\n", "      \t\t\t", 
         RowBox[{"uniqs", " ", "=", " ", 
          RowBox[{"Sort", "@", "SortDiploid"}]}], ";", "\n", "      ", "\n", 
         "      ", "\n", "      \t\t\t", 
         RowBox[{"haps", " ", "=", " ", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"uniqs", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", 
               RowBox[{";;", " ", 
                RowBox[{"1", " ", "+", " ", "Snumber"}]}]}], "]"}], "]"}], 
            ",", " ", 
            RowBox[{"uniqs", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", 
               RowBox[{
                RowBox[{"2", " ", "+", " ", "Snumber"}], " ", ";;"}]}], "]"}],
              "]"}]}], "]"}]}], ";", "\n", "      \t\t\t", "\n", 
         "      \t\t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"Uniqs", ",", " ", "uniqs"}], "]"}], ";", "\n", 
         "      \t\t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"Haps", ",", " ", "haps"}], "]"}], ";", "\n", 
         "      \t\t\t", 
         RowBox[{"(*", " ", 
          RowBox[{
          "every", " ", "1000", " ", "generations", " ", "remember", " ", 
           "the", " ", "genotypes", " ", "and", " ", "haplotypes"}], " ", 
          "*)"}], "\n", "      \t\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"kk", ",", " ", "freqStore"}], "]"}], " ", "==", " ", 
            "0"}], ",", "\n", "        \t\t\t\t", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"uniqsStore", ",", " ", "uniqs"}], "]"}], ";"}]}], "\n", 
          "        \t\t\t\t", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"hapsStore", ",", "haps"}], "]"}], ";"}], "*)"}], "\n", 
          "        \t\t\t", "]"}], ";", "\n", "      ", "\n", "      ", "\n", 
         "      \t\t\t", 
         RowBox[{"typesf", " ", "=", " ", 
          RowBox[{
           RowBox[{"Tally", "[", 
            RowBox[{"Sort", "@", "uniqs"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"typesfM", " ", "=", " ", 
          RowBox[{
           RowBox[{"Tally", "[", 
            RowBox[{"Sort", "@", "uniqsM"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
         "\n", "      \t\t\t", 
         RowBox[{"Ntypesf", " ", "=", " ", 
          RowBox[{"Length", "[", "typesf", "]"}]}], ";", " ", 
         RowBox[{"NtypesfM", " ", "=", " ", 
          RowBox[{"Length", "[", "typesfM", "]"}]}], ";", "\n", 
         "      \t\t\t", 
         RowBox[{"freqTypesf", " ", "=", " ", 
          RowBox[{
           RowBox[{"N", "@", " ", 
            RowBox[{
             RowBox[{"Tally", "[", 
              RowBox[{"Sort", "@", "uniqs"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
           "popsize"}]}], ";", " ", "\n", "      \t\t\t", 
         RowBox[{"freqTypesfM", " ", "=", " ", 
          RowBox[{
           RowBox[{"N", "@", " ", 
            RowBox[{
             RowBox[{"Tally", "[", 
              RowBox[{"Sort", "@", "uniqsM"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}]}], "/", 
           "popsize"}]}], ";", " ", "\n", "      \t\t\t", 
         RowBox[{"MC", " ", "=", " ", "CompatibilityMatrixDfast"}], ";", "\n",
          "      \t\t\t", 
         RowBox[{"reprodMatrix", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"freqTypesf", "*", "MC"}], ")"}], "\[Transpose]"}], 
             "*", "freqTypesf"}], ")"}], "\[Transpose]"}]}], " ", ";", " ", 
         "\n", "      \t\t\t", 
         RowBox[{"reprodMatrix", " ", "=", " ", 
          RowBox[{"reprodMatrix", "/", 
           RowBox[{"(", 
            RowBox[{"Total", "@", 
             RowBox[{"Total", "@", "reprodMatrix"}]}], ")"}]}]}], " ", ";", 
         " ", "\n", "      \t\t\t", 
         RowBox[{"Gfrs", " ", "=", " ", 
          RowBox[{
           RowBox[{"Total", "[", 
            RowBox[{"reprodMatrix", " ", "+", " ", 
             RowBox[{"reprodMatrix", "\[Transpose]"}]}], "]"}], "/", "2"}]}], 
         ";", "\n", "      ", "\n", "      \t\t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqGen", " ", ",", " ", "freqTypesfM"}], "]"}], ";", 
         " ", 
         RowBox[{"(*", " ", 
          RowBox[{
          "genotype", " ", "frequencies", " ", "after", " ", "mutation"}], 
          " ", "*)"}], "\n", "      \t\t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqGen", " ", ",", " ", "Gfrs"}], "]"}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{
          "genotype", " ", "frequencies", " ", "after", " ", "reproduction"}],
           " ", "*)"}], "\n", "      \t\t\t", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqGen", " ", ",", " ", "freqTypesf"}], "]"}], ";", 
         " ", 
         RowBox[{"(*", " ", 
          RowBox[{
          "genotype", " ", "frequencies", " ", "after", " ", "viability", " ",
            "selection"}], " ", "*)"}], "\n", "      ", "\n", "      \t\t\t", 
         
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToHap", "[", 
           RowBox[{"typesfM", ",", " ", "freqTypesfM", ",", " ", "Snumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqHap", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "haplotype", " ", "frequencies", " ", "after", " ", "mutation"}], 
          " ", "*)"}], "\n", "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToHap", "[", 
           RowBox[{"typesf", ",", " ", "Gfrs", ",", " ", "Snumber"}], "]"}]}],
          ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqHap", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "haplotype", " ", "frequencies", " ", "after", " ", 
           "reproduction"}], " ", "*)"}], "\n", "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToHap", "[", 
           RowBox[{"typesf", ",", " ", "freqTypesf", ",", " ", "Snumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqHap", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "haplotype", " ", "frequencies", " ", "after", " ", "viability", 
           " ", "selection"}], " ", "*)"}], "\n", "      ", "\n", 
         "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToClass", "[", 
           RowBox[{"typesfM", ",", " ", "freqTypesfM", ",", " ", "Snumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqClass", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "class", " ", "frequencies", " ", "after", " ", "mutation"}], " ", 
          "*)"}], "\n", "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToClass", "[", 
           RowBox[{"typesf", ",", " ", "Gfrs", ",", " ", "Snumber"}], "]"}]}],
          ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqClass", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "class", " ", "frequencies", " ", "after", " ", "reproduction"}], 
          " ", "*)"}], "\n", "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Hps", ",", " ", "Hfrs"}], "}"}], " ", "=", " ", 
          RowBox[{"GenToClass", "[", 
           RowBox[{"typesf", ",", " ", "freqTypesf", ",", " ", "Snumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqClass", " ", ",", " ", "Hfrs"}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "class", " ", "frequencies", " ", "after", " ", "viability", " ", 
           "selection"}], " ", "*)"}], "\n", "      ", "\n", "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "HpsC", ",", " ", "HfrsC", ",", " ", "HpsI", ",", " ", "HfrsI"}], 
           "}"}], " ", "=", " ", 
          RowBox[{"GenToClassCI", "[", 
           RowBox[{"typesfM", ",", " ", "freqTypesfM", ",", " ", "Snumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqClassC", " ", ",", " ", "HfrsC"}], "]"}], ";", " ", 
         
         RowBox[{"AppendTo", "[", 
          RowBox[{"mutFreqClassI", " ", ",", " ", "HfrsI"}], "]"}], ";", "\n",
          "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "HpsC", ",", " ", "HfrsC", ",", " ", "HpsI", ",", " ", "HfrsI"}], 
           "}"}], " ", "=", " ", 
          RowBox[{"GenToClassCI", "[", 
           RowBox[{"typesf", ",", " ", "Gfrs", ",", " ", "Snumber"}], "]"}]}],
          ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqClassC", " ", ",", " ", "HfrsC"}], "]"}], ";", 
         " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"reprodFreqClassI", " ", ",", " ", "HfrsI"}], "]"}], ";", 
         "\n", "      \t\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "HpsC", ",", " ", "HfrsC", ",", " ", "HpsI", ",", " ", "HfrsI"}], 
           "}"}], " ", "=", " ", 
          RowBox[{"GenToClassCI", "[", 
           RowBox[{"typesf", ",", " ", "freqTypesf", ",", " ", "Snumber"}], 
           "]"}]}], ";", " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqClassC", " ", ",", " ", "HfrsC"}], "]"}], ";", 
         " ", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"adultFreqClassI", " ", ",", " ", "HfrsI"}], "]"}], ";", 
         "\n", "      ", "\n", "      \t\t\t", 
         RowBox[{"CompStructTimeSimp", "[", "kk", "]"}], ";"}], "\n", 
        "      ", "\n", "      \t\t", ",", " ", 
        RowBox[{"{", 
         RowBox[{"kk", ",", " ", "1", ",", " ", "generations"}], "}"}]}], 
       "]"}], ";", "\n", "    ", "\n", "    \t\t", 
      RowBox[{"types", " ", "=", " ", 
       RowBox[{
        RowBox[{"Tally", "[", 
         RowBox[{"Sort", "@", "haps"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], " ", ";", "\n", 
      "    \t\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"SIcounts", ",", " ", "SCcounts"}], "}"}], " ", "=", " ", 
       RowBox[{"CompatibilityHaplotypesDiploidPart", "[", 
        RowBox[{"Fnumber", ",", " ", "Rnumber", ",", " ", "tD"}], "]"}]}], 
      ";", "\n", "    \t\t", 
      RowBox[{"InvasionFreq", " ", "=", " ", 
       RowBox[{"Mean", "[", 
        RowBox[{"N", "@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Total", "[", 
            RowBox[{"SIcounts", "\[Transpose]"}], "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", "popsize"}], ")"}]}], ")"}]}], "]"}]}], ";", 
      "\n", "    \t\t", 
      RowBox[{"InvasionTypes", " ", "=", " ", 
       RowBox[{"Mean", "[", 
        RowBox[{"N", "@", 
         RowBox[{"Total", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Unitize", "@", "SIcounts"}], ")"}], "\[Transpose]"}], 
          "]"}]}], "]"}]}], ";", "\n", "    \t\t", 
      RowBox[{"{", 
       RowBox[{
       "reprodFreqGen", ",", " ", "adultFreqGen", ",", " ", "reprodFreqHap", 
        ",", " ", "adultFreqHap", ",", " ", "reprodFreqClass", ",", " ", 
        "adultFreqClass", ",", " ", "reprodFreqClassC", ",", " ", 
        "reprodFreqClassI", ",", " ", "adultFreqClassC", " ", ",", " ", 
        "adultFreqClassI", ",", " ", "mutFreqGen", ",", " ", "mutFreqHap", 
        ",", " ", "mutFreqClass", " ", ",", " ", "mutFreqClassC", ",", " ", 
        "mutFreqClassI", ",", " ", "uniqsStore", ",", " ", "CStructureTimeF", 
        ",", " ", "CStructureTimeM"}], "}"}]}]}], "\n", "    ", 
    "]"}]}]}]], "Code",
 CellChangeTimes->{{3.723526293740756*^9, 3.723526299974514*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetClasses", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"List", " ", "of", " ", 
    RowBox[{"R", "'"}], "s", " ", "such", " ", "that", " ", "A", " ", 
    "haplotype", " ", "with", " ", "these", " ", 
    RowBox[{"R", "'"}], "s", " ", "exist", " ", "at", " ", "that", " ", 
    "time"}], " ", "*)"}], "\n", 
  RowBox[{"GetClasses", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{
      "Print", "[", "\"\<Clustering haplotypes to RNase classes\>\"", "]"}], 
      ";", "\n", "    \t", 
      RowBox[{"TypesTime", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"Length", "@", "CStructureTimeF"}], "}"}]}], "]"}]}], ";", 
      "\n", "    \t", 
      RowBox[{
       RowBox[{"Do", "[", "\n", "      \t\t", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"TypesTime", "[", 
            RowBox[{"[", "time", "]"}], "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Tally", "@", 
              RowBox[{"Flatten", "@", 
               RowBox[{"Haps", "[", 
                RowBox[{"[", 
                 RowBox[{"time", ",", " ", ";;", " ", ",", " ", "1"}], "]"}], 
                "]"}]}]}], ")"}], "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";"}], "\n", 
         "        \t", ",", " ", 
         RowBox[{"{", 
          RowBox[{"time", ",", " ", "1", ",", " ", "generations"}], "}"}]}], 
        "]"}], "\n", "      \t", 
       RowBox[{"{", "TypesTime", "}"}]}], ";"}]}], "\n", "    ", 
    "]"}]}]}]], "Code",
 CellChangeTimes->{{3.725625519630459*^9, 3.725625542075183*^9}, {
  3.725625785252223*^9, 3.72562581453115*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetSIClasses", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"First", " ", "obtain", " ", "the", " ", "list", " ", "of", " ", 
    RowBox[{"R", "'"}], "s", " ", "such", " ", "that", " ", "SI", " ", 
    "haplotype", " ", "with", " ", "these", " ", 
    RowBox[{"R", "'"}], "s", " ", "exist", " ", "at", " ", "that", " ", 
    "time"}], " ", "*)"}], "\n", 
  RowBox[{"GetSIClasses", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{
      "Print", "[", "\"\<Clustering haplotypes to RNase classes\>\"", "]"}], 
      ";", "\n", "    \t", 
      RowBox[{"SItypesTime", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"Length", "@", "CStructureTimeF"}], "}"}]}], "]"}]}], ";", 
      "\n", "    \t", 
      RowBox[{"SItypesTimeCount", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"Length", "@", "CStructureTimeF"}], "}"}]}], "]"}]}], ";", 
      "\n", "    \t", 
      RowBox[{
       RowBox[{"Do", "[", "\n", "        \t\t", 
        RowBox[{
         RowBox[{
          RowBox[{"OutputFreq", "[", "time", "]"}], ";", "\n", "        \t\t", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"FreqOut", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", " ", ";;"}], "]"}], "]"}], "]"}], " ", ">", 
             " ", "0"}], ",", "\n", "          \t\t\t", 
            RowBox[{
             RowBox[{
              RowBox[{"SItypesTime", "[", 
               RowBox[{"[", "time", "]"}], "]"}], " ", "=", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{"FreqOut", "\[Transpose]"}], ",", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", "!=", " ", "0"}], 
                    " ", "&"}]}], "]"}], "\[Transpose]"}], ")"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", 
             "          \t\t\t", 
             RowBox[{
              RowBox[{"SItypesTimeCount", "[", 
               RowBox[{"[", "time", "]"}], "]"}], " ", "=", " ", 
              RowBox[{"Length", "@", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Select", "[", 
                   RowBox[{
                    RowBox[{"FreqOut", "\[Transpose]"}], ",", " ", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", "!=", " ", "0"}], 
                    " ", "&"}]}], "]"}], "\[Transpose]"}], ")"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]}], "\n", 
           "          \t\t\t", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{
              RowBox[{"SItypesTime", "[", 
               RowBox[{"[", "time", "]"}], "]"}], " ", "=", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{"FreqOut", "\[Transpose]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "\[GreaterEqual]", 
                    "thresh1"}], " ", "&"}]}], "]"}], "\[Transpose]"}], ")"}],
                "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", 
             "          \t\t\t", 
             RowBox[{
              RowBox[{"SItypesTimeCount", "[", 
               RowBox[{"[", "time", "]"}], "]"}], " ", "=", " ", 
              RowBox[{"Length", "@", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Select", "[", 
                   RowBox[{
                    RowBox[{"FreqOut", "\[Transpose]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "\[GreaterEqual]", 
                    "thresh1"}], " ", "&"}]}], "]"}], "\[Transpose]"}], ")"}],
                 "[", 
                RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "*)"}], "\n", 
           "          \t\t", "]"}]}], "\n", "        \t", ",", " ", 
         RowBox[{"{", 
          RowBox[{"time", ",", " ", "1", ",", " ", 
           RowBox[{"Length", "@", "CStructureTimeF"}]}], "}"}]}], "]"}], "\n",
        "      \t", 
       RowBox[{"{", 
        RowBox[{"SItypesTime", ",", " ", "SItypesTimeCount"}], "}"}]}], 
      ";"}]}], "\n", "    ", "]"}]}]}]], "Code",
 CellChangeTimes->{{3.7256258444121723`*^9, 3.725625847444481*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetBDTimes", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Specify", " ", "times", " ", "when", " ", "the", " ", "new", " ", "SI", 
    " ", "class", " ", "appears"}], " ", "*)"}], "\n", 
  RowBox[{"GetBDTimes", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{
      "Print", "[", "\"\<Computing birth/death of S-alleles\>\"", "]"}], ";", 
      "\n", "    \t", 
      RowBox[{"FlagNewSItmp", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RTypes", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
           RowBox[{"Length", "@", "CStructureTimeF"}]}], "}"}]}], "]"}]}], 
      ";", "\n", "    \t", 
      RowBox[{"FlagNewSI", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", 
           RowBox[{"RTypes", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", "\n", 
      "    \t", 
      RowBox[{"events", " ", "=", " ", "generations"}], ";", "\n", "    \t", 
      RowBox[{"FlagBirth", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RTypes", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", " ", "events"}], "}"}]}], 
        "]"}]}], ";", " ", "\n", "    \t", 
      RowBox[{"FlagDeath", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RTypes", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", " ", "events"}], "}"}]}], 
        "]"}]}], ";", " ", "\n", "    ", "\n", "    \t", 
      RowBox[{"Do", "[", "\t", "\n", "      \t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"iB", " ", "=", " ", "1"}], ";", " ", 
         RowBox[{"iD", " ", "=", " ", "1"}], ";", "\n", "      ", "\n", 
         "      \t\t", 
         RowBox[{"Do", "[", "\n", "        \t\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{"If", "[", "  ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Length", "@", 
                 RowBox[{"Position", "[", 
                  RowBox[{
                   RowBox[{"SItypesTime", "[", 
                    RowBox[{"[", 
                    RowBox[{"time", " ", "-", " ", "1"}], "]"}], "]"}], ",", 
                   " ", "type"}], "]"}]}], " ", "==", " ", "0"}], " ", "&&", 
               " ", 
               RowBox[{
                RowBox[{"Length", "@", 
                 RowBox[{"Position", "[", 
                  RowBox[{
                   RowBox[{"SItypesTime", "[", 
                    RowBox[{"[", "time", "]"}], "]"}], ",", " ", "type"}], 
                  "]"}]}], " ", ">=", " ", "1"}]}], "  ", ",", " ", "\n", 
              "          \t\t\t\t", 
              RowBox[{
               RowBox[{
                RowBox[{"FlagNewSItmp", "[", 
                 RowBox[{"[", 
                  RowBox[{"type", ",", " ", "time"}], "]"}], "]"}], " ", "=", 
                " ", "type"}], ";", " ", "\n", "          \t\t\t\t", 
               RowBox[{
                RowBox[{"FlagBirth", "[", 
                 RowBox[{"[", 
                  RowBox[{"type", ",", " ", "iB"}], "]"}], "]"}], " ", "=", 
                " ", "time"}], ";", " ", 
               RowBox[{"iB", " ", "=", " ", 
                RowBox[{"iB", " ", "+", " ", "1"}]}]}]}], "]"}], ";", "\n", 
            "        \t\t\t", 
            RowBox[{"If", "[", "  ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Length", "@", 
                 RowBox[{"Position", "[", 
                  RowBox[{
                   RowBox[{"SItypesTime", "[", 
                    RowBox[{"[", 
                    RowBox[{"time", " ", "-", " ", "1"}], "]"}], "]"}], ",", 
                   " ", "type"}], "]"}]}], " ", ">=", "  ", "1"}], " ", "&&", 
               " ", 
               RowBox[{
                RowBox[{"Length", "@", 
                 RowBox[{"Position", "[", 
                  RowBox[{
                   RowBox[{"SItypesTime", "[", 
                    RowBox[{"[", "time", "]"}], "]"}], ",", " ", "type"}], 
                  "]"}]}], " ", "==", " ", "0"}]}], "  ", ",", " ", "\n", 
              "          \t\t\t\t", 
              RowBox[{
               RowBox[{
                RowBox[{"FlagNewSItmp", "[", 
                 RowBox[{"[", 
                  RowBox[{"type", ",", " ", "time"}], "]"}], "]"}], " ", "=", 
                " ", 
                RowBox[{"-", "type"}]}], ";", " ", "\n", "          \t\t\t\t", 
               RowBox[{
                RowBox[{"FlagDeath", "[", 
                 RowBox[{"[", 
                  RowBox[{"type", ",", " ", "iD"}], "]"}], "]"}], " ", "=", 
                " ", "time"}], ";", " ", 
               RowBox[{"iD", " ", "=", " ", 
                RowBox[{"iD", " ", "+", " ", "1"}]}]}]}], "]"}], ";"}], "\n", 
           "        \t\t", ",", " ", 
           RowBox[{"{", 
            RowBox[{"time", ",", " ", 
             RowBox[{"Length", "@", "CStructureTimeF"}], ",", " ", "2", ",", 
             " ", 
             RowBox[{"-", "1"}]}], "}"}]}], "]"}], ";", "\n", "   \t\t\t", 
         RowBox[{"If", "[", "\n", "    \t\t\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "@", 
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"SItypesTime", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", "type"}], "]"}]}], 
            " ", ">=", "  ", "1"}], ",", "\n", "    \t\t\t\t", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Print", "[", "type", "]"}], ";"}], "*)"}], "\n", 
           "    \t\t\t\t", 
           RowBox[{
            RowBox[{
             RowBox[{"FlagNewSItmp", "[", 
              RowBox[{"[", 
               RowBox[{"type", ",", " ", "1"}], "]"}], "]"}], " ", "=", " ", 
             "type"}], ";", " ", "\n", "    \t\t\t\t", 
            RowBox[{
             RowBox[{"FlagBirth", "[", 
              RowBox[{"[", 
               RowBox[{"type", ",", " ", "iB"}], "]"}], "]"}], " ", "=", " ", 
             "1"}], ";"}]}], " ", "\n", "    \t\t\t", "]"}], ";"}], "\n", 
        "      \t\t", 
        RowBox[{"(*", 
         RowBox[{"Print", "[", "FlagBirth", "]"}], "*)"}], "\n", "      \t", 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{"type", ",", " ", "1", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
      "    ", "\n", "    \t", 
      RowBox[{"TimeBirth", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", 
           RowBox[{"RTypes", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", "\n", 
      "    \t", 
      RowBox[{
       RowBox[{"TimeBirth", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", " ", ";;"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Range", "[", 
        RowBox[{"RTypes", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\n", "    \t", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"TimeBirth", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         RowBox[{"FlagBirth", "[", 
          RowBox[{"[", 
           RowBox[{"type", ",", " ", 
            RowBox[{"1", " ", ";;", " ", 
             RowBox[{"Length", "[", 
              RowBox[{"Select", "[", 
               RowBox[{
                RowBox[{"FlagBirth", "[", 
                 RowBox[{"[", "type", "]"}], "]"}], ",", " ", 
                RowBox[{
                 RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}]}], "]"}], 
              "]"}]}]}], "]"}], "]"}]}], "\n", "      \t", ",", " ", 
        RowBox[{"{", 
         RowBox[{"type", ",", " ", "1", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
      "    ", "\n", "    \t", 
      RowBox[{"TimeDeath", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", 
           RowBox[{"RTypes", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", "\n", 
      "    \t", 
      RowBox[{
       RowBox[{"TimeDeath", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", " ", ";;"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Range", "[", 
        RowBox[{"RTypes", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\n", "    \t", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"TimeDeath", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         RowBox[{"FlagDeath", "[", 
          RowBox[{"[", 
           RowBox[{"type", ",", " ", 
            RowBox[{"1", " ", ";;", " ", 
             RowBox[{"Length", "[", 
              RowBox[{"Select", "[", 
               RowBox[{
                RowBox[{"FlagDeath", "[", 
                 RowBox[{"[", "type", "]"}], "]"}], ",", " ", 
                RowBox[{
                 RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}]}], "]"}], 
              "]"}]}]}], "]"}], "]"}]}], "\n", "      \t", ",", " ", 
        RowBox[{"{", 
         RowBox[{"type", ",", " ", "1", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
      "    ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{
       "TimeBirth", ",", " ", "TimeDeath", ",", " ", "FlagBirth", ",", " ", 
        "FlagDeath"}], 
       RowBox[{"(*", 
        RowBox[{",", "FlagNewSI"}], "*)"}], "}"}]}]}], "\n", "    ", 
    "]"}]}]}]], "Code",
 CellChangeTimes->{{3.7256255610060863`*^9, 3.725625577276319*^9}, 
   3.725625858781513*^9}],

Cell[BoxData[
 RowBox[{"GetFreqUpDownTime", " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    \t", 
    RowBox[{
     RowBox[{"EquilFreq", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"generations", " ", "+", " ", "1"}], "}"}]}], "]"}]}], ";", 
     "\n", "    \t", 
     RowBox[{"EquilFreq", " ", "=", " ", 
      RowBox[{"0.3", "/", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"SItypesTimeCount", "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", " ", "2"}], "]"}], ",", " ", 
         
         RowBox[{"{", 
          RowBox[{"j", ",", " ", "1", ",", " ", 
           RowBox[{"Length", "@", "SItypesTimeCount"}]}], "}"}]}], "]"}]}]}], 
     ";", "\n", "    \t", 
     RowBox[{"TimeFreqUp", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"2", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", "\n", 
     "    \t", 
     RowBox[{"TimeFreqDown", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"2", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", "\n", 
     "    ", "\n", "    \t", 
     RowBox[{"Do", "[", "\n", "      \t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"OutputFreq", "[", "2", "]"}], ";", " ", 
        RowBox[{"freqPrev", " ", "=", " ", 
         RowBox[{"FreqOut", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}], ";", " ", "\n", 
        "      \t\t", 
        RowBox[{
         RowBox[{"TimeFreqUp", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", " ", 
        RowBox[{
         RowBox[{"TimeFreqDown", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", "\n", "      \t\t", 
        RowBox[{"timesUp", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"timesDown", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", "\t", "\n", "   ", "\n", "   \t\t\t", 
        RowBox[{"time", " ", "=", " ", "1"}], ";", "\n", "   \t\t\t", 
        RowBox[{"OutputFreq", "[", "time", "]"}], ";", "\n", "   \t\t\t", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"FreqOut", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", ">", " ", 
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", 
               RowBox[{"Max", "[", 
                RowBox[{
                 RowBox[{"SItypesTimeCount", "[", 
                  RowBox[{"[", "time", "]"}], "]"}], ",", " ", "2"}], "]"}]}],
               ")"}]}]}], ",", " ", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"timesUp", ",", " ", "time"}], "]"}], ";"}]}], "]"}], 
         "\n", "    ", "\n", "       \t\t", 
         RowBox[{"Do", "[", "\n", "         \t\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{"OutputFreq", "[", "time", "]"}], ";", "\n", 
            "         \t\t\t", 
            RowBox[{"If", "[", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"FreqOut", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", ">", 
                   " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", "time", "]"}], "]"}]}], ")"}], " ", "&&", 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{"freqPrev", " ", "<", " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", "time", "]"}], "]"}]}], ")"}]}], ")"}], " ", 
               "||", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"FreqOut", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", ">", 
                   " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", 
                    RowBox[{"time", " ", "-", " ", "1"}], "]"}], "]"}]}], 
                  ")"}], " ", "&&", " ", 
                 RowBox[{"(", 
                  RowBox[{"freqPrev", " ", "<", " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", 
                    RowBox[{"time", " ", "-", " ", "1"}], "]"}], "]"}]}], 
                  ")"}]}], ")"}]}], ",", "\n", "           \t\t\t\t", 
              RowBox[{
               RowBox[{"AppendTo", "[", 
                RowBox[{"timesUp", ",", " ", "time"}], "]"}], ";"}]}], "]"}], 
            ";", "\n", "         \t\t\t", 
            RowBox[{"If", "[", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"FreqOut", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "<", 
                   " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", "time", "]"}], "]"}]}], ")"}], " ", "&&", 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{"freqPrev", " ", ">", " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", "time", "]"}], "]"}]}], ")"}]}], ")"}], " ", 
               "||", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"FreqOut", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "<", 
                   " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", 
                    RowBox[{"time", " ", "-", " ", "1"}], "]"}], "]"}]}], 
                  ")"}], " ", "&&", " ", 
                 RowBox[{"(", 
                  RowBox[{"freqPrev", " ", ">", " ", 
                   RowBox[{"EquilFreq", "[", 
                    RowBox[{"[", 
                    RowBox[{"time", " ", "-", " ", "1"}], "]"}], "]"}]}], 
                  ")"}]}], ")"}]}], ",", "\n", "           \t\t\t\t", 
              RowBox[{
               RowBox[{"AppendTo", "[", 
                RowBox[{"timesDown", ",", " ", "time"}], "]"}], ";"}]}], 
             "]"}], ";", "\n", "         \t\t", 
            RowBox[{
             RowBox[{"TimeFreqUp", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
             "timesUp"}], ";", "\n", "         \t\t", 
            RowBox[{
             RowBox[{"TimeFreqDown", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
             "timesDown"}], ";", "\n", "         \t\t", 
            RowBox[{"freqPrev", " ", "=", " ", 
             RowBox[{"FreqOut", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}], ";"}], "\n", 
           "         \t\t", ",", " ", 
           RowBox[{"{", 
            RowBox[{"time", ",", " ", "3", ",", " ", "generations"}], "}"}]}],
           "]"}]}]}], "\n", "      \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"type", ",", " ", "1", ",", " ", 
         RowBox[{"RTypes", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
     "    \t", 
     RowBox[{"{", 
      RowBox[{"TimeFreqUp", ",", " ", "TimeFreqDown"}], "}"}]}]}], "\n", 
   "    ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetBornHaps", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Haplotype", " ", "of", " ", "all", " ", "the", " ", "new", " ", "SI", " ",
     "guys"}], "*)"}], "\n", 
  RowBox[{"GetBornHaps", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"Print", "[", "\"\<Computing founder haplotypes\>\"", "]"}], 
      ";", "\n", "    \t", 
      RowBox[{"BornHaps", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", 
           RowBox[{"RTypes", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", "\n", 
      "    \t", 
      RowBox[{"Do", "[", "\n", "      \t\t", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"BornHaps", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
          "type"}], ";", "\n", "      \t\t", 
         RowBox[{"newhaps", " ", "=", " ", 
          RowBox[{"{", "}"}]}], ";", "\n", "      \t\t", 
         RowBox[{"Do", "[", "\n", "        \t\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{"time", " ", "=", " ", 
             RowBox[{"FlagBirth", "[", 
              RowBox[{"[", 
               RowBox[{"type", ",", " ", "event"}], "]"}], "]"}]}], ";", "\n",
             "        \t\t\t", 
            RowBox[{"OutputFreqAB", "[", 
             RowBox[{"time", ",", " ", "type"}], "]"}], ";", " ", "\n", 
            "        \t\t\t", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"newhaps", ",", " ", 
              RowBox[{
               RowBox[{"typesA2", "[", 
                RowBox[{"[", 
                 RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\n", 
           "        \t\t", ",", " ", 
           RowBox[{"{", 
            RowBox[{"event", ",", " ", "1", ",", " ", 
             RowBox[{"Length", "[", 
              RowBox[{"Select", "[", 
               RowBox[{
                RowBox[{"FlagBirth", "[", 
                 RowBox[{"[", "type", "]"}], "]"}], ",", " ", 
                RowBox[{
                 RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}]}], "]"}], 
              "]"}]}], "}"}]}], "]"}], ";", "\n", "      \t\t", 
         RowBox[{
          RowBox[{"BornHaps", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
          "newhaps"}], ";"}], "\n", "      \t", ",", " ", 
        RowBox[{"{", 
         RowBox[{"type", ",", " ", "1", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
      "    \t", "BornHaps"}]}], "\n", "    ", "]"}]}]}]], "Code",
 CellChangeTimes->{{3.7256261023560677`*^9, 3.725626119882316*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetDeadHaps", "Subsubsection"],

Cell[BoxData[
 RowBox[{"GetDeadHaps", " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"Print", "[", "\"\<Computing last survivors\>\"", "]"}], ";", 
     "\n", "    \t", 
     RowBox[{"DeadHaps", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"2", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", "\n", 
     "    \t", 
     RowBox[{"Do", "[", "\n", "      \t\t", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"DeadHaps", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", "\n", "      \t\t", 
        RowBox[{"oldhaps", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", "\n", "      \t\t", 
        RowBox[{"Do", "[", "\n", "        \t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{"time", " ", "=", " ", 
            RowBox[{
             RowBox[{"TimeDeath", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], "[", 
             RowBox[{"[", "event", "]"}], "]"}]}], ";", "\n", 
           "        \t\t\t", 
           RowBox[{"OutputFreqAB", "[", 
            RowBox[{
             RowBox[{"time", " ", "-", " ", "1"}], ",", " ", "type"}], "]"}], 
           ";", " ", "\n", "        \t\t\t", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"oldhaps", ",", " ", 
             RowBox[{
              RowBox[{"typesA2", "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\n", 
          "        \t\t", ",", " ", 
          RowBox[{"{", 
           RowBox[{"event", ",", " ", "1", ",", " ", 
            RowBox[{"Length", "[", 
             RowBox[{"TimeDeath", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], "]"}]}], 
           "}"}]}], "]"}], ";", "\n", "      \t\t", 
        RowBox[{
         RowBox[{"DeadHaps", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "oldhaps"}], ";"}], "\n", "      \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"type", ",", " ", "1", ",", " ", 
         RowBox[{"RTypes", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
     "    \t", "DeadHaps"}]}], "\n", "    ", "]"}]}]], "Code",
 CellChangeTimes->{{3.725626126689871*^9, 3.725626143041423*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetAncestors", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetAncestors", "[", 
   RowBox[{"TimeEvent_", ",", " ", "HapEvent_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    \t", 
    RowBox[{
     RowBox[{"ancestorHap", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"2", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], ";", " ", "\n",
      "    \t", 
     RowBox[{"ancestorType", " ", "=", " ", "ancestorHap"}], ";", " ", "\n", 
     "    \t", 
     RowBox[{"ancestorComp", " ", "=", " ", "ancestorHap"}], ";", " ", "\n", 
     "    \t", 
     RowBox[{"ancestorFreq", " ", "=", " ", "ancestorHap"}], ";", "\n", 
     "    \t", 
     RowBox[{"ancestorSIfreq", " ", "=", " ", "ancestorHap"}], ";", "\n", 
     "    \t", 
     RowBox[{"ancestorFreqs", " ", "=", " ", "ancestorHap"}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"frequency", " ", 
        RowBox[{"of", ":", " ", 
         RowBox[{"SC", " ", "new", " ", "type"}]}]}], ",", " ", 
       RowBox[{"SC", " ", "other", " ", "type"}], ",", " ", 
       RowBox[{"SI", " ", "other", " ", "type"}]}], " ", "*)"}], "\n", 
     "    \t", 
     RowBox[{"freqF", " ", "=", " ", "ancestorHap"}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "frequency", " ", "of", " ", "the", " ", "F", " ", "to", " ", "the", 
       " ", "newlu", " ", "formed", " ", "R"}], " ", "*)"}], "\n", "    \t", 
     RowBox[{"Do", "[", "\n", "      \t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"ancestorHap1", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"ancestorType1", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"ancestorComp1", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"ancestorFreq1", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"ancestorSIfreq1", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"ancestorFreqs1", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"freqF1", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", "\n", "      \t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"type", " ", "=", " ", "3"}], ";"}], " ", "*)"}], 
        RowBox[{"(*", 
         RowBox[{"Print", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<type=\>\"", ",", "type", ",", "\"\<events=\>\"", ",", 
            RowBox[{"Length", "@", 
             RowBox[{"TimeBirth", "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "type"}], "\[RightDoubleBracket]"}]}]}], 
           "}"}], "]"}], "*)"}], "\n", "      \t\t", 
        RowBox[{"Do", "[", "\n", "        \t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{"ancestorHap0", " ", "=", " ", 
            RowBox[{"{", "}"}]}], ";", " ", 
           RowBox[{"ancestorType0", " ", "=", " ", 
            RowBox[{"{", "}"}]}], ";", " ", 
           RowBox[{"ancestorComp0", " ", "=", " ", 
            RowBox[{"{", "}"}]}], ";", " ", 
           RowBox[{"ancestorFreq0", " ", "=", " ", 
            RowBox[{"{", "}"}]}], ";", " ", 
           RowBox[{"ancestorSIfreq0", " ", "=", " ", 
            RowBox[{"{", "}"}]}], ";", " ", 
           RowBox[{"ancestorFreqs0", " ", "=", " ", 
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0", ",", " ", "0", ",", " ", "0"}], 
             "}"}]}], ";", " ", 
           RowBox[{"freqF0", " ", "=", " ", "0"}], ";", "\n", 
           "        \t\t\t", 
           RowBox[{"time", " ", "=", " ", 
            RowBox[{
             RowBox[{"TimeEvent", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], "[", 
             RowBox[{"[", "event", "]"}], "]"}]}], ";", " ", 
           RowBox[{"(*", " ", 
            RowBox[{"time", " ", "of", " ", "the", " ", "event"}], " ", 
            "*)"}], "\n", "        \t\t\t", 
           RowBox[{"newhap", " ", "=", " ", 
            RowBox[{
             RowBox[{"HapEvent", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], "[", 
             RowBox[{"[", "event", "]"}], "]"}]}], ";", " ", 
           RowBox[{"(*", " ", 
            RowBox[{"new", " ", "SI", " ", "haplotype"}], " ", "*)"}], "\n", 
           "        \t\t\t", "\n", "    \t\t\t\t", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{
             "If", " ", "born", " ", "at", " ", "the", " ", "beginning", " ", 
              "of", " ", "the", " ", "simulation"}], " ", "-", " ", 
             RowBox[{"set", " ", "ancestor", " ", "as", " ", "itself"}]}], 
            " ", "*)"}], "\n", "    \t\t\t\t", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"time", " ", "==", " ", "1"}], ",", "\n", 
              "      \t\t\t\t\t", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"Print", "[", "type", "]"}], ";"}], "*)"}], "\n", 
              "      \t\t\t\t\t", 
              RowBox[{
               RowBox[{"ancestor", " ", "=", " ", "newhap"}], ";", "\n", 
               "      \t\t\t\t\t", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"ancestorHap0", ",", " ", "ancestor"}], "]"}], ";", 
               "\n", "      \t\t\t\t\t", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"ancestorType0", ",", " ", 
                 RowBox[{"ancestor", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", "\n", 
               "      \t\t\t\t\t", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"ancestorComp0", ",", " ", 
                 RowBox[{"Boole", "@", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
               "\n", "      \t\t\t\t\t", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"ancestorFreq0", ",", " ", 
                 RowBox[{
                  RowBox[{"1", "/", "2."}], "/", "popsize"}]}], "]"}], ";", 
               "\n", "      \t\t\t\t\t", 
               RowBox[{"ancestorFreqs0", " ", "=", " ", 
                RowBox[{"{", 
                 RowBox[{"0", ",", " ", "0", ",", " ", "0", ",", " ", "1"}], 
                 "}"}]}], ";", "\n", "      \t\t\t\t\t", 
               RowBox[{"ancestorSIfreq0", " ", "=", " ", "1"}], ";"}], "\n", 
              "      \t\t\t\t\t", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"Print", "[", "newhap", "]"}], ";", "\n", 
                "      \t\t\t\t\t", 
                RowBox[{"Print", "[", "ancestorHap0", "]"}], ";", "\n", 
                "      \t\t\t\t\t", 
                RowBox[{"Print", "[", "ancestorComp0", "]"}], ";", "\n", 
                "      \t\t\t\t\t", 
                RowBox[{"Print", "[", "ancestorFreq0", "]"}], ";"}], "*)"}], 
              "\n", "      \t\t\t\t\t", ",", "\n", "      \t\t\t\t", "\n", 
              "      ", "\n", "      \t\t\t\t\t", 
              RowBox[{
               RowBox[{"hapTime", " ", "=", " ", 
                RowBox[{
                 RowBox[{"Tally", "[", 
                  RowBox[{"Haps", "[", 
                   RowBox[{"[", 
                    RowBox[{"time", " ", "-", " ", "1"}], "]"}], "]"}], "]"}],
                  "[", 
                 RowBox[{"[", 
                  RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", 
               " ", 
               RowBox[{"(*", " ", 
                RowBox[{
                 RowBox[{"all", " ", "haps", " ", "at", " ", "t"}], "-", 
                 "1"}], " ", "*)"}], "\n", "          \t\t\t", "\n", 
               "          \t\t\t\t", 
               RowBox[{"A", " ", "=", " ", 
                RowBox[{"Tally", "[", 
                 RowBox[{"Haps", "[", 
                  RowBox[{"[", "time", "]"}], "]"}], "]"}]}], ";", "\n", 
               "          \t\t\t\t", 
               RowBox[{"Do", "[", "\n", "            \t\t\t\t\t", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Length", "@", 
                    RowBox[{"Position", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"A", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", 
                    RowBox[{"2", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}]}], " ", ">", " ", "0"}], ",", "\n", 
                   "              \t\t\t\t\t\t", 
                   RowBox[{
                    RowBox[{"freqF0", " ", "=", " ", 
                    RowBox[{"freqF0", " ", "+", " ", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"A", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}], "/", "2."}], "/", 
                    "popsize"}]}]}], ";"}]}], "\n", 
                  "              \t\t\t\t\t", "]"}], "\n", 
                 "            \t\t\t\t", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", " ", "1", ",", " ", 
                   RowBox[{"Length", "@", "A"}]}], "}"}]}], "]"}], ";", "\n", 
               "          ", "\n", "          \t\t\t\t", 
               RowBox[{"Do", "[", "\n", "            \t\t\t\t\t", 
                RowBox[{"(*", 
                 RowBox[{"Print", "[", 
                  RowBox[{"Length", "@", 
                   RowBox[{"Position", "[", 
                    RowBox[{
                    RowBox[{"hapTime", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", 
                    RowBox[{"2", ";;"}]}], "]"}], "]"}], ",", "type"}], 
                    "]"}]}], "]"}], "*)"}], "\n", "            ", "\n", 
                "            \t\t\t\t\t", 
                RowBox[{
                 RowBox[{
                  RowBox[{"If", "[", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"hapTime", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "-", " ", "newhap"}],
                     ",", " ", "0"}], "]"}], " ", "==", " ", 
                    RowBox[{"SLength", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
                    RowBox[{"(*", " ", 
                    RowBox[{"differ", " ", "by", " ", "one", " ", "F"}], " ", 
                    "*)"}], "\n", "                \t\t\t\t\t\t", 
                    RowBox[{
                    RowBox[{"ancestor", " ", "=", " ", 
                    RowBox[{"hapTime", "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ";", "\n", 
                    "                \t\t\t\t\t\t", 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<time=\>\"", ",", "time", ",", " ", "\"\<event=\>\"", 
                    ",", "event", ",", "\"\<saving\>\"", ",", "ancestor"}], 
                    "}"}], "]"}], ";"}], "*)"}], "\n", 
                    "                \t\t\t\t\t\t", 
                    RowBox[{"OutputFreqAB", "[", 
                    RowBox[{
                    RowBox[{"time", " ", "-", " ", "1"}], ",", " ", 
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", " ", 
                    RowBox[{"(*", " ", 
                    RowBox[{
                    "frequencies", " ", "of", " ", "the", " ", "given", " ", 
                    "R", " ", "at", " ", "the", " ", "given", " ", "time"}], 
                    " ", "*)"}], "\n", "                \t\t\t\t\t\t", 
                    RowBox[{"typesAll", " ", "=", " ", 
                    RowBox[{"Join", "[", 
                    RowBox[{"typesA2", ",", " ", "typesB2"}], "]"}]}], ";", 
                    "\n", "                \t\t\t\t\t\t", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"ancestorHap0", ",", " ", "ancestor"}], "]"}], 
                    ";", "\n", "                \t\t\t\t\t\t", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"ancestorType0", ",", " ", 
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", "\t\t\t\t", 
                    "\n", "                \t\t\t\t\t\t", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"ancestorComp0", ",", " ", 
                    RowBox[{"Boole", "@", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
                    "\n", "                \t\t\t\t\t\t", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"ancestorFreq0", ",", " ", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"typesAll", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Flatten", "@", 
                    RowBox[{"Position", "[", 
                    RowBox[{"typesAll", ",", " ", "ancestor"}], "]"}]}], 
                    ")"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", " ", "2"}], "]"}], 
                    "]"}], "/", "2."}], "/", "popsize"}]}], "]"}], ";", "\n", 
                    "                ", "\n", "                \t\t\t\t\t\t", 
                    
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", 
                    RowBox[{"newhap", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"ancestorFreqs0", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "=", " ", 
                    RowBox[{
                    RowBox[{"ancestorFreqs0", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", 
                    RowBox[{"\[Mu]F", "*", 
                    RowBox[{"ancestorFreq0", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}], "*", 
                    RowBox[{"ancestorComp0", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}]}]}]}]}], "]"}], ";", 
                    RowBox[{"(*", " ", 
                    RowBox[{"compatible", ",", " ", 
                    RowBox[{"same", " ", "R"}]}], " ", "*)"}], "\n", 
                    "                \t\t\t\t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "!=", " ", 
                    RowBox[{"newhap", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"ancestorFreqs0", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", "=", " ", 
                    RowBox[{
                    RowBox[{"ancestorFreqs0", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", "+", " ", 
                    RowBox[{"\[Mu]R", "*", 
                    RowBox[{"ancestorFreq0", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}], "*", 
                    RowBox[{"ancestorComp0", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}]}]}]}]}], "]"}], ";", 
                    RowBox[{"(*", " ", 
                    RowBox[{"compatible", ",", " ", 
                    RowBox[{"different", " ", "R"}]}], " ", "*)"}], "\n", 
                    "                \t\t\t\t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ancestor", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "!=", " ", 
                    RowBox[{"newhap", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"ancestorFreqs0", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], " ", "=", " ", 
                    RowBox[{
                    RowBox[{"ancestorFreqs0", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], " ", "+", " ", 
                    RowBox[{"\[Mu]R", "*", 
                    RowBox[{"ancestorFreq0", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{"1", " ", "-", " ", 
                    RowBox[{"ancestorComp0", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}]}], ")"}]}]}]}]}], "]"}], 
                    ";"}]}], " ", 
                   RowBox[{"(*", " ", 
                    RowBox[{"incompatible", ",", " ", 
                    RowBox[{"different", " ", "R"}]}], " ", "*)"}], "\t", 
                   "\n", "                \t\t\t\t\t", "]"}], ";"}], "\n", 
                 "            \t\t\t\t", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", " ", "1", ",", " ", 
                   RowBox[{"Length", "@", "hapTime"}]}], "}"}]}], "]"}], ";", 
               "\n", "          ", "\n", "          \t\t\t\t", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Length", "@", "ancestorFreq0"}], " ", ">", " ", 
                   "0"}], ",", "\n", "              \t\t\t\t\t", 
                  RowBox[{
                   RowBox[{"ancestorSIfreq0", " ", "=", " ", 
                    RowBox[{
                    RowBox[{"Total", "[", 
                    RowBox[{"\[Mu]R", "*", "ancestorFreq0", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", " ", "-", " ", "ancestorComp0"}], ")"}]}], 
                    "]"}], "/", 
                    RowBox[{"Total", "[", 
                    RowBox[{
                    RowBox[{"\[Mu]R", "*", "ancestorFreq0", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", " ", "-", " ", "ancestorComp0"}], ")"}]}], 
                    " ", "+", " ", 
                    RowBox[{"\[Mu]F", "*", "ancestorFreq0", "*", 
                    RowBox[{"(", "ancestorComp0", ")"}]}]}], "]"}]}]}], 
                   ";"}]}], "\n", "              \t\t\t\t", "]"}], "\n", 
                "            \t\t\t\t", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Total", "@", "ancestorFreqs0"}], " ", ">", " ", 
                   "0"}], ",", "\n", "              \t\t\t\t\t", 
                  RowBox[{
                   RowBox[{"ancestorFreqs0", " ", "=", " ", 
                    RowBox[{"ancestorFreqs0", "/", 
                    RowBox[{"Total", "@", "ancestorFreqs0"}]}]}], ";"}], ",", 
                  "\n", "              \t\t\t\t\t", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"ancestorFreqs0", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], " ", "=", " ", "1"}], 
                   ";"}]}], "\n", "              \t\t\t\t", "]"}]}]}]}], "\n",
              "      \t\t\t\t", "]"}], "\n", "          \t\t\t", "\n", 
            "          ", "\n", "     \t\t\t", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"ancestorHap1", ",", " ", "ancestorHap0"}], "]"}]}], ";",
            "\n", "        \t\t", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ancestorType1", ",", " ", 
             RowBox[{"Flatten", "@", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Tally", "@", "ancestorType0"}], ")"}], "[", 
               RowBox[{"[", 
                RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}]}], "]"}], 
           ";", "\n", "        \t\t", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ancestorComp1", ",", " ", "ancestorComp0"}], "]"}], ";", 
           "\n", "        \t\t", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ancestorFreq1", ",", " ", "ancestorFreq0"}], "]"}], ";", 
           "\n", "        \t\t", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ancestorSIfreq1", ",", " ", "ancestorSIfreq0"}], "]"}], 
           ";", "\n", "        \t\t", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ancestorFreqs1", ",", " ", "ancestorFreqs0"}], "]"}], 
           ";", "\n", "        \t\t", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"freqF1", ",", " ", "freqF0"}], "]"}], ";"}], "\n", 
          "    ", "\n", "        \t\t", ",", " ", 
          RowBox[{"{", 
           RowBox[{"event", ",", " ", "1", ",", " ", 
            RowBox[{"Length", "@", 
             RowBox[{"TimeEvent", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}]}], "}"}]}], 
         "]"}], ";", " ", "\n", "      ", "\n", "      \t\t", 
        RowBox[{
         RowBox[{"ancestorHap", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorType", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorComp", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorFreq", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorSIfreq", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorFreqs", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", " ", 
        RowBox[{
         RowBox[{"freqF", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "type"}], ";", "\n", "      \t\t", 
        RowBox[{
         RowBox[{"ancestorHap", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "ancestorHap1"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorType", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "ancestorType1"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorComp", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "ancestorComp1"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorFreq", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "ancestorFreq1"}], ";", " ", 
        RowBox[{
         RowBox[{"ancestorFreqs", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "ancestorFreqs1"}], ";", " ", "\n", "      \t\t", 
        RowBox[{
         RowBox[{"ancestorSIfreq", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "ancestorSIfreq1"}], ";", "\n", "      \t\t", 
        RowBox[{
         RowBox[{"freqF", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], " ", "=", " ", 
         "freqF1"}], ";"}], " ", "\n", "      ", "\n", "      \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"type", ",", " ", "1", ",", " ", 
         RowBox[{"RTypes", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
     "    \t", 
     RowBox[{"{", 
      RowBox[{
      "ancestorHap", ",", " ", "ancestorType", ",", " ", "ancestorComp", ",", 
       " ", "ancestorFreq", ",", " ", "ancestorSIfreq", ",", " ", 
       "ancestorFreqs", ",", " ", "freqF"}], "}"}]}]}], "\n", "    ", 
   "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["Annotate", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Annotate", "[", 
   RowBox[{
   "times_", ",", " ", "state_", ",", " ", "type_", ",", " ", "anc_"}], "]"}],
   " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    \t", 
    RowBox[{
     RowBox[{"events", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"times", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}], ",", " ", "3"}],
          "}"}]}], "]"}]}], ";", "\n", "    \t", 
     RowBox[{
      RowBox[{"events", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], " ", "=", " ", 
      RowBox[{"times", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}], ";", " ", "\n", 
     "    \t", 
     RowBox[{
      RowBox[{"events", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}], " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"state", ",", " ", 
        RowBox[{"Dimensions", "@", 
         RowBox[{"times", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}]}], "]"}]}], ";", 
     "\n", "    \t", 
     RowBox[{"tmp", " ", "=", " ", 
      RowBox[{"{", "0", "}"}]}], ";", "\n", "    \t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"state", " ", "==", " ", "1"}], ",", "\n", "      \t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"anc", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}], " ", "==", " ", 
          "1"}], ",", "\n", "        \t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"[", "1", "]"}], "]"}], " ", "=", " ", 
           RowBox[{"anc", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}], ";", "\n", 
          "        \t\t\t", 
          RowBox[{
           RowBox[{"events", "[", 
            RowBox[{"[", 
             RowBox[{";;", " ", ",", " ", "3"}], "]"}], "]"}], " ", "=", " ", 
           
           RowBox[{"{", "tmp", "}"}]}], ";"}]}], " ", "\n", "        \t\t", 
        "]"}]}], "\n", "      \t", "]"}], ";", "\n", "    \t", 
     RowBox[{"Do", "[", "\n", "      \t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"state", " ", "==", " ", "1"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"events", "[", 
             RowBox[{"[", 
              RowBox[{";;", " ", ",", " ", "3"}], "]"}], "]"}], " ", "=", " ", 
            RowBox[{
             RowBox[{"anc", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
       "      \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", 
          RowBox[{"anc", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", " ", "type"}], "]"}], "]"}]}]}], "}"}]}], "]"}],
      ";", "\n", "    \t", "events"}]}], "\n", "    ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetSIavg", "Subsubsection"],

Cell[BoxData[
 RowBox[{"GetSIavg", " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "    \t", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"thresh", " ", "=", " ", "0.02"}], ";"}], "*)"}], "\n", 
    "    \t", 
    RowBox[{
     RowBox[{"SItypesTimeCount", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"Length", "@", "CStructureTimeF"}], "}"}]}], "]"}]}], ";", 
     "\n", "    \t", 
     RowBox[{"Do", "[", "\n", "      \t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"OutputFreq", "[", "time", "]"}], ";", "\n", "      \t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"FreqOut", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", " ", ";;"}], "]"}], "]"}], "]"}], " ", ">", 
           " ", "thresh2"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"SItypesTimeCount", "[", 
             RowBox[{"[", "time", "]"}], "]"}], " ", "=", " ", 
            RowBox[{"Length", "@", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{
                  RowBox[{"FreqOut", "\[Transpose]"}], ",", " ", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", ">=", " ", 
                    "thresh2"}], " ", "&"}]}], "]"}], "\[Transpose]"}], ")"}],
               "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]}], "]"}]}], "\n", 
       "      \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"time", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", "CStructureTimeF"}]}], "}"}]}], "]"}], ";", 
     "\t", "\n", "    ", 
     RowBox[{"SIavg", " ", "=", " ", 
      RowBox[{"N", "@", 
       RowBox[{"Mean", "@", 
        RowBox[{"SItypesTimeCount", "[", 
         RowBox[{"[", 
          RowBox[{"Tavg", " ", ";;"}], "]"}], "]"}]}]}]}]}]}], "\n", "    ", 
   "]"}]}]], "Code"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot", "Subsection"],

Cell[CellGroupData[{

Cell["PlotTabs", "Subsubsection",
 CellChangeTimes->{{3.721122870640935*^9, 3.721122886927369*^9}, {
   3.7219955014351883`*^9, 3.721995502824703*^9}, 3.723526776177511*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotTabs", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "  \t", 
     RowBox[{
      RowBox[{"color0", " ", "=", " ", "Gray"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"when", " ", "incomplete"}], " ", "<", 
        RowBox[{"50", " ", "generations"}]}], " ", "*)"}], "\n", "  \t", 
      RowBox[{"color1", " ", "=", " ", "Green"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "when", " ", "incomplete", " ", "more", " ", "than", " ", "50", " ", 
        "generations"}], " ", "*)"}], "\n", "  \t", 
      RowBox[{"th", " ", "=", " ", "0.003"}], ";", "\n", "  ", "\n", "  \t", 
      RowBox[{"tbls", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"ind", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", "  \t", 
      RowBox[{"Do", "[", "\n", "   \t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"Bevents", " ", "=", " ", 
          RowBox[{"Annotate", "[", 
           RowBox[{
           "TimeBirth", ",", " ", "1", ",", " ", "type", ",", " ", 
            "ancestorType"}], "]"}]}], ";", "\n", "   \t\t", 
         RowBox[{"Devents", " ", "=", " ", 
          RowBox[{"Annotate", "[", 
           RowBox[{"TimeDeath", ",", " ", 
            RowBox[{"-", "1"}], ",", " ", "type", ",", " ", "ancestorType"}], 
           "]"}]}], ";", "\n", "   \t\t", 
         RowBox[{"StateSeq", " ", "=", " ", 
          RowBox[{"Sort", "@", 
           RowBox[{"Join", "[", 
            RowBox[{"Bevents", ",", " ", "Devents"}], "]"}]}]}], ";", "\n", 
         "\n", "           ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "@", "StateSeq"}], " ", ">", " ", "0"}], ",", 
           "\n", "    \t\t\t", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"StateSeq", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", " ", "2"}], "]"}], "]"}], " ", "==",
                " ", "1"}], ",", " ", 
              RowBox[{
               RowBox[{"AppendTo", "[", 
                RowBox[{"StateSeq", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"generations", ",", " ", 
                   RowBox[{"-", "1"}], ",", " ", 
                   RowBox[{"{", "type", "}"}]}], "}"}]}], "]"}], ";"}]}], 
             "]"}], ";", "\n", "    \t\t\t", 
            RowBox[{"state", " ", "=", " ", "1"}], ";", " ", 
            RowBox[{"tblB", " ", "=", " ", 
             RowBox[{"{", "}"}]}], ";", " ", "\n", "    \t\t\t\t", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "@", 
                RowBox[{"Position", "[", 
                 RowBox[{
                  RowBox[{"StateSeq", "[", 
                   RowBox[{"[", 
                    RowBox[{";;", " ", ",", " ", "2"}], "]"}], "]"}], ",", 
                  " ", "1"}], "]"}]}], " ", ">", " ", "0"}], ",", "\n", 
              "     \t\t\t\t\t", 
              RowBox[{
               RowBox[{"Do", "[", "\n", "     \t\t\t\t\t\t", 
                RowBox[{
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "2"}], "]"}], "]"}], " ", "==", 
                    " ", "state"}], ",", " ", "\n", "     \t\t\t\t\t\t\t", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"k", " ", "+", " ", "1"}], ",", " ", "1"}], "]"}],
                     "]"}], "-", 
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}]}], " ", "<", 
                    " ", "100"}], ",", "\n", "     \t\t\t\t\t\t\t\t", 
                    RowBox[{"tblB", " ", "=", " ", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"tblB", ",", " ", 
                    RowBox[{"ListPlot", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"k", " ", "+", " ", "1"}], ",", " ", "1"}], "]"}],
                     "]"}]}], "}"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"type", ",", " ", "type"}], "}"}]}], "}"}], 
                    "\[Transpose]"}], ",", " ", 
                    RowBox[{"PlotStyle", " ", "->", " ", 
                    RowBox[{"{", 
                    RowBox[{"color0", ",", " ", 
                    RowBox[{"Thickness", "\[Rule]", 
                    RowBox[{"th", "*", 
                    RowBox[{"2", "/", "3"}]}]}]}], "}"}]}], ",", " ", 
                    RowBox[{"Joined", " ", "->", " ", "True"}]}], "]"}]}], 
                    "]"}]}]}], "]"}], ";", "\n", "     \t\t\t\t\t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"k", " ", "+", " ", "1"}], ",", " ", "1"}], "]"}],
                     "]"}], "-", 
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}]}], " ", ">", 
                    " ", "100"}], ",", "\n", "     \t\t\t\t\t\t\t\t", 
                    RowBox[{"tblB", " ", "=", " ", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"tblB", ",", " ", 
                    RowBox[{"ListPlot", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"StateSeq", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"k", " ", "+", " ", "1"}], ",", " ", "1"}], "]"}],
                     "]"}]}], "}"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"type", ",", " ", "type"}], "}"}]}], "}"}], 
                    "\[Transpose]"}], ",", " ", 
                    RowBox[{"PlotStyle", " ", "->", " ", 
                    RowBox[{"{", 
                    RowBox[{"color1", ",", " ", 
                    RowBox[{"Thickness", "\[Rule]", "th"}]}], "}"}]}], ",", 
                    " ", 
                    RowBox[{"Joined", " ", "->", " ", "True"}]}], "]"}]}], 
                    "]"}]}]}], "]"}], ";"}]}], "\n", "     \t\t\t\t\t\t", 
                   "]"}], ";"}], "\n", "     \t\t\t\t\t", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", " ", "1", ",", " ", 
                   RowBox[{
                    RowBox[{"Length", "@", "StateSeq"}], " ", "-", " ", 
                    "1"}]}], "}"}]}], "]"}], ";"}]}], "\n", "     \t\t\t\t", 
             "]"}], ";", "\n", "    \t\t\t", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "@", "tblB"}], " ", ">", " ", "0"}], ",", 
              " ", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"tbls", ",", " ", "tblB"}], "]"}]}], "]"}], ";"}], 
           "\n", "    \t\t", ",", " ", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ind", ",", " ", "type"}], "]"}]}], "]"}], ";"}], "\n", 
        "   \t", ",", " ", 
        RowBox[{"{", 
         RowBox[{"type", ",", " ", "1", ",", " ", 
          RowBox[{"RTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "\n", "   \t", "]"}], 
      ";"}]}], "\n", "  ", "]"}]}], "\n"}]], "Code",
 CellChangeTimes->{{3.72112094149716*^9, 3.721120996820828*^9}, {
   3.7211210333885098`*^9, 3.721121076257634*^9}, {3.7211211901477833`*^9, 
   3.721121196044215*^9}, {3.7211212466496267`*^9, 3.721121251719665*^9}, {
   3.721121285031575*^9, 3.7211212996468983`*^9}, {3.721121374890534*^9, 
   3.721121388856143*^9}, {3.721121462273869*^9, 3.7211215593338614`*^9}, {
   3.721121607439028*^9, 3.72112161434816*^9}, {3.721121665172217*^9, 
   3.7211216805406857`*^9}, {3.7211217424028683`*^9, 3.721121771951581*^9}, 
   3.721121821275676*^9, {3.721121858845368*^9, 3.7211218853721313`*^9}, {
   3.721121947687743*^9, 3.72112199663155*^9}, {3.721122031944373*^9, 
   3.721122056535719*^9}, 3.721122255432726*^9, {3.721122425722465*^9, 
   3.721122469785511*^9}, {3.7211225218404922`*^9, 3.7211226228930063`*^9}, {
   3.721122664756467*^9, 3.7211227303545923`*^9}, {3.7211227736182957`*^9, 
   3.7211227767602262`*^9}, {3.7211229911793423`*^9, 3.7211229974240627`*^9}, 
   3.721123030881254*^9, {3.721123062392253*^9, 3.7211230932703648`*^9}, {
   3.721123125191881*^9, 3.7211231736948977`*^9}, {3.72112373573171*^9, 
   3.721123735907143*^9}, {3.721975349789681*^9, 3.7219753594527693`*^9}, {
   3.721975411237447*^9, 3.721975418403319*^9}, {3.721975493293572*^9, 
   3.7219755404011507`*^9}, {3.721975591109597*^9, 3.721975612585836*^9}, {
   3.721975668839961*^9, 3.721975727268046*^9}, 3.722064590249807*^9, 
   3.723526779627273*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotTabsComplete", "Subsubsection",
 CellChangeTimes->{{3.723532411889365*^9, 3.723532415423691*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotTabsComplete", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tbls", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"all", " ", "complete", " ", "haplotypes"}], " ", "*)"}], "\n", 
      RowBox[{"Do", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"color2", " ", "=", " ", 
          RowBox[{"Darker", "[", 
           RowBox[{"Green", ",", " ", "0.5"}], "]"}]}], ";", " ", 
         RowBox[{"pm", " ", "=", " ", "8"}], ";", "  \t ", "\n", "  ", 
         RowBox[{"Do", "[", "\n", "    ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"deficit", "\[LeftDoubleBracket]", 
               RowBox[{"type", ",", "time"}], "\[RightDoubleBracket]"}], "<", 
              "100"}], ",", "\n", "  \t", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"deficit", "\[LeftDoubleBracket]", 
                 RowBox[{"type", ",", "time"}], "\[RightDoubleBracket]"}], 
                "\[Equal]", "0"}], ",", 
               RowBox[{
                RowBox[{"AppendTo", "[", 
                 RowBox[{"tbls", ",", 
                  RowBox[{"ListPlot", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"time", ",", " ", "type"}], "}"}], "}"}], ",", 
                    " ", 
                    RowBox[{"PlotStyle", " ", "->", " ", 
                    RowBox[{"{", "color2", "}"}]}], ",", " ", 
                    RowBox[{"PlotMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\[FilledSmallCircle]", ",", "pm"}], "}"}]}]}], 
                   "]"}]}], "]"}], ";"}]}], "]"}]}], "\n", "    ", "]"}], 
           "\n", "  ", ",", 
           RowBox[{"{", 
            RowBox[{"time", ",", "1", ",", "generations"}], "}"}]}], "]"}]}], 
        "\n", ",", 
        RowBox[{"{", 
         RowBox[{"type", ",", "1", ",", 
          RowBox[{
          "FTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         "}"}]}], "]"}], ";", "\[IndentingNewLine]", "tbls"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellChangeTimes->{
  3.7235324422400227`*^9, {3.724391522224724*^9, 3.7243915262551813`*^9}, {
   3.724391725098796*^9, 3.724391755004387*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotTabsCompleteAll", "Subsubsection",
 CellChangeTimes->{{3.723532411889365*^9, 3.723532415423691*^9}, {
  3.724391748660345*^9, 3.7243917491150503`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotTabsCompleteAll", " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tbls", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"all", " ", "complete", " ", "haplotypes"}], " ", "*)"}], "\n", 
      RowBox[{"Do", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"color2", " ", "=", " ", 
          RowBox[{"Darker", "[", 
           RowBox[{"Green", ",", " ", "0.5"}], "]"}]}], ";", " ", 
         RowBox[{"pm", " ", "=", " ", "8"}], ";", "  \t ", "\n", "  ", 
         RowBox[{"Do", "[", "\n", "    ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"deficitAll", "\[LeftDoubleBracket]", 
               RowBox[{"type", ",", "time"}], "\[RightDoubleBracket]"}], "<", 
              "100"}], ",", "\n", "  \t", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"deficitAll", "\[LeftDoubleBracket]", 
                 RowBox[{"type", ",", "time"}], "\[RightDoubleBracket]"}], 
                "\[Equal]", "0"}], ",", 
               RowBox[{
                RowBox[{"AppendTo", "[", 
                 RowBox[{"tbls", ",", 
                  RowBox[{"ListPlot", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"time", ",", " ", "type"}], "}"}], "}"}], ",", 
                    " ", 
                    RowBox[{"PlotStyle", " ", "->", " ", 
                    RowBox[{"{", "color2", "}"}]}], ",", " ", 
                    RowBox[{"PlotMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\[FilledSmallCircle]", ",", "pm"}], "}"}]}]}], 
                   "]"}]}], "]"}], ";"}]}], "]"}]}], "\n", "    ", "]"}], 
           "\n", "  ", ",", 
           RowBox[{"{", 
            RowBox[{"time", ",", "1", ",", "generations"}], "}"}]}], "]"}]}], 
        "\n", ",", 
        RowBox[{"{", 
         RowBox[{"type", ",", "1", ",", 
          RowBox[{
          "FTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         "}"}]}], "]"}], ";", "\[IndentingNewLine]", "tbls"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellChangeTimes->{
  3.7235324422400227`*^9, {3.724391522224724*^9, 3.7243915262551813`*^9}, {
   3.724391725098796*^9, 3.72439172815456*^9}, {3.724391825320944*^9, 
   3.72439182582484*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetLegend", "Subsubsection",
 CellChangeTimes->{{3.723533874184251*^9, 3.723533876646837*^9}}],

Cell[BoxData[
 RowBox[{"GetLegend", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R1", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Black", ",", " ", 
          RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     RowBox[{"F1x", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
          "White", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     RowBox[{"F1", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
          "Black", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     RowBox[{"R2", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
          RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     RowBox[{"F2x", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", 
          " ", "White", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     RowBox[{"F2", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", 
          " ", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\n", 
     RowBox[{"l1", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"l2", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"l3", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"l4", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"l5", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"l6", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"l7", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"l8", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "l1", ",", "l2", ",", "l3", ",", "l4", ",", "l5", ",", "l6", ",", "l7", 
       ",", "l8"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Code"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis", "Subsection",
 CellChangeTimes->{{3.724392576972517*^9, 3.724392578595028*^9}}],

Cell[CellGroupData[{

Cell["GetDeficit", "Subsubsection",
 CellChangeTimes->{{3.72353211990172*^9, 3.723532122116418*^9}}],

Cell[BoxData[
 RowBox[{"GetDeficit", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"deficit", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          ",", "generations"}], "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"deficitAll", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          ",", "generations"}], "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"fr", " ", "-", " ", 
         RowBox[{
         "threshold", " ", "SI", " ", "frequency", " ", "so", " ", "that", 
          " ", "it", " ", "counts", " ", "as", " ", "a", " ", "class"}]}], 
        ",", " ", 
        RowBox[{"0", "=", "all"}]}], "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{
        RowBox[{"fr", " ", "=", " ", "0.05"}], ";", "\[IndentingNewLine]", 
        "\t", 
        RowBox[{"GetClass2", "[", 
         RowBox[{"time", ",", "typ", ",", "fr"}], "]"}], ";", 
        "\[IndentingNewLine]", "\t", 
        RowBox[{
         RowBox[{"deficit", "\[LeftDoubleBracket]", 
          RowBox[{"typ", ",", "time"}], "\[RightDoubleBracket]"}], " ", "=", 
         " ", "cl"}], ";"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"time", ",", "1", ",", "generations"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"typ", ",", "1", ",", 
         RowBox[{
         "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"deficitAll", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          ",", "generations"}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"Do", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"fr", " ", "=", " ", "0.05"}], ";", "\[IndentingNewLine]", 
        "\t", 
        RowBox[{"GetClass2all", "[", 
         RowBox[{"time", ",", "type", ",", "fr"}], "]"}], ";", 
        "\[IndentingNewLine]", "\t", 
        RowBox[{
         RowBox[{"deficitAll", "\[LeftDoubleBracket]", 
          RowBox[{"type", ",", "time"}], "\[RightDoubleBracket]"}], " ", "=", 
         " ", "cl"}], ";"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"time", ",", "1", ",", "generations"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"type", ",", "1", ",", 
         RowBox[{
         "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        "}"}]}], "]"}], ";", "\n", 
     RowBox[{"{", 
      RowBox[{"deficit", ",", "deficitAll"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Code",
 CellChangeTimes->{{3.7243906818020363`*^9, 3.724390701118883*^9}, {
  3.72439167649469*^9, 3.7243916781758003`*^9}, {3.7243917135186167`*^9, 
  3.724391715029524*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetClass2", "Subsubsection",
 CellChangeTimes->{{3.72147407820984*^9, 3.721474080096204*^9}, 
   3.7215406509111223`*^9, 3.721541804253271*^9, 3.721541883114624*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetClass2", "[", 
   RowBox[{"time_", ",", "type_", ",", "fr_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"fr", " ", "=", " ", 
       RowBox[{"0", " ", "all", " ", "haplotypes"}]}], ",", " ", "other", ",",
       " ", 
      RowBox[{"freq", " ", ">", " ", "fr"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "\t", 
    RowBox[{"(*", " ", 
     RowBox[{
     "returns", " ", "the", " ", "minimal", " ", "completeness", " ", 
      "deficit", " ", "and", " ", "the", " ", "first", " ", "haplotype", " ", 
      "that", " ", "reaches", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]",
     "\t", 
    RowBox[{
     RowBox[{"SItypesT", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"SIcounts", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", ";;"}], "]"}], "]"}], ",", " ", 
         RowBox[{"_", "?", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"#", "/", "2"}], "/", "popsize"}], " ", ">", " ", 
             "fr"}], " ", "&"}], ")"}]}]}], "]"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"LSI", " ", "=", " ", 
      RowBox[{"Length", "@", "SItypesT"}]}], ";", "\[IndentingNewLine]", "\t",
      "\[IndentingNewLine]", "\t\t", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Boole", "@", 
         RowBox[{"SubsetQ", "[", 
          RowBox[{"SItypesT", ",", 
           RowBox[{"{", "type", "}"}]}], "]"}]}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", "\t\t", 
       RowBox[{
        RowBox[{"SItypesT", " ", "=", " ", 
         RowBox[{"SItypesT", " ", "/.", " ", 
          RowBox[{"type", " ", "->", " ", 
           RowBox[{"Sequence", "[", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
        "\t\t", 
        RowBox[{"OutputFreqAB", "[", 
         RowBox[{"time", ",", "type"}], "]"}], ";", "\[IndentingNewLine]", 
        "\t\t", 
        RowBox[{"hps", " ", "=", " ", 
         RowBox[{"typesA2", "[", 
          RowBox[{"[", 
           RowBox[{";;", ",", "1"}], "]"}], "]"}]}], ";", " ", "\n", "\t\t\t",
         "\[IndentingNewLine]", "\t\t", 
        RowBox[{"CL", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", "\t\t", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"CL", ",", 
             RowBox[{
              RowBox[{"Length", "@", "SItypesT"}], " ", "-", " ", 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{"Boole", "@", 
                 RowBox[{"SubsetQ", "[", 
                  RowBox[{
                   RowBox[{"hps", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"2", ";;"}]}], "]"}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"SItypesT", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "1", ",", 
                  RowBox[{"Length", "@", "SItypesT"}]}], "}"}]}], "]"}]}]}], 
            "]"}], ";"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "@", "hps"}]}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\t\t", 
        RowBox[{"cl", " ", "=", " ", 
         RowBox[{"Min", "[", "CL", "]"}]}], ";", " ", "\[IndentingNewLine]", 
        "\t\t", 
        RowBox[{"hapout", " ", "=", " ", 
         RowBox[{"hps", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Flatten", "@", 
              RowBox[{"Position", "[", 
               RowBox[{"CL", ",", 
                RowBox[{"Min", "[", "CL", "]"}]}], "]"}]}], ")"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], ";"}], 
       "\[IndentingNewLine]", "\t\t", ",", 
       RowBox[{
        RowBox[{"cl", " ", "=", " ", "100"}], ";", 
        RowBox[{"hapout", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";"}]}], "\[IndentingNewLine]", "\t\t", "]"}], 
     ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"{", 
      RowBox[{"cl", ",", "LSI", ",", "hapout", ",", "SItypesT"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Code",
 CellChangeTimes->{{3.721124441656599*^9, 3.7211244666544*^9}, {
   3.72112450245443*^9, 3.7211246286491547`*^9}, {3.721124718911776*^9, 
   3.7211247450051813`*^9}, {3.721125157146541*^9, 3.721125161937471*^9}, {
   3.721125277024209*^9, 3.7211252788019953`*^9}, {3.7211253098248377`*^9, 
   3.72112553546878*^9}, {3.721126601045929*^9, 3.7211267684469*^9}, {
   3.721126858094535*^9, 3.721126928680732*^9}, {3.72112695985664*^9, 
   3.721127020346423*^9}, {3.721127058158143*^9, 3.721127173121209*^9}, 
   3.7211272281185007`*^9, {3.72112746486909*^9, 3.721127493364108*^9}, {
   3.721127543960767*^9, 3.7211275875799932`*^9}, {3.72112762076579*^9, 
   3.7211277506231127`*^9}, 3.721127900674759*^9, {3.721130163171468*^9, 
   3.7211301750498533`*^9}, {3.7215410745037622`*^9, 3.721541082159059*^9}, {
   3.721541807742712*^9, 3.721541878493881*^9}, {3.722060607015552*^9, 
   3.722060607295745*^9}, {3.7243910035004*^9, 3.724391010987076*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetClass2all", "Subsubsection",
 CellChangeTimes->{{3.72147407820984*^9, 3.721474080096204*^9}, 
   3.7215406509111223`*^9, 3.721541804253271*^9, 3.721541883114624*^9, {
   3.722063153578391*^9, 3.722063153889369*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetClass2all", "[", 
   RowBox[{"time_", ",", "type_", ",", "fr_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t", 
    RowBox[{"(*", " ", 
     RowBox[{
     "considers", " ", "compatibility", " ", "of", " ", "ALL", " ", "SI", " ",
       "haplotypes", " ", "among", " ", "the", " ", "frequent", " ", "ones"}],
      " ", "*)"}], "\n", "\t", 
    RowBox[{"(*", " ", 
     RowBox[{
     "returns", " ", "the", " ", "minimal", " ", "completeness", " ", 
      "deficit", " ", "and", " ", "the", " ", "first", " ", "haplotype", " ", 
      "that", " ", "reaches", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]",
     "\t", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"time", " ", "=", " ", "1000"}], ";", " ", 
      RowBox[{"type", " ", "=", " ", "4"}], ";"}], "*)"}], "\t\t\t", 
    "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{"SItypesTall", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"SIcounts", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", ";;"}], "]"}], "]"}], ",", " ", 
         RowBox[{"_", "?", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"#", "/", "2"}], "/", "popsize"}], " ", ">", " ", "0"}],
             " ", "&"}], ")"}]}]}], "]"}], "]"}]}], ";", " ", "\n", "\t", 
     RowBox[{"SItypesT", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"SIcounts", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", ";;"}], "]"}], "]"}], ",", " ", 
         RowBox[{"_", "?", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"#", "/", "2"}], "/", "popsize"}], " ", ">", " ", 
             "fr"}], " ", "&"}], ")"}]}]}], "]"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"LSI", " ", "=", " ", 
      RowBox[{"Length", "@", "SItypesT"}]}], ";", "\[IndentingNewLine]", "\t",
      "\[IndentingNewLine]", "\t\t", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Boole", "@", 
         RowBox[{"SubsetQ", "[", 
          RowBox[{"SItypesTall", ",", 
           RowBox[{"{", "type", "}"}]}], "]"}]}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", "\t\t", 
       RowBox[{
        RowBox[{"SItypesTall", " ", "=", " ", 
         RowBox[{"SItypesTall", " ", "/.", " ", 
          RowBox[{"type", " ", "->", " ", 
           RowBox[{"Sequence", "[", "]"}]}]}]}], ";", "\n", "\t\t", 
        RowBox[{"SItypesT", " ", "=", " ", 
         RowBox[{"SItypesT", " ", "/.", " ", 
          RowBox[{"type", " ", "->", " ", 
           RowBox[{"Sequence", "[", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
        "\t\t", 
        RowBox[{"OutputFreqAB", "[", 
         RowBox[{"time", ",", "type"}], "]"}], ";", "\[IndentingNewLine]", 
        "\t\t", 
        RowBox[{"hps", " ", "=", " ", 
         RowBox[{"typesA2", "[", 
          RowBox[{"[", 
           RowBox[{";;", ",", "1"}], "]"}], "]"}]}], ";", " ", "\n", "\t\t\t",
         "\[IndentingNewLine]", "\t\t", 
        RowBox[{"CL", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", "\t\t", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"CL", ",", 
             RowBox[{
              RowBox[{"Length", "@", "SItypesT"}], " ", "-", " ", 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{"Boole", "@", 
                 RowBox[{"SubsetQ", "[", 
                  RowBox[{
                   RowBox[{"hps", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"2", ";;"}]}], "]"}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"SItypesT", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "1", ",", 
                  RowBox[{"Length", "@", "SItypesT"}]}], "}"}]}], "]"}]}]}], 
            "]"}], ";"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "@", "hps"}]}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\t\t", 
        RowBox[{"cl", " ", "=", " ", 
         RowBox[{"Min", "[", "CL", "]"}]}], ";", " ", "\[IndentingNewLine]", 
        "\t\t", 
        RowBox[{"hapout", " ", "=", " ", 
         RowBox[{"hps", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Flatten", "@", 
              RowBox[{"Position", "[", 
               RowBox[{"CL", ",", 
                RowBox[{"Min", "[", "CL", "]"}]}], "]"}]}], ")"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], ";"}], 
       "\[IndentingNewLine]", "\t\t", ",", 
       RowBox[{
        RowBox[{"cl", " ", "=", " ", "100"}], ";", 
        RowBox[{"hapout", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";"}]}], "\[IndentingNewLine]", "\t\t", "]"}], 
     ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"{", 
      RowBox[{"cl", ",", "LSI", ",", "hapout", ",", "SItypesT"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Code",
 CellChangeTimes->{{3.721124441656599*^9, 3.7211244666544*^9}, {
   3.72112450245443*^9, 3.7211246286491547`*^9}, {3.721124718911776*^9, 
   3.7211247450051813`*^9}, {3.721125157146541*^9, 3.721125161937471*^9}, {
   3.721125277024209*^9, 3.7211252788019953`*^9}, {3.7211253098248377`*^9, 
   3.72112553546878*^9}, {3.721126601045929*^9, 3.7211267684469*^9}, {
   3.721126858094535*^9, 3.721126928680732*^9}, {3.72112695985664*^9, 
   3.721127020346423*^9}, {3.721127058158143*^9, 3.721127173121209*^9}, 
   3.7211272281185007`*^9, {3.72112746486909*^9, 3.721127493364108*^9}, {
   3.721127543960767*^9, 3.7211275875799932`*^9}, {3.72112762076579*^9, 
   3.7211277506231127`*^9}, 3.721127900674759*^9, {3.721130163171468*^9, 
   3.7211301750498533`*^9}, {3.7215410745037622`*^9, 3.721541082159059*^9}, {
   3.721541807742712*^9, 3.721541878493881*^9}, {3.722060607015552*^9, 
   3.722060607295745*^9}, {3.722063156267292*^9, 3.722063284833825*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["MostComplete", "Subsubsection",
 CellChangeTimes->{{3.7214740489877453`*^9, 3.721474070960575*^9}, 
   3.721541750294693*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MostComplete", "[", 
    RowBox[{"time_", ",", "fr_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"HapSet", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", "\t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"GetClass2", "[", 
          RowBox[{"time", ",", "type", ",", "fr"}], "]"}], ";", "\n", "\t\t", 
         
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"cl", "\[NotEqual]", "100"}], ",", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"HapSet", ",", "hapout"}], "]"}], ";"}]}], "]"}]}], 
        "\[IndentingNewLine]", "\t", ",", 
        RowBox[{"{", 
         RowBox[{"type", ",", "1", ",", 
          RowBox[{
          "RTypes", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         "}"}]}], "]"}], ";", "\[IndentingNewLine]", "HapSet"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]], "Code",
 CellChangeTimes->{{3.7211243685637836`*^9, 3.721124377480372*^9}, 
   3.721125464974258*^9, {3.721125596939046*^9, 3.721125660296144*^9}, {
   3.72112569443991*^9, 3.721125982070719*^9}, {3.721126038716457*^9, 
   3.7211260678594723`*^9}, {3.721126100431202*^9, 3.721126184199795*^9}, {
   3.7211263952151403`*^9, 3.721126415049028*^9}, {3.721126471796194*^9, 
   3.721126471926992*^9}, {3.721127793966148*^9, 3.721127889854129*^9}, {
   3.721127931588018*^9, 3.721128064295845*^9}, 3.721128231006125*^9, 
   3.721130098064741*^9, {3.7215405804539957`*^9, 3.721540595764163*^9}, {
   3.7215411532710657`*^9, 3.7215411694823847`*^9}, {3.72154175423358*^9, 
   3.721541758199238*^9}, {3.721541903547859*^9, 3.721541910666432*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotGraphFull", "Subsubsection",
 CellChangeTimes->{{3.7214955024604387`*^9, 3.721495508649207*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotGraphFull", "[", 
   RowBox[{"time_", ",", "fr_", ",", "fs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MostComplete", "[", 
      RowBox[{"time", ",", "fr"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"CubeEdges", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Boole", "@", 
         RowBox[{"SubsetQ", "[", 
          RowBox[{
           RowBox[{"HapSet", "\[LeftDoubleBracket]", 
            RowBox[{"j", ",", 
             RowBox[{"2", ";;"}]}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "SItypesT", "\[LeftDoubleBracket]", "k", 
             "\[RightDoubleBracket]"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"Length", "@", "SItypesT"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "@", "SItypesT"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gpart", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", 
     RowBox[{"Vid", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"CubeEdges", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], ">", "0"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"gpart", ",", 
            RowBox[{"i", "\[DirectedEdge]", "j"}]}], "]"}]}], "]"}], ";", " ", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"Vid", ",", "i"}], 
         RowBox[{"(*", 
          RowBox[{
          "SItypesT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "*)"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "@", "SItypesT"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "@", "SItypesT"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Vid", " ", "=", " ", 
      RowBox[{"DeleteDuplicates", "@", "Vid"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"VNid", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"SItypesT", "\[LeftDoubleBracket]", 
         RowBox[{
         "Vid", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
         "\[RightDoubleBracket]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "@", "Vid"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Vlabels", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
         "Vid", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
         "\[Rule]", 
         RowBox[{
         "VNid", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "@", "Vid"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"coord", " ", "=", " ", 
      RowBox[{"N", "@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", " ", 
            RowBox[{
             FractionBox[
              RowBox[{" ", 
               RowBox[{"VNid", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], 
              RowBox[{"RTypes", "[", 
               RowBox[{"[", "1", "]"}], "]"}]], "2", "\[Pi]"}], "]"}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{
             FractionBox[
              RowBox[{"VNid", "[", 
               RowBox[{"[", "i", "]"}], "]"}], 
              RowBox[{"RTypes", "[", 
               RowBox[{"[", "1", "]"}], "]"}]], "2", "\[Pi]"}], "]"}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "@", "Vid"}]}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"options1", "=", 
      RowBox[{"Sequence", "[", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"VertexCoordinates", "\[Rule]", "coord"}], 
         "\[IndentingNewLine]", ","}], "*)"}], 
       RowBox[{
        RowBox[{"VertexLabels", "\[Rule]", "Vlabels"}], "\[IndentingNewLine]",
         ",", 
        RowBox[{"VertexLabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"15", ",", "Black", ",", "Bold", ",", "Italic"}], "]"}]}], 
        "\t\t", "\[IndentingNewLine]", ",", 
        RowBox[{"EdgeStyle", "\[Rule]", 
         RowBox[{"Darker", "[", 
          RowBox[{"Blue", ",", "0.5"}], "]"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"VertexStyle", "\[Rule]", 
         RowBox[{"Lighter", "[", 
          RowBox[{"Gray", ",", "1"}], "]"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"VertexSize", "\[Rule]", "0.8"}], "\[IndentingNewLine]", ",", 
        
        RowBox[{"GraphLayout", "\[Rule]", "\"\<CircularEmbedding\>\""}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Gsub", " ", "=", " ", 
      RowBox[{"Graph", "[", 
       RowBox[{"gpart", ",", "options1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"gbasic", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"gbasic", ",", 
         RowBox[{"i", "\[DirectedEdge]", "j"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "@", "SItypesT"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "@", "SItypesT"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Gbasic", " ", "=", " ", 
      RowBox[{"Graph", "[", 
       RowBox[{"gbasic", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{"VertexLabels", "\[Rule]", "Vlabels"}]}], "*)"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"VertexLabels", " ", "->", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Vid", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            " ", "->", " ", 
            RowBox[{"Placed", "[", 
             RowBox[{
              RowBox[{
              "VNid", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              ",", " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", 
                RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "@", "Vid"}]}], "}"}]}], "]"}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"VertexLabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"fs", ",", "White", ",", "Bold"}], "]"}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"EdgeStyle", "\[Rule]", 
         RowBox[{"Lighter", "[", 
          RowBox[{"Gray", ",", "1"}], "]"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"VertexStyle", "\[Rule]", 
         RowBox[{"Lighter", "[", 
          RowBox[{"Gray", ",", "0.8"}], "]"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"VertexSize", "\[Rule]", "0.5"}], "\[IndentingNewLine]", ",", 
        
        RowBox[{"GraphLayout", "\[Rule]", "\"\<CircularEmbedding\>\""}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"HighlightGraph", "[", 
      RowBox[{"Gbasic", ",", "Gsub"}], "]"}]}]}], "\n", "\n", "]"}]}]], "Code",\

 CellChangeTimes->{{3.721493044728684*^9, 3.721493134021202*^9}, {
  3.7214931802042923`*^9, 3.721493191363596*^9}, {3.7214934535669937`*^9, 
  3.721493605253149*^9}, {3.721541311290255*^9, 3.721541312568315*^9}, {
  3.7215414043434267`*^9, 3.7215414939392*^9}, {3.721541546754573*^9, 
  3.721541566488872*^9}, {3.721541919550376*^9, 3.721541925740718*^9}, {
  3.7215437147312202`*^9, 3.7215437521917686`*^9}, {3.722329526051441*^9, 
  3.722329536410523*^9}, {3.722569529798675*^9, 3.722569566969026*^9}, {
  3.722573434834841*^9, 3.722573518120596*^9}, {3.7225746357119083`*^9, 
  3.72257464066218*^9}, {3.7225747004692802`*^9, 3.7225747221822042`*^9}, {
  3.72257476729139*^9, 3.722574791712772*^9}, {3.7225748827479353`*^9, 
  3.722575108995391*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetClass", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetClass", "[", 
   RowBox[{"time_", ",", "type_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t\t", 
    RowBox[{"(*", " ", 
     RowBox[{
     "what", " ", "is", " ", "the", " ", "max", " ", "number", " ", "of", " ",
       "other", " ", "classes", " ", "that", " ", "the", " ", "SI", " ", 
      "types", " ", "can", " ", "mate", " ", "with", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"have", " ", "Fbox"}], ")"}], "?"}]}], " ", "*)"}], "\n", 
    "\t\t\t", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"time", " ", "=", " ", "1488"}], ";", " ", 
      RowBox[{"type", " ", "=", " ", "3"}], ";"}], "*)"}], "\n", "\t\t\t", 
    RowBox[{
     RowBox[{"SItypesT", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"SIcounts", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", ";;"}], "]"}], "]"}], ",", " ", 
         RowBox[{"_", "?", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}], ")"}]}]}], "]"}], 
       "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"alternativa", " ", "10"}], " ", "*)"}], "\n", "\t\t\t", 
     RowBox[{"SItypesT", " ", "=", " ", 
      RowBox[{"SItypesT", " ", "/.", " ", 
       RowBox[{"type", " ", "->", " ", 
        RowBox[{"Sequence", "[", "]"}]}]}]}], ";", "\n", "\t\t\t", 
     RowBox[{"OutputFreqAB", "[", 
      RowBox[{"time", ",", "type"}], "]"}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"typesA2", " ", "-", " ", "SI"}], " ", "*)"}], "\n", "\t\t\t", 
     RowBox[{"hps", " ", "=", " ", 
      RowBox[{"typesA2", "[", 
       RowBox[{"[", 
        RowBox[{";;", ",", "1"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"hps", "//", "MatrixForm"}], "*)"}], "\n", "\t\t\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"Length", "@", "hps"}], "]"}], ";"}], "*)"}], "\n", "\t\t\t", 
     
     RowBox[{"CL", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "\t\t\t", 
     RowBox[{"Do", "[", "\n", "\t\t\t\t", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", "i", "]"}], ";"}], "*)"}], "\n", "\t\t\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"CL", ",", 
          RowBox[{
           RowBox[{"Length", "@", "SItypesT"}], " ", "-", " ", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"Boole", "@", 
              RowBox[{"SubsetQ", "[", 
               RowBox[{
                RowBox[{"hps", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", 
                   RowBox[{"2", ";;"}]}], "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"SItypesT", "[", 
                  RowBox[{"[", "k", "]"}], "]"}], "}"}]}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", 
               RowBox[{"Length", "@", "SItypesT"}]}], "}"}]}], "]"}]}]}], 
         "]"}], ";"}], "\n", "\t\t\t", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "@", "hps"}]}], "}"}]}], "]"}], ";", "\n", 
     "\t\t\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", "CL", "]"}], ";"}], "*)"}], "\n", "\t\t\t", 
     RowBox[{"cl", " ", "=", " ", 
      RowBox[{"Max", "[", "CL", "]"}]}], ";", " ", 
     RowBox[{"hapout", " ", "=", " ", 
      RowBox[{"hps", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Flatten", "@", 
           RowBox[{"Position", "[", 
            RowBox[{"CL", ",", 
             RowBox[{"Min", "[", "CL", "]"}]}], "]"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], ";", "\n", "\t\t\t", 
     
     RowBox[{"{", 
      RowBox[{"cl", ",", "hapout"}], "}"}]}]}], "\n", "\t\t", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["Labels", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"R1", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Black", ",", " ", 
       RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"F1x", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
       "White", ",", " ", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"F1", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
       "Black", ",", " ", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"R2", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Lighter", "[", 
        RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
       RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"F2x", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", " ", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", " ",
        "White", ",", " ", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"F2", " ", "=", " ", 
    RowBox[{"Graphics", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", " ", 
           RowBox[{"Lighter", "[", 
            RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", 
        " ", 
        RowBox[{"Lighter", "[", 
         RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",",
       " ", 
      RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{"l1", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l2", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l3", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l4", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l5", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l6", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l7", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l8", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}]}], "Code"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphs/Paths", "Subsection",
 CellChangeTimes->{{3.724392611754977*^9, 3.724392613193692*^9}}],

Cell[CellGroupData[{

Cell["GetMutPath", "Subsubsection",
 CellChangeTimes->{{3.696227970668805*^9, 3.6962279734912767`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Gets", " ", "the", " ", "path", " ", "from", " ", "the", " ", "mutation", 
    " ", "data"}], " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"GetMutPath", "[", 
     RowBox[{"H0", ",", "H"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\n", "\t", 
      RowBox[{
       RowBox[{"PathH", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", " ", 
       RowBox[{"PathT", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"T", " ", "=", " ", 
          RowBox[{"{", 
           RowBox[{"MasterList", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}], "}"}]}], ";", " ", 
         RowBox[{"H", " ", "=", " ", 
          RowBox[{"MasterList", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ";"}], "*)"}], "\n", 
       "\t", 
       RowBox[{"PrependTo", "[", 
        RowBox[{"PathH", ",", "H"}], "]"}], ";", " ", 
       RowBox[{"PrependTo", "[", 
        RowBox[{"PathT", ",", "T"}], "]"}], ";", "\n", "\n", "\t", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"H", "\[NotEqual]", "H0"}], ",", "\n", "\t\t", 
         RowBox[{
          RowBox[{"p", " ", "=", " ", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"MutationTo", ",", "H"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
          RowBox[{"H", " ", "=", " ", 
           RowBox[{"Flatten", "@", 
            RowBox[{"MutationFrom", "[", 
             RowBox[{"[", "p", "]"}], "]"}]}]}], ";", " ", 
          RowBox[{"T", " ", "=", " ", 
           RowBox[{"MutationTime", "[", 
            RowBox[{"[", "p", "]"}], "]"}]}], ";", "\n", "\t\t", 
          RowBox[{"PrependTo", "[", 
           RowBox[{"PathH", ",", "H"}], "]"}], ";", " ", 
          RowBox[{"PrependTo", "[", 
           RowBox[{"PathT", ",", "T"}], "]"}], ";"}]}], "\n", "\t", "]"}], 
       ";", "\n", "\t", 
       RowBox[{"{", 
        RowBox[{"PathH", ",", "PathT"}], "}"}]}]}], "\n", "\t", "]"}]}], 
   "\n"}]}]], "Code",
 CellChangeTimes->{{3.696225762960422*^9, 3.696225776661384*^9}, {
   3.696225893046322*^9, 3.696226018527285*^9}, {3.696226059677898*^9, 
   3.696226068392188*^9}, {3.696226110482959*^9, 3.696226129885437*^9}, {
   3.6962270992028093`*^9, 3.696227509420632*^9}, {3.696227545005822*^9, 
   3.696227545340064*^9}, {3.6962275844387503`*^9, 3.696227599018281*^9}, {
   3.696227649113613*^9, 3.696227799549485*^9}, 3.696227846896863*^9, {
   3.6962279305124197`*^9, 3.696227950221179*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetMutationGraph", "Subsubsection"],

Cell[BoxData[
 RowBox[{"GetMutationGraph", " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  \t", 
    RowBox[{
     RowBox[{"nmax", " ", "=", " ", 
      RowBox[{"Length", "@", "MutationFrom"}]}], ";", "\n", "  \t", 
     RowBox[{"idDiff", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "  \t", 
     RowBox[{"Do", "[", "\n", "   \t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"MutationFrom", "[", 
            RowBox[{"[", "k", "]"}], "]"}], " ", "!=", " ", 
           RowBox[{"MutationTo", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], ",", " ", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"idDiff", ",", " ", "k"}], "]"}]}], "]"}], ";"}], "\n", 
       "   \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", "1", ",", " ", "nmax"}], 
        RowBox[{"(*", 
         RowBox[{"Length", "@", "MutationFrom"}], "*)"}], "}"}]}], "]"}], ";",
      "\n", "  ", "\n", "  \t", 
     RowBox[{"dataMut", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"MutationFrom", "[", 
            RowBox[{"[", 
             RowBox[{"idDiff", ",", " ", ";;"}], "]"}], "]"}], 
           "\[Transpose]"}], ")"}], "~", "Join", "~", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"MutationTo", "[", 
            RowBox[{"[", 
             RowBox[{"idDiff", ",", " ", ";;"}], "]"}], "]"}], 
           "\[Transpose]"}], ")"}]}], ")"}], "\[Transpose]"}]}], ";", "\n", 
     "  \t", 
     RowBox[{"dataMut0", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Tally", "@", "dataMut"}], ")"}], "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}]}], ";", "\n", "  ", 
     "\n", "  \t", 
     RowBox[{"idSI", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "  \t", 
     RowBox[{"Do", "[", "\n", "   \t\t", 
      RowBox[{
       RowBox[{"If", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "@", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"dataMut0", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", " ", 
                RowBox[{"18", " ", ";;"}]}], "]"}], "]"}], ",", " ", 
             RowBox[{"dataMut0", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", " ", "17"}], "]"}], "]"}]}], "]"}]}], " ", "==",
           " ", "0"}], ",", "\n", "    \t\t", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"idSI", ",", " ", "k"}], "]"}], ";"}]}], "]"}], "\n", 
       "   \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", "dataMut0"}]}], "}"}]}], "]"}], ";", "\n", 
     "  \t", 
     RowBox[{"g", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"dataMut0", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", " ", 
            RowBox[{"1", " ", ";;", " ", 
             RowBox[{
              RowBox[{"SLength", "[", 
               RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", "1"}]}]}], 
           "]"}], "]"}], " ", "->", " ", 
         RowBox[{"dataMut0", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"SLength", "[", 
               RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", "2"}], " ", 
             ";;"}]}], "]"}], "]"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"k", ",", " ", "1", ",", " ", 
          RowBox[{"Length", "@", "dataMut0"}]}], "}"}]}], "]"}]}], ";", "\n", 
     "  \t", 
     RowBox[{"gSI", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"dataMut0", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"idSI", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", " ", 
            RowBox[{"1", " ", ";;", " ", 
             RowBox[{
              RowBox[{"SLength", "[", 
               RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", "1"}]}]}], 
           "]"}], "]"}], " ", "->", " ", 
         RowBox[{"dataMut0", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"idSI", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"SLength", "[", 
               RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", "2"}], " ", 
             ";;"}]}], "]"}], "]"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"k", ",", " ", "1", ",", " ", 
          RowBox[{"Length", "@", "idSI"}]}], "}"}]}], "]"}]}], ";", "\n", 
     "  \t", 
     RowBox[{"{", 
      RowBox[{"g", ",", " ", "gSI"}], "}"}]}]}], "\n", "  ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetFullPaths", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetFullPaths", "[", 
   RowBox[{"type_", ",", " ", "id_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  \t", 
    RowBox[{
     RowBox[{"hapFrom", " ", "=", " ", 
      RowBox[{"MutationFrom", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "  \t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"type", " ", "=", " ", "40"}], ";", " ", 
       RowBox[{"id", " ", "=", " ", "15"}], ";", " ", 
       RowBox[{"Length", "@", 
        RowBox[{"DeadHaps", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "type"}], "]"}], "]"}]}]}], "*)"}], "\n", "  \t", 
     
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"hapTo", " ", "=", " ", 
        RowBox[{
         RowBox[{"DeadHaps", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "type"}], "]"}], "]"}], "[", 
         RowBox[{"[", "id", "]"}], "]"}]}], ";"}], "*)"}], "\n", "  \t", 
     RowBox[{"hapTo", " ", "=", " ", 
      RowBox[{
       RowBox[{"BornHaps", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", " ", "type"}], "]"}], "]"}], "[", 
       RowBox[{"[", "id", "]"}], "]"}]}], ";", "\n", "  \t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<Class \>\"", ",", 
          RowBox[{"hapTo", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< at time \>\"", ",", 
          RowBox[{
           RowBox[{"TimeDeath", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "type"}], "]"}], "]"}], "[", 
           RowBox[{"[", "id", "]"}], "]"}]}], "}"}], "]"}], ";"}], "*)"}], 
     "\n", "  \t", 
     RowBox[{"path", " ", "=", " ", 
      RowBox[{"FindPath", "[", 
       RowBox[{"g", ",", " ", "hapFrom", ",", " ", "hapTo"}], "]"}]}], ";", 
     " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "full", " ", "path", " ", "from", " ", "the", " ", "beginning"}], " ", 
      "*)"}], "\n", "  \t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"path", "//", "MatrixForm"}], "]"}], ";"}], "*)"}], "\n", 
     "  \t", "\n", "  \t", 
     RowBox[{"N2", " ", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{
        RowBox[{"Split", "[", 
         RowBox[{"path", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", ";;", " ", ",", " ", "1"}], "]"}], "]"}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Count", "[", 
        RowBox[{
         RowBox[{"path", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", ";;", ",", "1"}], "]"}], "]"}], ",", "type"}], 
        "]"}], ";"}], "*)"}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"new", " ", "R", " ", "states"}], " ", "*)"}], "\n", "  \t", 
     RowBox[{"typeFrom", " ", "=", " ", 
      RowBox[{
       RowBox[{"path", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", " ", ";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"-", "N2"}], " ", "-", " ", "1"}], "]"}], "]"}]}], ";", "\n",
      "  \t", 
     RowBox[{"N1", " ", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{
        RowBox[{"Split", "[", 
         RowBox[{"path", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", ";;", " ", ",", " ", "1"}], "]"}], "]"}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"-", "2"}], "]"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Count", "[", 
        RowBox[{
         RowBox[{"path", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", ";;", ",", "1"}], "]"}], "]"}], ",", 
         "typeFrom"}], "]"}], ";"}], "*)"}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"old", " ", "R", " ", "states"}], " ", "*)"}], "\n", "  \t", 
     RowBox[{"path", " ", "=", " ", 
      RowBox[{"path", "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "N2"}], " ", "-", " ", "N1"}], " ", ";;"}], ",", " ", 
         ";;"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "relevant", " ", "part", " ", "of", " ", "the", " ", "path", " ", "on", 
       " ", "the", " ", "cube"}], " ", "*)"}], "\n", "  \t", 
     RowBox[{"(*", 
      RowBox[{"path", "//", "MatrixForm"}], "*)"}], "\n", "  \t", 
     RowBox[{"Np", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"path", " ", "//", " ", "Dimensions"}], ")"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\n", "  \t", 
     RowBox[{"pathCode", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", "Np"}], "]"}]}], ";", "\n", "  ", "\n", "  \t", 
     
     RowBox[{"Do", "[", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "labels", " ", "haplotypes", " ", "by", " ", "positions", " ", "on", 
        " ", "the", " ", "cube"}], " ", "*)"}], "\n", "   \t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"hap", " ", "=", " ", 
         RowBox[{"path", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", " ", "k", ",", " ", ";;"}], "]"}], "]"}]}], ";", 
        "\n", "   \t\t", 
        RowBox[{"(*", 
         RowBox[{"If", " ", "[", 
          RowBox[{
           RowBox[{"typeFrom", "\[NotEqual]", "type"}], ","}]}], "*)"}], "\n",
         "   \t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"hap", "[", 
            RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", "typeFrom"}], ",",
           "\n", "    \t\t\t", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", ">", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "3"}]}], "]"}], 
           ";", "\n", "    \t\t\t", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", "==", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "4"}]}], "]"}], 
           ";", "\n", "    \t\t\t", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", ">", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "1"}]}], "]"}], 
           ";", "\n", "    \t\t\t", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", "==", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "2"}]}], "]"}], 
           ";"}]}], "\n", "    \t\t", "]"}], ";", "\n", "   \t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"hap", "[", 
            RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", "type"}], ",", 
          "\n", "    \t\t\t", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", ">", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "7"}]}], "]"}], 
           ";", "\n", "    \t\t\t", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", "==", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "8"}]}], "]"}], 
           ";", "\n", "    \t\t\t", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", ">", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "5"}]}], "]"}], 
           ";", "\n", "    \t\t\t", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                 "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", " ", 
              RowBox[{
               RowBox[{"Count", "[", 
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", "type"}],
                 "]"}], " ", "==", " ", "0"}]}], ",", " ", 
             RowBox[{
              RowBox[{"pathCode", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "6"}]}], "]"}], 
           ";"}]}], "\t", "\n", "    \t\t", "]"}], ";"}], "\n", "   \t\t", 
       RowBox[{"(*", 
        RowBox[{"]", ";"}], "*)"}], "\n", "   \t", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", "1", ",", " ", "Np"}], "}"}]}], "]"}], ";", 
     "\n", "  \t", 
     RowBox[{"pathCode", " ", "=", " ", 
      RowBox[{"First", " ", "/@", " ", 
       RowBox[{"Split", "[", 
        RowBox[{"pathCode", " ", "//", " ", "Flatten"}], "]"}]}]}], ";", "\n",
      "  \t", 
     RowBox[{"{", 
      RowBox[{"pathCode", ",", " ", "type", ",", " ", "typeFrom"}], "}"}]}]}],
    "\n", "  ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetPaths", "Subsubsection"],

Cell[BoxData[
 RowBox[{"GetPaths", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"AllPaths", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", 
     RowBox[{"CubeID", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", 
     RowBox[{
      RowBox[{"Do", "[", "\n", " \t", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "@", "haps0"}], " ", ">", " ", "0"}], ",", " ", 
           "\n", " \t\t", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{"haps0", "[", 
               RowBox[{"[", "id", "]"}], "]"}], "]"}], ";"}], "*)"}], "\n", 
           " \t\t", "\n", " \t\t", 
           RowBox[{
            RowBox[{"hapFrom", " ", "=", " ", 
             RowBox[{"MutationFrom", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", " \t\t", 
            RowBox[{"hapTo", " ", "=", " ", 
             RowBox[{"haps0", "[", 
              RowBox[{"[", "id", "]"}], "]"}]}], ";", "\n", " \t\t", 
            RowBox[{"Print", "[", 
             RowBox[{"id", ",", "\"\<,\>\"", ",", "hapTo"}], "]"}], ";", "\n",
             " \t\t", 
            RowBox[{"If", "[", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"hapTo", "[", 
                RowBox[{"[", "1", "]"}], "]"}], " ", "!=", " ", 
               RowBox[{"hapFrom", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], ",", "\n", "     \t\t", 
              RowBox[{
               RowBox[{"path", " ", "=", " ", 
                RowBox[{"FindPath", "[", 
                 RowBox[{"g", ",", " ", "hapFrom", ",", " ", "hapTo"}], 
                 "]"}]}], ";", " ", 
               RowBox[{"(*", " ", 
                RowBox[{
                "full", " ", "path", " ", "from", " ", "the", " ", 
                 "beginning"}], " ", "*)"}], "\n", "     \t", "\n", "     \t", 
               RowBox[{"(*", 
                RowBox[{"If", "[", " ", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Tally", "@", 
                    RowBox[{"path", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", ";;", ",", "1"}], "]"}], "]"}]}], "//", 
                   
                   RowBox[{"Length", " ", ">", " ", "1"}]}], ","}]}], "*)"}], 
               "\n", "\t     \t", 
               RowBox[{"N2", " ", "=", " ", 
                RowBox[{"Length", "[", 
                 RowBox[{
                  RowBox[{"Split", "[", 
                   RowBox[{"path", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", " ", ";;", " ", ",", " ", "1"}], "]"}], 
                    "]"}], "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";", 
               RowBox[{"(*", 
                RowBox[{
                 RowBox[{"Count", "[", 
                  RowBox[{
                   RowBox[{"path", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", ";;", ",", "1"}], "]"}], "]"}], ",", 
                   "type"}], "]"}], ";"}], "*)"}], " ", 
               RowBox[{"(*", " ", 
                RowBox[{"new", " ", "R", " ", "states"}], " ", "*)"}], "\n", 
               "\t  \t   ", 
               RowBox[{"typeFrom", " ", "=", " ", 
                RowBox[{
                 RowBox[{"path", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", " ", ";;", " ", ",", " ", "1"}], "]"}], 
                  "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"-", "N2"}], " ", "-", " ", "1"}], "]"}], "]"}]}], 
               ";", "\n", "\t  \t   ", 
               RowBox[{"N1", " ", "=", " ", 
                RowBox[{"Length", "[", 
                 RowBox[{
                  RowBox[{"Split", "[", 
                   RowBox[{"path", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", " ", ";;", " ", ",", " ", "1"}], "]"}], 
                    "]"}], "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"-", "2"}], "]"}], "]"}], "]"}]}], ";", " ", 
               RowBox[{"(*", 
                RowBox[{
                 RowBox[{"Count", "[", 
                  RowBox[{
                   RowBox[{"path", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", ";;", ",", "1"}], "]"}], "]"}], ",", 
                   "typeFrom"}], "]"}], ";"}], "*)"}], " ", 
               RowBox[{"(*", " ", 
                RowBox[{"old", " ", "R", " ", "states"}], " ", "*)"}], "\n", 
               "\t  \t   ", 
               RowBox[{"path", " ", "=", " ", 
                RowBox[{"path", "[", 
                 RowBox[{"[", 
                  RowBox[{";;", " ", ",", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "N2"}], " ", "-", " ", "N1"}], " ", ";;"}], 
                   ",", " ", ";;"}], "]"}], "]"}]}], ";", " ", 
               RowBox[{"(*", " ", 
                RowBox[{
                "relevant", " ", "part", " ", "of", " ", "the", " ", "path", 
                 " ", "on", " ", "the", " ", "cube"}], " ", "*)"}], "\n", 
               "\t  \t   ", 
               RowBox[{"Print", "[", 
                RowBox[{"path", "//", "MatrixForm"}], "]"}], ";", "\n", 
               "\t  \t   ", 
               RowBox[{"Np", " ", "=", " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"path", " ", "//", " ", "Dimensions"}], ")"}], "[", 
                 
                 RowBox[{"[", "2", "]"}], "]"}]}], ";", "\n", "\t  \t   ", 
               RowBox[{"pathCode", " ", "=", " ", 
                RowBox[{"ConstantArray", "[", 
                 RowBox[{"0", ",", " ", "Np"}], "]"}]}], ";", "\n", 
               "\t  \t   ", 
               RowBox[{"type", " ", "=", " ", 
                RowBox[{"hapTo", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "\t\t\t ", 
               RowBox[{"Do", "[", " ", 
                RowBox[{"(*", " ", 
                 RowBox[{
                 "labels", " ", "haplotypes", " ", "by", " ", "positions", 
                  " ", "on", " ", "the", " ", "cube"}], " ", "*)"}], "\n", 
                "\t   \t\t", 
                RowBox[{
                 RowBox[{
                  RowBox[{"hap", " ", "=", " ", 
                   RowBox[{"path", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", " ", "k", ",", " ", ";;"}], "]"}], 
                    "]"}]}], ";", " ", 
                  RowBox[{"(*", 
                   RowBox[{
                    RowBox[{"Print", "[", "hap", "]"}], ";"}], " ", "*)"}], 
                  "\n", "\t   \t\t", 
                  RowBox[{"(*", 
                   RowBox[{"If", " ", "[", 
                    RowBox[{
                    RowBox[{"typeFrom", "\[NotEqual]", "type"}], ","}]}], 
                   "*)"}], "\n", "\t   \t\t", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", 
                    "typeFrom"}], ",", "\n", "\t    \t\t\t", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "3"}]}], 
                    "]"}], ";", "\n", "\t    \t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "4"}]}], 
                    "]"}], ";", "\n", "\t    \t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "1"}]}], 
                    "]"}], ";", "\n", "\t    \t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "2"}]}], 
                    "]"}], ";"}]}], "\n", "\t    \t\t", "]"}], ";", "\n", 
                  "\t   \t\t", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", "type"}], 
                    ",", "\n", "\t    \t\t\t", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "7"}]}], 
                    "]"}], ";", "\n", "\t    \t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "8"}]}], 
                    "]"}], ";", "\n", "\t    \t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "5"}]}], 
                    "]"}], ";", "\n", "\t    \t\t\t", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                    RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "6"}]}], 
                    "]"}], ";"}]}], "\t", "\n", "\t    \t\t", "]"}], ";"}], 
                 "\n", "\t   \t\t", 
                 RowBox[{"(*", 
                  RowBox[{"]", ";"}], "*)"}], "\n", "\t   \t  ", ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", " ", "1", ",", " ", "Np"}], "}"}]}], 
                "]"}], ";", "\n", "\t   \t  ", 
               RowBox[{"pathCode", " ", "=", " ", 
                RowBox[{"First", " ", "/@", " ", 
                 RowBox[{"Split", "[", 
                  RowBox[{"pathCode", " ", "//", " ", "Flatten"}], "]"}]}]}], 
               ";", "\n", "\t   \t  ", 
               RowBox[{"(*", 
                RowBox[{
                 RowBox[{"Print", "[", "pathCode", "]"}], ";"}], "*)"}], "\n",
                "   \t  ", "\n", "   \t    ", "\n", "\t\t\t ", 
               RowBox[{"(*", 
                RowBox[{
                 RowBox[{"Print", "[", 
                  RowBox[{"(*", 
                   RowBox[{"\"\<T=\>\"", ",", 
                    RowBox[{"time0", "[", 
                    RowBox[{"[", "id", "]"}], "]"}], ","}], "*)"}], 
                  RowBox[{
                  "\"\<Path: \>\"", ",", "pathCode", ",", "\"\< \>\"", ",", 
                   "typeFrom", ",", "\"\<->\>\"", ",", "type", ",", 
                   "\"\< Hap: \>\"", ",", "hapTo"}], "]"}], ";"}], "*)"}], 
               "\n", "\t   \t  ", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"AllPaths", ",", " ", "pathCode"}], "]"}], ";", "\n", 
               "\t   \t  ", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"CubeID", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"type", ",", " ", "typeFrom"}], "}"}]}], "]"}], 
               ";"}]}], "\n", "\t   \t", "]"}], ";"}]}], "\n", "   \t", "]"}],
          ";"}], "\n", " ", ",", "  ", 
        RowBox[{"{", 
         RowBox[{"id", ",", " ", "5", ",", " ", 
          RowBox[{"Length", "@", "haps0"}]}], "}"}]}], "]"}], "\n", " ", 
      RowBox[{"{", 
       RowBox[{"AllPaths", ",", "CubeID"}], "}"}]}]}]}], "\n", " ", 
   "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetMasterList", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Makes", " ", "a", " ", "list", " ", "of", " ", "all", " ", "SI", " ", 
     "haplotypes", " ", "and", " ", "computes", " ", "its", " ", 
     "frequency"}], ",", " ", 
    RowBox[{"lifetime", " ", "and", " ", "compatibility", " ", 
     RowBox[{"class", ".", " ", "Defines"}], " ", "compatibility", " ", 
     "classes", " ", "with", " ", "a", " ", "threshold"}]}], " ", "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{"GetMasterList", "[", 
    RowBox[{"t0_", ",", "t1_", ",", "dt_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"MasterList", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", 
      RowBox[{"Do", "[", "\n", "\t", 
       RowBox[{
        RowBox[{
         RowBox[{"SItypesT", " ", "=", " ", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"SIcounts", "[", 
              RowBox[{"[", 
               RowBox[{"time", ",", ";;"}], "]"}], "]"}], ",", " ", 
             RowBox[{"_", "?", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"#", " ", ">", " ", "10"}], " ", "&"}], ")"}]}]}], 
            "]"}], "]"}]}], ";", "\n", "\t", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Print", "[", "SItypesT", "]"}], ";"}], "*)"}], "\n", "\t", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"SItypesT", " ", "=", " ", 
            RowBox[{"SItypesTime", "[", 
             RowBox[{"[", "time", "]"}], "]"}]}], ";"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{"all", " ", "Rs", " ", "at", " ", "given", " ", "time"}], 
           " ", "*)"}], "*)"}], "\n", "\t", 
         RowBox[{"Do", "[", "\n", "\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{"masterlist", " ", "=", " ", 
             RowBox[{"Flatten", "@", 
              RowBox[{"ConstantArray", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "5"}], "}"}]}], "]"}]}]}], ";", "\n", 
            "\t\t", 
            RowBox[{"OutputFreqAB", "[", 
             RowBox[{"time", ",", " ", "type"}], "]"}], ";", "  ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "get", " ", "haps", " ", "and", " ", "frequencies", " ", "of", 
              " ", "the", " ", 
              RowBox[{"SI", "/", "SC"}]}], " ", "*)"}], "\n", "\t\t", 
            RowBox[{"timeApp", " ", "=", " ", 
             RowBox[{
              RowBox[{"FlagBirth", "[", 
               RowBox[{"[", "type", "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"1", " ", ";;", " ", 
                RowBox[{"Length", "[", 
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{"FlagBirth", "[", 
                    RowBox[{"[", "type", "]"}], "]"}], ",", " ", 
                   RowBox[{
                    RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}]}], "]"}], 
                 "]"}]}], "]"}], "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{"appearance", " ", "times", " ", "of", " ", "type"}], 
             " ", "*)"}], "\n", "\t\t", 
            RowBox[{"timeDis", " ", "=", " ", 
             RowBox[{
              RowBox[{"FlagDeath", "[", 
               RowBox[{"[", "type", "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"1", " ", ";;", " ", 
                RowBox[{"Length", "[", 
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{"FlagDeath", "[", 
                    RowBox[{"[", "type", "]"}], "]"}], ",", " ", 
                   RowBox[{
                    RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}]}], "]"}], 
                 "]"}]}], "]"}], "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{"disappearance", " ", "times", " ", "of", " ", "type"}], 
             " ", "*)"}], "\n", "\t\t", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "@", "timeApp"}], " ", ">", " ", 
               RowBox[{"Length", "@", "timeDis"}]}], ",", " ", 
              RowBox[{"PrependTo", "[", 
               RowBox[{"timeDis", ",", " ", 
                RowBox[{"generations", " ", "+", " ", "1"}]}], "]"}]}], "]"}],
             ";", 
            RowBox[{"(*", " ", 
             RowBox[{"truncate", " ", "to", " ", "same", " ", "size"}], " ", 
             "*)"}], "\n", "\n", "\t\t", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "@", "typesA2"}], ">", "0"}], ",", "\t", 
              "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"pos", " ", "=", " ", 
                RowBox[{"First", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"Position", "[", 
                   RowBox[{"timeApp", ",", " ", 
                    RowBox[{"_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", " ", "<=", " ", "time"}], " ", "&"}], 
                    ")"}]}]}], "]"}], "]"}], "]"}]}], ";", "\n", "\t\t\t", 
               RowBox[{"(*", 
                RowBox[{
                 RowBox[{"Print", "[", "pos", "]"}], ";", "\n", "\t\t\t", 
                 RowBox[{"Print", "[", 
                  RowBox[{
                   RowBox[{"timeApp", "[", 
                    RowBox[{"[", "pos", "]"}], "]"}], ",", "\"\<-\>\"", ",", 
                   RowBox[{"timeDis", "[", 
                    RowBox[{"[", "pos", "]"}], "]"}]}], "]"}], ";"}], "*)"}], 
               "\n", "\n", "\t\t\t", 
               RowBox[{"Do", "[", "\n", "\t\t\t\t", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"masterlist", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "=", " ", "time"}], 
                  ";", " ", 
                  RowBox[{"(*", "time", "*)"}], "\n", "\t\t\t\t", 
                  RowBox[{"haptemp", " ", "=", " ", 
                   RowBox[{
                    RowBox[{"typesA2", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", ",", "1"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ";", "\n", "\t\t\t\t", 
                  RowBox[{
                   RowBox[{"masterlist", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", "=", " ", 
                   "haptemp"}], ";", " ", 
                  RowBox[{"(*", "haplotype", "*)"}], "\n", "\t\t\t\t", 
                  RowBox[{
                   RowBox[{"masterlist", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], " ", "=", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"N", "@", 
                    RowBox[{
                    RowBox[{"typesA2", "[", 
                    RowBox[{"[", 
                    RowBox[{";;", ",", "2"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], "/", "2"}], "/", 
                    "popsize"}]}], ";", " ", 
                  RowBox[{"(*", "frequency", "*)"}], "\n", "\t\t\t", "\n", 
                  "\t\t\t\t", 
                  RowBox[{"ind", " ", "=", " ", 
                   RowBox[{"Flatten", "@", 
                    RowBox[{"Position", "[", 
                    RowBox[{"SItypesT", ",", " ", "type"}], "]"}]}]}], ";", 
                  " ", 
                  RowBox[{"(*", " ", 
                   RowBox[{
                   "index", " ", "of", " ", "your", " ", "own", " ", "type"}],
                    " ", "*)"}], "\n", "\t\t\t    ", 
                  RowBox[{"SItypes", " ", "=", " ", 
                   RowBox[{"Drop", "[", 
                    RowBox[{"SItypesT", ",", " ", "ind"}], "]"}]}], ";", " ", 
                  
                  RowBox[{"(*", " ", 
                   RowBox[{
                   "SI", " ", "types", " ", "except", " ", "your", " ", 
                    "type"}], " ", "*)"}], "\n", "\t\t    ", "\n", 
                  "\t\t\t    ", 
                  RowBox[{"class", " ", "=", " ", 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{"1", "-", 
                    RowBox[{"Boole", "@", 
                    RowBox[{"SubsetQ", "[", 
                    RowBox[{
                    RowBox[{"haptemp", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ";;"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"SItypes", "[", 
                    RowBox[{"[", "id", "]"}], "]"}], "}"}]}], "]"}]}]}], ",", 
                    
                    RowBox[{"{", 
                    RowBox[{"id", ",", "1", ",", 
                    RowBox[{"Length", "@", "SItypes"}]}], "}"}]}], "]"}]}], 
                  ";", "\n", "\t\t\t    ", 
                  RowBox[{
                   RowBox[{"masterlist", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], " ", "=", " ", "class"}], 
                  ";", "\n", "\t\t\t\t", 
                  RowBox[{
                   RowBox[{"masterlist", "[", 
                    RowBox[{"[", "5", "]"}], "]"}], " ", "=", " ", 
                   RowBox[{
                    RowBox[{"timeDis", "[", 
                    RowBox[{"[", "pos", "]"}], "]"}], "-", 
                    RowBox[{"timeApp", "[", 
                    RowBox[{"[", "pos", "]"}], "]"}]}]}], ";", "\n", 
                  "\t\t\t\t", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"MasterList", ",", "masterlist"}], "]"}], ";"}], 
                 "\n", "\t\t\t\t", ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", "1", ",", 
                   RowBox[{"Length", "@", "typesA2"}]}], "}"}]}], "]"}], 
               ";"}]}], "\n", "\t\t", "]"}]}], "\n", "\t", ",", 
           RowBox[{"{", 
            RowBox[{"type", ",", "1", ",", 
             RowBox[{"FTypes", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";"}], "\n", 
        ",", 
        RowBox[{"{", 
         RowBox[{"time", ",", "t0", ",", "t1", ",", "dt"}], "}"}]}], 
       "]"}]}]}], "\n", "]"}]}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetCubeEdges", "Subsubsection"],

Cell[BoxData[
 RowBox[{"GetCubeEdges", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"CubeEdges", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"8", ",", " ", "8"}], "}"}]}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"First", " ", 
        RowBox[{"entry", ":", " ", 
         RowBox[{"forward", " ", "rate"}]}]}], ",", " ", 
       RowBox[{"Second", " ", 
        RowBox[{"entry", ":", " ", 
         RowBox[{"backward", " ", "rate"}]}]}]}], " ", "*)"}], "\n", 
     RowBox[{"CubeEdgesP", " ", "=", " ", "CubeEdges"}], ";", " ", 
     RowBox[{"CubeEdgesM", " ", "=", " ", "CubeEdges"}], ";", "\n", 
     RowBox[{"Do", "[", "\n", " \t", 
      RowBox[{
       RowBox[{
        RowBox[{"Do", "[", "\n", "   \t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"CubeEdges", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"AllPaths", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", " ", "k"}], "]"}], "]"}], ",", " ", 
               RowBox[{"AllPaths", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", " ", 
                  RowBox[{"k", " ", "+", " ", "1"}]}], "]"}], "]"}]}], "]"}], 
             "]"}], " ", "=", " ", 
            RowBox[{
             RowBox[{"CubeEdges", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"AllPaths", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", " ", "k"}], "]"}], "]"}], ",", " ", 
                RowBox[{"AllPaths", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", " ", 
                   RowBox[{"k", " ", "+", " ", "1"}]}], "]"}], "]"}]}], "]"}],
               "]"}], " ", "+", " ", "1"}]}], ";"}], "\n", "   \t", ",", " ", 
          
          RowBox[{"{", 
           RowBox[{"k", ",", " ", "1", ",", " ", 
            RowBox[{
             RowBox[{"Length", "@", 
              RowBox[{"AllPaths", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], " ", "-", " ", "1"}]}], 
           "}"}]}], "]"}], ";"}], "\n", " ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", "AllPaths"}]}], "}"}]}], "]"}], ";", "\n", 
     " ", 
     RowBox[{
      RowBox[{"Do", "[", "\n", " ", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "<", "j"}], ",", 
          RowBox[{
           RowBox[{"CubeEdgesP", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{"CubeEdges", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"CubeEdgesM", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "i"}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{"CubeEdges", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], "]"}], "\n", " ", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "8"}], "}"}]}], "]"}], "\n", " ", 
      RowBox[{"{", 
       RowBox[{"CubeEdges", ",", "CubeEdgesM", ",", "CubeEdgesP"}], 
       "}"}]}]}]}], "\n", " ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["Labels", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"R1", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Black", ",", " ", 
       RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"F1x", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
       "White", ",", " ", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"F1", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
       "Black", ",", " ", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"R2", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Lighter", "[", 
        RowBox[{"Blue", ",", " ", "0.25"}], "]"}], ",", " ", 
       RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"F2x", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", " ", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Blue", ",", " ", "0.25"}], "]"}]}], "]"}], "]"}], ",", 
       " ", "White", ",", " ", 
       RowBox[{"Polygon", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"F2", " ", "=", " ", 
    RowBox[{"Graphics", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", " ", 
           RowBox[{"Lighter", "[", 
            RowBox[{"Blue", ",", " ", "0.25"}], "]"}]}], "]"}], "]"}], ",", 
        " ", 
        RowBox[{"Lighter", "[", 
         RowBox[{"Blue", ",", " ", "0.25"}], "]"}], ",", " ", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",",
       " ", 
      RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{"l1", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l2", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l3", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l4", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R1", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l5", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l6", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l7", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"l8", "=", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"R2", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], 
  ";"}]}], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetMasterList", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetMasterList", ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\t", "\n", 
     RowBox[{
      RowBox[{"MasterList", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\n", 
      RowBox[{"Do", "[", "\n", "\t", 
       RowBox[{
        RowBox[{
         RowBox[{"timeApp", " ", "=", " ", 
          RowBox[{
           RowBox[{"FlagBirth", "[", 
            RowBox[{"[", "type", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", " ", ";;", " ", 
             RowBox[{"Length", "[", 
              RowBox[{"Select", "[", 
               RowBox[{
                RowBox[{"FlagBirth", "[", 
                 RowBox[{"[", "type", "]"}], "]"}], ",", " ", 
                RowBox[{
                 RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}]}], "]"}], 
              "]"}]}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"appearance", " ", "times", " ", "of", " ", "type"}], " ", 
          "*)"}], "\n", "\t", 
         RowBox[{"timeDis", " ", "=", " ", 
          RowBox[{
           RowBox[{"FlagDeath", "[", 
            RowBox[{"[", "type", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", " ", ";;", " ", 
             RowBox[{"Length", "[", 
              RowBox[{"Select", "[", 
               RowBox[{
                RowBox[{"FlagDeath", "[", 
                 RowBox[{"[", "type", "]"}], "]"}], ",", " ", 
                RowBox[{
                 RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}]}], "]"}], 
              "]"}]}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"disappearance", " ", "times", " ", "of", " ", "type"}], 
          " ", "*)"}], "\n", "\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "@", "timeApp"}], " ", ">", " ", 
            RowBox[{"Length", "@", "timeDis"}]}], ",", " ", 
           RowBox[{
            RowBox[{"PrependTo", "[", 
             RowBox[{"timeDis", ",", " ", 
              RowBox[{"generations", " ", "+", " ", "1"}]}], "]"}], ";", 
            RowBox[{"sh", "=", "1"}], ";"}]}], "]"}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"truncate", " ", "to", " ", "same", " ", "size"}], " ", 
          "*)"}], "\n", "\n", "\t", 
         RowBox[{"Do", "[", "\n", "\n", "\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{"haptemp", " ", "=", " ", 
             RowBox[{
              RowBox[{"BornHaps", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "type"}], "]"}], "]"}], "[", 
              RowBox[{"[", "ev", "]"}], "]"}]}], ";", " ", "\n", "\t\t", 
            RowBox[{"timeA", " ", "=", " ", 
             RowBox[{"timeApp", "[", 
              RowBox[{"[", "ev", "]"}], "]"}]}], ";", "\n", "\t\t", 
            RowBox[{"timeD", " ", "=", " ", 
             RowBox[{
              RowBox[{"timeDis", "[", 
               RowBox[{"[", "ev", "]"}], "]"}], "-", "1"}]}], ";", "\n", 
            "\t\t", "\n", "\t\t", 
            RowBox[{"masterlist", " ", "=", " ", 
             RowBox[{"Flatten", "@", 
              RowBox[{"ConstantArray", "[", 
               RowBox[{"0", ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "11"}], "}"}]}], "]"}]}]}], ";", "\n", 
            "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "1", "]"}], "]"}], " ", "=", " ", "haptemp"}], ";",
             "\t\t", "\n", "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "2", "]"}], "]"}], " ", "=", " ", "timeA"}], ";", 
            " ", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "5", "]"}], "]"}], " ", "=", " ", 
             RowBox[{
              RowBox[{"GetClass", "[", 
               RowBox[{"timeA", ",", "type"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "4", "]"}], "]"}], " ", "=", " ", "timeD"}], ";", 
            " ", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "7", "]"}], "]"}], " ", "=", " ", 
             RowBox[{
              RowBox[{"GetClass", "[", 
               RowBox[{"timeD", ",", "type"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "8", "]"}], "]"}], " ", "=", " ", 
             RowBox[{
              RowBox[{"timeDis", "[", 
               RowBox[{"[", "ev", "]"}], "]"}], "-", 
              RowBox[{"timeApp", "[", 
               RowBox[{"[", "ev", "]"}], "]"}], "+", "1"}]}], ";", "\n", 
            "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "9", "]"}], "]"}], " ", "=", " ", "hapout"}], ";", 
            "\n", "\t\t", "\n", "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "3", "]"}], "]"}], " ", "=", " ", "timeA"}], ";", 
            "\n", "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "6", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "5", "]"}], "]"}]}], ";", "\n", "\t\t", "\n", 
            "\t\t", 
            RowBox[{"Class", " ", "=", " ", 
             RowBox[{"{", "}"}]}], ";", " ", 
            RowBox[{"ClassT", " ", "=", " ", 
             RowBox[{"{", "}"}]}], ";", "\n", "\t\t", 
            RowBox[{"If", "[", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"timeD", "-", "timeA"}], " ", ">=", " ", "1"}], ",", 
              "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"Do", "[", "\n", "\t\t\t\t", 
                RowBox[{
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"Class", ",", 
                    RowBox[{
                    RowBox[{"GetClass", "[", 
                    RowBox[{"t", ",", "type"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", "\n", 
                  "\t\t\t\t", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"ClassT", ",", "t"}], "]"}], ";"}], "\n", "\t\t\t",
                  ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "timeA", ",", "timeD"}], "}"}]}], "]"}], 
               ";", "\n", "\t\t\t\t", "\n", "\t\t\t", 
               RowBox[{"P", " ", "=", " ", 
                RowBox[{"Flatten", "@", 
                 RowBox[{"Position", "[", 
                  RowBox[{"Class", ",", 
                   RowBox[{"Min", "[", "Class", "]"}]}], "]"}]}]}], ";", " ", 
               "\n", "\t\t\t", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "@", "P"}], ">=", "1"}], ",", "\n", 
                 "\t\t\t\t", 
                 RowBox[{"P", "=", 
                  RowBox[{"P", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ";", " ", "\n", 
               "\t\t\t\t", 
               RowBox[{
                RowBox[{"masterlist", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], " ", "=", " ", 
                RowBox[{"ClassT", "[", 
                 RowBox[{"[", "P", "]"}], "]"}]}], ";", "\n", "\t\t\t\t", 
               RowBox[{
                RowBox[{"masterlist", "[", 
                 RowBox[{"[", "6", "]"}], "]"}], " ", "=", " ", 
                RowBox[{"Class", "[", 
                 RowBox[{"[", "P", "]"}], "]"}]}], ";", "\n", "\t\t\t\t", 
               RowBox[{
                RowBox[{
                "masterlist", "\[LeftDoubleBracket]", "11", 
                 "\[RightDoubleBracket]"}], " ", "=", " ", 
                RowBox[{
                 RowBox[{"GetClass", "[", 
                  RowBox[{
                   RowBox[{
                   "ClassT", "\[LeftDoubleBracket]", "P", 
                    "\[RightDoubleBracket]"}], ",", "type"}], "]"}], 
                 "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
               ";"}]}], "\n", "\t\t\t\t", "]"}], ";", "\n", "\t\t", 
            RowBox[{
             RowBox[{"masterlist", "[", 
              RowBox[{"[", "10", "]"}], "]"}], " ", "=", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"N", "@", 
                RowBox[{"Max", "[", 
                 RowBox[{"SIcounts", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"timeA", ";;", "timeD"}], ",", "type"}], "]"}], 
                  "]"}], "]"}]}], "/", "2"}], "/", "popsize"}]}], ";", "\n", 
            "\t\t\t\t\t\t\t\t", "\n", "\t\t", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"MasterList", ",", "masterlist"}], "]"}], ";"}], "\n", 
           "\t\t", "\n", "\t\t", ",", 
           RowBox[{"{", 
            RowBox[{"ev", ",", "1", ",", 
             RowBox[{"Length", "@", "timeApp"}]}], "}"}]}], "]"}], ";"}], 
        "\n", ",", 
        RowBox[{"{", 
         RowBox[{"type", ",", "1", ",", 
          RowBox[{"FTypes", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ";", "\n", 
      "MasterList"}]}], "\t", "\n", "]"}]}], ";"}]], "Code",
 CellChangeTimes->{
  3.722581468642363*^9, {3.722582195548208*^9, 3.7225822179456387`*^9}, {
   3.723528986930769*^9, 3.723529029376068*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetPaths", "Subsubsection"],

Cell[BoxData[
 RowBox[{"GetPaths", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"tp", ":", " ", "1"}], "=", 
       RowBox[{"starting", " ", "hap"}]}], ",", " ", 
      RowBox[{"9", " ", "=", " ", 
       RowBox[{"last", " ", "hap"}]}], ",", " ", 
      RowBox[{"11", " ", "=", " ", 
       RowBox[{"most", " ", "complete", " ", "hap"}]}]}], " ", "*)"}], "\n", 
    "\t", 
    RowBox[{
     RowBox[{"typ", " ", "=", " ", "11"}], ";", "\n", "\t", 
     RowBox[{"AllPaths", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "\t", 
     RowBox[{"CubeID", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"Do", "[", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"id", " ", "=", " ", "299"}], ";"}], "*)"}], "\n", "\t\t", 
      RowBox[{"(*", " ", "GetPaths", " ", "*)"}], "\n", "\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"H0", " ", "=", " ", 
         RowBox[{"MutationFrom", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"H", " ", "=", " ", 
         RowBox[{"MasterListTest", "[", 
          RowBox[{"[", 
           RowBox[{"id", ",", "typ"}], "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"T", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"MasterListTest", "[", 
           RowBox[{"[", 
            RowBox[{"id", ",", "2"}], "]"}], "]"}], "}"}]}], ";", "\n", "\n", 
        "\t\t", 
        RowBox[{"PathH", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", " ", 
        RowBox[{"PathT", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", "\n", "\t\t", 
        RowBox[{"PrependTo", "[", 
         RowBox[{"PathH", ",", "H"}], "]"}], ";", " ", 
        RowBox[{"PrependTo", "[", 
         RowBox[{"PathT", ",", "T"}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"Rs", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"H", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "}"}]}], ";", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Print", "[", "H", "]"}], ";"}], "*)"}], "\n", "\t\t", 
        RowBox[{"ncount", " ", "=", " ", "1"}], ";", "\n", "\n", "\n", "\t\t", 
        RowBox[{"While", "[", " ", 
         RowBox[{
          RowBox[{"ncount", "<", "generations"}], ",", "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"p", " ", "=", " ", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"MutationTo", ",", "H"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t\t", 
           RowBox[{"H", " ", "=", " ", 
            RowBox[{"Flatten", "@", 
             RowBox[{"MutationFrom", "[", 
              RowBox[{"[", "p", "]"}], "]"}]}]}], ";", " ", "\n", "\t\t\t", 
           RowBox[{"T", " ", "=", " ", 
            RowBox[{"MutationTime", "[", 
             RowBox[{"[", "p", "]"}], "]"}]}], ";", "\n", "\t\t\t", 
           RowBox[{"PrependTo", "[", 
            RowBox[{"PathH", ",", "H"}], "]"}], ";", " ", 
           RowBox[{"PrependTo", "[", 
            RowBox[{"PathT", ",", "T"}], "]"}], ";", "\n", "\t\t\t", 
           RowBox[{"ncount", " ", "=", " ", 
            RowBox[{"ncount", "+", "1"}]}], ";", "\n", "\n", "\t\t\t", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Boole", "@", 
               RowBox[{"SubsetQ", "[", 
                RowBox[{"Rs", ",", 
                 RowBox[{"{", 
                  RowBox[{"H", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}]}], "==", 
              "0"}], ",", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"Rs", ",", 
               RowBox[{"H", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}], ";", "\n", 
           "\t\t\t", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "@", "Rs"}], ">", "2"}], ",", " ", 
              RowBox[{
               RowBox[{"Break", "[", "]"}], ";"}]}], "]"}], "\n", "\t\t\t", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"H", "==", "H0"}], ",", " ", 
              RowBox[{
               RowBox[{"Break", "[", "]"}], ";"}]}], "]"}]}]}]}], "\n", 
         "\t\t\t", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"H", ",", "\"\<,\>\"", ",", "T"}], "]"}], ";"}], "*)"}], 
         "\n", "\t\t", "\n", "\t\t", "]"}], ";", "\n", "\t\t", 
        RowBox[{"path", " ", "=", " ", "PathH"}], ";", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{"PathH", "//", "MatrixForm"}], "]"}], ";", "\n", "\t\t", 
          RowBox[{"Print", "[", 
           RowBox[{"PathT", "//", "MatrixForm"}], "]"}], ";"}], "*)"}], "\n", 
        "\t", "\n", "\t\t", 
        RowBox[{"(*", " ", 
         RowBox[{"Cube", " ", "codes"}], " ", "*)"}], "\n", "\t\t", 
        RowBox[{"If", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Tally", "@", 
               RowBox[{"path", "[", 
                RowBox[{"[", 
                 RowBox[{";;", ",", "1"}], "]"}], "]"}]}], ")"}], "[", 
             RowBox[{"[", 
              RowBox[{";;", ",", "1"}], "]"}], "]"}], "]"}], " ", ">", " ", 
           "1"}], ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{
            "exclude", " ", "events", " ", "that", " ", "only", " ", "have", 
             " ", "the", " ", "starting", " ", "R"}], "=", "1"}], " ", "*)"}],
           "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"N2", " ", "=", " ", 
            RowBox[{"Length", "[", 
             RowBox[{
              RowBox[{"Split", "[", 
               RowBox[{"path", "[", 
                RowBox[{"[", " ", 
                 RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";", "\n", "\t\t\t", 
           RowBox[{"typeFrom", " ", "=", " ", 
            RowBox[{
             RowBox[{"path", "[", 
              RowBox[{"[", " ", 
               RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"-", "N2"}], " ", "-", " ", "1"}], "]"}], "]"}]}], ";",
            "\n", "\t\t\t", 
           RowBox[{"N1", " ", "=", " ", 
            RowBox[{"Length", "[", 
             RowBox[{
              RowBox[{"Split", "[", 
               RowBox[{"path", "[", 
                RowBox[{"[", 
                 RowBox[{";;", " ", ",", " ", "1"}], "]"}], "]"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"-", "2"}], "]"}], "]"}], "]"}]}], ";", "\n", "\t\t\t", 
           RowBox[{"path", " ", "=", " ", 
            RowBox[{"path", "[", 
             RowBox[{"[", " ", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"-", "N2"}], " ", "-", " ", "N1"}], " ", ";;"}], ",",
                " ", ";;"}], "]"}], "]"}]}], ";", " ", "\n", "\t\t\t", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{"path", "//", "MatrixForm"}], "]"}], ";"}], "*)"}], 
           "\n", "\t\t\t", 
           RowBox[{"Np", " ", "=", " ", 
            RowBox[{"path", "//", "Length"}]}], ";", "\n", "\t\t\t", 
           RowBox[{"pathCode", " ", "=", " ", 
            RowBox[{"ConstantArray", "[", 
             RowBox[{"0", ",", " ", "Np"}], "]"}]}], ";", "\n", "\t\t\t", 
           RowBox[{"type", " ", "=", " ", 
            RowBox[{"path", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}], ";", "\n", 
           "\n", "\t\t\t\t\t ", 
           RowBox[{"Do", "[", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "labels", " ", "haplotypes", " ", "by", " ", "positions", " ", 
              "on", " ", "the", " ", "cube"}], " ", "*)"}], "\n", "\n", 
            "\t\t\t   \t\t", 
            RowBox[{
             RowBox[{
              RowBox[{"hap", " ", "=", " ", 
               RowBox[{"path", "[", 
                RowBox[{"[", 
                 RowBox[{"k", ",", " ", ";;"}], "]"}], "]"}]}], ";", "\n", 
              "\t\t\t   \t\t", 
              RowBox[{"(*", 
               RowBox[{"If", " ", "[", 
                RowBox[{
                 RowBox[{"typeFrom", "\[NotEqual]", "type"}], ","}]}], "*)"}],
               "\n", "\t\t\t   \t\t", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", 
                 "typeFrom"}], ",", "\n", "\t\t\t    \t\t\t", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "3"}]}], 
                  "]"}], ";", "\n", "\t\t\t    \t\t\t", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "4"}]}], 
                  "]"}], ";", "\n", "\t\t\t    \t\t\t", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "1"}]}], 
                  "]"}], ";", "\n", "\t\t\t    \t\t\t", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "2"}]}], 
                  "]"}], ";"}]}], "\n", "\t\t\t    \t\t", "]"}], ";", "\n", 
              "\t\t\t   \t\t", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"hap", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", "type"}], 
                ",", "\n", "\t\t\t    \t\t\t", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "7"}]}], 
                  "]"}], ";", "\n", "\t\t\t    \t\t\t", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", ">", " ", "0"}], " ", "&&", " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "8"}]}], 
                  "]"}], ";", "\n", "\t\t\t    \t\t\t", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", ">", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "5"}]}], 
                  "]"}], ";", "\n", "\t\t\t    \t\t\t", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "typeFrom"}], "]"}], " ", "==", " ", "0"}], " ", "&&", 
                    " ", 
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"hap", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", " ", ";;"}], "]"}], "]"}], ",", " ", 
                    "type"}], "]"}], " ", "==", " ", "0"}]}], ",", " ", 
                   RowBox[{
                    RowBox[{"pathCode", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "=", " ", "6"}]}], 
                  "]"}], ";"}]}], "\t", "\n", "\t\t\t    \t\t", "]"}], ";"}], 
             "\n", "\t\t\t   \t\t", 
             RowBox[{"(*", 
              RowBox[{"]", ";"}], "*)"}], "\n", "\t\t\t   \t  ", ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", " ", "1", ",", " ", "Np"}], "}"}]}], "]"}], 
           ";", "\n", "\t\t\t   \t  ", 
           RowBox[{"pathCode", " ", "=", " ", 
            RowBox[{"First", " ", "/@", " ", 
             RowBox[{"Split", "[", 
              RowBox[{"pathCode", " ", "//", " ", "Flatten"}], "]"}]}]}], ";",
            "\n", "\t\t\t   \t  ", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Print", "[", "pathCode", "]"}], ";"}], "*)"}], "\n", 
           "\t\t\t   \t  ", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"AllPaths", ",", " ", "pathCode"}], "]"}], ";", "\n", 
           "\t\t\t   \t  ", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"CubeID", ",", " ", 
             RowBox[{"{", 
              RowBox[{"type", ",", " ", "typeFrom"}], "}"}]}], "]"}], ";"}]}],
          "\n", "\t\t\t   \t  ", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Print", "[", "AllPaths", "]"}], ";"}], "*)"}], "\n", 
         "\t\t\t", "]"}], ";"}], "\t   \t  ", "\n", "\t ", ",", "  ", 
       RowBox[{"{", 
        RowBox[{"id", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", "MasterListTest"}]}], "}"}]}], "]"}], ";", 
     "\n", "\t ", 
     RowBox[{"{", 
      RowBox[{"AllPaths", ",", "pathCode"}], "}"}]}]}], "\n", " ", 
   "]"}]}]], "Code",
 CellChangeTimes->{{3.722593135608203*^9, 3.722593205757966*^9}, {
   3.7225932399346333`*^9, 3.722593243941886*^9}, {3.7225932927562017`*^9, 
   3.722593353098587*^9}, {3.722594651762971*^9, 3.722594651992897*^9}, {
   3.722595344573517*^9, 3.722595345162898*^9}, 3.723533372508581*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetCubeEdges", "Subsubsection"],

Cell[BoxData[
 RowBox[{"GetCubeEdges", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"CubeEdges", " ", "=", " ", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{"{", 
         RowBox[{"8", ",", " ", "8"}], "}"}]}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"First", " ", 
        RowBox[{"entry", ":", " ", 
         RowBox[{"forward", " ", "rate"}]}]}], ",", " ", 
       RowBox[{"Second", " ", 
        RowBox[{"entry", ":", " ", 
         RowBox[{"backward", " ", "rate"}]}]}]}], " ", "*)"}], "\n", 
     RowBox[{"CubeEdgesP", " ", "=", " ", "CubeEdges"}], ";", " ", 
     RowBox[{"CubeEdgesM", " ", "=", " ", "CubeEdges"}], ";", "\n", 
     RowBox[{"Do", "[", "\n", " \t", 
      RowBox[{
       RowBox[{
        RowBox[{"Do", "[", "\n", "   \t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"CubeEdges", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"AllPaths", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", " ", "k"}], "]"}], "]"}], ",", " ", 
               RowBox[{"AllPaths", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", " ", 
                  RowBox[{"k", " ", "+", " ", "1"}]}], "]"}], "]"}]}], "]"}], 
             "]"}], " ", "=", " ", 
            RowBox[{
             RowBox[{"CubeEdges", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"AllPaths", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", " ", "k"}], "]"}], "]"}], ",", " ", 
                RowBox[{"AllPaths", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", " ", 
                   RowBox[{"k", " ", "+", " ", "1"}]}], "]"}], "]"}]}], "]"}],
               "]"}], " ", "+", " ", "1"}]}], ";"}], "\n", "   \t", ",", " ", 
          
          RowBox[{"{", 
           RowBox[{"k", ",", " ", "1", ",", " ", 
            RowBox[{
             RowBox[{"Length", "@", 
              RowBox[{"AllPaths", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], " ", "-", " ", "1"}]}], 
           "}"}]}], "]"}], ";"}], "\n", " ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "@", "AllPaths"}]}], "}"}]}], "]"}], ";", "\n", 
     " ", 
     RowBox[{
      RowBox[{"Do", "[", "\n", " ", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "<", "j"}], ",", 
          RowBox[{
           RowBox[{"CubeEdgesP", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{"CubeEdges", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"CubeEdgesM", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "i"}], "]"}], "]"}], " ", "=", " ", 
           RowBox[{"CubeEdges", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], "]"}], "\n", " ", ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "8"}], "}"}]}], "]"}], "\n", " ", 
      RowBox[{"{", 
       RowBox[{"CubeEdges", ",", "CubeEdgesM", ",", "CubeEdgesP"}], 
       "}"}]}]}]}], "\n", " ", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetCube", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetCube", "[", 
   RowBox[{
   "CubeEdges_", ",", "CubeEdgesM_", ",", "CubeEdgesP_", ",", "id_", ",", 
    "lbl_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"id", "==", "1"}], ",", "\n", "\t\t", 
       RowBox[{
        RowBox[{"PE", " ", "=", " ", 
         RowBox[{"Position", "[", 
          RowBox[{"CubeEdgesP", ",", " ", 
           RowBox[{"_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}], ")"}]}]}], 
          "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"TotalCE", " ", "=", " ", "CubeEdgesP"}], ";", "\n", "\t\t", 
        RowBox[{"Capacity", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"CubeEdgesP", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "k"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", 
        "\t\t", 
        RowBox[{"Lab", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ToString", "[", 
            RowBox[{"NumberForm", "[", " ", 
             RowBox[{
              RowBox[{"CubeEdgesP", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "2"}], "]"}], "]"}]}], "]"}], "]"}],
               " ", ",", " ", "2"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", "1", ",", " ", 
             RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], ";"}]}], "\n",
       "\t", "]"}], ";", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"id", "==", "2"}], ",", "\n", "\t\t", 
       RowBox[{
        RowBox[{"PE", " ", "=", " ", 
         RowBox[{"Position", "[", 
          RowBox[{"CubeEdgesM", ",", " ", 
           RowBox[{"_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}], ")"}]}]}], 
          "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"TotalCE", " ", "=", " ", "CubeEdgesM"}], ";", "\n", "\t\t", 
        RowBox[{"Capacity", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"CubeEdgesM", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "k"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", 
        "\t\t", 
        RowBox[{"Lab", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ToString", "[", 
            RowBox[{"NumberForm", "[", " ", 
             RowBox[{
              RowBox[{"CubeEdgesM", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "2"}], "]"}], "]"}]}], "]"}], "]"}],
               " ", ",", " ", "2"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", "1", ",", " ", 
             RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], ";"}]}], "\n",
       "\t", "]"}], ";", "\n", "\t", 
     RowBox[{"NE", " ", "=", " ", 
      RowBox[{"Flatten", "@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PE", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}], "<->", 
           RowBox[{"PE", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}]}], ";", "\n", 
     "\t", 
     RowBox[{"gfull", " ", "=", " ", 
      RowBox[{"Flatten", "@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"i", "<->", "j"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"i", "+", "1"}], ",", "8"}], "}"}]}], "]"}]}]}], ";", "\n",
      "\t", 
     RowBox[{"gpart", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "\t", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"TotalCE", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}], ">", "0"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"gpart", ",", 
           RowBox[{"i", "<->", "j"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"i", "+", "1"}], ",", "8"}], "}"}]}], "]"}], ";", "\n", "\n",
      "\t", 
     RowBox[{"coord", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]}], ";", "\n", "\t", 
     RowBox[{
      RowBox[{"ef", "[", 
       RowBox[{"pts_List", ",", " ", "e_"}], "]"}], " ", ":=", 
      RowBox[{
       RowBox[{
        RowBox[{"Block", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"s", " ", "=", " ", "0.004"}], ",", " ", 
            RowBox[{"ge", " ", "=", " ", 
             RowBox[{"Graphics", "[", 
              RowBox[{
               RowBox[{"Circle", "[", 
                RowBox[{"{", 
                 RowBox[{"0", ",", " ", "0"}], "}"}], "]"}], ",", " ", 
               RowBox[{"ImageSize", " ", "->", " ", 
                RowBox[{"{", 
                 RowBox[{"11.", ",", " ", "Automatic"}], "}"}]}]}], "]"}]}]}],
            "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Arrowheads", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"s", ",", " ", "0.33", ",", " ", "ge"}], "}"}], ",", 
               " ", 
               RowBox[{"{", 
                RowBox[{"s", ",", " ", "0.67", ",", " ", "ge"}], "}"}]}], 
              "}"}], "]"}], ",", " ", 
            RowBox[{"Arrow", "[", "pts", "]"}]}], "}"}]}], "]"}], "\n", "\t", 
        "R1"}], " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Black", ",", " ", 
           RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
         RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}]}], ";", "\n", 
     "\t", 
     RowBox[{"F1x", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
          "White", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"F1", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
          "Black", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"R2", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
          RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"F2x", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", 
          " ", "White", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"F2", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", 
          " ", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\n", "\t", 
     RowBox[{"l1", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l2", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l3", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l4", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l5", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l6", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l7", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l8", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\n", "\t", 
     RowBox[{"Vlabels", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "->", "l1"}], ",", 
        RowBox[{"2", "->", "l2"}], ",", 
        RowBox[{"3", "->", "l3"}], ",", 
        RowBox[{"4", "->", "l4"}], ",", 
        RowBox[{"5", "->", "l5"}], ",", 
        RowBox[{"6", "->", "l6"}], ",", 
        RowBox[{"7", "->", "l7"}], ",", 
        RowBox[{"8", "->", "l8"}]}], "}"}]}], ";", "\n", "\n", "\t", 
     RowBox[{"g1", " ", "=", " ", 
      RowBox[{"Graph", "[", 
       RowBox[{"gfull", " \t\t", "\n", "\t\t", ",", 
        RowBox[{"VertexStyle", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "->", "Red"}], ",", 
           RowBox[{"2", "->", "Red"}], ",", 
           RowBox[{"3", "->", "Green"}], ",", 
           RowBox[{"4", "->", "Green"}], ",", 
           RowBox[{"5", "->", "Green"}], ",", 
           RowBox[{"6", "->", "Red"}], ",", 
           RowBox[{"7", "->", "Green"}], ",", 
           RowBox[{"8", "->", "Red"}]}], "}"}]}], "\n", "\t\t", ",", 
        RowBox[{"EdgeStyle", "->", " ", "\n", "\t\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"id", "==", "1"}], ",", "\n", "\t\t\t", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
                RowBox[{"{", 
                 RowBox[{"Blue", ",", 
                  RowBox[{"Thickness", "->", 
                   RowBox[{"0.03", "*", 
                    RowBox[{
                    RowBox[{"Capacity", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
                    "/", 
                    RowBox[{"Max", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"Max", "@", "Capacity"}]}], "}"}], "]"}]}]}]}]}], 
                 "}"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", 
                 RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}], ",", "\n", 
             "\t\t\t", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Thickness", "->", 
                   RowBox[{"0.03", "*", 
                    RowBox[{
                    RowBox[{"Capacity", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
                    "/", 
                    RowBox[{"Max", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"Max", "@", "Capacity"}]}], "}"}], "]"}]}]}]}]}], 
                 "}"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", 
                 RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], "*)"}], 
           "\n", "\t\t\t", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Thickness", "->", 
                 RowBox[{"0.01", "*", 
                  RowBox[{"Log", "@", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Capacity", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], 
                    ")"}]}]}]}]}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}], ",", "\n", 
           "\t\t\t", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Thickness", "->", 
                 RowBox[{"0.01", "*", 
                  RowBox[{"Log", "@", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"Capacity", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], 
                    ")"}]}]}]}]}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], "\n", 
          "\t\t\t", "]"}]}], "\n", "\t\t", ",", 
        RowBox[{"EdgeShapeFunction", "->", 
         RowBox[{"GraphElementData", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<HalfFilledArrow\>\"", ",", " ", 
            RowBox[{"\"\<ArrowSize\>\"", " ", "->", " ", ".0001"}]}], "}"}], 
          "]"}]}], "\n", "\t\t", ",", 
        RowBox[{"VertexCoordinates", "->", "coord"}], "\n", "\t\t", ",", 
        RowBox[{"VertexSize", "->", "0.07"}], "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{"VertexLabels", "->", "Vlabels"}]}], " ", "*)"}], "\n", 
        "\t    ", ",", 
        RowBox[{"EdgeLabels", " ", "->", " ", "\n", "\t\t", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PE", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], "<->", 
             RowBox[{"PE", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "->", 
            RowBox[{"Placed", "[", 
             RowBox[{
              RowBox[{"Lab", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.5", ",", 
                RowBox[{"{", 
                 RowBox[{"0.5", ",", "0.2"}], "}"}]}], "}"}]}], "]"}]}], ",", 
           
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], " ", "\n", 
        "\t\t", ",", 
        RowBox[{"EdgeLabelStyle", " ", "->", " ", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", " ", "Bold", ",", "10"}], "]"}]}], "\n", 
        "\t\t", ",", 
        RowBox[{"PlotLabel", " ", "->", " ", "lbl"}]}], "\n", "\t", "]"}]}], 
     ";", "\n", "\t", 
     RowBox[{"{", "g1", "}"}]}]}], "\n", "]"}]}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetProbabilities", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Prob", "[", 
   RowBox[{"p_", ",", "P_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Total", "@", "P"}], "==", "0"}], ",", 
       RowBox[{"Pres", " ", "=", " ", "0"}], ",", "\n", "\t", 
       RowBox[{"Pres", " ", "=", " ", 
        RowBox[{
         RowBox[{"N", "@", "p"}], "/", 
         RowBox[{"Total", "@", "P"}]}]}]}], "]"}], ";", "\n", "\t", 
     "Pres"}]}], "\n", "]"}]}]], "Code"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GetProbabilities", "[", 
    RowBox[{"CubeEdgesProbM_", ",", "CubeEdgesProbP_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"CubeProbM", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "8"}], "}"}]}], "]"}]}], ";", " ", 
      RowBox[{"CubeProbP", " ", "=", " ", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", "\t", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", 
            RowBox[{"2", ";;", "5"}]}], "]"}], "]"}]}], "]"}]}], ";", " ", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", 
            RowBox[{"2", ";;", "5"}]}], "]"}], "]"}]}], "]"}]}], ";", " ", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "4"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "4"}], "]"}], "]"}], ",", 
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", 
            RowBox[{"2", ";;", "5"}]}], "]"}], "]"}]}], "]"}]}], ";", " ", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "5"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "5"}], "]"}], "]"}], ",", 
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", 
            RowBox[{"2", ";;", "5"}]}], "]"}], "]"}]}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "4"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "6"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "6"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "6"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "6"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"4", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"4", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "4"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "7"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "7"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "7"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "6"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "5"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "7"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "5"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"5", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "5"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"6", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"6", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"6", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbP", "[", 
        RowBox[{"[", 
         RowBox[{"7", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbP", "[", 
          RowBox[{"[", 
           RowBox[{"7", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"7", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\n", "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "6"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "4"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "4"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "4"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "4"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "4"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "7"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "5"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "5"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "5"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "6"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "6"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"6", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "6"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"6", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "7"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "7"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"7", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "7"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "7"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbP", "[", 
            RowBox[{"[", 
             RowBox[{"7", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"4", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"4", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"6", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"7", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"5", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"6", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"7", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"6", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"6", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"6", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"7", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", 
      RowBox[{
       RowBox[{"CubeProbM", "[", 
        RowBox[{"[", 
         RowBox[{"7", ",", "8"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"Prob", "[", 
        RowBox[{
         RowBox[{"CubeEdgesProbM", "[", 
          RowBox[{"[", 
           RowBox[{"7", ",", "8"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"5", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"6", ",", "8"}], "]"}], "]"}], ",", 
           RowBox[{"CubeEdgesProbM", "[", 
            RowBox[{"[", 
             RowBox[{"7", ",", "8"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\t", "\n", "\t", 
      RowBox[{"{", 
       RowBox[{"CubeProbM", ",", "CubeProbP"}], "}"}]}]}], "\n", "]"}]}], 
  "\n", "\n"}]], "Code"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetCubeProb", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetCubeProb", "[", 
   RowBox[{
   "CubeEdges_", ",", "CubeEdgesM_", ",", "CubeEdgesP_", ",", "id_", ",", 
    "lbl_", ",", "thick_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"id", "==", "1"}], ",", "\n", "\t\t", 
       RowBox[{
        RowBox[{"PE", " ", "=", " ", 
         RowBox[{"Position", "[", 
          RowBox[{"CubeEdgesP", ",", " ", 
           RowBox[{"_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}], ")"}]}]}], 
          "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"TotalCE", " ", "=", " ", "CubeEdgesP"}], ";", "\n", "\t\t", 
        RowBox[{"Capacity", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"CubeEdgesP", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "k"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", 
        "\t\t", 
        RowBox[{"Lab", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ToString", "[", 
            RowBox[{"NumberForm", "[", " ", 
             RowBox[{
              RowBox[{"CubeEdgesP", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "2"}], "]"}], "]"}]}], "]"}], "]"}],
               " ", ",", " ", "2"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", "1", ",", " ", 
             RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], ";"}]}], "\n",
       "\t", "]"}], ";", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"id", "==", "2"}], ",", "\n", "\t\t", 
       RowBox[{
        RowBox[{"PE", " ", "=", " ", 
         RowBox[{"Position", "[", 
          RowBox[{"CubeEdgesM", ",", " ", 
           RowBox[{"_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", " ", ">", " ", "0"}], " ", "&"}], ")"}]}]}], 
          "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"TotalCE", " ", "=", " ", "CubeEdgesM"}], ";", "\n", "\t\t", 
        RowBox[{"Capacity", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"CubeEdgesM", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "k"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", 
        "\t\t", 
        RowBox[{"Lab", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ToString", "[", 
            RowBox[{"NumberForm", "[", " ", 
             RowBox[{
              RowBox[{"CubeEdgesM", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "1"}], "]"}], "]"}], ",", " ", 
                 RowBox[{"PE", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", " ", "2"}], "]"}], "]"}]}], "]"}], "]"}],
               " ", ",", " ", "2"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", "1", ",", " ", 
             RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], ";"}]}], "\n",
       "\t", "]"}], ";", "\n", "\t", 
     RowBox[{"NE", " ", "=", " ", 
      RowBox[{"Flatten", "@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PE", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}], "<->", 
           RowBox[{"PE", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}]}], ";", "\n", 
     "\t", 
     RowBox[{"gfull", " ", "=", " ", 
      RowBox[{"Flatten", "@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"i", "<->", "j"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"i", "+", "1"}], ",", "8"}], "}"}]}], "]"}]}]}], ";", "\n",
      "\t", 
     RowBox[{"gpart", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "\t", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"TotalCE", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}], ">", "0"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"gpart", ",", 
           RowBox[{"i", "<->", "j"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"i", "+", "1"}], ",", "8"}], "}"}]}], "]"}], ";", "\n", "\n",
      "\t", 
     RowBox[{"coord", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]}], ";", "\n", "\t", 
     RowBox[{
      RowBox[{"ef", "[", 
       RowBox[{"pts_List", ",", " ", "e_"}], "]"}], " ", ":=", 
      RowBox[{
       RowBox[{
        RowBox[{"Block", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"s", " ", "=", " ", "0.004"}], ",", " ", 
            RowBox[{"ge", " ", "=", " ", 
             RowBox[{"Graphics", "[", 
              RowBox[{
               RowBox[{"Circle", "[", 
                RowBox[{"{", 
                 RowBox[{"0", ",", " ", "0"}], "}"}], "]"}], ",", " ", 
               RowBox[{"ImageSize", " ", "->", " ", 
                RowBox[{"{", 
                 RowBox[{"11.", ",", " ", "Automatic"}], "}"}]}]}], "]"}]}]}],
            "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Arrowheads", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"s", ",", " ", "0.33", ",", " ", "ge"}], "}"}], ",", 
               " ", 
               RowBox[{"{", 
                RowBox[{"s", ",", " ", "0.67", ",", " ", "ge"}], "}"}]}], 
              "}"}], "]"}], ",", " ", 
            RowBox[{"Arrow", "[", "pts", "]"}]}], "}"}]}], "]"}], "\n", "\t", 
        "R1"}], " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Black", ",", " ", 
           RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
         RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}]}], ";", "\n", 
     "\t", 
     RowBox[{"F1x", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
          "White", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"F1", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", "Black"}], "]"}], "]"}], ",", " ", 
          "Black", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"R2", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
          RowBox[{"Disk", "[", "]"}]}], "}"}], ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"F2x", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", 
          " ", "White", ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\t", 
     RowBox[{"F2", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", " ", 
             RowBox[{"Lighter", "[", 
              RowBox[{"Gray", ",", " ", "0.2"}], "]"}]}], "]"}], "]"}], ",", 
          " ", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", " ", "0.2"}], "]"}], ",", " ", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"1", ",", " ", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", " ", 
        RowBox[{"ImageSize", " ", "->", " ", "10"}]}], "]"}]}], ";", "\n", 
     "\n", "\t", 
     RowBox[{"l1", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l2", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l3", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l4", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R1", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l5", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1x", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l6", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1x", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l7", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1", ",", "F2"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"l8", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"R2", ",", "F1", ",", "F2x"}], "}"}], "}"}], "]"}]}], ";", 
     "\n", "\n", "\t", 
     RowBox[{"Vlabels", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "->", "l1"}], ",", 
        RowBox[{"2", "->", "l2"}], ",", 
        RowBox[{"3", "->", "l3"}], ",", 
        RowBox[{"4", "->", "l4"}], ",", 
        RowBox[{"5", "->", "l5"}], ",", 
        RowBox[{"6", "->", "l6"}], ",", 
        RowBox[{"7", "->", "l7"}], ",", 
        RowBox[{"8", "->", "l8"}]}], "}"}]}], ";", "\n", "\n", "\t", 
     RowBox[{"g1", " ", "=", " ", 
      RowBox[{"Graph", "[", 
       RowBox[{"gfull", " \t\t", "\n", "\t\t", ",", 
        RowBox[{"VertexStyle", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "->", "Red"}], ",", 
           RowBox[{"2", "->", "Red"}], ",", 
           RowBox[{"3", "->", "Green"}], ",", 
           RowBox[{"4", "->", "Green"}], ",", 
           RowBox[{"5", "->", "Green"}], ",", 
           RowBox[{"6", "->", "Red"}], ",", 
           RowBox[{"7", "->", "Green"}], ",", 
           RowBox[{"8", "->", "Red"}]}], "}"}]}], "\n", "\t\t", ",", 
        RowBox[{"EdgeStyle", "->", " ", "\n", "\t\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"id", "==", "1"}], ",", "\n", "\t\t\t", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
                RowBox[{"{", 
                 RowBox[{"Blue", ",", 
                  RowBox[{"Thickness", "->", 
                   RowBox[{"0.03", "*", 
                    RowBox[{
                    RowBox[{"Capacity", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
                    "/", 
                    RowBox[{"Max", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"Max", "@", "Capacity"}]}], "}"}], "]"}]}]}]}]}], 
                 "}"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", 
                 RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}], ",", "\n", 
             "\t\t\t", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                  RowBox[{"PE", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Thickness", "->", 
                   RowBox[{"0.03", "*", 
                    RowBox[{
                    RowBox[{"Capacity", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
                    "/", 
                    RowBox[{"Max", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"Max", "@", "Capacity"}]}], "}"}], "]"}]}]}]}]}], 
                 "}"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", 
                 RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], "*)"}], 
           "\n", "\t\t\t", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Thickness", "->", 
                 RowBox[{"thick", "*", 
                  RowBox[{"Capacity", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}]}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}], ",", "\n", 
           "\t\t\t", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "1"}], "]"}], "]"}], "->", 
                RowBox[{"PE", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "->", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Thickness", "->", 
                 RowBox[{"thick", "*", 
                  RowBox[{"Capacity", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"PE", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}]}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], "\n", 
          "\t\t\t", "]"}]}], "\n", "\t\t", ",", 
        RowBox[{"EdgeShapeFunction", "->", 
         RowBox[{"GraphElementData", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<HalfFilledArrow\>\"", ",", " ", 
            RowBox[{"\"\<ArrowSize\>\"", " ", "->", " ", ".0001"}]}], "}"}], 
          "]"}]}], "\n", "\t\t", ",", 
        RowBox[{"VertexCoordinates", "->", "coord"}], "\n", "\t\t", ",", 
        RowBox[{"VertexSize", "->", "0.07"}], "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{"VertexLabels", "->", "Vlabels"}]}], " ", "*)"}], "\n", 
        "\t    ", ",", 
        RowBox[{"EdgeLabels", " ", "->", " ", "\n", "\t\t", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PE", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], "<->", 
             RowBox[{"PE", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "->", 
            RowBox[{"Placed", "[", 
             RowBox[{
              RowBox[{"Lab", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.5", ",", 
                RowBox[{"{", 
                 RowBox[{"0.5", ",", "0.2"}], "}"}]}], "}"}]}], "]"}]}], ",", 
           
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "@", "PE"}]}], "}"}]}], "]"}]}], " ", "\n", 
        "\t\t", ",", 
        RowBox[{"EdgeLabelStyle", " ", "->", " ", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", " ", "Bold", ",", "10"}], "]"}]}], "\n", 
        "\t\t", ",", 
        RowBox[{"PlotLabel", " ", "->", " ", "lbl"}]}], "\n", "\t", "]"}]}], 
     ";", "\n", "\t", 
     RowBox[{"{", "g1", "}"}]}]}], "\n", "]"}]}]], "Code"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1410, 850},
WindowMargins->{{Automatic, 30}, {Automatic, 16}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 114, 1, 92, "Title"],
Cell[CellGroupData[{
Cell[719, 27, 101, 1, 35, "Subsubsection"],
Cell[823, 30, 2319, 55, 249, "Text"],
Cell[3145, 87, 3108, 75, 222, "Input"],
Cell[6256, 164, 563, 12, 51, "Text"],
Cell[CellGroupData[{
Cell[6844, 180, 2028, 48, 96, "Input"],
Cell[8875, 230, 2878, 52, 146, "Output"]
}, Open  ]],
Cell[11768, 285, 426, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[12219, 296, 125, 2, 32, "Input"],
Cell[12347, 300, 601, 9, 32, "Output"]
}, Open  ]],
Cell[12963, 312, 290, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[13278, 322, 610, 10, 32, "Input"],
Cell[CellGroupData[{
Cell[13913, 336, 301, 4, 24, "Print"],
Cell[14217, 342, 297, 4, 24, "Print"],
Cell[14517, 348, 291, 4, 24, "Print"],
Cell[14811, 354, 287, 4, 24, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[15159, 365, 185, 2, 29, "Subsubsection"],
Cell[15347, 369, 389, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[15761, 379, 3477, 89, 243, "Input"],
Cell[19241, 470, 150405, 2561, 263, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[169695, 3037, 170, 2, 29, "Subsubsection"],
Cell[169868, 3041, 817, 13, 68, "Text"],
Cell[CellGroupData[{
Cell[170710, 3058, 1872, 44, 180, "Input"],
Cell[172585, 3104, 22487, 425, 275, "Output"]
}, Open  ]],
Cell[195087, 3532, 794, 12, 68, "Text"],
Cell[195884, 3546, 172, 3, 32, "Input"],
Cell[196059, 3551, 326, 6, 30, "Text"],
Cell[196388, 3559, 3385, 69, 180, "Input"],
Cell[CellGroupData[{
Cell[199798, 3632, 1109, 16, 32, "Input"],
Cell[200910, 3650, 477976, 9208, 275, 458413, 8886, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[678901, 12861, 1065, 16, 87, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[680003, 12882, 115, 1, 29, "Subsubsection"],
Cell[680121, 12885, 454, 8, 49, "Text"],
Cell[CellGroupData[{
Cell[680600, 12897, 1194, 24, 54, "Input"],
Cell[681797, 12923, 69480, 1349, 270, "Output"]
}, Open  ]],
Cell[751292, 14275, 547, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[751864, 14287, 682, 15, 32, "Input"],
Cell[752549, 14304, 34385, 689, 270, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[786983, 14999, 220, 4, 29, "Subsubsection"],
Cell[787206, 15005, 2038, 37, 372, "Text"],
Cell[CellGroupData[{
Cell[789269, 15046, 301, 8, 54, "Input"],
Cell[789573, 15056, 7865, 173, 204, "Output"]
}, Open  ]],
Cell[797453, 15232, 535, 9, 68, "Text"],
Cell[CellGroupData[{
Cell[798013, 15245, 9943, 277, 432, "Input"],
Cell[807959, 15524, 8497, 163, 343, "Output"]
}, Open  ]],
Cell[816471, 15690, 16646, 282, 353, "Text"],
Cell[CellGroupData[{
Cell[833142, 15976, 534, 10, 75, "Input"],
Cell[833679, 15988, 14526, 383, 236, "Print"]
}, Open  ]],
Cell[848220, 16374, 300, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[848545, 16384, 1408, 36, 180, "Input"],
Cell[CellGroupData[{
Cell[849978, 16424, 302, 6, 24, "Print"],
Cell[850283, 16432, 292, 6, 24, "Print"],
Cell[850578, 16440, 188, 2, 24, "Print"],
Cell[850769, 16444, 1226, 37, 108, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[852056, 16488, 212, 3, 50, "Section"],
Cell[CellGroupData[{
Cell[852293, 16495, 32, 0, 44, "Subsection"],
Cell[CellGroupData[{
Cell[852350, 16499, 98, 1, 35, "Subsubsection"],
Cell[852451, 16502, 956, 25, 72, "Code"]
}, Open  ]],
Cell[CellGroupData[{
Cell[853444, 16532, 35, 0, 35, "Subsubsection"],
Cell[853482, 16534, 2654, 73, 224, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[856173, 16612, 54, 0, 29, "Subsubsection"],
Cell[856230, 16614, 3544, 96, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[859811, 16715, 55, 0, 29, "Subsubsection"],
Cell[859869, 16717, 3932, 104, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[863838, 16826, 37, 0, 29, "Subsubsection"],
Cell[863878, 16828, 4971, 145, 395, "Code"],
Cell[868852, 16975, 1172, 30, 70, "Code"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[870073, 17011, 37, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[870135, 17015, 36, 0, 35, "Subsubsection"],
Cell[870174, 17017, 348, 9, 52, "Code"],
Cell[870525, 17028, 1909, 53, 224, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[872471, 17086, 38, 0, 29, "Subsubsection"],
Cell[872512, 17088, 8904, 204, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[881453, 17297, 38, 0, 29, "Subsubsection"],
Cell[881494, 17299, 12740, 286, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[894271, 17590, 33, 0, 29, "Subsubsection"],
Cell[894307, 17592, 2263, 58, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[896607, 17655, 44, 0, 29, "Subsubsection"],
Cell[896654, 17657, 2662, 70, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[899353, 17732, 46, 0, 29, "Subsubsection"],
Cell[899402, 17734, 2112, 55, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[901551, 17794, 42, 0, 29, "Subsubsection"],
Cell[901596, 17796, 2199, 57, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[903832, 17858, 41, 0, 29, "Subsubsection"],
Cell[903876, 17860, 398, 11, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[904311, 17876, 38, 0, 29, "Subsubsection"],
Cell[904352, 17878, 5098, 138, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[909487, 18021, 46, 0, 29, "Subsubsection"],
Cell[909536, 18023, 3494, 86, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[913067, 18114, 42, 0, 29, "Subsubsection"],
Cell[913112, 18116, 1329, 32, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[914478, 18153, 31, 0, 29, "Subsubsection"],
Cell[914512, 18155, 304, 8, 70, "Code"],
Cell[914819, 18165, 5751, 162, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[920607, 18332, 32, 0, 29, "Subsubsection"],
Cell[920642, 18334, 3041, 81, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[923720, 18420, 48, 0, 29, "Subsubsection"],
Cell[923771, 18422, 3622, 94, 70, "Code"],
Cell[927396, 18518, 3500, 90, 70, "Code"],
Cell[930899, 18610, 4593, 118, 70, "Code"],
Cell[935495, 18730, 5443, 139, 70, "Code"],
Cell[940941, 18871, 4674, 121, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[945652, 18997, 40, 0, 29, "Subsubsection"],
Cell[945695, 18999, 9391, 234, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[955123, 19238, 33, 0, 29, "Subsubsection"],
Cell[955159, 19240, 3434, 88, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[958630, 19333, 35, 0, 29, "Subsubsection"],
Cell[958668, 19335, 3342, 86, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[962047, 19426, 37, 0, 29, "Subsubsection"],
Cell[962087, 19428, 5700, 141, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[967824, 19574, 41, 0, 29, "Subsubsection"],
Cell[967868, 19576, 11664, 265, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[979569, 19846, 35, 0, 29, "Subsubsection"],
Cell[979607, 19848, 11956, 298, 908, "Code"],
Cell[991566, 20148, 5909, 151, 566, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[997512, 20304, 43, 0, 29, "Subsubsection"],
Cell[997558, 20306, 24768, 578, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1022363, 20889, 30, 0, 29, "Subsubsection"],
Cell[1022396, 20891, 1786, 39, 205, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1024219, 20935, 43, 0, 29, "Subsubsection"],
Cell[1024265, 20937, 26405, 602, 2333, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1050707, 21544, 35, 0, 29, "Subsubsection"],
Cell[1050745, 21546, 1809, 46, 205, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1052591, 21597, 37, 0, 29, "Subsubsection"],
Cell[1052631, 21599, 4961, 119, 338, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1057629, 21723, 35, 0, 29, "Subsubsection"],
Cell[1057667, 21725, 10087, 248, 813, "Code"],
Cell[1067757, 21975, 8086, 197, 566, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1075880, 22177, 36, 0, 29, "Subsubsection"],
Cell[1075919, 22179, 2881, 70, 338, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1078837, 22254, 36, 0, 29, "Subsubsection"],
Cell[1078876, 22256, 2643, 65, 319, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1081556, 22326, 37, 0, 29, "Subsubsection"],
Cell[1081596, 22328, 25309, 546, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1106942, 22879, 33, 0, 29, "Subsubsection"],
Cell[1106978, 22881, 3328, 90, 338, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1110343, 22976, 33, 0, 29, "Subsubsection"],
Cell[1110379, 22978, 2124, 57, 70, "Code"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1112552, 23041, 26, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[1112603, 23045, 173, 2, 35, "Subsubsection"],
Cell[1112779, 23049, 9974, 213, 604, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1122790, 23267, 107, 1, 29, "Subsubsection"],
Cell[1122900, 23270, 2501, 59, 243, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1125438, 23334, 161, 2, 29, "Subsubsection"],
Cell[1125602, 23338, 2558, 60, 243, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1128197, 23403, 100, 1, 29, "Subsubsection"],
Cell[1128300, 23406, 6203, 168, 376, "Code"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1134552, 23580, 96, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[1134673, 23585, 100, 1, 35, "Subsubsection"],
Cell[1134776, 23588, 3338, 82, 357, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1138151, 23675, 171, 2, 29, "Subsubsection"],
Cell[1138325, 23679, 5383, 124, 395, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1143745, 23808, 224, 3, 29, "Subsubsection"],
Cell[1143972, 23813, 6279, 145, 452, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1150288, 23963, 131, 2, 29, "Subsubsection"],
Cell[1150422, 23967, 1856, 39, 205, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1152315, 24011, 106, 1, 29, "Subsubsection"],
Cell[1152424, 24014, 8755, 212, 772, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1161216, 24231, 33, 0, 29, "Subsubsection"],
Cell[1161252, 24233, 3931, 103, 357, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1165220, 24341, 31, 0, 29, "Subsubsection"],
Cell[1165254, 24343, 5585, 174, 319, "Code"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1170888, 24523, 100, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[1171013, 24528, 103, 1, 35, "Subsubsection"],
Cell[1171119, 24531, 2676, 64, 300, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1173832, 24600, 41, 0, 29, "Subsubsection"],
Cell[1173876, 24602, 4848, 131, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1178761, 24738, 37, 0, 29, "Subsubsection"],
Cell[1178801, 24740, 13252, 343, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1192090, 25088, 33, 0, 29, "Subsubsection"],
Cell[1192126, 25090, 17468, 393, 1022, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1209631, 25488, 38, 0, 29, "Subsubsection"],
Cell[1209672, 25490, 10268, 232, 810, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1219977, 25727, 37, 0, 29, "Subsubsection"],
Cell[1220017, 25729, 3437, 89, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1223491, 25823, 31, 0, 29, "Subsubsection"],
Cell[1223525, 25825, 5589, 174, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1229151, 26004, 38, 0, 29, "Subsubsection"],
Cell[1229192, 26006, 9534, 222, 889, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1238763, 26233, 33, 0, 29, "Subsubsection"],
Cell[1238799, 26235, 18753, 435, 1459, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1257589, 26675, 37, 0, 29, "Subsubsection"],
Cell[1257629, 26677, 3437, 89, 281, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1261103, 26771, 32, 0, 29, "Subsubsection"],
Cell[1261138, 26773, 21737, 566, 1136, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1282912, 27344, 41, 0, 29, "Subsubsection"],
Cell[1282956, 27346, 565, 17, 70, "Code"],
Cell[1283524, 27365, 22632, 618, 70, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[1306193, 27988, 36, 0, 29, "Subsubsection"],
Cell[1306232, 27990, 21506, 560, 1136, "Code"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

